(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1367187,      26663]
NotebookOptionsPosition[   1345161,      26317]
NotebookOutlinePosition[   1345612,      26335]
CellTagsIndexPosition[   1345569,      26332]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
An unbiased ray-marching transmittance estimator - Supplemental\
\>", "Title",
 CellChangeTimes->{{3.8207242438111343`*^9, 3.820724265286731*^9}, 
   3.8207245751901608`*^9, {3.828130263839985*^9, 3.828130279750759*^9}, {
   3.8281629294536324`*^9, 
   3.828162932792782*^9}},ExpressionUUID->"885c3c71-893f-4d5d-b400-\
6f8b24c883be"],

Cell[TextData[{
 "Markus Kettunen, Eugene d\[CloseCurlyQuote]Eon, Jacopo Pantaleoni, Jan \
Novak\[LineSeparator](NVIDIA)\[LineSeparator]ACM ",
 StyleBox["SIGGRAPH 2021",
  FontSlant->"Italic"],
 "\[LineSeparator]doi: https://doi.org/10.1145/3450626.3459937"
}], "Text",
 CellChangeTimes->{{3.82813025613843*^9, 3.828130259394559*^9}, {
  3.828162946608923*^9, 3.828162951523035*^9}, {3.82850610675119*^9, 
  3.828506206429891*^9}},ExpressionUUID->"a8e66931-c88a-4a23-9853-\
f8e215cec53d"],

Cell[CellGroupData[{

Cell["Summary", "Section",
 CellChangeTimes->{{3.828130287297862*^9, 
  3.828130288072473*^9}},ExpressionUUID->"175de73f-80fe-4968-8eeb-\
5afcd16f423a"],

Cell["\<\
In this supplemental material we include code, derivations and plots that \
expand upon on empirical investigations, validate our derivations and \
implementations.\
\>", "Text",
 CellChangeTimes->{{3.8207245522131968`*^9, 3.82072461128928*^9}, 
   3.828130293389019*^9, {3.828163261630126*^9, 
   3.828163262123653*^9}},ExpressionUUID->"406c46df-3069-4c25-bf55-\
5c27251c93d0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Estimators", "Section",
 CellChangeTimes->{{3.820724278160993*^9, 
  3.8207242798708344`*^9}},ExpressionUUID->"f83989db-7d1d-4027-91b8-\
da9afe36c1f5"],

Cell[TextData[{
 "Code for various transmittance estimation: \n",
 StyleBox["inputs: ",
  FontWeight->"Bold"],
 "each estimator takes a function f[x], an interval [0,d]\[LineSeparator]",
 StyleBox["outputs:",
  FontWeight->"Bold"],
 " each estimator returns: {estimate of T, number of density lookups}"
}], "Text",
 CellChangeTimes->{{3.8207244547809668`*^9, 
  3.820724538745315*^9}},ExpressionUUID->"7184670b-adc1-4aab-9d33-\
2825c271437d"],

Cell[CellGroupData[{

Cell["helper - Comb filter", "Subsection",
 CellChangeTimes->{{3.820724308506413*^9, 3.820724308953745*^9}, {
  3.8207243632388563`*^9, 3.8207243692647753`*^9}, {3.820724960041419*^9, 
  3.820724960590653*^9}},ExpressionUUID->"f8cc2528-ddce-485b-9f3f-\
0c0158a1b7da"],

Cell[BoxData[
 RowBox[{
  RowBox[{"equiTupleEval", "[", 
   RowBox[{"f_", ",", "d_", ",", "k_", ",", "x_"}], "]"}], ":=", 
  RowBox[{"Mean", "[", "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"Mod", "[", 
       RowBox[{
        RowBox[{"x", "+", 
         RowBox[{"i", " ", 
          FractionBox["d", "k"]}]}], ",", "d"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Range", "[", "k", "]"}]}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.813636859726419*^9, 3.813636884908095*^9}, {
  3.813637078701624*^9, 3.813637093557065*^9}, {3.813637468887995*^9, 
  3.813637470951426*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"2698f9e4-bd13-4d1f-b794-26eb387bf95b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"equiTupleSamples", "[", 
   RowBox[{"f_", ",", "d_", ",", "k_", ",", "x_"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"Mod", "[", 
      RowBox[{
       RowBox[{"x", "+", 
        RowBox[{"i", " ", 
         FractionBox["d", "k"]}]}], ",", "d"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Range", "[", "k", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.817021162805585*^9, 3.8170211703958893`*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"0970d2f4-46e9-40bb-b85b-30625939676d"]
}, Open  ]],

Cell[CellGroupData[{

Cell["helper - figure of merit (FoM) - inverse efficiency", "Subsection",
 CellChangeTimes->{{3.820726004876775*^9, 
  3.8207260154276*^9}},ExpressionUUID->"86d1ce9a-7cb8-45bd-8eb9-455ed7abce21"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FoM", "[", 
   RowBox[{"estimator_", ",", "f_", ",", "d_", ",", "MCn_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "samples", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"samples", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"estimator", "[", 
         RowBox[{"f", ",", "d"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Range", "[", "MCn", "]"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Mean", "[", 
       RowBox[{"Last", "/@", "samples"}], "]"}], 
      RowBox[{"Variance", "[", 
       RowBox[{"First", "/@", "samples"}], "]"}]}]}]}], "\[IndentingNewLine]",
    "]"}]}]], "Input",
 CellChangeTimes->{{3.814652886685824*^9, 3.814652950899866*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"be8bbe52-3a74-438c-b0b0-e18a67daf062"],

Cell[BoxData[
 RowBox[{
  RowBox[{"checkMean", "[", 
   RowBox[{"estimator_", ",", "f_", ",", "d_", ",", "MCn_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "samples", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"samples", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"estimator", "[", 
         RowBox[{"f", ",", "d"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Range", "[", "MCn", "]"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Mean", "[", 
      RowBox[{"First", "/@", "samples"}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8146547558770514`*^9, 3.814654764388075*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"6cf563cf-c8d9-4458-8607-0da21bb570e2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Biased \[OpenCurlyDoubleQuote]exp(mean)\[CloseCurlyDoubleQuote] estimators \
with Comb and end-point matching CV\
\>", "Subsection",
 CellChangeTimes->{{3.814653230905262*^9, 3.814653233659273*^9}, {
  3.81701668949835*^9, 3.81701670609137*^9}, {3.820724389376499*^9, 
  3.8207244060007544`*^9}},ExpressionUUID->"2b1f6991-da34-4e89-9a77-\
d4fa110b683c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TBiasedExpMean", "[", 
   RowBox[{"f_", ",", "x_", ",", "n_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "tau", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tau", "=", 
      RowBox[{"Mean", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"f", "[", 
           RowBox[{"RandomReal", "[", 
            RowBox[{"{", 
             RowBox[{"0", ",", "x"}], "}"}], "]"}], "]"}], 
          RowBox[{"1", " ", "/", "x"}]], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Range", "[", "n", "]"}]}], "}"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{"-", "tau"}], "]"}], ",", "n"}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.814653042755314*^9, 3.814653046585085*^9}, 
   3.81465331393782*^9, {3.820724850101542*^9, 3.820724873664373*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"0dd4d647-990b-4347-94fd-86790e9bc30b"],

Cell["exp(mean) with query size M comb filter", "Text",
 CellChangeTimes->{{3.820724902393196*^9, 
  3.820724916173127*^9}},ExpressionUUID->"345a457f-6e35-485e-926e-\
7d064a8caea1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TBiasedExpMeanComb", "[", 
   RowBox[{"f_", ",", "d_", ",", "M_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "tau", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tau", "=", 
      RowBox[{"d", " ", 
       RowBox[{"equiTupleEval", "[", 
        RowBox[{"f", ",", "d", ",", "M", ",", 
         RowBox[{"RandomReal", "[", 
          RowBox[{"{", 
           RowBox[{"0", ",", "d"}], "}"}], "]"}]}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{"-", "tau"}], "]"}], ",", "M"}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.816226421921649*^9, 3.816226427739781*^9}, {
   3.816226624092548*^9, 3.816226624274147*^9}, {3.816226687788959*^9, 
   3.8162266881045923`*^9}, 3.820724853021763*^9, {3.820724884976366*^9, 
   3.820724924136156*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"df1c138b-ed45-4d1a-80c4-b3ce2dad98f4"],

Cell["\<\
exp(mean) with query size M comb filter and end-point matching\
\>", "Text",
 CellChangeTimes->{{3.820724902393196*^9, 
  3.820724939230316*^9}},ExpressionUUID->"508c7ea9-a0df-43a6-94db-\
73e90c0a3cbd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TBiasedExpMeanComb", "[", 
   RowBox[{"f_", ",", "d_", ",", "M_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"tau", ",", "fp"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fp", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", "#", "]"}], "+", 
        RowBox[{
         FractionBox["1", "2"], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"f", "[", "0", "]"}], "+", 
           RowBox[{"f", "[", "d", "]"}]}], ")"}]}], "-", 
        RowBox[{
         FractionBox["#", "d"], 
         RowBox[{"f", "[", "d", "]"}]}], "-", 
        RowBox[{
         FractionBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "#"}], ")"}], "d"], 
         RowBox[{"f", "[", "0", "]"}]}]}], "&"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tau", "=", 
      RowBox[{"d", " ", 
       RowBox[{"equiTupleEval", "[", 
        RowBox[{"fp", ",", "d", ",", "n", ",", 
         RowBox[{"RandomReal", "[", 
          RowBox[{"{", 
           RowBox[{"0", ",", "d"}], "}"}], "]"}]}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{"-", "tau"}], "]"}], ",", 
       RowBox[{"n", "+", "2"}]}], "}"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.814653042755314*^9, 3.814653046585085*^9}, 
   3.81465331393782*^9, {3.814657651486703*^9, 3.814657737910981*^9}, {
   3.814657799047841*^9, 3.814657800272571*^9}, {3.8162266900658903`*^9, 
   3.8162266902523518`*^9}, {3.820724929749481*^9, 3.8207249318623543`*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"4fa95096-ac6d-4722-b7ad-64f1313aba6d"],

Cell["Jackknife exp(mean) estimator to reduce bias:", "Text",
 CellChangeTimes->{{3.820724425696653*^9, 
  3.8207244345084867`*^9}},ExpressionUUID->"6317ac86-3059-4519-9783-\
a5b36818cc28"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TBiasedExpMeanJackknife", "[", 
   RowBox[{"f_", ",", "x_", ",", "n_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"tau", ",", "samples"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"samples", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"f", "[", 
          RowBox[{"RandomReal", "[", 
           RowBox[{"{", 
            RowBox[{"0", ",", "x"}], "}"}], "]"}], "]"}], 
         RowBox[{"1", " ", "/", "x"}]], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Range", "[", "n", "]"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tau", "=", 
      RowBox[{"Mean", "[", "samples", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"n", " ", 
         RowBox[{"Exp", "[", 
          RowBox[{"-", "tau"}], "]"}]}], "-", 
        RowBox[{
         FractionBox[
          RowBox[{"n", "-", "1"}], "n"], 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"Exp", "[", 
            RowBox[{"-", 
             RowBox[{"Mean", "[", 
              RowBox[{"Delete", "[", 
               RowBox[{"samples", ",", "i"}], "]"}], "]"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}]}]}], ",", "n"}],
       "}"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.8168030432412653`*^9, 3.8168030450360603`*^9}, {
  3.8168031686083393`*^9, 3.816803203495088*^9}, {3.8168032540570908`*^9, 
  3.816803289115176*^9}, {3.816803323319158*^9, 3.8168033265327253`*^9}, {
  3.8207249731527863`*^9, 3.820724977602624*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"111d688d-d577-4f4c-9dce-4c0ed2c87bf1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Delta tracking \[OpenCurlyDoubleQuote]Track-length\
\[CloseCurlyDoubleQuote] binary transmittance estimator", "Subsection",
 CellChangeTimes->{{3.820724442458826*^9, 3.82072444396772*^9}, {
  3.82813033025208*^9, 
  3.828130337773905*^9}},ExpressionUUID->"6a14e38a-d5a4-4075-aaf8-\
87f042da81dc"],

Cell["\[CapitalSigma]max = majorant density", "Text",
 CellChangeTimes->{{3.82081149443398*^9, 
  3.8208114998215847`*^9}},ExpressionUUID->"b13f0cfb-3bc1-47b6-a6b3-\
6c3f49e35618"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TDeltaTracking", "[", 
   RowBox[{"f_", ",", "\[CapitalSigma]max_", ",", "d_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "w", ",", "cost"}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"x", "=", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Log", "[", 
         RowBox[{"RandomReal", "[", "]"}], "]"}]}], "/", 
       "\[CapitalSigma]max"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"w", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"cost", "=", "0"}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"x", "<", "d"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"cost", "+=", "1"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"RandomReal", "[", "]"}], "<", 
           FractionBox[
            RowBox[{"f", "[", "x", "]"}], "\[CapitalSigma]max"]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"w", "=", "0"}], ";", "\[IndentingNewLine]", 
           RowBox[{"Break", "[", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}],
         ";", "\[IndentingNewLine]", 
        RowBox[{"x", "+=", " ", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Log", "[", 
            RowBox[{"RandomReal", "[", "]"}], "]"}]}], "/", 
          "\[CapitalSigma]max"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"w", ",", "cost"}], "}"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.81465315991969*^9, 3.814653174349935*^9}, {
  3.8207249940657377`*^9, 3.820724999915991*^9}, {3.820811435775812*^9, 
  3.820811435900784*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"ffe46f81-4ea0-42e4-97e7-d8cdd40a0d7f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Johnson\[CloseCurlyQuote]s estimator Eq.(6)", "Subsection",
 CellChangeTimes->{{3.820724639147791*^9, 
  3.8207246636668787`*^9}},ExpressionUUID->"0cdff726-f6b9-4b1b-a251-\
5f79a5d506e0"],

Cell["\<\
This is a novel variation of the standard track-length / delta-tracking \
transmittance estimator based on a zero-order Poisson probability estimator \
by [Johnson 1951].  This can outperform the average of n delta-tracking \
estimates in some cases (see efficiency comparison below).\
\>", "Text",
 CellChangeTimes->{{3.820724671991597*^9, 3.820724705133997*^9}, {
  3.828130343120154*^9, 
  3.8281303818394623`*^9}},ExpressionUUID->"75353d7b-ff0b-41b7-921f-\
e61d60ec1cf0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TJohnson", "[", 
   RowBox[{"f_", ",", "\[CapitalSigma]max_", ",", "d_", ",", "n_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "w", ",", "cost", ",", "vsum"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"vsum", "=", "0"}], ";", "\[IndentingNewLine]", 
     RowBox[{"x", "=", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Log", "[", 
         RowBox[{"RandomReal", "[", "]"}], "]"}]}], "/", 
       "\[CapitalSigma]max"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"cost", "=", "0"}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"x", "<", 
        RowBox[{"n", " ", "d"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"cost", "+=", "1"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"RandomReal", "[", "]"}], "<", 
           FractionBox[
            RowBox[{"f", "[", 
             RowBox[{"Mod", "[", 
              RowBox[{"x", ",", "d"}], "]"}], "]"}], "\[CapitalSigma]max"]}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"vsum", "+=", "1"}], ";"}]}], "\[IndentingNewLine]", "]"}],
         ";", "\[IndentingNewLine]", 
        RowBox[{"x", "+=", " ", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Log", "[", 
            RowBox[{"RandomReal", "[", "]"}], "]"}]}], "/", 
          "\[CapitalSigma]max"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SuperscriptBox["n", 
           RowBox[{"-", "1"}]]}], ")"}], "vsum"], ",", "cost"}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.816838363312731*^9, 3.81683836833852*^9}, {
  3.816838547157673*^9, 3.816838589290844*^9}, {3.81683873356915*^9, 
  3.8168387590667953`*^9}, {3.816838794303034*^9, 3.816838822114249*^9}, {
  3.820725003622447*^9, 3.820725004703128*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"398e166c-ddfc-49ec-843d-4d255549daf2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DT Next Flight", "Subsection",
 CellChangeTimes->{{3.817016832911887*^9, 
  3.817016835811956*^9}},ExpressionUUID->"0cfd71b0-9713-494c-a5c5-\
af46fba3bc4c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TDeltaTrackingNextFlight", "[", 
   RowBox[{"f_", ",", "\[CapitalSigma]max_", ",", "d_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "ans", ",", "cost"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ans", "=", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "\[CapitalSigma]max"}], " ", "d"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"cost", "=", "0"}], ";", "\[IndentingNewLine]", 
     RowBox[{"x", "=", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Log", "[", 
         RowBox[{"RandomReal", "[", "]"}], "]"}]}], "/", 
       "\[CapitalSigma]max"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"x", "<", "d"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"cost", "+=", "1"}], ";", "\[IndentingNewLine]", 
        RowBox[{"ans", "+=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            FractionBox[
             RowBox[{"f", "[", "x", "]"}], "\[CapitalSigma]max"]}], ")"}], 
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{"-", "\[CapitalSigma]max"}], " ", 
            RowBox[{"(", 
             RowBox[{"d", "-", "x"}], ")"}]}], "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"RandomReal", "[", "]"}], "<", 
           FractionBox[
            RowBox[{"f", "[", "x", "]"}], "\[CapitalSigma]max"]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Break", "[", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}],
         ";", "\[IndentingNewLine]", 
        RowBox[{"x", "+=", " ", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Log", "[", 
            RowBox[{"RandomReal", "[", "]"}], "]"}]}], "/", 
          "\[CapitalSigma]max"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"ans", ",", "cost"}], "}"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.814653634976911*^9, 3.814653648207143*^9}, {
  3.820725010285161*^9, 3.820725016790947*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"43f09951-a01e-4011-b18c-3a919a8cb4aa"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ratio Tracking", "Subsection",
 CellChangeTimes->{{3.8170168394321423`*^9, 
  3.8170168409581633`*^9}},ExpressionUUID->"15531b68-c3f6-4be4-bf29-\
26423d025da0"],

Cell["basic ratio tracking:", "Text",
 CellChangeTimes->{{3.820724811816883*^9, 
  3.820724814384946*^9}},ExpressionUUID->"1ca29a32-9749-4cd2-b3b7-\
290bcf7e903b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TRatioTracking", "[", 
   RowBox[{"f_", ",", "\[CapitalSigma]max_", ",", "d_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "w", ",", "cost"}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"x", "=", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Log", "[", 
         RowBox[{"RandomReal", "[", "]"}], "]"}]}], "/", 
       "\[CapitalSigma]max"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"cost", "=", "0"}], ";", "\[IndentingNewLine]", 
     RowBox[{"w", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"x", "<", "d"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"cost", "+=", "1"}], ";", "\[IndentingNewLine]", 
        RowBox[{"w", "*=", 
         RowBox[{"1", "-", 
          FractionBox[
           RowBox[{"f", "[", "x", "]"}], "\[CapitalSigma]max"]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"x", "+=", " ", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Log", "[", 
            RowBox[{"RandomReal", "[", "]"}], "]"}]}], "/", 
          "\[CapitalSigma]max"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"w", ",", "cost"}], "}"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.814653734852538*^9, 3.8146537474492607`*^9}, {
  3.8207250199638*^9, 3.82072502170499*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"5fbbbb6e-cd79-4b87-a19c-deeb567da4d0"],

Cell["next-flight ratio tracking:", "Text",
 CellChangeTimes->{{3.8207248064327173`*^9, 
  3.820724809150289*^9}},ExpressionUUID->"f1ecdfda-f532-4af0-87df-\
74e3cc38cad9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TNextFlightRatioTracking", "[", 
   RowBox[{"f_", ",", "\[CapitalSigma]max_", ",", "d_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "ans", ",", "w", ",", "cost"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ans", "=", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "\[CapitalSigma]max"}], " ", "d"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"x", "=", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Log", "[", 
         RowBox[{"RandomReal", "[", "]"}], "]"}]}], "/", 
       "\[CapitalSigma]max"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"w", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"cost", "=", "0"}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"x", "<", "d"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"cost", "+=", "1"}], ";", "\[IndentingNewLine]", 
        RowBox[{"ans", "+=", 
         RowBox[{"w", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            FractionBox[
             RowBox[{"f", "[", "x", "]"}], "\[CapitalSigma]max"]}], ")"}], 
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{"-", "\[CapitalSigma]max"}], " ", 
            RowBox[{"(", 
             RowBox[{"d", "-", "x"}], ")"}]}], "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"w", "*=", 
         RowBox[{"1", "-", 
          FractionBox[
           RowBox[{"f", "[", "x", "]"}], "\[CapitalSigma]max"]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"x", "+=", " ", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Log", "[", 
            RowBox[{"RandomReal", "[", "]"}], "]"}]}], "/", 
          "\[CapitalSigma]max"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"ans", ",", "cost"}], "}"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.814653811150279*^9, 3.814653823787054*^9}, {
  3.820725025063408*^9, 3.820725029112709*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"4ca10856-3419-43c4-ae03-c4b747b4bb1e"],

Cell["Poisson estimator (equivalent to residual ratio tracking):", "Text",
 CellChangeTimes->{{3.8207250493111553`*^9, 
  3.8207250588156652`*^9}},ExpressionUUID->"e18d7ac2-a700-491f-8fe0-\
9523631bff9c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TPoissonEstimator", "[", 
   RowBox[{"f_", ",", "controlvariate_", ",", "d_", ",", "\[Lambda]_"}], 
   "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "w", ",", "k", ",", "cost"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"x", "=", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Log", "[", 
         RowBox[{"RandomReal", "[", "]"}], "]"}]}], "/", "\[Lambda]"}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"w", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"cost", "=", "0"}], ";", "\[IndentingNewLine]", 
     RowBox[{"k", "=", "0"}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"x", "<", "d"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"cost", "+=", "1"}], ";", "\[IndentingNewLine]", 
        RowBox[{"w", "*=", 
         RowBox[{"controlvariate", "-", 
          RowBox[{"f", "[", "x", "]"}]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"k", "+=", "1"}], ";", "\[IndentingNewLine]", 
        RowBox[{"x", "+=", " ", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Log", "[", 
            RowBox[{"RandomReal", "[", "]"}], "]"}]}], "/", "\[Lambda]"}]}], 
        ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"w", " ", 
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Lambda]", "-", "controlvariate"}], ")"}], "d"}], "]"}], 
        
        SuperscriptBox["\[Lambda]", 
         RowBox[{"-", "k"}]]}], ",", "cost"}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.820725036490734*^9, 3.820725085794449*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"c8e3ac36-f5a8-4b05-a2df-64a20fef7058"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bhanot and Kennedy", "Subsection",
 CellChangeTimes->{{3.8207251418874693`*^9, 
  3.820725144539996*^9}},ExpressionUUID->"59d36a9f-e7b0-4c10-a354-\
9d2bcb80d3d9"],

Cell["\<\
Our generalization of the BK estimator with minimum expansion order K and \
roulette parameter c (BK\[CloseCurlyQuote]s original estimator is when K = \
Floor[c])\
\>", "Text",
 CellChangeTimes->{{3.82072514993783*^9, 3.8207251580422153`*^9}, {
  3.828130480219913*^9, 3.828130480358397*^9}, {3.8281305324684763`*^9, 
  3.828130559111806*^9}},ExpressionUUID->"74f3dc22-78ff-4627-b9e4-\
913ef40ac97e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TBK", "[", 
   RowBox[{
   "f_", ",", "\[CapitalSigma]max_", ",", "d_", ",", "K_", ",", "C_"}], "]"}],
   ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"xnproduct", ",", "result", ",", "i", ",", "cost"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xnproduct", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"result", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"cost", "=", "0"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"cost", "+=", "1"}], ";", "\[IndentingNewLine]", 
        RowBox[{"xnproduct", "*=", 
         RowBox[{"d", 
          RowBox[{"(", 
           RowBox[{"\[CapitalSigma]max", "-", 
            RowBox[{"f", "[", 
             RowBox[{"RandomReal", "[", 
              RowBox[{"{", 
               RowBox[{"0", ",", "d"}], "}"}], "]"}], "]"}]}], ")"}]}]}], ";",
         "\[IndentingNewLine]", 
        RowBox[{"result", "+=", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"i", "!"}]], "xnproduct"}]}], ";"}], "\[IndentingNewLine]",
        ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Range", "[", "K", "]"}]}], "}"}]}], "\[IndentingNewLine]", 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"i", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"RandomReal", "[", "]"}], "<", 
        FractionBox["C", 
         RowBox[{"K", "+", "i"}]]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"cost", "+=", "1"}], ";", "\[IndentingNewLine]", 
        RowBox[{"xnproduct", "*=", 
         RowBox[{"d", 
          RowBox[{"(", 
           RowBox[{"\[CapitalSigma]max", "-", 
            RowBox[{"f", "[", 
             RowBox[{"RandomReal", "[", 
              RowBox[{"{", 
               RowBox[{"0", ",", "d"}], "}"}], "]"}], "]"}]}], ")"}]}]}], ";",
         "\[IndentingNewLine]", 
        RowBox[{"result", "+=", 
         FractionBox["xnproduct", 
          RowBox[{
           SuperscriptBox["C", "i"], 
           RowBox[{"K", "!"}]}]]}], ";", "\[IndentingNewLine]", 
        RowBox[{"i", "+=", "1"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"result", " ", 
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "\[CapitalSigma]max"}], " ", "d"}], "]"}]}], ",", 
       "cost"}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.815795274414815*^9, 3.8157952793975897`*^9}, {
   3.815795470812333*^9, 3.8157954923074636`*^9}, 3.8157956534876137`*^9, {
   3.820725163057979*^9, 3.820725186646762*^9}, {3.828130508585585*^9, 
   3.828130510539563*^9}, {3.8281305669381247`*^9, 3.828130583656631*^9}, {
   3.828131081701353*^9, 3.828131153019648*^9}, 3.828131191989065*^9, {
   3.828131237819556*^9, 3.828131263308927*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"1ef92d76-1dd1-4ae9-917c-61323b418172"],

Cell["Generalized BK symmetrized with U-statistics:", "Text",
 CellChangeTimes->{{3.820725207601973*^9, 
  3.820725223457988*^9}},ExpressionUUID->"47773916-0f39-41bc-aaf8-\
98d5417dd701"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TUBK", "[", 
   RowBox[{
   "f_", ",", "\[CapitalSigma]max_", ",", "d_", ",", "K_", ",", "c_"}], "]"}],
   ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"i", ",", "m", ",", "positions", ",", "x", ",", "p", ",", "e"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ";", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"RandomReal", "[", "]"}], "<", 
        FractionBox["c", 
         RowBox[{"K", "+", "i"}]]}], ",", 
       RowBox[{
        RowBox[{"i", "+=", "1"}], ";"}]}], "]"}], ";", 
     RowBox[{"m", "=", 
      RowBox[{"K", "+", "i", "-", "1"}]}], ";", 
     RowBox[{"(*", 
      RowBox[{"m", " ", "total", " ", "samples"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"positions", "=", 
      RowBox[{"RandomReal", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "d"}], "}"}], ",", "m"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"x", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"d", 
         RowBox[{"(", 
          RowBox[{"\[CapitalSigma]max", "-", 
           RowBox[{"f", "[", "#", "]"}]}], ")"}]}], "&"}], "/@", 
       "positions"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"p", "[", "0", "]"}], "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "=", 
         RowBox[{"Sum", "[", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"x", "[", 
             RowBox[{"[", "j", "]"}], "]"}], "i"], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", 
             RowBox[{"Range", "[", "m", "]"}]}], "}"}]}], "]"}]}], ";"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Range", "[", "m", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"e", "[", "0", "]"}], "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"e", "[", "k", "]"}], "=", 
         RowBox[{
          FractionBox["1", "k"], 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{"i", "-", "1"}]], 
             RowBox[{"e", "[", 
              RowBox[{"k", "-", "i"}], "]"}], 
             RowBox[{"p", "[", "i", "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", "k"}], "}"}]}], "]"}]}]}], ";"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", 
         RowBox[{"Range", "[", "m", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "\[CapitalSigma]max"}], " ", "d"}], "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             FractionBox["1", 
              RowBox[{"i", "!"}]], 
             FractionBox[
              RowBox[{"e", "[", "i", "]"}], 
              RowBox[{"Binomial", "[", 
               RowBox[{"m", ",", "i"}], "]"}]]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "0", ",", "K"}], "}"}]}], "]"}], "+", 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             FractionBox["1", 
              RowBox[{
               SuperscriptBox["c", 
                RowBox[{"i", "-", "K"}]], 
               RowBox[{"K", "!"}]}]], 
             FractionBox[
              RowBox[{"e", "[", "i", "]"}], 
              RowBox[{"Binomial", "[", 
               RowBox[{"m", ",", "i"}], "]"}]]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", 
              RowBox[{"K", "+", "1"}], ",", "m"}], "}"}]}], "]"}]}], ")"}]}], 
       ",", "m"}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{
  3.8207252034451942`*^9, 3.8207252375117083`*^9, {3.828131390784399*^9, 
   3.828131444317308*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"feb4697d-f6e8-4798-9261-1acd00caa878"],

Cell["U-BK estimator with query-size M Comb filter (K = Floor[c])", "Text",
 CellChangeTimes->{{3.820725349587261*^9, 3.820725369044381*^9}, {
  3.828131782372053*^9, 
  3.8281317868596067`*^9}},ExpressionUUID->"261dd6aa-14b5-4948-bf6e-\
2e530b7ad9b1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TUBKComb", "[", 
   RowBox[{
   "f_", ",", "\[CapitalSigma]max_", ",", "d_", ",", "c_", ",", "M_"}], "]"}],
   ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "K", ",", "i", ",", "m", ",", "positions", ",", "x", ",", "p", ",", 
      "e"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"K", "=", 
      RowBox[{"Floor", "[", "c", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"i", "=", "1"}], ";", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"RandomReal", "[", "]"}], "<", 
        FractionBox["c", 
         RowBox[{"K", "+", "i"}]]}], ",", 
       RowBox[{
        RowBox[{"i", "+=", "1"}], ";"}]}], "]"}], ";", 
     RowBox[{"m", "=", 
      RowBox[{"K", "+", "i", "-", "1"}]}], ";", 
     RowBox[{"(*", 
      RowBox[{"m", " ", "total", " ", "samples"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"positions", "=", 
      RowBox[{"RandomReal", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "d"}], "}"}], ",", "m"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"x", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"d", 
         RowBox[{"(", 
          RowBox[{"\[CapitalSigma]max", "-", 
           RowBox[{"equiTupleEval", "[", 
            RowBox[{"f", ",", "d", ",", "M", ",", "#"}], "]"}]}], ")"}]}], 
        "&"}], "/@", "positions"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"p", "[", "0", "]"}], "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "=", 
         RowBox[{"Sum", "[", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"x", "[", 
             RowBox[{"[", "j", "]"}], "]"}], "i"], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", 
             RowBox[{"Range", "[", "m", "]"}]}], "}"}]}], "]"}]}], ";"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Range", "[", "m", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"e", "[", "0", "]"}], "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"e", "[", "k", "]"}], "=", 
         RowBox[{
          FractionBox["1", "k"], 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{"i", "-", "1"}]], 
             RowBox[{"e", "[", 
              RowBox[{"k", "-", "i"}], "]"}], 
             RowBox[{"p", "[", "i", "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", "k"}], "}"}]}], "]"}]}]}], ";"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", 
         RowBox[{"Range", "[", "m", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "\[CapitalSigma]max"}], " ", "d"}], "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             FractionBox["1", 
              RowBox[{"i", "!"}]], 
             FractionBox[
              RowBox[{"e", "[", "i", "]"}], 
              RowBox[{"Binomial", "[", 
               RowBox[{"m", ",", "i"}], "]"}]]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "0", ",", "K"}], "}"}]}], "]"}], "+", 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             FractionBox["1", 
              RowBox[{
               SuperscriptBox["c", 
                RowBox[{"i", "-", "K"}]], 
               RowBox[{"K", "!"}]}]], 
             FractionBox[
              RowBox[{"e", "[", "i", "]"}], 
              RowBox[{"Binomial", "[", 
               RowBox[{"m", ",", "i"}], "]"}]]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", 
              RowBox[{"K", "+", "1"}], ",", "m"}], "}"}]}], "]"}]}], ")"}]}], 
       ",", 
       RowBox[{"m", " ", "M"}]}], "}"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.814659075905147*^9, 3.814659079976419*^9}, {
  3.81465922104493*^9, 3.814659255272871*^9}, {3.8207253275430813`*^9, 
  3.820725341837058*^9}, {3.828131804229607*^9, 3.828131834159955*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"180d17a5-ed88-467a-9088-fd041c7ce7d9"],

Cell["\<\
U-BK estimator with tuple-size M Comb filter and endpoint matching (K = \
Floor[c])\
\>", "Text",
 CellChangeTimes->{{3.820725349587261*^9, 3.820725383937626*^9}, {
  3.828131960603497*^9, 3.828131961208873*^9}, {3.828136703830126*^9, 
  3.828136704256071*^9}},ExpressionUUID->"3e0c60b6-c45f-4cc2-8858-\
9570fdb85269"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TUBKCombEndpoint", "[", 
   RowBox[{
   "f_", ",", "\[CapitalSigma]max_", ",", "d_", ",", "c_", ",", "M_"}], "]"}],
   ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "K", ",", "i", ",", "m", ",", "positions", ",", "x", ",", "p", ",", "e", 
      ",", "fp"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fp", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", "#", "]"}], "+", 
        RowBox[{
         FractionBox["1", "2"], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"f", "[", "0", "]"}], "+", 
           RowBox[{"f", "[", "d", "]"}]}], ")"}]}], "-", 
        RowBox[{
         FractionBox["#", "d"], 
         RowBox[{"f", "[", "d", "]"}]}], "-", 
        RowBox[{
         FractionBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "#"}], ")"}], "d"], 
         RowBox[{"f", "[", "0", "]"}]}]}], "&"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"K", "=", 
      RowBox[{"Floor", "[", "c", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"i", "=", "1"}], ";", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"RandomReal", "[", "]"}], "<", 
        FractionBox["c", 
         RowBox[{"K", "+", "i"}]]}], ",", 
       RowBox[{
        RowBox[{"i", "+=", "1"}], ";"}]}], "]"}], ";", 
     RowBox[{"m", "=", 
      RowBox[{"K", "+", "i", "-", "1"}]}], ";", 
     RowBox[{"(*", 
      RowBox[{"m", " ", "total", " ", "samples"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"positions", "=", 
      RowBox[{"RandomReal", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "d"}], "}"}], ",", "m"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"x", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"d", 
         RowBox[{"(", 
          RowBox[{"\[CapitalSigma]max", "-", 
           RowBox[{"equiTupleEval", "[", 
            RowBox[{"fp", ",", "d", ",", "M", ",", "#"}], "]"}]}], ")"}]}], 
        "&"}], "/@", "positions"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"p", "[", "0", "]"}], "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "=", 
         RowBox[{"Sum", "[", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"x", "[", 
             RowBox[{"[", "j", "]"}], "]"}], "i"], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", 
             RowBox[{"Range", "[", "m", "]"}]}], "}"}]}], "]"}]}], ";"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Range", "[", "m", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"e", "[", "0", "]"}], "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"e", "[", "k", "]"}], "=", 
         RowBox[{
          FractionBox["1", "k"], 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{"i", "-", "1"}]], 
             RowBox[{"e", "[", 
              RowBox[{"k", "-", "i"}], "]"}], 
             RowBox[{"p", "[", "i", "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", "k"}], "}"}]}], "]"}]}]}], ";"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", 
         RowBox[{"Range", "[", "m", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "\[CapitalSigma]max"}], " ", "d"}], "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             FractionBox["1", 
              RowBox[{"i", "!"}]], 
             FractionBox[
              RowBox[{"e", "[", "i", "]"}], 
              RowBox[{"Binomial", "[", 
               RowBox[{"m", ",", "i"}], "]"}]]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "0", ",", "K"}], "}"}]}], "]"}], "+", 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             FractionBox["1", 
              RowBox[{
               SuperscriptBox["c", 
                RowBox[{"i", "-", "K"}]], 
               RowBox[{"K", "!"}]}]], 
             FractionBox[
              RowBox[{"e", "[", "i", "]"}], 
              RowBox[{"Binomial", "[", 
               RowBox[{"m", ",", "i"}], "]"}]]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", 
              RowBox[{"K", "+", "1"}], ",", "m"}], "}"}]}], "]"}]}], ")"}]}], 
       ",", 
       RowBox[{
        RowBox[{"m", " ", "M"}], "+", "2"}]}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.814659565376808*^9, 3.814659584567527*^9}, {
  3.820725481236421*^9, 3.820725491971284*^9}, {3.82813196892968*^9, 
  3.82813199311983*^9}, {3.82813674382006*^9, 3.828136743823329*^9}},
 CellLabel->"In[25]:=",ExpressionUUID->"5a37a768-fbd1-4338-be84-44c285f2ccea"],

Cell["\<\
U-BK estimator with tuple-size M Comb filter and pivot estimation (K = \
Floor[c])\
\>", "Text",
 CellChangeTimes->{{3.820725349587261*^9, 3.820725369044381*^9}, {
   3.820725557883006*^9, 3.8207255597199183`*^9}, {3.828136706457808*^9, 
   3.828136706823038*^9}, 
   3.828136807714164*^9},ExpressionUUID->"6e99dcde-f056-4320-85b7-\
57b194d82a5e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TUBKCombPivotEstimation", "[", 
   RowBox[{"f_", ",", "d_", ",", "c_", ",", "combM_", ",", "pivotM_"}], "]"}],
   ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "K", ",", "i", ",", "m", ",", "positions", ",", "x", ",", "p", ",", "e", 
      ",", "fp", ",", "piv"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"K", "=", 
      RowBox[{"Floor", "[", "c", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"fp", "=", "f"}], ";", "\[IndentingNewLine]", 
     RowBox[{"piv", "=", 
      RowBox[{"equiTupleEval", "[", 
       RowBox[{"fp", ",", "d", ",", "pivotM", ",", 
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{"0", ",", "d"}], "}"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"i", "=", "1"}], ";", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"RandomReal", "[", "]"}], "<", 
        FractionBox["c", 
         RowBox[{"K", "+", "i"}]]}], ",", 
       RowBox[{
        RowBox[{"i", "+=", "1"}], ";"}]}], "]"}], ";", 
     RowBox[{"m", "=", 
      RowBox[{"K", "+", "i", "-", "1"}]}], ";", 
     RowBox[{"(*", 
      RowBox[{"m", " ", "total", " ", "samples"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"positions", "=", 
      RowBox[{"RandomReal", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "d"}], "}"}], ",", "m"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"x", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"d", 
         RowBox[{"(", 
          RowBox[{"piv", "-", 
           RowBox[{"equiTupleEval", "[", 
            RowBox[{"fp", ",", "d", ",", "combM", ",", "#"}], "]"}]}], 
          ")"}]}], "&"}], "/@", "positions"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"p", "[", "0", "]"}], "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "=", 
         RowBox[{"Sum", "[", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"x", "[", 
             RowBox[{"[", "j", "]"}], "]"}], "i"], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", 
             RowBox[{"Range", "[", "m", "]"}]}], "}"}]}], "]"}]}], ";"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Range", "[", "m", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"e", "[", "0", "]"}], "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"e", "[", "k", "]"}], "=", 
         RowBox[{
          FractionBox["1", "k"], 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{"i", "-", "1"}]], 
             RowBox[{"e", "[", 
              RowBox[{"k", "-", "i"}], "]"}], 
             RowBox[{"p", "[", "i", "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", "k"}], "}"}]}], "]"}]}]}], ";"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", 
         RowBox[{"Range", "[", "m", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "piv"}], " ", "d"}], "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             FractionBox["1", 
              RowBox[{"i", "!"}]], 
             FractionBox[
              RowBox[{"e", "[", "i", "]"}], 
              RowBox[{"Binomial", "[", 
               RowBox[{"m", ",", "i"}], "]"}]]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "0", ",", "K"}], "}"}]}], "]"}], "+", 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             FractionBox["1", 
              RowBox[{
               SuperscriptBox["c", 
                RowBox[{"i", "-", "K"}]], 
               RowBox[{"K", "!"}]}]], 
             FractionBox[
              RowBox[{"e", "[", "i", "]"}], 
              RowBox[{"Binomial", "[", 
               RowBox[{"m", ",", "i"}], "]"}]]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", 
              RowBox[{"K", "+", "1"}], ",", "m"}], "}"}]}], "]"}]}], ")"}]}], 
       ",", 
       RowBox[{
        RowBox[{"m", " ", "combM"}], "+", "pivotM"}]}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.819512959698468*^9, 3.819512968109542*^9}, {
  3.820725565804542*^9, 3.820725586289459*^9}, {3.8281368009369507`*^9, 
  3.828136827814283*^9}, {3.8281368712970743`*^9, 3.828136874008883*^9}, {
  3.828136947311203*^9, 3.828136951274544*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"37fbd550-686a-4906-8fe7-0aecf7a2feb3"],

Cell["\<\
U-BK estimator with pivot-size M Comb filter, endpoint matching and pivot \
estimation  (K = Floor[c])\
\>", "Text",
 CellChangeTimes->{{3.820725349587261*^9, 3.820725369044381*^9}, {
  3.820725557883006*^9, 3.8207255597199183`*^9}, {3.820725755986993*^9, 
  3.820725758600281*^9}, {3.828137041661561*^9, 
  3.8281370482933187`*^9}},ExpressionUUID->"9469aa15-a6db-4bb7-a71d-\
df8c5e043e45"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TUBKCombEndpointPivotEstimation", "[", 
   RowBox[{"f_", ",", "d_", ",", "c_", ",", "combM_", ",", "pivotM_"}], "]"}],
   ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "K", ",", "i", ",", "m", ",", "positions", ",", "x", ",", "p", ",", "e", 
      ",", "fp", ",", "piv"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fp", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", "#", "]"}], "+", 
        RowBox[{
         FractionBox["1", "2"], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"f", "[", "0", "]"}], "+", 
           RowBox[{"f", "[", "d", "]"}]}], ")"}]}], "-", 
        RowBox[{
         FractionBox["#", "d"], 
         RowBox[{"f", "[", "d", "]"}]}], "-", 
        RowBox[{
         FractionBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "#"}], ")"}], "d"], 
         RowBox[{"f", "[", "0", "]"}]}]}], "&"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"piv", "=", 
      RowBox[{"equiTupleEval", "[", 
       RowBox[{"fp", ",", "d", ",", "pivotM", ",", 
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{"0", ",", "d"}], "}"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"K", "=", 
      RowBox[{"Floor", "[", "c", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"i", "=", "1"}], ";", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"RandomReal", "[", "]"}], "<", 
        FractionBox["c", 
         RowBox[{"K", "+", "i"}]]}], ",", 
       RowBox[{
        RowBox[{"i", "+=", "1"}], ";"}]}], "]"}], ";", 
     RowBox[{"m", "=", 
      RowBox[{"K", "+", "i", "-", "1"}]}], ";", 
     RowBox[{"(*", 
      RowBox[{"m", " ", "total", " ", "samples"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"positions", "=", 
      RowBox[{"RandomReal", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "d"}], "}"}], ",", "m"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"x", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"d", 
         RowBox[{"(", 
          RowBox[{"piv", "-", 
           RowBox[{"equiTupleEval", "[", 
            RowBox[{"fp", ",", "d", ",", "combM", ",", "#"}], "]"}]}], 
          ")"}]}], "&"}], "/@", "positions"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"p", "[", "0", "]"}], "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "=", 
         RowBox[{"Sum", "[", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"x", "[", 
             RowBox[{"[", "j", "]"}], "]"}], "i"], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", 
             RowBox[{"Range", "[", "m", "]"}]}], "}"}]}], "]"}]}], ";"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Range", "[", "m", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"e", "[", "0", "]"}], "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"e", "[", "k", "]"}], "=", 
         RowBox[{
          FractionBox["1", "k"], 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{"i", "-", "1"}]], 
             RowBox[{"e", "[", 
              RowBox[{"k", "-", "i"}], "]"}], 
             RowBox[{"p", "[", "i", "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", "k"}], "}"}]}], "]"}]}]}], ";"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", 
         RowBox[{"Range", "[", "m", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "piv"}], " ", "d"}], "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             FractionBox["1", 
              RowBox[{"i", "!"}]], 
             FractionBox[
              RowBox[{"e", "[", "i", "]"}], 
              RowBox[{"Binomial", "[", 
               RowBox[{"m", ",", "i"}], "]"}]]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "0", ",", "K"}], "}"}]}], "]"}], "+", 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             FractionBox["1", 
              RowBox[{
               SuperscriptBox["c", 
                RowBox[{"i", "-", "K"}]], 
               RowBox[{"K", "!"}]}]], 
             FractionBox[
              RowBox[{"e", "[", "i", "]"}], 
              RowBox[{"Binomial", "[", 
               RowBox[{"m", ",", "i"}], "]"}]]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", 
              RowBox[{"K", "+", "1"}], ",", "m"}], "}"}]}], "]"}]}], ")"}]}], 
       ",", 
       RowBox[{
        RowBox[{"m", " ", "combM"}], "+", "2", "+", "pivotM"}]}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.8146602137572937`*^9, 3.814660342437263*^9}, {
  3.820725718542025*^9, 3.8207257430242367`*^9}, {3.8281370700967197`*^9, 
  3.8281370910684557`*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"b4b49323-5311-472b-b3c8-5d6f0de65a50"]
}, Open  ]],

Cell[CellGroupData[{

Cell["unbiased ray marching", "Subsection",
 CellChangeTimes->{{3.8281572094773607`*^9, 
  3.828157211554262*^9}},ExpressionUUID->"90c8a61f-ce26-42ed-a456-\
12136a8c225e"],

Cell[CellGroupData[{

Cell["Algorithm 1:", "Subsubsection",
 CellChangeTimes->{{3.828158575352921*^9, 
  3.828158577053019*^9}},ExpressionUUID->"5e69a57c-01a8-4724-b018-\
793116a5ef67"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ElementaryMeans", "[", "x_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"NN", ",", "m", ",", "i", ",", "n"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"NN", "=", 
      RowBox[{"Length", "[", "x", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"m", "[", "0", "]"}], "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"Do", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"m", "[", "k", "]"}], "=", 
            RowBox[{
             RowBox[{"m", "[", "k", "]"}], "+", 
             RowBox[{
              FractionBox["k", "n"], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"m", "[", 
                  RowBox[{"k", "-", "1"}], "]"}], 
                 RowBox[{"x", "[", 
                  RowBox[{"[", "n", "]"}], "]"}]}], "-", 
                RowBox[{"m", "[", "k", "]"}]}], ")"}]}]}]}], ";"}], 
          "\[IndentingNewLine]", ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", 
            RowBox[{"Min", "[", 
             RowBox[{"n", ",", "NN"}], "]"}], ",", "1", ",", 
            RowBox[{"-", "1"}]}], "}"}]}], "\[IndentingNewLine]", "]"}], 
        ";"}], "\[IndentingNewLine]", ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "NN"}], "}"}]}], "\[IndentingNewLine]", 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"m", "[", "i", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "NN"}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.82815858233543*^9, 3.8281586393666162`*^9}, {
  3.8281591759354477`*^9, 3.828159275410652*^9}},
 CellLabel->"In[28]:=",ExpressionUUID->"ce7c0c34-158a-44bf-a99e-cf01dbcbef4f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Algorithm 2:", "Subsubsection",
 CellChangeTimes->{{3.8281572165746593`*^9, 
  3.828157218294013*^9}},ExpressionUUID->"b3734b6c-c0c0-4c92-a94c-\
a274a1927463"],

Cell[BoxData[
 RowBox[{
  RowBox[{"AggressiveBKRoulette", "[", 
   RowBox[{"K_", ",", "c_", ",", "pZ_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"ws", ",", "P", ",", "i", ",", "u"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ws", "=", 
      RowBox[{"{", "1", "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"P", "=", 
      RowBox[{"1", "-", "pZ"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"u", "=", 
      RowBox[{"RandomReal", "[", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"P", "\[LessEqual]", "u"}], ",", "\[IndentingNewLine]", "ws", 
       ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{"AppendTo", "[", 
           RowBox[{"ws", ",", 
            FractionBox["1", "P"]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Range", "[", "K", "]"}]}], "}"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"i", "=", 
         RowBox[{"K", "+", "1"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"While", "[", 
         RowBox[{"True", ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"P", "=", 
            RowBox[{"P", " ", 
             RowBox[{"Min", "[", 
              RowBox[{
               FractionBox["c", "i"], ",", "1"}], "]"}]}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"P", "\[LessEqual]", "u"}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Break", "[", "]"}], ";"}]}], "\[IndentingNewLine]", 
            "]"}], ";", "\[IndentingNewLine]", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"ws", ",", 
             FractionBox["1", "P"]}], "]"}], ";", "\[IndentingNewLine]", 
           RowBox[{"i", "+=", "1"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
        ";", "\[IndentingNewLine]", "ws"}]}], "\[IndentingNewLine]", 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.828156716363278*^9, 3.828156782145878*^9}, {
  3.828156829512504*^9, 3.8281569106093397`*^9}, {3.828157011732939*^9, 
  3.828157127005925*^9}, {3.828157852419469*^9, 3.828157859164081*^9}, {
  3.828159693062739*^9, 3.828159696160239*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"65b1db0a-3b86-42f9-968a-bc02566a0e10"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Algorithm 5:", "Subsubsection",
 CellChangeTimes->{{3.828157886035771*^9, 
  3.8281578877631397`*^9}},ExpressionUUID->"1401d31e-5b59-4c81-81ef-\
473e89d7ece4"],

Cell["Our unbiased ray marching estimator:", "Text",
 CellChangeTimes->{{3.8281403942873173`*^9, 3.8281404023477793`*^9}, {
  3.828140841437134*^9, 3.828140847257799*^9}, {3.828141020348933*^9, 
  3.8281410252292843`*^9}, {3.828163357843976*^9, 
  3.828163366392188*^9}},ExpressionUUID->"459550af-efba-4f35-9cc2-\
a29c1a5bc578"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TURM", "[", 
   RowBox[{"f_", ",", "d_", ",", "maj_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "K", ",", "i", ",", "m", ",", "positions", ",", "x", ",", "p", ",", "e", 
      ",", "fp", ",", "piv", ",", "c", ",", "taubar", ",", "M", ",", "Xs", 
      ",", "w", ",", "NN", ",", "cost", ",", "ms", ",", "T"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"cost", " ", "=", " ", "0"}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"control", " ", "optical", " ", "thickness"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"taubar", "=", 
      RowBox[{"d", " ", "maj"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Algorithm", " ", "4"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"M", "=", 
      RowBox[{"Max", "[", 
       RowBox[{"1", ",", 
        RowBox[{"Floor", "[", 
         RowBox[{
          FractionBox[
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"0.015", "+", "taubar"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"0.65", "+", "taubar"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"60.3", "+", "taubar"}], ")"}]}], ")"}], 
            RowBox[{"1", "/", "3"}]], 
           RowBox[{"0.31945", "+", "1"}]], "+", "0.5"}], "]"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"endpoint", " ", "matching"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"fp", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", "#", "]"}], "+", 
        RowBox[{
         FractionBox["1", "2"], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"f", "[", "0", "]"}], "+", 
           RowBox[{"f", "[", "d", "]"}]}], ")"}]}], "-", 
        RowBox[{
         FractionBox["#", "d"], 
         RowBox[{"f", "[", "d", "]"}]}], "-", 
        RowBox[{
         FractionBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "#"}], ")"}], "d"], 
         RowBox[{"f", "[", "0", "]"}]}]}], "&"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"cost", "+=", "2"}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"aggressive", " ", "roulette"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"K", "=", 
      RowBox[{"c", "=", "2"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"w", "=", 
      RowBox[{"AggressiveBKRoulette", "[", 
       RowBox[{"K", ",", "c", ",", "0.9"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"NN", "=", 
      RowBox[{
       RowBox[{"Length", "[", "w", "]"}], "-", "1"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "combed", " ", "negative", " ", "optical", " ", "depth", " ", 
       "estimation"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"Xs", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "d"}], " ", 
         RowBox[{"equiTupleEval", "[", 
          RowBox[{"fp", ",", "d", ",", "M", ",", 
           RowBox[{"RandomReal", "[", 
            RowBox[{"{", 
             RowBox[{"0", ",", "d"}], "}"}], "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Range", "[", 
           RowBox[{"NN", "+", "1"}], "]"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"cost", " ", "+=", " ", 
      RowBox[{"M", 
       RowBox[{"(", 
        RowBox[{"NN", "+", "1"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"truncated", " ", "power", " ", "series", " ", "estimation"}], 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{"T", "=", "0"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"ms", "=", 
         RowBox[{"ElementaryMeans", "[", 
          RowBox[{
           RowBox[{"Delete", "[", 
            RowBox[{"Xs", ",", "i"}], "]"}], "-", 
           RowBox[{"Xs", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"T", "=", 
         RowBox[{"T", "+", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"NN", "+", "1"}]], 
           RowBox[{"Exp", "[", 
            RowBox[{"Xs", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}], " ", 
           RowBox[{"Sum", "[", 
            RowBox[{
             FractionBox[
              RowBox[{"ms", "[", 
               RowBox[{"[", 
                RowBox[{"k", "+", "1"}], "]"}], "]"}], 
              RowBox[{
               RowBox[{"k", "!"}], " ", 
               RowBox[{"w", "[", 
                RowBox[{"[", 
                 RowBox[{"k", "+", "1"}], "]"}], "]"}]}]], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", "0", ",", "NN"}], "}"}]}], "]"}]}]}]}], ";"}],
        "\[IndentingNewLine]", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"NN", "+", "1"}], "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"T", ",", "cost"}], "}"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.828140408395927*^9, 3.8281404449975433`*^9}, {
   3.8281405629321127`*^9, 3.8281406115517063`*^9}, {3.828140656315181*^9, 
   3.828140692909759*^9}, {3.828140788329894*^9, 3.828140830044978*^9}, {
   3.828141247114719*^9, 3.828141276061969*^9}, {3.828155556233656*^9, 
   3.828155571999157*^9}, {3.8281572690929003`*^9, 3.828157315553626*^9}, {
   3.828157865642592*^9, 3.8281578738771343`*^9}, {3.828157925240324*^9, 
   3.828158091467909*^9}, {3.8281583495226793`*^9, 3.8281584144652233`*^9}, {
   3.828158499831523*^9, 3.828158556087158*^9}, 3.828159397400655*^9, {
   3.828159457790092*^9, 3.8281594596484737`*^9}, 3.828159523884068*^9, {
   3.82815975122303*^9, 3.828159761574855*^9}, {3.828159824028141*^9, 
   3.8281598243270683`*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"3c7d334d-c9ea-426d-98f3-1cd119f4652e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Algorithm 6:", "Subsubsection",
 CellChangeTimes->{{3.8281602059348803`*^9, 
  3.828160207743067*^9}},ExpressionUUID->"f8f3e514-951f-4589-8253-\
e4cbd0d40c51"],

Cell["Biased ray marching", "Text",
 CellChangeTimes->{{3.8281602147554827`*^9, 
  3.828160217049191*^9}},ExpressionUUID->"71c5f2d3-a619-455f-8af0-\
6a27998134dc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TBRM", "[", 
   RowBox[{"f_", ",", "d_", ",", "maj_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "K", ",", "i", ",", "m", ",", "positions", ",", "x", ",", "p", ",", "e", 
      ",", "fp", ",", "piv", ",", "c", ",", "taubar", ",", "M", ",", "Xs", 
      ",", "w", ",", "NN", ",", "cost", ",", "ms", ",", "T"}], "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"control", " ", "optical", " ", "thickness"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"taubar", "=", 
      RowBox[{"d", " ", "maj"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Algorithm", " ", "4"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"M", "=", 
      RowBox[{"Max", "[", 
       RowBox[{"1", ",", 
        RowBox[{"Floor", "[", 
         RowBox[{
          FractionBox[
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"0.015", "+", "taubar"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"0.65", "+", "taubar"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"60.3", "+", "taubar"}], ")"}]}], ")"}], 
            RowBox[{"1", "/", "3"}]], 
           RowBox[{"0.31945", "+", "1"}]], "+", "0.5"}], "]"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"endpoint", " ", "matching"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"fp", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", "#", "]"}], "+", 
        RowBox[{
         FractionBox["1", "2"], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"f", "[", "0", "]"}], "+", 
           RowBox[{"f", "[", "d", "]"}]}], ")"}]}], "-", 
        RowBox[{
         FractionBox["#", "d"], 
         RowBox[{"f", "[", "d", "]"}]}], "-", 
        RowBox[{
         FractionBox[
          RowBox[{"(", 
           RowBox[{"d", "-", "#"}], ")"}], "d"], 
         RowBox[{"f", "[", "0", "]"}]}]}], "&"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "d"}], " ", 
         RowBox[{"equiTupleEval", "[", 
          RowBox[{"fp", ",", "d", ",", "M", ",", 
           RowBox[{"RandomReal", "[", 
            RowBox[{"{", 
             RowBox[{"0", ",", "d"}], "}"}], "]"}]}], "]"}]}], "]"}], ",", 
       RowBox[{"2", "+", "M"}]}], "}"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.828160209624579*^9, 3.828160229260577*^9}, {
  3.8281603245114822`*^9, 3.8281603671369047`*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"d962fe5b-b998-42a8-985b-e1d8771dd02b"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["p-series CMF", "Subsection",
 CellChangeTimes->{{3.820725772215843*^9, 
  3.8207257743357697`*^9}},ExpressionUUID->"158d51c0-78be-4347-93c0-\
928981d63344"],

Cell["[Georgiev et al. 2019]", "Text",
 CellChangeTimes->{{3.820725776568735*^9, 
  3.8207257837664547`*^9}},ExpressionUUID->"f14ca6bb-dc12-46ed-9b2a-\
2e582b265b9f"],

Cell["goal parameter is typically 0.99", "Text",
 CellChangeTimes->{{3.8207257921733418`*^9, 
  3.820725798772643*^9}},ExpressionUUID->"c265fbe3-802a-4191-8715-\
31a335ae23ab"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TpCMF", "[", 
   RowBox[{"f_", ",", "\[CapitalSigma]max_", ",", "d_", ",", "goal_"}], "]"}],
   ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "x", ",", "Tr", ",", "w", ",", "runningCDF", ",", "maxD", ",", "pdf", 
      ",", "exponent", ",", "lastPDF", ",", "tau", ",", "rr", ",", "i", ",", 
      "tmpT", ",", "invI", ",", "dense", ",", "wi", ",", "accept"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"runningCDF", "=", "0"}], ";", "\[IndentingNewLine]", 
     RowBox[{"i", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"maxD", "=", "\[CapitalSigma]max"}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"pdf", "=", "d"}], ";", "\[IndentingNewLine]", 
     RowBox[{"w", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"tau", "=", 
      RowBox[{"pdf", "*", " ", "maxD"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Tr", "=", "0"}], ";", "\[IndentingNewLine]", 
     RowBox[{"exponent", "=", 
      RowBox[{"Exp", "[", 
       RowBox[{"-", "tau"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"lastPDF", "=", "exponent"}], ";", "\[IndentingNewLine]", 
     RowBox[{"rr", "=", 
      RowBox[{"RandomReal", "[", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"runningCDF", "<", "goal"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"tmpT", "=", 
         RowBox[{
          RowBox[{"RandomReal", "[", "]"}], " ", "d"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"runningCDF", "+=", "lastPDF"}], ";", "\[IndentingNewLine]", 
        RowBox[{"invI", " ", "=", " ", 
         RowBox[{"1.0", " ", "/", " ", "i"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"dense", "=", 
         RowBox[{"f", "[", "tmpT", "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"wi", "=", 
         RowBox[{"invI", " ", "pdf", " ", 
          RowBox[{"(", 
           RowBox[{"maxD", "-", "dense"}], ")"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"lastPDF", " ", "*=", " ", 
         RowBox[{"tau", " ", "invI"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"Tr", " ", "+=", " ", "w"}], ";", "\[IndentingNewLine]", 
        RowBox[{"w", " ", "*=", " ", "wi"}], ";", "\[IndentingNewLine]", 
        RowBox[{"i", "+=", "1"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{"True", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"accept", " ", "=", " ", 
         RowBox[{"tau", "/", "i"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"Tr", " ", "+=", " ", "w"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"accept", " ", "\[LessEqual]", " ", "rr"}], ",", 
          RowBox[{"Break", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"rr", "/=", "accept"}], ";", "\[IndentingNewLine]", 
        RowBox[{"runningCDF", "+=", "lastPDF"}], ";", "\[IndentingNewLine]", 
        RowBox[{"tmpT", "=", 
         RowBox[{
          RowBox[{"RandomReal", "[", "]"}], " ", "d"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"invI", "=", 
         RowBox[{"1", "/", "i"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"dense", "=", 
         RowBox[{"f", "[", "tmpT", "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"wi", "=", 
         RowBox[{"invI", " ", 
          RowBox[{"(", 
           RowBox[{"maxD", "-", "dense"}], ")"}], "pdf"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"lastPDF", "*=", 
         RowBox[{"tau", " ", "invI"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"w", "*=", 
         RowBox[{"(", 
          RowBox[{"wi", "/", "accept"}], ")"}]}], ";", "\[IndentingNewLine]", 
        
        RowBox[{"i", "+=", "1"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Tr", " ", "exponent"}], ",", 
       RowBox[{"i", "-", "1"}]}], "}"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8157848406776123`*^9, 3.815784853050462*^9}, {
  3.820725854222293*^9, 3.8207258552298527`*^9}, {3.828136743826923*^9, 
  3.8281367438289213`*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"2fac3913-c380-4f4f-8ea0-18310f0cbaaf"],

Cell["\<\
approximate mean number of samples taken by pCMF estimator at 99% mass with \
majorant optical depth m:\
\>", "Text",
 CellChangeTimes->{{3.820727990885808*^9, 
  3.820728013679051*^9}},ExpressionUUID->"b56fe297-f4b9-4892-b6d3-\
b4a4177e9763"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pCMFMeanN", "[", "\[Tau]bar_", "]"}], ":=", 
  RowBox[{"Ceiling", "[", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"0.015", "+", "\[Tau]bar"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"0.65", "+", "\[Tau]bar"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"60.3", "+", "\[Tau]bar"}], ")"}]}], ")"}], 
    RowBox[{"1", "/", "3"}]], "]"}]}]], "Input",
 CellChangeTimes->{{3.820729973023028*^9, 3.820730028140386*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"d230c5be-b9f6-4ef3-bbf4-c6b31462e0b0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["p-series Cumulative", "Subsection",
 CellChangeTimes->{{3.820725815172881*^9, 
  3.8207258186341753`*^9}},ExpressionUUID->"ce8e1988-5d6b-47ae-8146-\
0175b6467e31"],

Cell["[Georgiev et al. 2019]", "Text",
 CellChangeTimes->{{3.820725776568735*^9, 
  3.8207257837664547`*^9}},ExpressionUUID->"6e7d027b-e98e-46a7-91b0-\
eb3dd0b6e1d8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TpCumulative", "[", 
   RowBox[{"f_", ",", "\[CapitalSigma]max_", ",", "d_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "t", ",", "W", ",", "i", ",", "rr", ",", "left", ",", "x", ",", "wi", 
      ",", "accept", ",", "pdf", ",", "tmpT", ",", "dense", ",", "invI"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"t", "=", "0"}], ";", 
     RowBox[{"W", "=", "1"}], ";", 
     RowBox[{"i", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"pdf", "=", "d"}], ";", "\[IndentingNewLine]", 
     RowBox[{"rr", "=", 
      RowBox[{"RandomReal", "[", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{"True", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"left", "=", "W"}], ";", "\[IndentingNewLine]", 
        RowBox[{"tmpT", "=", 
         RowBox[{
          RowBox[{"RandomReal", "[", "]"}], " ", "d"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"dense", "=", 
         RowBox[{"f", "[", "tmpT", "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"invI", " ", "=", " ", 
         RowBox[{"1.0", " ", "/", " ", "i"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"wi", "=", 
         RowBox[{"invI", " ", "pdf", " ", 
          RowBox[{"(", 
           RowBox[{"\[CapitalSigma]max", "-", "dense"}], ")"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"accept", "=", 
         RowBox[{"Min", "[", 
          RowBox[{"1", ",", 
           RowBox[{"Abs", "[", 
            RowBox[{"W", " ", "wi"}], "]"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"accept", "\[LessEqual]", "rr"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"t", "+=", "left"}], ";", "\[IndentingNewLine]", 
           RowBox[{"Break", "[", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}],
         ";", "\[IndentingNewLine]", 
        RowBox[{"rr", "/=", "accept"}], ";", "\[IndentingNewLine]", 
        RowBox[{"t", "+=", "left"}], ";", "\[IndentingNewLine]", 
        RowBox[{"W", "*=", 
         RowBox[{"(", 
          RowBox[{"wi", "/", "accept"}], ")"}]}], ";", "\[IndentingNewLine]", 
        
        RowBox[{"i", "+=", "1.0"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"t", " ", 
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "\[CapitalSigma]max"}], " ", "d"}], "]"}]}], ",", 
       "i"}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.815806310548356*^9, 3.815806342403791*^9}, {
  3.8158063860666523`*^9, 3.815806388892901*^9}, {3.8158064500073557`*^9, 
  3.815806546425901*^9}, {3.815806617639976*^9, 3.815806657355056*^9}, {
  3.815806941530346*^9, 3.81580696354816*^9}, {3.815807171292622*^9, 
  3.815807176339962*^9}, {3.815807261754784*^9, 3.815807451496347*^9}, {
  3.817495245869475*^9, 3.817495246016612*^9}, {3.8207258604284897`*^9, 
  3.8207258626919203`*^9}, {3.8281367438317137`*^9, 3.8281367438344297`*^9}},
 CellLabel->"In[34]:=",ExpressionUUID->"9b43f3e3-71b3-4858-a22f-a2f850aa5ad9"]
}, Open  ]],

Cell[CellGroupData[{

Cell["p-series next flight", "Subsection",
 CellChangeTimes->{{3.820725834721209*^9, 
  3.820725838965085*^9}},ExpressionUUID->"b6860615-f382-4985-ae7e-\
0d21aea53c65"],

Cell["[Georgiev et al. 2019]", "Text",
 CellChangeTimes->{{3.820725776568735*^9, 
  3.8207257837664547`*^9}},ExpressionUUID->"5e61885c-b701-4e1d-83fd-\
50de5e7e7551"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TpNF", "[", 
   RowBox[{"f_", ",", "pivot_", ",", "d_", ",", "\[Lambda]_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"xnproduct", ",", "eN", ",", "result", ",", "i", ",", "cost"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xnproduct", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"result", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"result", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"eN", "=", 
      RowBox[{"RandomVariate", "[", 
       RowBox[{"PoissonDistribution", "[", "\[Lambda]", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"cost", "=", "0"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"cost", "+=", "1"}], ";", "\[IndentingNewLine]", 
        RowBox[{"xnproduct", "*=", 
         RowBox[{"d", 
          RowBox[{"(", 
           RowBox[{"pivot", "-", 
            RowBox[{"f", "[", 
             RowBox[{"RandomReal", "[", 
              RowBox[{"{", 
               RowBox[{"0", ",", "d"}], "}"}], "]"}], "]"}]}], ")"}]}]}], ";",
         "\[IndentingNewLine]", 
        RowBox[{"result", "+=", 
         RowBox[{
          FractionBox["1", 
           RowBox[{
            RowBox[{"i", "!"}], 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{
               RowBox[{"CDF", "[", 
                RowBox[{"PoissonDistribution", "[", "\[Lambda]", "]"}], "]"}],
                "[", 
               RowBox[{"i", "-", "1"}], "]"}]}], ")"}]}]], "xnproduct"}]}], 
        ";"}], "\[IndentingNewLine]", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Range", "[", "eN", "]"}]}], "}"}]}], "\[IndentingNewLine]", 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"result", " ", 
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "pivot"}], " ", "d"}], "]"}]}], ",", "cost"}], 
      "}"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.816752210961853*^9, 3.816752226297077*^9}, {
  3.816753508930731*^9, 3.81675351066514*^9}, {3.8167540748791924`*^9, 
  3.8167541046706963`*^9}, {3.820725869740484*^9, 3.8207258709517927`*^9}},
 CellLabel->"In[35]:=",ExpressionUUID->"101dd5f2-489c-4f7d-945c-bece9e85c3b2"],

Cell["Generalized with U-statistics", "Text",
 CellChangeTimes->{{3.82072588914695*^9, 
  3.8207258928818693`*^9}},ExpressionUUID->"8756acae-f5c6-4134-81cf-\
d48fe48be218"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TUpNF", "[", 
   RowBox[{"f_", ",", "pivot_", ",", "d_", ",", "\[Lambda]_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "eN", ",", "i", ",", "m", ",", "positions", ",", "x", ",", "p", ",", 
      "e"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"eN", "=", 
      RowBox[{"RandomVariate", "[", 
       RowBox[{"PoissonDistribution", "[", "\[Lambda]", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"i", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"m", "=", 
      RowBox[{"eN", "+", "i", "-", "1"}]}], ";", 
     RowBox[{"(*", 
      RowBox[{"m", " ", "total", " ", "samples"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"positions", "=", 
      RowBox[{"RandomReal", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "d"}], "}"}], ",", "m"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"x", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"d", 
         RowBox[{"(", 
          RowBox[{"pivot", "-", 
           RowBox[{"f", "[", "#", "]"}]}], ")"}]}], "&"}], "/@", 
       "positions"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"p", "[", "0", "]"}], "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "=", 
         RowBox[{"Sum", "[", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"x", "[", 
             RowBox[{"[", "j", "]"}], "]"}], "i"], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", 
             RowBox[{"Range", "[", "m", "]"}]}], "}"}]}], "]"}]}], ";"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Range", "[", "m", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"e", "[", "0", "]"}], "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"e", "[", "k", "]"}], "=", 
         RowBox[{
          FractionBox["1", "k"], 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], 
              RowBox[{"i", "-", "1"}]], 
             RowBox[{"e", "[", 
              RowBox[{"k", "-", "i"}], "]"}], 
             RowBox[{"p", "[", "i", "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", "k"}], "}"}]}], "]"}]}]}], ";"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", 
         RowBox[{"Range", "[", "m", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "pivot"}], " ", "d"}], "]"}], 
        RowBox[{"(", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            FractionBox["1", 
             RowBox[{
              RowBox[{"i", "!"}], " ", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{
                 RowBox[{"CDF", "[", 
                  RowBox[{"PoissonDistribution", "[", "\[Lambda]", "]"}], 
                  "]"}], "[", 
                 RowBox[{"i", "-", "1"}], "]"}]}], ")"}]}]], 
            FractionBox[
             RowBox[{"e", "[", "i", "]"}], 
             RowBox[{"Binomial", "[", 
              RowBox[{"m", ",", "i"}], "]"}]]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", "eN"}], "}"}]}], "]"}], ")"}]}], ",", 
       "m"}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.816670816051416*^9, 3.816670881852166*^9}, {
   3.816671070007884*^9, 3.816671094232706*^9}, 3.816754727437443*^9, {
   3.82072590246416*^9, 3.8207259053862534`*^9}},
 CellLabel->"In[36]:=",ExpressionUUID->"f2b5182f-5ad1-4099-a3d5-d28a23d1ed37"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compare estimators", "Section",
 CellChangeTimes->{{3.8207260308150997`*^9, 
  3.8207260345501003`*^9}},ExpressionUUID->"ac53f248-739d-4eba-9202-\
ee7b996ec306"],

Cell["\<\
Plot cost * variance for various estimators for a fixed density function f[x] \
as the interval with [0,d] is varied from d = 0 to d = 4.\
\>", "Text",
 CellChangeTimes->{{3.820726304158876*^9, 
  3.820726343505081*^9}},ExpressionUUID->"52710e7a-20dd-46b7-968b-\
5b6777872307"],

Cell[CellGroupData[{

Cell["Basic estimators", "Subsection",
 CellChangeTimes->{{3.820727441961548*^9, 
  3.820727443451466*^9}},ExpressionUUID->"2acc0348-954e-4c0b-bca4-\
30c0841a95f0"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"maxpos", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"td", "=", 
   RowBox[{
    RowBox[{".1", 
     RowBox[{"RandomFunction", "[", 
      RowBox[{
       RowBox[{"FractionalBrownianMotionProcess", "[", ".3", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "maxpos", ",", "0.01"}], "}"}]}], "]"}]}], "+", 
    "1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"TimeSeriesMap", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Max", "[", 
       RowBox[{"0", ",", "#"}], "]"}], "&"}], ",", "td"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "f", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "=", 
   RowBox[{"Interpolation", "[", "data", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maxT", "=", 
   RowBox[{"Exp", "[", 
    RowBox[{"-", 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "maxpos"}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maj", "=", 
   RowBox[{"Max", "[", "data", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"min", "=", 
   RowBox[{"Min", "[", "data", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"midcontrol", "=", 
   RowBox[{
    RowBox[{"maj", "/", "2"}], "+", 
    RowBox[{"min", "/", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MCn", "=", "100"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rate", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Magnify", "[", 
  RowBox[{
   RowBox[{"GraphicsRow", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"LogLogPlot", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", " ", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"FoM", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"TDeltaTracking", "[", 
               RowBox[{"#1", ",", "maj", ",", "#2"}], "]"}], "&"}], ",", "f", 
             ",", "pos", ",", "MCn"}], "]"}], " ", 
           RowBox[{"(*", " ", 
            RowBox[{
             RowBox[{"delta", " ", "tracking"}], " ", "-", " ", 
             RowBox[{"tight", " ", "majorant"}]}], " ", "*)"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"FoM", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"TDeltaTrackingNextFlight", "[", 
               RowBox[{"#1", ",", "maj", ",", "#2"}], "]"}], "&"}], ",", "f", 
             ",", "pos", ",", "MCn"}], "]"}], " ", 
           RowBox[{"(*", " ", 
            RowBox[{
             RowBox[{"NF", " ", "delta", " ", "tracking"}], " ", "-", " ", 
             RowBox[{"tight", " ", "majorant"}]}], " ", "*)"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"FoM", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"TRatioTracking", "[", 
               RowBox[{"#1", ",", "maj", ",", "#2"}], "]"}], "&"}], ",", "f", 
             ",", "pos", ",", "MCn"}], "]"}], " ", 
           RowBox[{"(*", " ", 
            RowBox[{"RT", " ", "-", " ", 
             RowBox[{"tight", " ", "majorant"}]}], " ", "*)"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"FoM", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"TNextFlightRatioTracking", "[", 
               RowBox[{"#1", ",", "maj", ",", "#2"}], "]"}], "&"}], ",", "f", 
             ",", "pos", ",", "MCn"}], "]"}], " ", 
           RowBox[{"(*", " ", 
            RowBox[{"NFRT", " ", "-", " ", 
             RowBox[{"tight", " ", "majorant"}]}], " ", "*)"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"FoM", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"TPoissonEstimator", "[", 
               RowBox[{"#1", ",", 
                RowBox[{"midcontrol", "+", "rate"}], ",", "#2", ",", "rate"}],
                "]"}], "&"}], ",", "f", ",", "pos", ",", "MCn"}], "]"}], " ", 
           
           RowBox[{"(*", " ", 
            RowBox[{"RRT", " ", "-", " ", 
             RowBox[{"mid", " ", "control"}]}], " ", "*)"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"FoM", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"TURM", "[", 
               RowBox[{"#1", ",", "#2", ",", "maj"}], "]"}], "&"}], ",", "f", 
             ",", "pos", ",", "MCn"}], "]"}], 
           RowBox[{"(*", " ", 
            RowBox[{"unbiased", " ", "ray", " ", "marching"}], " ", "*)"}], 
           "\[IndentingNewLine]", ","}], "\[IndentingNewLine]", "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"pos", ",", 
           RowBox[{".01", " ", "maxpos"}], ",", "maxpos"}], "}"}], ",", 
         RowBox[{"MaxRecursion", "\[Rule]", "1"}], ",", 
         RowBox[{"PlotPoints", "\[Rule]", "22"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
           "Blue", ",", "Dashed", ",", "Red", ",", "DotDashed", ",", "Thin", 
            ",", "Black", ",", 
            RowBox[{"{", 
             RowBox[{"Red", ",", "Dashed"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"Green", ",", "Dashed"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"Orange", ",", "DotDashed"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\"\<lookups * Variance\>\"", ","}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\"\<depth\>\"", ","}], "}"}]}], "}"}]}], ",", 
         RowBox[{"PlotLabels", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<DT\>\"", ",", "\"\<NFDT\>\"", ",", "\"\<RT\>\"", ",", 
            "\"\<NFRT\>\"", ",", "\"\<RRT\>\"", ",", "\"\<URM (ours)\>\""}], 
           "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"f", "[", "x", "]"}], ",", "midcontrol"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "maxpos"}], "}"}], ",", 
         RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"0", ",", "All"}], "}"}]}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"\"\<T[0,\>\"", "<>", 
           RowBox[{"ToString", "[", "maxpos", "]"}], "<>", "\"\<] = \>\"", "<>", 
           RowBox[{"ToString", "[", "maxT", "]"}]}]}]}], "]"}]}], 
      "\[IndentingNewLine]", "}"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "1200"}]}], "\[IndentingNewLine]", "]"}],
    ",", "0.5"}], "]"}]}], "Input",
 CellChangeTimes->{{3.8136471833561707`*^9, 3.8136471901226788`*^9}, {
   3.813647220681862*^9, 3.81364733082242*^9}, {3.813647554300034*^9, 
   3.8136475569101152`*^9}, 3.814651018670517*^9, {3.814651078791485*^9, 
   3.8146510820772533`*^9}, {3.8146511343198967`*^9, 
   3.8146511345148373`*^9}, {3.814651164947537*^9, 3.814651184476014*^9}, {
   3.8146512214217587`*^9, 3.814651237498398*^9}, {3.8146514060586147`*^9, 
   3.8146514106610537`*^9}, {3.81465144115003*^9, 3.814651489295813*^9}, {
   3.814651585618697*^9, 3.8146515991349907`*^9}, {3.8146516876448298`*^9, 
   3.8146516997037888`*^9}, {3.814651819829131*^9, 3.814651845218582*^9}, {
   3.814651883104527*^9, 3.814651883270433*^9}, {3.814651916535117*^9, 
   3.814651916916444*^9}, {3.814652034306196*^9, 3.814652059828785*^9}, {
   3.814652348156502*^9, 3.814652390678404*^9}, 3.8146525900047913`*^9, {
   3.814652674754283*^9, 3.8146526749932737`*^9}, {3.814652714919053*^9, 
   3.814652715023005*^9}, {3.8146532722183857`*^9, 3.814653304197576*^9}, {
   3.8146533855676928`*^9, 3.814653538700119*^9}, {3.814653653752761*^9, 
   3.814653692175058*^9}, {3.8146537515535994`*^9, 3.814653771433859*^9}, {
   3.814653828674862*^9, 3.8146538386970167`*^9}, {3.814653973842194*^9, 
   3.81465403202361*^9}, 3.8146541830896177`*^9, 3.8146542314828253`*^9, {
   3.8146542640818367`*^9, 3.814654300911084*^9}, {3.814654343081044*^9, 
   3.8146543473009987`*^9}, {3.8146544437108603`*^9, 3.814654497147352*^9}, {
   3.8146546171331*^9, 3.814654617414711*^9}, {3.814654648663618*^9, 
   3.81465466120158*^9}, 3.814654692346129*^9, {3.8146553486895733`*^9, 
   3.814655354015953*^9}, {3.81465539178897*^9, 3.8146554075194407`*^9}, {
   3.8146555526315203`*^9, 3.8146555746072063`*^9}, {3.814655796215267*^9, 
   3.814655797391954*^9}, {3.814655883884716*^9, 3.814655885371552*^9}, {
   3.8146559798083973`*^9, 3.8146559830117073`*^9}, {3.814656807849605*^9, 
   3.814656832399253*^9}, {3.814657075174089*^9, 3.814657075555786*^9}, {
   3.81465724728135*^9, 3.814657295528401*^9}, {3.8146587404349937`*^9, 
   3.814658755533692*^9}, {3.820726121713317*^9, 3.820726266381765*^9}, {
   3.820726433709855*^9, 3.8207264447722893`*^9}, {3.82072659541789*^9, 
   3.820726599669594*^9}, {3.8207269491384068`*^9, 3.820727027275569*^9}, 
   3.820727217374394*^9, {3.820812617584944*^9, 3.82081267483506*^9}, {
   3.820813046661792*^9, 3.820813059174079*^9}, {3.828160841265098*^9, 
   3.8281608472710876`*^9}, {3.8281617755270977`*^9, 3.828161785810874*^9}},
 CellLabel->
  "In[1088]:=",ExpressionUUID->"719f6578-f13c-4fcc-abf4-fc81a12c6b79"],

Cell[BoxData[
 StyleBox[
  GraphicsBox[{{}, {InsetBox[
      GraphicsBox[{{{}, {}, 
         TagBox[
          {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
           LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAYKx+2kHACcBmBfySxN8ZwCgW/xVH
6AjA2UOME34hGMDwf39RTBAIwJUwv9RE+xjAbCxdyiYmB8DZQ4wTfiEYwOfY
OkMBPAbAb7Odksh/FMBErVD1X2EFwLvDc3YvhhXAoIFmp76GBMAmH/2Sy2YX
wCTcwD5nsAPAkMAgIfIcEcCoNhvWD9oCwG1NRbZEzBLA4NPSqo3xAcB80ag+
cLwRwBdxin8LCQHAFAVTwYkVEsAwNnqNDTAAwKMH5XQsBxTAkvbTNh+u/r8s
iIT9GQQQwCsGbs3N1/y/jveu04axDcDEFQhkfAH7v1u4dfDbkg/ArDErxb4z
+b+JHlw1B4QPwJRNTiYBZve/eFunKWWLCMA+ueH5S7f1v/PX3wiHFgjA6SR1
zZYI9L/oS+y5QuoGwPoVwxuMNfK/w3b9MwFPCMAMBxFqgWLwv2VtblYvhQXA
wI+eVf5c7b92CpbMNMYFwGgRG9f59Om/P4COuOy3A8Cuq6ntHJ7mvwx1cqh6
IAXA9EU4BEBH47/h5l8NCp4CwBDWdyBwT9+/E3EfJIoqAcA3IH84YBDYv5RA
ePeh4v+/aqlHGnJN0b8NcdrS/q/9vzllIPgHFcW/TtJt8aCe/L9aixZG/rGp
vx8W7nFaFf6/GD8qqhF4sD9Zy0ofVzP9v3h/Z+fyn8Y/sCXQzhmE/b+y79x8
7oHSPwisxV1N2P2/neBEvME32T/Lkl8dbbL8v4jRrPuU7d8/QzDkFKaEAMBs
VhUoX5rjP0m3Tkdmmv6/E0RU0vM95z9bWMf3S+r9vzWSspd3o+o/sWfuLPCX
A8BX4BBd+wjuP4SpWij1wALA1hF9FpXb8D8VbbLgghoDwICzcX6ssvI//Iod
gGudDsDkFUehd3D0PwDwBzv0rgnASHgcxEIu9j9ApAy9O5sHwE1zWOk=
            "]]},
          Annotation[#, "Charting`Private`Tag$3352056#1"]& ], 
         TagBox[
          {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
           Opacity[1.], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAYKx+2kHACcCqRhzS2WYpwCgW/xVH
6AjA+91DJipRKMDwf39RTBAIwN3s8xrJaCfAbCxdyiYmB8DB83Kq5B0qwOfY
OkMBPAbAq+C+cdRwJsBErVD1X2EFwDKVduaB5CjAoIFmp76GBMA8eCttl1Un
wCTcwD5nsAPA8CAhh4jDJMCoNhvWD9oCwEayEXAK7SbA4NPSqo3xAcDz2Du/
9asjwBdxin8LCQHAl4ssBCI6JMAwNnqNDTAAwG9cGMbt7SPAkvbTNh+u/r/I
yFKTWvgkwCsGbs3N1/y/uzYBTmvOJsDEFQhkfAH7v8nabk7Y2CPArDErxb4z
+b+x/w4EYEojwJRNTiYBZve/NJ0NpBfbIcA+ueH5S7f1v8gAQglqiyDA6SR1
zZYI9L83u6VkRx4gwPoVwxuMNfK/mua9IFoLHsAMBxFqgWLwv8CsMR8+UB3A
wI+eVf5c7b8ArAdP8ZYcwGgRG9f59Om/1vcSPDW8G8Cuq6ntHJ7mvzuzfoAs
vR3A9EU4BEBH478zE2Y2nj0cwBDWdyBwT9+/wsQuaCKKHcA3IH84YBDYv5R1
piK16RzAaqlHGnJN0b++xj2tC70cwDllIPgHFcW/rroUxQy+G8BaixZG/rGp
v3DdFwTtYB7AGD8qqhF4sD9KuZnzFx4fwHh/Z+fyn8Y/mWUCmCGEG8Cy79x8
7oHSPyfBSz9IFxvAneBEvME32T/4grs2W98awIjRrPuU7d8/cSTv6ABoF8Bs
VhUoX5rjP5Z4JCQGLxnAE0RU0vM95z+bw4X6qbQXwDWSspd3o+o/ALpCpJeh
GMBX4BBd+wjuP547rWdrWhnA1hF9FpXb8D8jYtSwn+IawICzcX6ssvI/YvIZ
Zm+PG8DkFUehd3D0PzqazvMxUhzASHgcxEIu9j+h6RJcwr4bwC8YUpU=
            "]]},
          Annotation[#, "Charting`Private`Tag$3352056#2"]& ], 
         TagBox[
          {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
           LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAYKx+2kHACcCjH6amQYccwCgW/xVH
6AjARv82QwODGMDwf39RTBAIwI53y0/ijBzAbCxdyiYmB8C/kuZxOI8YwOfY
OkMBPAbA+8giXpjFH8BErVD1X2EFwCuDn4qkUhrAoIFmp76GBMCHBoblTeEU
wCTcwD5nsAPAX0dPObLDEsCoNhvWD9oCwGawFx/+uhHA4NPSqo3xAcAYA2GV
tlcSwBdxin8LCQHA4uqsyvbMEcAwNnqNDTAAwIsm/U9WdhLAkvbTNh+u/r9v
RyHtwiUQwCsGbs3N1/y/+MVqNdMmDcDEFQhkfAH7v41b1Ly8sgrArDErxb4z
+b+cU1joUqIQwJRNTiYBZve/4yNdE36wC8A+ueH5S7f1v/xxQgk+gA/A6SR1
zZYI9L/pjt0ssWYHwPoVwxuMNfK/tTkp0HHLB8AMBxFqgWLwvzdxGTCs2AfA
wI+eVf5c7b/RMerMaSsCwGgRG9f59Om/q9hFfIKMAcCuq6ntHJ7mv+Ye/FSn
fQPA9EU4BEBH47/XhHL7fskAwBDWdyBwT9+/Rum2/dMVAcA3IH84YBDYvyfr
oUXlxQDAaqlHGnJN0b81U1WVI5r7vzllIPgHFcW/Hp5bErLC+b9aixZG/rGp
v3VxnG1Ng/e/GD8qqhF4sD9YT4n3AdH2v3h/Z+fyn8Y/lV5sj9i99r+y79x8
7oHSPw3/AqfYGfS/neBEvME32T91fB2DvSX2v4jRrPuU7d8/7pG0uUPH9r9s
VhUoX5rjP7Srf/2wl/e/E0RU0vM95z+g9cEtJHH4vzWSspd3o+o/VzSuPHsO
+b9X4BBd+wjuP1IWj9+sdPy/1hF9FpXb8D9hrwjuiG8BwICzcX6ssvI/5JSi
EBRA/b/kFUehd3D0P7NIb/uMWQTASHgcxEIu9j8egFu3syMDwM+6YhM=
            "]]},
          Annotation[#, "Charting`Private`Tag$3352056#3"]& ], 
         TagBox[
          {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[1.6], 
           Opacity[1.], Dashing[{0, Small, Small, Small}], 
           LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAYKx+2kHACcBYm+F2+zYowCgW/xVH
6AjA221ntiUNLMDwf39RTBAIwH3E1pCchyfAbCxdyiYmB8DdNVoe7XclwOfY
OkMBPAbAk3uZealAKcBErVD1X2EFwNe2zlqBYibAoIFmp76GBMAIDm0Akhkn
wCTcwD5nsAPA7JELVTS3J8CoNhvWD9oCwBz9TVroiyXA4NPSqo3xAcCYN7EU
cn4mwBdxin8LCQHAYUVLAuZZJMAwNnqNDTAAwObhFAON2yTAkvbTNh+u/r9d
/RU284kkwCsGbs3N1/y/nzONK0b8IsDEFQhkfAH7v0hEAcvKxCPArDErxb4z
+b8MVWSeCg8lwJRNTiYBZve/nDwMBBH8I8A+ueH5S7f1v8YIfjd5HSDA6SR1
zZYI9L9AWo9G69EgwPoVwxuMNfK//1mFZCRVHcAMBxFqgWLwv+DiiiY4kB3A
wI+eVf5c7b9HbhTYXoYcwGgRG9f59Om/hpMvCZX/G8Cuq6ntHJ7mv6F0QAEX
+h3A9EU4BEBH47/bypQqDIUdwBDWdyBwT9+/KTLMsRwhG8A3IH84YBDYv7Ee
8Y58Eh3AaqlHGnJN0b997RQ2K2UcwDllIPgHFcW/1TJW5BLaHMBaixZG/rGp
v77L2rZ5Ex3AGD8qqhF4sD/WJ9UckzIdwHh/Z+fyn8Y/yePp16aSGsCy79x8
7oHSP/2QL1vidhbAneBEvME32T+e4lFzKzEXwIjRrPuU7d8/CgQ/3qkyGMBs
VhUoX5rjP4a4z8hx8BnAE0RU0vM95z/DDAQX92wVwDWSspd3o+o/e6SZM56L
FcBX4BBd+wjuP1IEBtYQWRbA1hF9FpXb8D98i8hqvzQYwICzcX6ssvI/lATO
I8rYFcDkFUehd3D0P8BO3sc1xRXASHgcxEIu9j8pdnFgUqEVwPZSTls=
            "]]},
          Annotation[#, "Charting`Private`Tag$3352056#4"]& ], 
         TagBox[
          {RGBColor[0.528488, 0.470624, 0.701351], Thickness[Tiny], Opacity[
           1.], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAYKx+2kHACcAGyEWY/2UmwCgW/xVH
6AjAU4niTv0PJcDwf39RTBAIwKoxn+cA4CTAbCxdyiYmB8COvgRXREEkwOfY
OkMBPAbAliD3t8f8I8BErVD1X2EFwEnw5Q3NiyPAoIFmp76GBMCyqNliVfci
wCTcwD5nsAPA0ZQTx6h0IsCoNhvWD9oCwJNarRHZtSHA4NPSqo3xAcDgHw1x
4AUjwBdxin8LCQHAVfLEK08hIcAwNnqNDTAAwL3XOTh9EyHAkvbTNh+u/r8K
O01Y3vQgwCsGbs3N1/y/aDl9sUCrH8DEFQhkfAH7v+yKk9TlKyDArDErxb4z
+b98l+c6UBIgwJRNTiYBZve/nPrQjiE/IMA+ueH5S7f1v5LQlmePPh7A6SR1
zZYI9L/mTKvd7JMfwPoVwxuMNfK/cSmu/moYHsAMBxFqgWLwv1Uv7uckCB3A
wI+eVf5c7b+prNw+nl0ewGgRG9f59Om/zFbmRWNDHcCuq6ntHJ7mv42n5Wur
Xx7A9EU4BEBH47+DAZ/J36kbwBDWdyBwT9+/nx/qwPVSG8A3IH84YBDYv09q
Sspr6RrAaqlHGnJN0b9YIcP4XbkawDllIPgHFcW/Vc6IghR1GcBaixZG/rGp
v3PcSWGOmhrAGD8qqhF4sD/lBkd3PJgawHh/Z+fyn8Y/Xqp6i1DtGsCy79x8
7oHSPzAWEyqfFxrAneBEvME32T8+2fxPkwobwIjRrPuU7d8/J64SHrYgHMBs
VhUoX5rjP7FqJVcDERvAE0RU0vM95z++sbv3rLscwDWSspd3o+o/N96Wf1fS
HcBX4BBd+wjuP1qYMVExZx7A1hF9FpXb8D8e61g11HkgwICzcX6ssvI/4lJ8
LI6iIcDkFUehd3D0P5Pp+jpVTCLASHgcxEIu9j/qeS0obpMjwOvhVoo=
            "]]},
          Annotation[#, "Charting`Private`Tag$3352056#5"]& ], 
         TagBox[
          {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
           LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAYKx+2kHACcC/hC+RldIwwCgW/xVH
6AjAfDavy9UwMMDwf39RTBAIwCjWVPGOpC/AbCxdyiYmB8CLb5VhVQktwOfY
OkMBPAbAiKd3UMNOK8BErVD1X2EFwCuNoHQFJSzAoIFmp76GBMA5EFj7Iogq
wCTcwD5nsAPAHv12VEAWKsCoNhvWD9oCwL2VexdJAynA4NPSqo3xAcDJ+3KM
NtgowBdxin8LCQHAIvVcC3aEKMAwNnqNDTAAwOhPJhzBdijAkvbTNh+u/r95
V9/0k3MowCsGbs3N1/y/uGhaQiqHKMDEFQhkfAH7v1AUPZhSyifArDErxb4z
+b98qJEGqrYnwJRNTiYBZve/MKh+HSBDJ8A+ueH5S7f1vxUOj/e68ybA6SR1
zZYI9L/VyoenJ1YlwPoVwxuMNfK/6huIXX9DJMAMBxFqgWLwv1MhOOp+ziTA
wI+eVf5c7b9FKc8XWtUlwGgRG9f59Om/6C620oQFJMCuq6ntHJ7mv9kMT0RR
ryLA9EU4BEBH478UOTJKmsAiwBDWdyBwT9+/lb/W5bBAI8A3IH84YBDYv4lK
GejE0CLAaqlHGnJN0b8LTKYyDgIiwDllIPgHFcW/zsK8m+c2IsBaixZG/rGp
v4hgoL5oxCHAGD8qqhF4sD+Y6OkrAGYhwHh/Z+fyn8Y/Cw7EcipMIcCy79x8
7oHSP2lzWqrs0SLAneBEvME32T/Ea+2dHxkjwIjRrPuU7d8/DVG0RInvIcBs
VhUoX5rjP1tzn1HQryHAE0RU0vM95z/6cEi5/wEiwDWSspd3o+o/onCgL1qE
I8BX4BBd+wjuP9I2PEggVyHA1hF9FpXb8D8VJHgNNsAiwICzcX6ssvI/Oxog
KL+3IsDkFUehd3D0P3lJSK5GKSPASHgcxEIu9j+sxb2R0PklwAxbTpU=
            "]]},
          
          Annotation[#, "Charting`Private`Tag$3352056#6"]& ]}, {{{}, {
           GraphicsGroupBox[{
             {GrayLevel[1], AbsoluteThickness[4], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], 
              JoinForm["Round"], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -2.950797535846988}], 
                Offset[{0, 0}, {1.482235406661309, -2.950797535846988}], 
                Offset[{0., 0.}, {1.52828710852119, -2.950797535846988}], 
                Offset[{0., 0.}, {1.52828710852119, -2.950797535846988}], 
                Offset[{0., 0.}, {1.574338810381071, -2.950797535846988}], 
                Offset[{0, 0}, {1.7167813031517485`, -3.502439460295738}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.7167813031517485`, -3.502439460295738}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.7167813031517485`, -3.502439460295738}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.7167813031517485`, -3.502439460295738}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -2.950797535846988}], 
                Offset[{0, 0}, {1.482235406661309, -2.950797535846988}], 
                Offset[{0., 0.}, {1.52828710852119, -2.950797535846988}], 
                Offset[{0., 0.}, {1.52828710852119, -2.950797535846988}], 
                Offset[{0., 0.}, {1.574338810381071, -2.950797535846988}], 
                Offset[{0, 0}, {1.7167813031517485`, -3.502439460295738}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.7167813031517485`, -3.502439460295738}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.7167813031517485`, -3.502439460295738}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.7167813031517485`, -3.502439460295738}]}]}, 
             {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]}], 
              PolygonBox[{
               Offset[{29., 6.500000000000006}, {
                 1.7167813031517485`, -3.502439460295738}], 
                Offset[{29., -6.499999999999994}, {
                 1.7167813031517485`, -3.502439460295738}], 
                Offset[{10.000000000000002`, -6.499999999999997}, {
                 1.7167813031517485`, -3.502439460295738}], 
                Offset[{9.999999999999998, 6.500000000000003}, {
                 1.7167813031517485`, -3.502439460295738}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
              StyleBox[
               RotationBox["\<\"DT\"\>",
                BoxRotation->0.],
               StripOnInput->False,
               LineOpacity->1,
               FrontFaceOpacity->1,
               BackFaceOpacity->1,
               Opacity->1,
               FontOpacity->1], 
              Offset[{19.5, 4.3298697960381105*^-15}, \
{1.7167813031517485, -3.502439460295738}], 
              ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}], 
           GraphicsGroupBox[{
             {GrayLevel[1], AbsoluteThickness[4], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], 
              JoinForm["Round"], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -6.93628829827722}], 
                Offset[{0, 0}, {1.482235406661309, -6.93628829827722}], 
                Offset[{0., 0.}, {1.52828710852119, -6.93628829827722}], 
                Offset[{0., 0.}, {1.52828710852119, -6.93628829827722}], 
                Offset[{0., 0.}, {1.574338810381071, -6.93628829827722}], 
                Offset[{0, 0}, {1.7167813031517485`, -7.0029736582511015`}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.7167813031517485`, -7.0029736582511015`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.7167813031517485`, -7.0029736582511015`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.7167813031517485`, -7.0029736582511015`}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -6.93628829827722}], 
                Offset[{0, 0}, {1.482235406661309, -6.93628829827722}], 
                Offset[{0., 0.}, {1.52828710852119, -6.93628829827722}], 
                Offset[{0., 0.}, {1.52828710852119, -6.93628829827722}], 
                Offset[{0., 0.}, {1.574338810381071, -6.93628829827722}], 
                Offset[{0, 0}, {1.7167813031517485`, -7.0029736582511015`}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.7167813031517485`, -7.0029736582511015`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.7167813031517485`, -7.0029736582511015`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.7167813031517485`, -7.0029736582511015`}]}]}, 
             {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]}], 
              PolygonBox[{
               Offset[{42., 6.500000000000009}, {
                 1.7167813031517485`, -7.0029736582511015`}], 
                Offset[{42., -6.499999999999991}, {
                 1.7167813031517485`, -7.0029736582511015`}], 
                Offset[{10.000000000000002`, -6.499999999999998}, {
                 1.7167813031517485`, -7.0029736582511015`}], 
                Offset[{10., 6.500000000000002}, {
                 1.7167813031517485`, -7.0029736582511015`}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
              StyleBox[
               RotationBox["\<\"NFDT\"\>",
                BoxRotation->0.],
               StripOnInput->False,
               LineOpacity->1,
               FrontFaceOpacity->1,
               BackFaceOpacity->1,
               Opacity->1,
               FontOpacity->1], 
              Offset[{26., 5.773159728050814*^-15}, \
{1.7167813031517485, -7.0029736582511015}], 
              ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}], 
           GraphicsGroupBox[{
             {GrayLevel[1], AbsoluteThickness[4], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], 
              JoinForm["Round"], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -2.3924326252745365`}], 
                Offset[{0, 0}, {1.482235406661309, -2.3924326252745365`}], 
                Offset[{0., 0.}, {1.52828710852119, -2.3924326252745365`}], 
                Offset[{0., 0.}, {1.52828710852119, -2.3924326252745365`}], 
                Offset[{0., 0.}, {1.574338810381071, -2.3924326252745365`}], 
                Offset[{0, 0}, {1.7167813031517485`, -1.8407695645364512`}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.7167813031517485`, -1.8407695645364512`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.7167813031517485`, -1.8407695645364512`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.7167813031517485`, -1.8407695645364512`}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -2.3924326252745365`}], 
                Offset[{0, 0}, {1.482235406661309, -2.3924326252745365`}], 
                Offset[{0., 0.}, {1.52828710852119, -2.3924326252745365`}], 
                Offset[{0., 0.}, {1.52828710852119, -2.3924326252745365`}], 
                Offset[{0., 0.}, {1.574338810381071, -2.3924326252745365`}], 
                Offset[{0, 0}, {1.7167813031517485`, -1.8407695645364512`}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.7167813031517485`, -1.8407695645364512`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.7167813031517485`, -1.8407695645364512`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.7167813031517485`, -1.8407695645364512`}]}]}, 
             {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]}], 
              PolygonBox[{
               Offset[{29., 6.500000000000006}, {
                 1.7167813031517485`, -1.8407695645364512`}], 
                Offset[{29., -6.499999999999994}, {
                 1.7167813031517485`, -1.8407695645364512`}], 
                Offset[{10.000000000000002`, -6.499999999999997}, {
                 1.7167813031517485`, -1.8407695645364512`}], 
                Offset[{9.999999999999998, 6.500000000000003}, {
                 1.7167813031517485`, -1.8407695645364512`}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
              StyleBox[
               RotationBox["\<\"RT\"\>",
                BoxRotation->0.],
               StripOnInput->False,
               LineOpacity->1,
               FrontFaceOpacity->1,
               BackFaceOpacity->1,
               Opacity->1,
               FontOpacity->1], 
              Offset[{19.5, 4.3298697960381105*^-15}, \
{1.7167813031517485, -1.8407695645364512}], 
              ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}], 
           GraphicsGroupBox[{
             {GrayLevel[1], AbsoluteThickness[4], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], 
              JoinForm["Round"], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -5.407540804791588}], 
                Offset[{0, 0}, {1.482235406661309, -5.407540804791588}], 
                Offset[{0., 0.}, {1.52828710852119, -5.407540804791588}], 
                Offset[{0., 0.}, {1.52828710852119, -5.407540804791588}], 
                Offset[{0., 0.}, {1.574338810381071, -5.407540804791588}], 
                Offset[{0, 0}, {1.7167813031517485`, -5.340871578387889}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.7167813031517485`, -5.340871578387889}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.7167813031517485`, -5.340871578387889}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.7167813031517485`, -5.340871578387889}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -5.407540804791588}], 
                Offset[{0, 0}, {1.482235406661309, -5.407540804791588}], 
                Offset[{0., 0.}, {1.52828710852119, -5.407540804791588}], 
                Offset[{0., 0.}, {1.52828710852119, -5.407540804791588}], 
                Offset[{0., 0.}, {1.574338810381071, -5.407540804791588}], 
                Offset[{0, 0}, {1.7167813031517485`, -5.340871578387889}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.7167813031517485`, -5.340871578387889}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.7167813031517485`, -5.340871578387889}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.7167813031517485`, -5.340871578387889}]}]}, 
             {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]}], 
              PolygonBox[{
               Offset[{42., 6.500000000000009}, {
                 1.7167813031517485`, -5.340871578387889}], 
                Offset[{42., -6.499999999999991}, {
                 1.7167813031517485`, -5.340871578387889}], 
                Offset[{10.000000000000002`, -6.499999999999998}, {
                 1.7167813031517485`, -5.340871578387889}], 
                Offset[{10., 6.500000000000002}, {
                 1.7167813031517485`, -5.340871578387889}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
              StyleBox[
               RotationBox["\<\"NFRT\"\>",
                BoxRotation->0.],
               StripOnInput->False,
               LineOpacity->1,
               FrontFaceOpacity->1,
               BackFaceOpacity->1,
               Opacity->1,
               FontOpacity->1], 
              Offset[{26., 5.773159728050814*^-15}, \
{1.7167813031517485, -5.340871578387889}], 
              ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}], 
           GraphicsGroupBox[{
             {GrayLevel[1], AbsoluteThickness[4], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], 
              JoinForm["Round"], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -9.787949805785463}], 
                Offset[{0, 0}, {1.482235406661309, -9.787949805785463}], 
                Offset[{0., 0.}, {1.52828710852119, -9.787949805785463}], 
                Offset[{0., 0.}, {1.52828710852119, -9.787949805785463}], 
                Offset[{0., 0.}, {1.574338810381071, -9.787949805785463}], 
                Offset[{0, 0}, {1.7167813031517485`, -9.500550148101018}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.7167813031517485`, -9.500550148101018}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.7167813031517485`, -9.500550148101018}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.7167813031517485`, -9.500550148101018}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -9.787949805785463}], 
                Offset[{0, 0}, {1.482235406661309, -9.787949805785463}], 
                Offset[{0., 0.}, {1.52828710852119, -9.787949805785463}], 
                Offset[{0., 0.}, {1.52828710852119, -9.787949805785463}], 
                Offset[{0., 0.}, {1.574338810381071, -9.787949805785463}], 
                Offset[{0, 0}, {1.7167813031517485`, -9.500550148101018}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.7167813031517485`, -9.500550148101018}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.7167813031517485`, -9.500550148101018}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.7167813031517485`, -9.500550148101018}]}]}, 
             {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]}], 
              PolygonBox[{
               Offset[{36., 6.500000000000008}, {
                 1.7167813031517485`, -9.500550148101018}], 
                Offset[{36., -6.499999999999992}, {
                 1.7167813031517485`, -9.500550148101018}], 
                Offset[{10.000000000000002`, -6.499999999999997}, {
                 1.7167813031517485`, -9.500550148101018}], 
                Offset[{9.999999999999998, 6.500000000000003}, {
                 1.7167813031517485`, -9.500550148101018}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
              StyleBox[
               RotationBox["\<\"RRT\"\>",
                BoxRotation->0.],
               StripOnInput->False,
               LineOpacity->1,
               FrontFaceOpacity->1,
               BackFaceOpacity->1,
               Opacity->1,
               FontOpacity->1], 
              Offset[{23., 5.10702591327572*^-15}, \
{1.7167813031517485, -9.500550148101018}], 
              ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}], 
           GraphicsGroupBox[{
             {GrayLevel[1], AbsoluteThickness[4], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], 
              JoinForm["Round"], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -10.987919382491633`}], 
                Offset[{0, 0}, {1.482235406661309, -10.987919382491633`}], 
                Offset[{0., 0.}, {1.52828710852119, -10.987919382491633`}], 
                Offset[{0., 0.}, {1.52828710852119, -10.987919382491633`}], 
                Offset[{0., 0.}, {1.574338810381071, -10.987919382491633`}], 
                Offset[{0, 0}, {1.7167813031517485`, -11.275325086787122`}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.7167813031517485`, -11.275325086787122`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.7167813031517485`, -11.275325086787122`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.7167813031517485`, -11.275325086787122`}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -10.987919382491633`}], 
                Offset[{0, 0}, {1.482235406661309, -10.987919382491633`}], 
                Offset[{0., 0.}, {1.52828710852119, -10.987919382491633`}], 
                Offset[{0., 0.}, {1.52828710852119, -10.987919382491633`}], 
                Offset[{0., 0.}, {1.574338810381071, -10.987919382491633`}], 
                Offset[{0, 0}, {1.7167813031517485`, -11.275325086787122`}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.7167813031517485`, -11.275325086787122`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.7167813031517485`, -11.275325086787122`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.7167813031517485`, -11.275325086787122`}]}]}, 
             {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]}], 
              PolygonBox[{
               Offset[{67., 7.500000000000015}, {
                 1.7167813031517485`, -11.275325086787122`}], 
                Offset[{67., -7.499999999999985}, {
                 1.7167813031517485`, -11.275325086787122`}], 
                Offset[{10., -7.499999999999997}, {
                 1.7167813031517485`, -11.275325086787122`}], 
                Offset[{10., 7.500000000000003}, {
                 1.7167813031517485`, -11.275325086787122`}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
              StyleBox[
               RotationBox["\<\"URM (ours)\"\>",
                BoxRotation->0.],
               StripOnInput->False,
               LineOpacity->1,
               FrontFaceOpacity->1,
               BackFaceOpacity->1,
               Opacity->1,
               FontOpacity->1], 
              Offset[{38.5, 8.548717289613705*^-15}, \
{1.7167813031517485, -11.275325086787122}], 
              ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}]}}, {}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{-3.2188758248682006`, -16.822594713307577`},
       CoordinatesToolOptions:>{"DisplayFunction" -> ({
           Exp[
            Part[#, 1]], 
           Exp[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Exp[
            Part[#, 1]], 
           Exp[
            Part[#, 2]]}& )},
       DisplayFunction->Identity,
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox["\"lookups * Variance\"", TraditionalForm], ""}, {
          FormBox["\"depth\"", TraditionalForm], ""}},
       FrameTicks->FrontEndValueCache[{{Quiet[
            Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
           Charting`ScaledFrameTicks[{Log, Exp}]}, {Quiet[
            Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
           
           Charting`ScaledFrameTicks[{
            Log, Exp}]}}, {{{{-13.815510557964274`, 
             FormBox[
              TemplateBox[{"10", 
                RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox], TraditionalForm], {0.01, 
             0.}}, {-9.210340371976182, 
             FormBox[
              TemplateBox[{"10", 
                RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox], TraditionalForm], {0.01, 
             0.}}, {-4.605170185988091, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.01\"", ShowStringCharacters -> False], 0.01, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 0.}}, {
            0., 
             FormBox["1", TraditionalForm], {0.01, 
             0.}}, {-18.420680743952367`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-16.11809565095832, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-11.512925464970229`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-6.907755278982137, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.3025850929940455`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.302585092994046, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {4.605170185988092, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}}, {{-13.815510557964274`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-9.210340371976182, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-4.605170185988091, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {0., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-18.420680743952367`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-16.11809565095832, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-11.512925464970229`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-6.907755278982137, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.3025850929940455`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.302585092994046, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {4.605170185988092, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}}}, {{{-2.995732273553991, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.05\"", ShowStringCharacters -> False], 0.05, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 
             0.}}, {-2.3025850929940455`, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.10\"", ShowStringCharacters -> False], 0.1, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 
             0.}}, {-0.6931471805599453, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.50\"", ShowStringCharacters -> False], 0.5, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 0.}}, {
            0., 
             FormBox["1", TraditionalForm], {0.01, 0.}}, {-4.605170185988091, 
             
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.912023005428146, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.506557897319982, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.2188758248682006`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.8134107167600364`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.659260036932778, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.5257286443082556`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.4079456086518722`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.2039728043259361`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.916290731874155, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.5108256237659907, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.35667494393873245`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.2231435513142097, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.10536051565782628`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.0986122886681098`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.3862943611198906`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.791759469228055, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.9459101490553132`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.0794415416798357`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.1972245773362196`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.302585092994046, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.3978952727983707`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.4849066497880004`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}}, {{-2.995732273553991, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-2.3025850929940455`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {0., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-4.605170185988091, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.912023005428146, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.506557897319982, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.2188758248682006`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.8134107167600364`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.659260036932778, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.5257286443082556`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.4079456086518722`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.2039728043259361`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.916290731874155, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.5108256237659907, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.35667494393873245`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.2231435513142097, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.10536051565782628`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.0986122886681098`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.3862943611198906`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.791759469228055, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.9459101490553132`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.0794415416798357`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.1972245773362196`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.302585092994046, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.3978952727983707`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.4849066497880004`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}}}}],
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->{{44., 89.33515794779282}, {36., 23.000000000000014`}},
       Method->{
        "DefaultBoundaryStyle" -> Automatic, 
         "DefaultGraphicsInteraction" -> {
          "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
           "Effects" -> {
            "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2},
              "Droplines" -> {
              "freeformCursorMode" -> True, 
               "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
         "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
         None},
       PlotRange->NCache[{{-3.2188758248682006`, 
           Log[4]}, {-16.822594713307577`, 0.}}, {{-3.2188758248682006`, 
         1.3862943611198906`}, {-16.822594713307577`, 0.}}],
       PlotRangeClipping->False,
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.05], 
          Scaled[0.08090169943749476]}},
       Ticks->{Quiet[
          Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , Quiet[
          Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& }], {342.00917394780754, -197.0176668279019},
       ImageScaled[{0.5, 0.5}], {645.0735932053547, 375.2717463388608}], 
     InsetBox[
      GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJwUmXc41e8bx+09sopKCgkhXxWJ3I+VlVVEKsloCAkZiShJRlSKRDKzsgkh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         "], {{{}, 
           {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl2gWYVdUehvEB6S4p6e7u7u4GAWlElO5SQTqlW0K6u5HuFhAQJKVVbAWF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              "]]]}, {}, 
           {RGBColor[0.880722, 0.611041, 0.142051], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[
             PolygonBox[{{2933, 2985, 2986, 2982, 2984, 2981, 2980, 2979, 
              2978, 2977, 2976, 2975, 2974, 2973, 2972, 2971, 2970, 2969, 
              2968, 2967, 2966, 2965, 2964, 2963, 2962, 2961, 2960, 2959, 
              2958, 2957, 2956, 2955, 2954, 2953, 2952, 2951, 2950, 2949, 
              2948, 2947, 2946, 2945, 2944, 2943, 2942, 2941, 2940, 2939, 
              2938, 2937, 2936, 2935, 2934, 
              2983}}]]}, {}, {}, {}, {}, {}, {}}, {{}, {}, 
           TagBox[
            {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
             Opacity[1.], LineBox[CompressedData["
1:eJwl2gXUVdXahuFPRRTpku7ukka6u7tBCSWkQxrpbknpDmkEFCnpFpUG6e5Q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              "]]},
            Annotation[#, "Charting`Private`Tag$3389333#1"]& ], 
           TagBox[
            {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
             Opacity[1.], 
             LineBox[{2933, 2983, 2934, 2935, 2936, 2937, 2938, 2939, 2940, 
              2941, 2942, 2943, 2944, 2945, 2946, 2947, 2948, 2949, 2950, 
              2951, 2952, 2953, 2954, 2955, 2956, 2957, 2958, 2959, 2960, 
              2961, 2962, 2963, 2964, 2965, 2966, 2967, 2968, 2969, 2970, 
              2971, 2972, 2973, 2974, 2975, 2976, 2977, 2978, 2979, 2980, 
              2981, 2984, 2982}]},
            Annotation[#, "Charting`Private`Tag$3389333#2"]& ]}}], {}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Frame->{{False, False}, {False, False}},
       FrameLabel->{{None, None}, {None, None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->{{10.030612244897956`, 1.5}, {36., 23.000000000000014`}},
       
       Method->{
        "DefaultBoundaryStyle" -> Automatic, 
         "DefaultGraphicsInteraction" -> {
          "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
           "Effects" -> {
            "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2},
              "Droplines" -> {
              "freeformCursorMode" -> True, 
               "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
         "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
         None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& )}, "AxesInFront" -> True},
       PlotLabel->FormBox["\"T[0,4] = 0.0279163\"", TraditionalForm],
       PlotRange->{{0., 3.999999918367347}, {0, All}},
       PlotRangeClipping->True,
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {0, 
          Scaled[0.05]}},
       Ticks->{Automatic, Automatic}], {965.1252489919752, -197.0176668279019},
       ImageScaled[{0.5, 0.5}], {523.2690475024599, 375.2717463388608}]}, {}},
   
   ImageSize->1200,
   PlotRange->{{0, 1246.2321500883354`}, {-394.0353336558038, 0}},
   PlotRangePadding->{6, 5}],
  StripOnInput->False,
  Magnification->0.5 Inherited]], "Output",
 CellChangeTimes->{{3.82072626498838*^9, 3.8207262691266317`*^9}, {
   3.8207264368297377`*^9, 3.820726447335442*^9}, 3.820726602520265*^9, {
   3.8207269694091454`*^9, 3.820726988090486*^9}, 3.820727029639641*^9, 
   3.820727225876343*^9, {3.820812620472424*^9, 3.820812625560306*^9}, 
   3.820812678605173*^9, {3.820813052196496*^9, 3.820813062981036*^9}, 
   3.828137379731741*^9, 3.8281608499897738`*^9, {3.828161795848291*^9, 
   3.828161801873754*^9}},
 CellLabel->
  "Out[1099]=",ExpressionUUID->"cc41affa-370f-4651-b926-c0e9e90f738c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"maxpos", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"td", "=", 
   RowBox[{
    RowBox[{".1", 
     RowBox[{"RandomFunction", "[", 
      RowBox[{
       RowBox[{"FractionalBrownianMotionProcess", "[", ".3", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "maxpos", ",", "0.01"}], "}"}]}], "]"}]}], "+", 
    ".2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"TimeSeriesMap", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Max", "[", 
       RowBox[{"0", ",", "#"}], "]"}], "&"}], ",", "td"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "f", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "=", 
   RowBox[{"Interpolation", "[", "data", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maxT", "=", 
   RowBox[{"Exp", "[", 
    RowBox[{"-", 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "maxpos"}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maj", "=", 
   RowBox[{"Max", "[", "data", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"min", "=", 
   RowBox[{"Min", "[", "data", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"midcontrol", "=", 
   RowBox[{
    RowBox[{"maj", "/", "2"}], "+", 
    RowBox[{"min", "/", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MCn", "=", "1000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rate", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Magnify", "[", 
  RowBox[{
   RowBox[{"GraphicsRow", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"LogLogPlot", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", " ", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"FoM", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"TDeltaTracking", "[", 
               RowBox[{"#1", ",", "maj", ",", "#2"}], "]"}], "&"}], ",", "f", 
             ",", "pos", ",", "MCn"}], "]"}], " ", 
           RowBox[{"(*", " ", 
            RowBox[{
             RowBox[{"delta", " ", "tracking"}], " ", "-", " ", 
             RowBox[{"tight", " ", "majorant"}]}], " ", "*)"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"FoM", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"TDeltaTrackingNextFlight", "[", 
               RowBox[{"#1", ",", "maj", ",", "#2"}], "]"}], "&"}], ",", "f", 
             ",", "pos", ",", "MCn"}], "]"}], " ", 
           RowBox[{"(*", " ", 
            RowBox[{
             RowBox[{"NF", " ", "delta", " ", "tracking"}], " ", "-", " ", 
             RowBox[{"tight", " ", "majorant"}]}], " ", "*)"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"FoM", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"TRatioTracking", "[", 
               RowBox[{"#1", ",", "maj", ",", "#2"}], "]"}], "&"}], ",", "f", 
             ",", "pos", ",", "MCn"}], "]"}], " ", 
           RowBox[{"(*", " ", 
            RowBox[{"RT", " ", "-", " ", 
             RowBox[{"tight", " ", "majorant"}]}], " ", "*)"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"FoM", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"TNextFlightRatioTracking", "[", 
               RowBox[{"#1", ",", "maj", ",", "#2"}], "]"}], "&"}], ",", "f", 
             ",", "pos", ",", "MCn"}], "]"}], " ", 
           RowBox[{"(*", " ", 
            RowBox[{"NFRT", " ", "-", " ", 
             RowBox[{"tight", " ", "majorant"}]}], " ", "*)"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"FoM", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"TPoissonEstimator", "[", 
               RowBox[{"#1", ",", 
                RowBox[{"midcontrol", "+", "rate"}], ",", "#2", ",", "rate"}],
                "]"}], "&"}], ",", "f", ",", "pos", ",", "MCn"}], "]"}], " ", 
           
           RowBox[{"(*", " ", 
            RowBox[{"RRT", " ", "-", " ", 
             RowBox[{"mid", " ", "control"}]}], " ", "*)"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"FoM", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"TURM", "[", 
               RowBox[{"#1", ",", "#2", ",", "maj"}], "]"}], "&"}], ",", "f", 
             ",", "pos", ",", "MCn"}], "]"}]}], 
          RowBox[{"(*", " ", 
           RowBox[{"unbiased", " ", "ray", " ", "marching"}], " ", "*)"}], 
          "\[IndentingNewLine]", "\[IndentingNewLine]", "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"pos", ",", 
           RowBox[{".01", " ", "maxpos"}], ",", "maxpos"}], "}"}], ",", 
         RowBox[{"MaxRecursion", "\[Rule]", "1"}], ",", 
         RowBox[{"PlotPoints", "\[Rule]", "22"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
           "Blue", ",", "Dashed", ",", "Red", ",", "DotDashed", ",", "Thin", 
            ",", "Black", ",", 
            RowBox[{"{", 
             RowBox[{"Red", ",", "Dashed"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"Green", ",", "Dashed"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"Orange", ",", "DotDashed"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\"\<lookups * Variance\>\"", ","}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\"\<depth\>\"", ","}], "}"}]}], "}"}]}], ",", 
         RowBox[{"PlotLabels", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<DT\>\"", ",", "\"\<NFDT\>\"", ",", "\"\<RT\>\"", ",", 
            "\"\<NFRT\>\"", ",", "\"\<RRT\>\"", ",", "\"\<ours\>\""}], 
           "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"f", "[", "x", "]"}], ",", "midcontrol"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "maxpos"}], "}"}], ",", 
         RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"0", ",", "All"}], "}"}]}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"\"\<T[0,\>\"", "<>", 
           RowBox[{"ToString", "[", "maxpos", "]"}], "<>", "\"\<] = \>\"", "<>", 
           RowBox[{"ToString", "[", "maxT", "]"}]}]}]}], "]"}]}], 
      "\[IndentingNewLine]", "}"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "1200"}]}], "\[IndentingNewLine]", "]"}],
    ",", "0.5"}], "]"}]}], "Input",
 CellChangeTimes->{{3.820727276297348*^9, 3.82072727645785*^9}, {
  3.820813136786072*^9, 3.8208131554165363`*^9}, {3.828161824655067*^9, 
  3.8281618300046263`*^9}},
 CellLabel->
  "In[1100]:=",ExpressionUUID->"a81afde5-9d0f-4e4d-9997-68025359d601"],

Cell[BoxData[
 StyleBox[
  GraphicsBox[{{}, {InsetBox[
      GraphicsBox[{{{}, {}, 
         TagBox[
          {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
           LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAYKx+2kHACcAj6tISfRcjwCgW/xVH
6AjAowQTuS7WJMDwf39RTBAIwGQjuLiaviDAbCxdyiYmB8CLh2bKuqAhwOfY
OkMBPAbAcTbMZcGlIsBErVD1X2EFwGMosuIWsh3AoIFmp76GBMB+xLCYU5cf
wCTcwD5nsAPAeZFwPHMnIMCoNhvWD9oCwLzu7fJ3zx7A4NPSqo3xAcANXr/9
neAcwBdxin8LCQHAmF+cbjHSHcAwNnqNDTAAwJy8HOJtqxvAkvbTNh+u/r80
0JknazoewCsGbs3N1/y/HdMcgtR3HMDEFQhkfAH7v6h7+y3rWRnArDErxb4z
+b+ohJo99fkZwJRNTiYBZve/17GfeQohGMA+ueH5S7f1v0h5qdSunRbA6SR1
zZYI9L8TKWcQTNcWwPoVwxuMNfK/8Q5nPzWsFsAMBxFqgWLwv1sbKXdjNxbA
wI+eVf5c7b83rMltzpsTwGgRG9f59Om/xzSN8gADE8Cuq6ntHJ7mv8LCDW7J
ORLA9EU4BEBH479ZlTfMqZYRwBDWdyBwT9+/gnN2iZ8tEMA3IH84YBDYvyBz
zEgAdBDAaqlHGnJN0b8SrpxqcCUPwDllIPgHFcW/IMo9pVymDMBaixZG/rGp
v/Yx9sHrDQrAGD8qqhF4sD9InarqMF4JwHh/Z+fyn8Y/SerrSSjHCMCy79x8
7oHSPzvNTsA/hAfAneBEvME32T/lo6IMZIcGwIjRrPuU7d8/+MxFzz+GBsBs
VhUoX5rjP1ZDxN1PPQTAE0RU0vM95z8h/CNnLkwEwDWSspd3o+o/NhQCnmS2
A8BX4BBd+wjuP5Nu1CCzJALA1hF9FpXb8D/iaxuhKcUBwICzcX6ssvI/k08N
/kZ2AMDkFUehd3D0P8K1PgPS/f2/SHgcxEIu9j8xjLZaBMf8v2qQU68=
            "]]},
          Annotation[#, "Charting`Private`Tag$3399634#1"]& ], 
         TagBox[
          {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
           Opacity[1.], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAYKx+2kHACcAfRFNhIy4pwCgW/xVH
6AjA3HgozTLYJsDwf39RTBAIwCF/sUwxGinAbCxdyiYmB8AADyIJUzcowOfY
OkMBPAbAekrE6ggwJsBErVD1X2EFwKEF9MEaMCbAoIFmp76GBMBfjk2GOR8l
wCTcwD5nsAPA+3M2/w8BJsCoNhvWD9oCwAiyb6JrfSXA4NPSqo3xAcCEofzO
VSEkwBdxin8LCQHABfUKKMCZIsAwNnqNDTAAwITXwkoLoyHAkvbTNh+u/r8n
xKQCQJMiwCsGbs3N1/y/ICJD9HHsIcDEFQhkfAH7v5pf9/UHHSHArDErxb4z
+b9jlPhean4hwJRNTiYBZve/QPqR4HirIMA+ueH5S7f1v6QM4hrcnh/A6SR1
zZYI9L/kxeLaaGwfwPoVwxuMNfK/KvHUmYzyH8AMBxFqgWLwv6H+BoYLEh3A
wI+eVf5c7b/t/0lBVlQcwGgRG9f59Om/SgDFj+JtG8Cuq6ntHJ7mvyghxpZp
iBvA9EU4BEBH478DAZok7qwbwBDWdyBwT9+/AAdsnVYNG8A3IH84YBDYv6df
2mamcRnAaqlHGnJN0b+40KxNlbEZwDllIPgHFcW/XFy85HhZGcBaixZG/rGp
v9b2ydW3tBfAGD8qqhF4sD9N2DHaZRgXwHh/Z+fyn8Y/fIAH/Sk7FcCy79x8
7oHSP0rldGvDOBPAneBEvME32T+Fp5k0Dt4RwIjRrPuU7d8/EmqQAQy1DcBs
VhUoX5rjP0kpxBpk/QrAE0RU0vM95z86mhZfgBkHwDWSspd3o+o/5YIWCbGi
A8BX4BBd+wjuP6x5qqPUMwPA1hF9FpXb8D9T0uy5qoUBwICzcX6ssvI/W0+J
hx4DAsDkFUehd3D0P0qiLsq9WADASHgcxEIu9j/+DOUlwh39v7msTcQ=
            "]]},
          Annotation[#, "Charting`Private`Tag$3399634#2"]& ], 
         TagBox[
          {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
           LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAYKx+2kHACcCkaCJyD0wiwCgW/xVH
6AjAHQmhCxauIcDwf39RTBAIwD4OEXXnRSHAbCxdyiYmB8DPsPlxocIiwOfY
OkMBPAbA1zQWRwbgIMBErVD1X2EFwEPrOR2LiiHAoIFmp76GBMA9sKEyU6Qh
wCTcwD5nsAPAoEYGatQSIMCoNhvWD9oCwDiEnWmI0R3A4NPSqo3xAcAwJeJJ
1TAcwBdxin8LCQHA9VUimokmIMAwNnqNDTAAwCsqdXp+9B3AkvbTNh+u/r81
S4SPf4wcwCsGbs3N1/y/90fdam+pHMDEFQhkfAH7v2dSu9kB4xjArDErxb4z
+b9ZCnV75q0XwJRNTiYBZve/E3MLjkw4GMA+ueH5S7f1v4FsCSaG6hfA6SR1
zZYI9L879HzK7aEXwPoVwxuMNfK/DkuFN+m4F8AMBxFqgWLwv5ntbAJAjxfA
wI+eVf5c7b/CFMdHz7EUwGgRG9f59Om/m76TUSbzE8Cuq6ntHJ7mv3UYsZSE
pRPA9EU4BEBH47+7L3g0+P0SwBDWdyBwT9+/PB6kYfYoEsA3IH84YBDYvzav
csDyHhDAaqlHGnJN0b/OKPyA3sINwDllIPgHFcW/HJ+0yRoVEMBaixZG/rGp
v3ku4s0L+AvAGD8qqhF4sD+7h5cRIRgLwHh/Z+fyn8Y/UOHvtNlLCsCy79x8
7oHSP25w6BrxDwnAneBEvME32T+wrH0xgrQIwIjRrPuU7d8/R1rjPUvJB8Bs
VhUoX5rjP2hNsWlmtAfAE0RU0vM95z9qSVW0uscFwDWSspd3o+o/hsgLc0yr
BcBX4BBd+wjuP4SaEHpEqATA1hF9FpXb8D83AeihFREEwICzcX6ssvI/9Pog
aZJ1AsDkFUehd3D0P3QxlcRF4wHASHgcxEIu9j9T0v6p158AwDPIT14=
            "]]},
          Annotation[#, "Charting`Private`Tag$3399634#3"]& ], 
         TagBox[
          {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[1.6], 
           Opacity[1.], Dashing[{0, Small, Small, Small}], 
           LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAYKx+2kHACcAB0Kmg4ssnwCgW/xVH
6AjAQ0iFB5/PJ8Dwf39RTBAIwJXKtqnYNyfAbCxdyiYmB8AKSNGHuxsmwOfY
OkMBPAbA+FlwKM6KJMBErVD1X2EFwKTwKHPChCbAoIFmp76GBMB15kr2Vp0m
wCTcwD5nsAPApIsxKkAKJcCoNhvWD9oCwP9VsAlA8CPA4NPSqo3xAcBejsCf
zi8jwBdxin8LCQHA6mpNNmXxIsAwNnqNDTAAwOec+xXi9iHAkvbTNh+u/r9d
aF+3O08iwCsGbs3N1/y/oLxwawgYIcDEFQhkfAH7v2fvrYVQkyHArDErxb4z
+b8fNxAMgs8hwJRNTiYBZve/T5U/R7AQIsA+ueH5S7f1v2QVIaQmQyDA6SR1
zZYI9L93pkD2mfAewPoVwxuMNfK/0cE4sRzXHcAMBxFqgWLwv97pWXiDKhvA
wI+eVf5c7b8Xo/8ffHscwGgRG9f59Om/vuUohXaxHMCuq6ntHJ7mv58XFGbj
KBvA9EU4BEBH47/WvohAKJoZwBDWdyBwT9+/T57JTTCmGcA3IH84YBDYv7hp
3QbUwxnAaqlHGnJN0b9RmXaIwSMawDllIPgHFcW/B4xq675RGcBaixZG/rGp
vxC7xsCunhfAGD8qqhF4sD/akIZbfrEXwHh/Z+fyn8Y/BcvltsTHFMCy79x8
7oHSP9VhfWI9hBLAneBEvME32T9AhIsJ+MsQwIjRrPuU7d8/vud6u4l6DcBs
VhUoX5rjP+m+VRhSugjAE0RU0vM95z+RG6Wv89QFwDWSspd3o+o/QJtvEF2y
BcBX4BBd+wjuP9mKxvKwlAHA1hF9FpXb8D8MmZFTZGH/v4CzcX6ssvI/w76O
Ny9P/r/kFUehd3D0P24NVUv2O/q/SHgcxEIu9j9o9Yxwha/6v+VcW9Q=
            "]]},
          Annotation[#, "Charting`Private`Tag$3399634#4"]& ], 
         TagBox[
          {RGBColor[0.528488, 0.470624, 0.701351], Thickness[Tiny], Opacity[
           1.], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAYKx+2kHACcCH6nx3H9MmwCgW/xVH
6AjAEg2dCGKSJsDwf39RTBAIwN68brcDDCbAbCxdyiYmB8AXgUf6FfUlwOfY
OkMBPAbA9xJHEP4uJcBErVD1X2EFwDPNR+I02yXAoIFmp76GBMBVB+2fkaMk
wCTcwD5nsAPAVDqMhzu4JMCoNhvWD9oCwM++qY0RMSTA4NPSqo3xAcD1Pb16
bvYjwBdxin8LCQHA5R9f2+f2I8AwNnqNDTAAwLMTAHabaCPAkvbTNh+u/r8u
UA0HesEiwCsGbs3N1/y/Q+CyhAUBIsDEFQhkfAH7v7Ho7stnMyHArDErxb4z
+b+C4chjdFsgwJRNTiYBZve/XZnqTzAgIMA+ueH5S7f1v8ruUs0q6B/A6SR1
zZYI9L8fJLhlg24fwPoVwxuMNfK/MYm1SpoPH8AMBxFqgWLwv1YedmEeXR7A
wI+eVf5c7b//rn3LNmIdwGgRG9f59Om/LA7J6RcnHMCuq6ntHJ7mv+26g6Ql
SBvA9EU4BEBH47/6R8gic+YawBDWdyBwT9+/UEy+N780GsA3IH84YBDYv0y+
XRSEhBjAaqlHGnJN0b/sCWKMsV8YwDllIPgHFcW/XXUJROZTF8BaixZG/rGp
v1dXffO4UxbAGD8qqhF4sD+CSyTmcuUVwHh/Z+fyn8Y/T67FKUwGFsCy79x8
7oHSP57iHWb/OhXAneBEvME32T9E3cxGSP0TwIjRrPuU7d8/vPT/dVq8EsBs
VhUoX5rjP3GqLdPwwxDAE0RU0vM95z/lpkqqILIOwDWSspd3o+o/4FEWObQE
DcBX4BBd+wjuP/nMYC7XsgrA1hF9FpXb8D/1GcKwiE0JwICzcX6ssvI/tmVk
0sTdCMDkFUehd3D0P/rgqS2PCgfASHgcxEIu9j8i3l11pz0GwHgsVEQ=
            "]]},
          Annotation[#, "Charting`Private`Tag$3399634#5"]& ], 
         TagBox[
          {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
           LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAYKx+2kHACcAtpV5c5uQrwCgW/xVH
6AjAsRJQmXn2KsDwf39RTBAIwPY6HrPWNCrAbCxdyiYmB8AG7u+ZROspwOfY
OkMBPAbAHfI3rgFdKcBErVD1X2EFwGBEyF5IwCjAoIFmp76GBMDRl+IaeqYo
wCTcwD5nsAPAJTx3/5dqKMCoNhvWD9oCwNKkJY3AFSjA4NPSqo3xAcBjxktq
8HAnwBdxin8LCQHAjYp7pKe+JsAwNnqNDTAAwA32X1NqISbAkvbTNh+u/r/X
JCK5OE0kwCsGbs3N1/y/UOMAxUuMI8DEFQhkfAH7v1sOGCWSEiPArDErxb4z
+b+VLIMdQo8iwJRNTiYBZve/vVpAoyoZIcA+ueH5S7f1v/menSRPlyDA6SR1
zZYI9L+i2WyMRnQgwPoVwxuMNfK/aFfrBa8oIMAMBxFqgWLwvxwuyd2w2R/A
wI+eVf5c7b+PODZ5X60ewGgRG9f59Om/xuhGYrXSHcCuq6ntHJ7mv65YZKNT
Yh3A9EU4BEBH47+h8ZKBqP0cwBDWdyBwT9+/lA6AGby1HcA3IH84YBDYv3pZ
s/XQ2B7AaqlHGnJN0b/zXZPhxHYewDllIPgHFcW/Qk9VOcDIHcBaixZG/rGp
v/vgl/YqAhvAGD8qqhF4sD/ukPsH8rMbwHh/Z+fyn8Y/orJMHsavGsCy79x8
7oHSP9jHVG2toxfAneBEvME32T9VCRbgc1gYwIjRrPuU7d8/no2puil1F8Bs
VhUoX5rjP9BsuF5Y/RXAE0RU0vM95z9FFdwwAwYXwDWSspd3o+o/ALcS20Um
GMBX4BBd+wjuP/+xTsYFrhXA1hF9FpXb8D+MS1WHKU8TwICzcX6ssvI/INjG
nwrOE8DkFUehd3D0P9Pzp69yqhLASHgcxEIu9j9+F1RfM0QQwFOCVU0=
            "]]},
          
          Annotation[#, "Charting`Private`Tag$3399634#6"]& ]}, {{{}, {
           GraphicsGroupBox[{
             {GrayLevel[1], AbsoluteThickness[4], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], 
              JoinForm["Round"], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -1.79858813700481}], 
                Offset[{0, 0}, {1.482235406661309, -1.79858813700481}], 
                Offset[{0., 0.}, {1.52828710852119, -1.79858813700481}], 
                Offset[{0., 0.}, {1.52828710852119, -1.79858813700481}], 
                Offset[{0., 0.}, {1.574338810381071, -1.79858813700481}], 
                Offset[{0, 0}, {1.8506490215403564`, -2.2347473049093067`}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8506490215403564`, -2.2347473049093067`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8506490215403564`, -2.2347473049093067`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8506490215403564`, -2.2347473049093067`}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -1.79858813700481}], 
                Offset[{0, 0}, {1.482235406661309, -1.79858813700481}], 
                Offset[{0., 0.}, {1.52828710852119, -1.79858813700481}], 
                Offset[{0., 0.}, {1.52828710852119, -1.79858813700481}], 
                Offset[{0., 0.}, {1.574338810381071, -1.79858813700481}], 
                Offset[{0, 0}, {1.8506490215403564`, -2.2347473049093067`}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8506490215403564`, -2.2347473049093067`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8506490215403564`, -2.2347473049093067`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8506490215403564`, -2.2347473049093067`}]}]}, 
             {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]}], 
              PolygonBox[{
               Offset[{29., 6.500000000000006}, {
                 1.8506490215403564`, -2.2347473049093067`}], 
                Offset[{29., -6.499999999999994}, {
                 1.8506490215403564`, -2.2347473049093067`}], 
                Offset[{10.000000000000002`, -6.499999999999997}, {
                 1.8506490215403564`, -2.2347473049093067`}], 
                Offset[{9.999999999999998, 6.500000000000003}, {
                 1.8506490215403564`, -2.2347473049093067`}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
              StyleBox[
               RotationBox["\<\"DT\"\>",
                BoxRotation->0.],
               StripOnInput->False,
               LineOpacity->1,
               FrontFaceOpacity->1,
               BackFaceOpacity->1,
               Opacity->1,
               FontOpacity->1], 
              Offset[{19.5, 4.3298697960381105*^-15}, \
{1.8506490215403564, -2.2347473049093067}], 
              ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}], 
           GraphicsGroupBox[{
             {GrayLevel[1], AbsoluteThickness[4], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], 
              JoinForm["Round"], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -1.819765232111251}], 
                Offset[{0, 0}, {1.482235406661309, -1.819765232111251}], 
                Offset[{0., 0.}, {1.52828710852119, -1.819765232111251}], 
                Offset[{0., 0.}, {1.52828710852119, -1.819765232111251}], 
                Offset[{0., 0.}, {1.574338810381071, -1.819765232111251}], 
                Offset[{0, 0}, {1.8506490215403564`, -3.4504214055206903`}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8506490215403564`, -3.4504214055206903`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8506490215403564`, -3.4504214055206903`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8506490215403564`, -3.4504214055206903`}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -1.819765232111251}], 
                Offset[{0, 0}, {1.482235406661309, -1.819765232111251}], 
                Offset[{0., 0.}, {1.52828710852119, -1.819765232111251}], 
                Offset[{0., 0.}, {1.52828710852119, -1.819765232111251}], 
                Offset[{0., 0.}, {1.574338810381071, -1.819765232111251}], 
                Offset[{0, 0}, {1.8506490215403564`, -3.4504214055206903`}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8506490215403564`, -3.4504214055206903`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8506490215403564`, -3.4504214055206903`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8506490215403564`, -3.4504214055206903`}]}]}, 
             {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]}], 
              PolygonBox[{
               Offset[{42., 6.500000000000009}, {
                 1.8506490215403564`, -3.4504214055206903`}], 
                Offset[{42., -6.499999999999991}, {
                 1.8506490215403564`, -3.4504214055206903`}], 
                Offset[{10.000000000000002`, -6.499999999999998}, {
                 1.8506490215403564`, -3.4504214055206903`}], 
                Offset[{10., 6.500000000000002}, {
                 1.8506490215403564`, -3.4504214055206903`}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
              StyleBox[
               RotationBox["\<\"NFDT\"\>",
                BoxRotation->0.],
               StripOnInput->False,
               LineOpacity->1,
               FrontFaceOpacity->1,
               BackFaceOpacity->1,
               Opacity->1,
               FontOpacity->1], 
              Offset[{26., 5.773159728050814*^-15}, \
{1.8506490215403564, -3.4504214055206903}], 
              ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}], 
           GraphicsGroupBox[{
             {GrayLevel[1], AbsoluteThickness[4], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], 
              JoinForm["Round"], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -2.0780480652704596`}], 
                Offset[{0, 0}, {1.482235406661309, -2.0780480652704596`}], 
                Offset[{0., 0.}, {1.52828710852119, -2.0780480652704596`}], 
                Offset[{0., 0.}, {1.52828710852119, -2.0780480652704596`}], 
                Offset[{0., 0.}, {1.574338810381071, -2.0780480652704596`}], 
                Offset[{0, 0}, {1.8506490215403564`, -4.6660955897110306`}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8506490215403564`, -4.6660955897110306`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8506490215403564`, -4.6660955897110306`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8506490215403564`, -4.6660955897110306`}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -2.0780480652704596`}], 
                Offset[{0, 0}, {1.482235406661309, -2.0780480652704596`}], 
                Offset[{0., 0.}, {1.52828710852119, -2.0780480652704596`}], 
                Offset[{0., 0.}, {1.52828710852119, -2.0780480652704596`}], 
                Offset[{0., 0.}, {1.574338810381071, -2.0780480652704596`}], 
                Offset[{0, 0}, {1.8506490215403564`, -4.6660955897110306`}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8506490215403564`, -4.6660955897110306`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8506490215403564`, -4.6660955897110306`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8506490215403564`, -4.6660955897110306`}]}]}, 
             {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]}], 
              PolygonBox[{
               Offset[{29., 6.500000000000006}, {
                 1.8506490215403564`, -4.6660955897110306`}], 
                Offset[{29., -6.499999999999994}, {
                 1.8506490215403564`, -4.6660955897110306`}], 
                Offset[{10.000000000000002`, -6.499999999999997}, {
                 1.8506490215403564`, -4.6660955897110306`}], 
                Offset[{9.999999999999998, 6.500000000000003}, {
                 1.8506490215403564`, -4.6660955897110306`}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
              StyleBox[
               RotationBox["\<\"RT\"\>",
                BoxRotation->0.],
               StripOnInput->False,
               LineOpacity->1,
               FrontFaceOpacity->1,
               BackFaceOpacity->1,
               Opacity->1,
               FontOpacity->1], 
              Offset[{19.5, 4.3298697960381105*^-15}, \
{1.8506490215403564, -4.6660955897110306}], 
              ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}], 
           GraphicsGroupBox[{
             {GrayLevel[1], AbsoluteThickness[4], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], 
              JoinForm["Round"], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -2.7801045579215193`}], 
                Offset[{0, 0}, {1.482235406661309, -2.7801045579215193`}], 
                Offset[{0., 0.}, {1.52828710852119, -2.7801045579215193`}], 
                Offset[{0., 0.}, {1.52828710852119, -2.7801045579215193`}], 
                Offset[{0., 0.}, {1.574338810381071, -2.7801045579215193`}], 
                Offset[{0, 0}, {1.8506490215403564`, -5.88176999905145}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8506490215403564`, -5.88176999905145}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8506490215403564`, -5.88176999905145}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8506490215403564`, -5.88176999905145}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -2.7801045579215193`}], 
                Offset[{0, 0}, {1.482235406661309, -2.7801045579215193`}], 
                Offset[{0., 0.}, {1.52828710852119, -2.7801045579215193`}], 
                Offset[{0., 0.}, {1.52828710852119, -2.7801045579215193`}], 
                Offset[{0., 0.}, {1.574338810381071, -2.7801045579215193`}], 
                Offset[{0, 0}, {1.8506490215403564`, -5.88176999905145}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8506490215403564`, -5.88176999905145}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8506490215403564`, -5.88176999905145}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8506490215403564`, -5.88176999905145}]}]}, 
             {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]}], 
              PolygonBox[{
               Offset[{36., 6.500000000000008}, {
                 1.8506490215403564`, -5.88176999905145}], 
                Offset[{36., -6.499999999999992}, {
                 1.8506490215403564`, -5.88176999905145}], 
                Offset[{10.000000000000002`, -6.499999999999997}, {
                 1.8506490215403564`, -5.88176999905145}], 
                Offset[{9.999999999999998, 6.500000000000003}, {
                 1.8506490215403564`, -5.88176999905145}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
              StyleBox[
               RotationBox["\<\"RRT\"\>",
                BoxRotation->0.],
               StripOnInput->False,
               LineOpacity->1,
               FrontFaceOpacity->1,
               BackFaceOpacity->1,
               Opacity->1,
               FontOpacity->1], 
              Offset[{23., 5.10702591327572*^-15}, \
{1.8506490215403564, -5.88176999905145}], 
              ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}], 
           GraphicsGroupBox[{
             {GrayLevel[1], AbsoluteThickness[4], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], 
              JoinForm["Round"], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -4.066602220065645}], 
                Offset[{0, 0}, {1.482235406661309, -4.066602220065645}], 
                Offset[{0., 0.}, {1.52828710852119, -4.066602220065645}], 
                Offset[{0., 0.}, {1.52828710852119, -4.066602220065645}], 
                Offset[{0., 0.}, {1.574338810381071, -4.066602220065645}], 
                Offset[{0, 0}, {1.8506490215403564`, -7.014703011852314}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8506490215403564`, -7.014703011852314}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8506490215403564`, -7.014703011852314}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8506490215403564`, -7.014703011852314}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -4.066602220065645}], 
                Offset[{0, 0}, {1.482235406661309, -4.066602220065645}], 
                Offset[{0., 0.}, {1.52828710852119, -4.066602220065645}], 
                Offset[{0., 0.}, {1.52828710852119, -4.066602220065645}], 
                Offset[{0., 0.}, {1.574338810381071, -4.066602220065645}], 
                Offset[{0, 0}, {1.8506490215403564`, -7.014703011852314}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8506490215403564`, -7.014703011852314}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8506490215403564`, -7.014703011852314}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8506490215403564`, -7.014703011852314}]}]}, 
             {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]}], 
              PolygonBox[{
               Offset[{35., 5.500000000000008}, {
                 1.8506490215403564`, -7.014703011852314}], 
                Offset[{35., -5.499999999999992}, {
                 1.8506490215403564`, -7.014703011852314}], 
                Offset[{10.000000000000002`, -5.499999999999997}, {
                 1.8506490215403564`, -7.014703011852314}], 
                Offset[{9.999999999999998, 5.500000000000003}, {
                 1.8506490215403564`, -7.014703011852314}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
              StyleBox[
               RotationBox["\<\"ours\"\>",
                BoxRotation->0.],
               StripOnInput->False,
               LineOpacity->1,
               FrontFaceOpacity->1,
               BackFaceOpacity->1,
               Opacity->1,
               FontOpacity->1], 
              Offset[{22.5, 4.9960036108132044*^-15}, \
{1.8506490215403564, -7.014703011852314}], 
              ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}]}, 
          GraphicsGroupBox[{
            {GrayLevel[1], AbsoluteThickness[4], Opacity[
              NCache[
               Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], 
             JoinForm["Round"], 
             BSplineCurveBox[{
              Offset[{0, 0}, {1.478397545545834, -1.6678518673428133`}], 
               Offset[{0, 0}, {1.478397545545834, -1.6678518673428133`}], 
               Offset[{0., 0.}, {1.478397545545834, -1.6678518673428133`}], 
               Offset[{0., 0.}, {1.478397545545834, -1.6678518673428133`}], 
               Offset[{0., 0.}, {1.478397545545834, -1.6678518673428133`}], 
               Offset[{0, 0}, {1.8506490215403564`, -1.01907322232636}], 
               Offset[{5., 1.1102230246251565`*^-15}, {
                1.8506490215403564`, -1.01907322232636}], 
               Offset[{10., 2.220446049250313*^-15}, {
                1.8506490215403564`, -1.01907322232636}], 
               Offset[{10., 2.220446049250313*^-15}, {
                1.8506490215403564`, -1.01907322232636}]}]}, 
            {RGBColor[
             0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
             AbsoluteThickness[1.25], 
             BSplineCurveBox[{
              Offset[{0, 0}, {1.478397545545834, -1.6678518673428133`}], 
               Offset[{0, 0}, {1.478397545545834, -1.6678518673428133`}], 
               Offset[{0., 0.}, {1.478397545545834, -1.6678518673428133`}], 
               Offset[{0., 0.}, {1.478397545545834, -1.6678518673428133`}], 
               Offset[{0., 0.}, {1.478397545545834, -1.6678518673428133`}], 
               Offset[{0, 0}, {1.8506490215403564`, -1.01907322232636}], 
               Offset[{5., 1.1102230246251565`*^-15}, {
                1.8506490215403564`, -1.01907322232636}], 
               Offset[{10., 2.220446049250313*^-15}, {
                1.8506490215403564`, -1.01907322232636}], 
               Offset[{10., 2.220446049250313*^-15}, {
                1.8506490215403564`, -1.01907322232636}]}]}, 
            {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
              NCache[
               Rational[2, 3], 0.6666666666666666]]}], 
             PolygonBox[{
              Offset[{42., 6.500000000000009}, {
                1.8506490215403564`, -1.01907322232636}], 
               Offset[{42., -6.499999999999991}, {
                1.8506490215403564`, -1.01907322232636}], 
               Offset[{10.000000000000002`, -6.499999999999998}, {
                1.8506490215403564`, -1.01907322232636}], 
               Offset[{10., 6.500000000000002}, {
                1.8506490215403564`, -1.01907322232636}]}]}, 
            {RGBColor[
             0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
             AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
             StyleBox[
              RotationBox["\<\"NFRT\"\>",
               BoxRotation->0.],
              StripOnInput->False,
              LineOpacity->1,
              FrontFaceOpacity->1,
              BackFaceOpacity->1,
              Opacity->1,
              FontOpacity->1], 
             Offset[{26., 5.773159728050814*^-15}, \
{1.8506490215403564, -1.01907322232636}], 
             ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}]}, {}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{-3.2188758248682006`, -13.947070013574},
       CoordinatesToolOptions:>{"DisplayFunction" -> ({
           Exp[
            Part[#, 1]], 
           Exp[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Exp[
            Part[#, 1]], 
           Exp[
            Part[#, 2]]}& )},
       DisplayFunction->Identity,
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox["\"lookups * Variance\"", TraditionalForm], ""}, {
          FormBox["\"depth\"", TraditionalForm], ""}},
       FrameTicks->FrontEndValueCache[{{Quiet[
            Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
           Charting`ScaledFrameTicks[{Log, Exp}]}, {Quiet[
            Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
           
           Charting`ScaledFrameTicks[{
            Log, Exp}]}}, {{{{-13.815510557964274`, 
             FormBox[
              TemplateBox[{"10", 
                RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox], TraditionalForm], {0.01, 
             0.}}, {-11.512925464970229`, 
             FormBox[
              TemplateBox[{"10", 
                RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox], TraditionalForm], {0.01, 
             0.}}, {-9.210340371976182, 
             FormBox[
              TemplateBox[{"10", 
                RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox], TraditionalForm], {0.01, 
             0.}}, {-6.907755278982137, 
             FormBox["0.001`", TraditionalForm], {0.01, 
             0.}}, {-4.605170185988091, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.010\"", ShowStringCharacters -> False], 0.01, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 
             0.}}, {-2.3025850929940455`, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.100\"", ShowStringCharacters -> False], 0.1, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 
             0.}}, {-16.11809565095832, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-15.424948470398375`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-15.01948336229021, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-14.73180128983843, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-14.508657738524219`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-14.326336181730264`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-14.172185501903007`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-14.038654109278484`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-13.9208710736221, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-13.122363377404328`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-12.716898269296165`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-12.429216196844383`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-12.206072645530174`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-12.02375108873622, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-11.86960040890896, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-11.736069016284437`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-11.618285980628055`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-10.819778284410283`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-10.41431317630212, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-10.126631103850338`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.903487552536127, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.721165995742174, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.567015315914915, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.433483923290392, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.315700887634009, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-8.517193191416238, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-8.111728083308073, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.824046010856292, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.600902459542082, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.418580902748128, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.264430222920869, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.1308988302963465`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.013115794639964, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-6.214608098422191, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.809142990314028, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.521460917862246, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.298317366548036, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.115995809754082, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-4.961845129926823, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-4.8283137373023015`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-4.710530701645918, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.912023005428146, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.506557897319982, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.2188758248682006`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.995732273553991, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.8134107167600364`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.659260036932778, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.5257286443082556`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.4079456086518722`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.2039728043259361`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.916290731874155, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.5108256237659907, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.35667494393873245`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.2231435513142097, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.10536051565782628`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.0986122886681098`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.3862943611198906`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.791759469228055, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.9459101490553132`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.0794415416798357`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}}, {{-13.815510557964274`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-11.512925464970229`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-9.210340371976182, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-6.907755278982137, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-4.605170185988091, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-2.3025850929940455`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-16.11809565095832, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-15.424948470398375`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-15.01948336229021, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-14.73180128983843, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-14.508657738524219`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-14.326336181730264`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-14.172185501903007`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-14.038654109278484`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-13.9208710736221, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-13.122363377404328`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-12.716898269296165`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-12.429216196844383`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-12.206072645530174`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-12.02375108873622, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-11.86960040890896, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-11.736069016284437`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-11.618285980628055`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-10.819778284410283`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-10.41431317630212, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-10.126631103850338`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.903487552536127, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.721165995742174, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.567015315914915, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.433483923290392, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.315700887634009, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-8.517193191416238, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-8.111728083308073, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.824046010856292, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.600902459542082, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.418580902748128, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.264430222920869, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.1308988302963465`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.013115794639964, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-6.214608098422191, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.809142990314028, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.521460917862246, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.298317366548036, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.115995809754082, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-4.961845129926823, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-4.8283137373023015`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-4.710530701645918, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.912023005428146, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.506557897319982, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.2188758248682006`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.995732273553991, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.8134107167600364`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.659260036932778, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.5257286443082556`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.4079456086518722`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.2039728043259361`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.916290731874155, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.5108256237659907, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.35667494393873245`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.2231435513142097, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.10536051565782628`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.0986122886681098`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.3862943611198906`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.791759469228055, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.9459101490553132`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.0794415416798357`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}}}, {{{-2.995732273553991, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.05\"", ShowStringCharacters -> False], 0.05, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 
             0.}}, {-2.3025850929940455`, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.10\"", ShowStringCharacters -> False], 0.1, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 
             0.}}, {-0.6931471805599453, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.50\"", ShowStringCharacters -> False], 0.5, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 0.}}, {
            0., 
             FormBox["1", TraditionalForm], {0.01, 0.}}, {-4.605170185988091, 
             
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.912023005428146, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.506557897319982, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.2188758248682006`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.8134107167600364`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.659260036932778, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.5257286443082556`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.4079456086518722`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.2039728043259361`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.916290731874155, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.5108256237659907, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.35667494393873245`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.2231435513142097, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.10536051565782628`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.0986122886681098`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.3862943611198906`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.791759469228055, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.9459101490553132`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.0794415416798357`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.1972245773362196`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.302585092994046, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.3978952727983707`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.4849066497880004`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}}, {{-2.995732273553991, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-2.3025850929940455`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {0., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-4.605170185988091, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.912023005428146, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.506557897319982, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.2188758248682006`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.8134107167600364`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.659260036932778, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.5257286443082556`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.4079456086518722`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.2039728043259361`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.916290731874155, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.5108256237659907, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.35667494393873245`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.2231435513142097, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.10536051565782628`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.0986122886681098`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.3862943611198906`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.791759469228055, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.9459101490553132`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.0794415416798357`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.1972245773362196`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.302585092994046, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.3978952727983707`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.4849066497880004`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}}}}],
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->{{47., 74.79999999999995}, {36., 22.99999999999997}},
       Method->{
        "DefaultBoundaryStyle" -> Automatic, 
         "DefaultGraphicsInteraction" -> {
          "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
           "Effects" -> {
            "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2},
              "Droplines" -> {
              "freeformCursorMode" -> True, 
               "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
         "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
         None},
       PlotRange->NCache[{{-3.2188758248682006`, 
           Log[
           4]}, {-13.947070013574, -1.6396391813912845`}}, \
{{-3.2188758248682006`, 
         1.3862943611198906`}, {-13.947070013574, -1.6396391813912845`}}],
       PlotRangeClipping->False,
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.05], 
          Scaled[0.08090169943749476]}},
       Ticks->{Quiet[
          Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , Quiet[
          Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& }], {336.67820963323345, -197.34852259912216},
       ImageScaled[{0.5, 0.5}], {634.5581226541494, 375.90194780785174}], 
     InsetBox[
      GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJxMunc81f8f/i97ExIZCRWFlAqlrmdSkQrRLoSkISMaIhq8FUrJyCgjQvZe
2Rx7lr13srdCP9/b7ff9+J5/zu1xe55/XrdzPe7XdT3P2WJgdvYGNRUV1S8m
Kqr/837yxlBt7i/rw6kvopq9P5biGWPi9lf8SdDLXYl/ql6Ci5eCYicmC5Hn
nC8UZVUNln/Prp4Qrobl83LWgLl8bNUaGypw+YHz3+Me+3BQ8LBKET4zzQiK
M+UMaqnExqT1HevWdYLv6mUGNVKKlJ6jFdVKPThhKWJ1r6IE+bcDBC6N9EFF
aNnb5FQVZrcd4og2HUQYF7dUAkc5qBe/cQpsHQbt3v2bdPwqsf+ffop2zAhc
Io25A3irUPFyb1XxjnH0bhCLNWkpwWb334sRYxOY3h+a1SpXiN/znR0/ZafQ
r7yTxog6CV+GM8vY30xDOl9DXakgGexCX8f7+mYgmD1X6DiXBddbycaB4nOY
qVsYP1MSjTnyrc/Efh5iut7lIfnhsNpTmMRbsABjl+nBwUYPdMYUutRu+QOq
///19/YPP0mbv/+bdx5hWDHOXMJNetutrbvdcCJ4y834jSuYZD7QQptujodC
eqLdV//97/NSI+dYGk9Tkf87c3NMMBb+WZtpc/xixfzX/W++szezmUmd+n/z
NzWDwOy5tXn29ybOAS+a/83J2idoPqjQkrES+62hG8Jhr+r4OWmAltD3fdC7
6RqKLe0nm0Ic6UitNhvdUEo6Dsi//MC/h544pPW48Ohk4qpw9eK6enqiuIFx
/am4DMyWufWYP2MgNHvEu3YpJsGHVtfqrDgjyf5parDeNB7cHcnB1IWM5EjX
TMzzwmjQ2T3TUbRgIgqiO97VO8eBKkI3toeLmYR+z93ikJEAS99YN658ZlLw
eoF18Ukivu90Zlx/j4V8CtW8WZnwEetPWko9Z2clvIa+rAMi1miTrql/nMVK
FuxGkibOhCHuE8T7dNnIhMXMmFzxO1yL3b9eaIWNPDmScuPmTBAcHIOetUWy
k7yAqd323NmIHhLyYz/FQbiyQ/PWB2XCezPL7L9/HGTImDPjA1U2AjdoOL3m
/wKxIGMmka0V8Gm3OZq8ko03VptK5lgo2BO1nl6QsQwlBgf2wbEK58K9y++z
1WFk3b0nW4WKUcXBwyNDGnHndXyN8WMKTuSFslfatOEGq5jhV89KXNcNuxbe
0QVm4c10N9+WIits4v6HD71oSCUQYStFm6rpBhrpAcw+/PNp144KLL2d4TAq
HUJjc77ArnoKBG2dDFNv/cbg1YfpfgUVWJd/UtltZBQ8G/I/nlMsgfKv53H0
yhNwkdPQi4koAl3hjZGct5PosokVkT1ZCNXJSh3LzimYKTx4/C0mFM0vdrc/
VpzB0JZtx5ZSI3H6qMy3/JezOCZ3RW/uSy6OnIsLpa2bw8Hhsbu0ZXFITk+t
wJYFSH+SC17q+oJIcxURK8vF/+l51LXCY7nyD+pIhtaD0fvgbhg9VbJp6X/n
6RYf9rjeWkZeiGFjX8pHdOrlqqhlrPzvfMjG0f/E0tp+/Nwcz/R9lIYECzyt
VawMwaYzxlpfPGmJvteARcn4V9RwDR2U2k9HItcz88rXxkPm9c2UjlY6kulU
V/FkNAzlkZIUt+f0JPjAbRvGc98RbiVzT3EHAzm4+F/V9dcpKB60/tZdx0B+
qDPkNMtl4fzkK5cdVozEz7wnT5k2Da7Rfn8DNjGRUubF2jt58aDmnljHns9E
ttF+UUs8n4H0Lf99srnNTJx+0kdIPAsEX69A+Xo+FmIncHTikLYjBg/Y+apl
s/xvH+cObqF6eoOV/Pfgzd7YO7OHjw8wLMWwsZEoMx1mqxlN0G/P9HWIYSMX
NF9Iahl+wb1Nd0ttddjJI/mfpZckQsGbqvfG+i87kbfI4c88mgvRlzyqDGEc
RMnCVeybRRLad/131I3/A3YltmTwd5aCddpr32bXdLTY7dxGc78QRc+bL9Pb
UeCafl7d4FUNRrVHstSramC7ZfRA+6cC2Mg+W1no/4n6o/S8TBVF6KSMhyXI
t6LrUQyEI1Z57H8h7MOuLpSKRWZcvFCGdJVNIglDPag1KFIfDClC9SVHvhjX
fnDQHxGaWSzHo1aft84CQ9gZ/+7QMfFSvD3Af+AWZRiejB0v7J9S4N91ztb8
9CiubVbKLfYsRfjOgI23G8fx3kC7ZJcDBVyREtN7MYmyM9Nhv+/lw3emgV/c
eQozj3NsZSsycDh1TruwdxpLP0eQpBcDmbjblfV7Z7G3feBhrUQ6jDv3OJ19
MgdZ3v9Otb+Mw3m7+Is6NfOo2mckLa6bgrdaL28XbVrECb13mxrVrTAQUPJ2
8OEa3/8TuT7zqGyN75bNp30ecy0jcq9bsPeAGbjXTZ5bNlnTr+wpS70PUWv6
7acbcNXKpyHLlv0r0bpeGKo5v0PQlJbUVBVtFv71GeHRKabm7HRkQEBh/Qm6
JITLXTqRF0dHXJIV6iWbUkE92RCtfZme7NQ2qeTVysPz0pXEgBV6Yq4WR5x4
U6DbvO6EZCQD+eTk1pqQnIn5P9P2h08xEopg8uHG6njUFEloaI4zEqF7xtrW
J0JBW6LwLeQjE6Fr3LGp7lIyrvZPhcUcZiY1H94fCWp9iaLsG1Jco8ykq/Lv
xxs3w3E28bmWtBcLCbduu5Sr4AHaAjVeqgOs5Df/q4v7rr/HeuaRmzz9rP/T
d6uBnV6CExspq4ib1K4MwICR1ugpSXZS3WJ84JtbBNQ/UTFK1rMTMbcVxf7E
DJjs/zjJ/JiDKGcFNfz3NRNaHi23z2yLwbors605NSXgMooND1XIB1WLT+vw
jXJ8+qkWv9ujAvsDD+VYXyvF9yXlFr9T9fDdxKftGlMI0fEwSUPfJgje1NG+
y0pBbMaVB4Pf27E1f8NC9cFKuIrM8mS5dePtfxW2VTHlyGGkUB6QPjwYlBU7
SFuGIflzXBcrB5Dz2Vm1LLwc9iqa7nj4C7R+4p1HFsoR8X3alY51BI4vTV91
ilfCOASMkS5jSKrP9GrlKkGckvy5iz4TeJ7Bc1u1tgAL7cH9J7smsds8ct8W
sQLMjRa+zd0/jQf5g7+PmiXBSvOu8a63M7BKFvpuRB2Fuw2TzvE/ZuHVH+6z
bTATguXSRSkS8yjSEE6lJwHgmftOdlouYBP75xMRNO4ofEvbIFq2xt+ZJzXe
3OJrev3sYhO68c4S6IVcI6VmTUHF3FrxKXf5f+ffst/KebKs6bVI0dZJgp+W
BLp1KDdPBOJUufUjqWxaIis2nJV65AsWHvIzD12jI/VZdHTV1JlI6rLeukRP
TzYpbjbnDE/DByPbLkokPbmdsD7e+FYuqjbrSvw8x0C6H+udKTibhV1zvzh8
/zIQ78X/juy5l4ikwc3evP6MpLO7ftv279+g6ske/vsYE5H/HZfpJhCEdbpf
Lz4aZiJbGFSHn7ckgFdXwOu4FzMxsZebjT8ZitsMdbfWH2VZ1dOi3NfKj7DN
f9h7Y4CFBMvUP9mi5odfSQu//rqzkrCYRNNrB6PxJF/MXW0/G3GvMjhhmR2K
Pb8Xfp5pYCOeT9a7BXwNwny1U2iUPTt5MCbsxX03Bz3V2Tz5YhzE/kFjfrJH
Gtpq336iqecgaZLftz6wj8cFo/nv7/lfQoN2B3uXYTGKl7/I/KhLwVV7xjq+
DArY7x1yfCJfvOoDj+9uXqxGeoRXcqpMDSwqtVPCfAtQk5t6v0PhJyhi9T+v
bqVgZznP/a1eLav5NLu941UllB/oe26I64Q5b37CygAFady75nLf94DWY6Za
mK0KqgbrfV8o9cNnm4DS8fHVvVh3p9q3cBAPUvSvJPmv5pSPBluVHwzj8iub
0o+TJfhldoW/Z3kE6klBdLSx5TjQNGTJ92wcb5yduw62loFP6PWDcd7VvCDp
XFmWt5onHlxZsr06hf/2HVQMlfiOSc1Lb3+lTSPKpyvebFMCPg0467axzuKo
rdpGFdt0PBa3erCoMYdvl6rYF6gTsE0v5lPH13lsebanWvx4AqiVv3CMjS3g
VqjjCmfodRiEFbu1nVrjbV7RJlWt4DX9nnHboT4xsIQfNtZPFHRfIVrrle4F
ssbbH0lDuRkv1/Q7+sihyi9qLf+e4armbbpISyZzklhuHA0Dz98Ap/d/aAnV
6PqTDhtCYcRY93aPHx1p6BI7Vm+QDOEP0kH7j69u2qs4+dKT2RifHmioHqIn
+zxflZ+S/44ddRSeSk8GwrTP4ZD/fAJK/knYqCowEtOQh3xO4kmY0hp/FNHM
SCreipb6mQfjpWi7/T1HJtLrvyxvMvgNMhSJbyUSzOTfw6cVgbJv4R/FfO19
IzPJfvJPiP1VDJzN6KQ3P2chnOOh5SN33fGaXnfLEfE1vs4JdAhRaljJ0yP5
L39wu6HYoeNIuSUbyRifKx7zc4cos8q/JG52Eq8Tf2FsxgcD62sLqXPYyfXg
/G5/gXS8fnul2NWAgxSK3GzeM5CLRz8+PBrZHIH4jIJ80RelMLu1fytVWy6E
qGX1DjwowVBudGvY6XI8JPkT1MHleHV2tI4hug4WD/v6917LxyP79k+qo43w
lPr9IturGH+/OyhfFmxHrnHHuWmDajzIOa24Z383riyK/e5FCbIbWwMch3ux
t9dSpIe6FAak20PabgB331wzcoqpxOHbojVaIr/AXqpwZOBIKXoEDz3qyPgN
mfsO1561ViFpz7FQAaUxPB1TJMXOJVjkan++y3QCp8t1U9fHFmJFk/YWXdok
nsRY27/sK8ZnMzVLfpZpRMtL1HoHZWDbcFWQjtEMPnIeGFBN/II2Vs5NGVGz
8NN4La26nAsZTrPka8tzeDVecVsrOAJ9jRlOyWoLCKLVEtn80gPyDuJP1D+t
8db8ZZUn4+Kafptl9y6OKy/B5YTIX6lbD9D2PdV+g+cyzKju74t7fBvHOCSU
xnvW9FsZxVtiSUNL/qTu286k44NE1jGjoQhactEzlvHNUiSMiqjEmE/SkSie
fT6ujEmwSB4zNZ2kI2Osnec16ZMRx1BfH+lFTzzqd32y88zAwZPH1RkIA9GI
cOdIWcnEn7HY9kODDITHM4Pb80MyHEd03ok4M5KbDoXHf04l4/aWn7UqskyE
zc3+spLdNzxPU5c+2sBErnQX+vfKJ2IIWr76DsxESstC2VfMEUdmH/i+k17L
swlP/2RfqFubzRdYZ5WesJLuj90bbCwDoP9jw/GlLWxEnJmmvl7pFQSZLqfd
zGcjtNSmAf5IwB7rx6k8t9nJ156RLdRUCbA9+rbWj4ODsB9us7whloF/O87e
d8ziIET4dNPFEwl4E80lobXtE9re/Kwh0pU4O+SsdPtYFniLjykzPCuArbe1
7Lv8EuRFuPmd56jBlpUjhZ2mtThmfEROXrMQ4oEnX3F7NGC3iLWH10kKPArL
WtDcir9zOydct1fi1PLKM+H/uiDAG7f5zfFyZFjTnQw53Aujjyk2OtsoOK+1
6NXU1o+iKFuT7rkSZCQXazywHMLTK3WczU9LcL61+ow7329U1Xj1pnRTcEZL
s3PFfxQO5azc9+JK4JIj0dHOOwHdTaHJMb+LwCpPMbO5OYlfaQaXksZyMWl5
Vr48cQpbE6cXy15nwFXoA99n9hn81s/6d0o2AdmPTymVX51FtuHuy7SPv0PH
d9LzW9gc6D2UnWSr4+Dkl8RVtjAPmcNjF3/kREPwulGR//FFDFHFcPJmieK2
Z9m7qeA/8GzI4VdXsoLXVot+6sPLUG3mcAzzN8PjuIunQ96t6bP9vbo6QxMN
oS9Y3uz9xR/P3nYc0n9GS4y5Zz+J5/hBSb9a54woHXEQ+Xr6RFYyfut2rWgU
05GCrdtfNpxLxsBphwzze/TErqu26+qRXGz4zPvuDg8Debgl/aiYZxzedx18
7JjNQIpzuRPdsrOwbS7bca8+I6HREgvZ8yUBMYoGW+dpmchSYJuC44dveGH6
oaEpelWfzgwlArtS8Jrme/AHHWbCZ2vnWLpshbGa3L/vqFmI/MRlPpeoEAjO
/7M+GMlCWKNZW5wO3IOd/T6WHA1WouJ072vQFmNILSzGX19c4+uEiqDdR182
4qBmXjJzRg+RObqtfYfZiY58jpyFcBTidsiqawyykwNTfRpUUjk41t4g+Oot
B5HLt6rbqpmGDZLuMhe94iHAUnjpb0IxknUlpNQ9C2Bnpj3d1VsNneF+p6ym
SjTOP74ma1KIyTCf7l0j9bj/a94r4UQBKnTNk+xONONrg6dk3r5yGKbuj7TS
68BzhpmiOzVlCHrmP3Gsvxuucb49uSlFyFVMmLzp1QeVgyGvt6pW496uUvfn
QoPYrGxq+jmsDLnCTzWlq35BtSYkS+NrJcx1I4Okro2gYrpI4g51Nfh5DtxR
aB2DrcvlawzfimFi/G77s4IJiN0ol2uxzcfU7SMG7oxTuCadnMR5MB2n75Lo
mwbTyH8ROyx0JQ55KUw7mTNm4HBdKONQZTqWPtfPhy/NQmq2TrTlYxyYnEZ+
cOjM42iSRPun29FQ4cn7E+i7gAc6vhdQGoRH9+s+Cmus+f2NgVwteCwhjHqf
8u18J4ifX+GXGFnG4ixVyKu2V/he3K3SIUNLNg5LZv0eDMPAq2UX8zpa0mnS
EKrgFQvXHXsmiyzoiEn+ugtWHcmYZ1luey1IT4ZjeaynzLPwKG/raF82PfEx
vbosp5IOg1lrupA7DETCZ2DiDSUBRstiynMcjGT2Sr6l3bok9PUM+7PGMRLp
fX/puObisI1J9en7K0wk6VKveaRDFBxoaF5GrzCRqNjLb/58iIOKbf87qahV
P7/wsEF2MB4f+KUV311kIU8lx+4G6H3EcfpZBqs/LOSli3vOJU5vGFj0dWSE
sZKPz7+wDtgEwitud4vXSTaym2MpWE3CH6qV3tP7htkI7/Eqzu/ZIcja8cFD
xZOdlGfcMm2WyYHq1bELQ/IcJOLshOEF2SxkPKosffaLgyQczBpoWYqHemVj
QgC/FWhUfk9nrlAgTiP1TeZBMmQMEvf8W/XjREOzTSkfimDQc/TC5V3VOBzR
aNj6vRohDaNc14wK8IdRW0ar5wdWBB9pZp+hoPbU9mbdYy0IqRDIbOqugtSG
9HSXi534zzs240cTBfJPFK+X3OxB/98tgpmp5XA0brx8j6cfI8d17qnFVICX
R2dc7OMgMhxDa9QEy3FDjcEv5vQweNWv17Fvq4C7fMfgpoYRNGqoVprcr8CL
mDeB4+fGYZ3mCVupcvg3HEiroJ5EZeT8Hj5SDN7UANOI41NI8n26t/1SCsoC
mKVtQ6bxzGnHoatPk9Cwju9r18IMdleWvGClzwA15cPYqQNzWCekkbV0OB7s
NVF5IR7zKF+xCxVriMLBA3sNqJsX8LKLQ8/93XMERhaxXpBf83ddn3mLQ2/W
9Ko06PNlZ+0STCS37F+w+A9/Hv80oJVaAV9gaN5Upy62/QqZrDRfy6cWCafH
c4PW8im1HAtbyhlacpRRkt1tdzjKgtZ7hEzQEoOqKqqsb0HIt2Tfe8edjrTO
D8loq6Qiqr9pk4QSPZHMXgnkcE1f1eOVoaF2elKw10er/ON3uFdF/v3kwkBk
FHveNWgnQfb50YenZRhJW5qqxoameFD71LE1VDGSU1edaM7FhKBQY9ew9hMm
EsYtam+lE4ONaUejfwoxE/E6qmwTqnD8J3bNuq6CmRwST/Ya2Z2I4MriTXyP
WAi1p1856y9PnJEYCrvOv8bPX+KNjwKLWQk7l+S24I3+yOTgSGw0YSOSMy9q
rHndkXv1EOMvRnayZCbJE5f1CYnqiiHjSezE67WDVOrxDAhmZcWdvsBBOARL
eBoic8E6a2Gf6R8GEcnvgjI9ZRAeeWwYLZ2LxP6nJ38kUuCW0mneHVmGY7U9
m9mtK2Bmp1x96FodUj6abLW1LEAI5dGlTK9GbLsV7Lc9lYIgeIR7lLfh0dUz
wWlB1Rhht1E3Ze5GzXnlP3JlJTiEAUa3nF4wMAeem1YqxWeVrzp85wYQ/LhP
vD2iEkJ2LBMtM0P4KrWjL6WVAvuK7tGT73/jcyPf/c+bqnH5D+W+Ds8YDP6W
ShUFUCC8Esvvd2ECvXVPNDFbiOfMyZE9IZNg/vTW27i5CFZxLr3HZqegb80m
7HkgAVTyDhg8M4MRhVuuznlfwCPx2SDbZxZueu/0HnvlIi3hrXT84Bz27JFr
YdkfgwrV9AibfQvw7DnFdj/xM8wfJVXqOa/l0xjnSp4XvWv6fUCzXqxNZgkj
No7FzFd1ULZxW7Om/TL+fO0/O6XsgffyVsS/as3/tQZ6h7wXaMgZ6QMs+oUB
MJbecaX4My3JiDg1uqUtGpvuWu0SIKt+fzXWKcIxATWbd3KFDdAR34juU9nO
8Th86elpf1d60jamc5OpPAWWehlXRfYxEP86X26mqAzo/35fyNHOQIR02fR2
J6Zj7J7Zm61PGclUxd0Ua9F0PLmZZmyxlYnk9NvuNUmOQ35/gLdEBRPJdz/J
ZTaSghrZu/6m1szky3oPnvvXXkPqbmlCrehaHq1oy4zSLFmb5TZ521wzZyVp
3zM2egu6QrudPejnRjbCt5K6tynTHOt9XktapbER2UiZPccsolBDscxV1WMn
CvzctcJ2kVCzm491puMgSRt7n48OZMH9QuK14/EcZEFy0y9N0wSkjFXsG9/8
EQVKisdT/itH7ChHeuFQBhT65XQ/thRAxO1rUfnmEmSleVwh+2vAIOmdu0G4
FptEtobr2BVAY6j/qJNSA0777DqdU14MxePt5LFzK1SZhGpY66qQd2rnh0tX
unClnseEu2+1v7dzJEdy9yJ4v+eX+vPFeH8u50JBUj/05h+E9YyV4GNJrNm/
40NQXN+lem2lBFOvrQqXxofx4lhimhCFglm++mh561EkbhLkCnUoQVzkXyu1
dRPIXm+3WMpUhLcTD+MvaE9C9Ljqu/DoXBQnfgifD5jCziKHo+z/0nHj9rGU
3YvT2Mzs5c7jnIC5D60vq1Vn4TQ8xfn3RTralbjY/7nPQeOX8CH7Z9G4x5q4
723fPF5SXUhXTE7E+UszG+NlF5F0Rr/TfP8thH8s5TR1W9PrS/vOw4clliH1
Iri66pA2ipu+aGnarenzegXfXalKGqJxoDD8nclH7I3btPfwQ1rC6T7SL2jj
gyn6o9f1+OgIdbTfHzrfZJwsFQxxzqQjqZLexlxMabD6vHOvgRE9ud6+dba1
Nwenkl4Hv2RiIEHSzRxnGeOw0CasfyGJgbiXqfI9s/6ON4+anyueZyRpFqUz
b4TjkWN/LEPsDyMpmprg6TsTjkLfAZIdwkSSd/FPPihMxv2Zxi9BaszE8OTJ
sW2LFmg5wc1TN89Mtu3wfj6jFA75c3mGewNZSB1zoIoDcQEJynHvVGEl5Tqb
qsJsXSG8bpr14PgaXwfqT42FurMR+vAPjwcVXaHKdbGPby87eTg7/329yjc8
NfKRVGpf5eldj43GXVloYFJgOPlyNQ8w7mW7fy4deukr8Tk6cdgbWFkV1EaB
Ufed2wsD+bB4GqK94l2Fxc6NgvP7KpEyuOi6cKYYjbWj7Tf86/HtkkYk75sC
zIexmE1MNOGcst+GLe2lYFJU44xh74CJ74/ZSbVy8NaWUD9L70bCTn3njU6l
q8+TddXsTh8MyVCJWEklvsm91TKdHYCJxTeegOEyBO6+aZ4S/Av7cjcP/RCo
BCu7xsaPe0cQFpRfnTlYgdzWLEWLxDGIHuO65eNcDFcto+yR6Am08E/lZO4r
gLX4VIjpzCQejX+UyaXOhWj0c+EPp6ZhQBsb/d+9ePjSZJb4f5nBWbiky6zy
aG+mAYkemoW0uGlcm2wS3kuwnTY8PI/9EufvvaAEQcoxR8jYaQFRB6Me113x
RsrDWr6Pimt+T50e8GSn/RIYL2gbRH8zBFfc3fuGDct4ey7c95P6Yxyhir1B
I05LNNKPPDyT+QUfIxWfnymhJUn7N1b+lY2Bcm3ocsNNOnLRMCXutGQazj9Q
fFawnp6czCloy7idCXruWuOGJHqy57ilCp16JnyYh3mz9BmIScXnuT2a6Shb
pJcsoVv17y2nnVrdE3HqBp3v+jBGMu7kcf7M5q+Q19jJnaPJRIYO/0iQbglF
ruy5sfczTIS1qf4aPyUe0qZUHxSDmMmIqkux6GIM7N3ttWpPsxDtrXodlDuf
cN0oZfbuBAvpFTx/QW5dILZ53DNq9WMlTR9DtTzWhcI5fcc+c8JGGNxt/+vJ
CcKhqyVGyl1sRG5FfZeTejAu27n5P3rNTmL3FynU1Gdjg9f5/T+lOcihVk0O
98eZUA+VSVLu4CAntp+3zvaMB2PP8+Dz295glTif/nCW4NaCUMLjXWmovpHr
vH9XMW4/YpkgLcU4L2nT5+NVg/qnR9KfPa3B1XkO1eiIAoQ+Eky/8/YnJHx+
uzkxF8NRjZptZKAF6SWOb5v1KxD1+0VaNU0Xzu97d/D2nhIoRIm7pH/vWf1+
fxhPXi8Fq656s49RP9iSOelSf1biwtiz2PUTgzgXXLih2rcUUsPfY39+GkaR
/wmjVAEKlMObTkZsHQV7vye15M8yTK47euxI1Di6DSgsu/jK4GnYvJdr5yQ8
O3s6eGaKcW8fv4um5RR2BOsuSWhng482fPJ81TTCFm5cfn4wGsblixuaRGax
nP5eeJI2HRPPtFdCb8xh6ZajCNPzBBwei33CnzUPHcMOC8GwJJSo8Xxvpl1E
9ZnKlBVXfejLZU0mLS1ho7LjGeHtTtCXPHQ5UmeNj7eQGP0glYac1soaPp/9
En6T70X+GNASLuMR+lOGIdDV2WHzjJaOvFR4G5UsEgf6T56/F0PpiHj9+mTx
ghS4Kz/ffkyTnvQd+HJteiUPaR2WRSnT9KQh29dm+5VMFP7sk/77mYGcYHz1
egN9CvTt2O2OKjOSKixEb9iVhG4W1j7bPkbSZXtWSPV2MFRmX2949ZaJxP+x
jjIOj8exBraITDlmUvQ+p0Rs4RXi9qWpnO1hJsQibbza6StM16tgmysLses8
ISIU4A5KX72fyC5WwpkqWFPqZwNa7v780RZWovm68mjL9QeomYyuybZlIzcu
Nb16uurDL1NPzjkIs5Oomzltv7KDwddkMrChlJ1MgYfhwLF0LBr8aS035SAO
wfSV5EQ2+hJTLYRCvqGUrUvDi70UuQNTA2df50HbMU3EyrwUR8ufHL87UY6n
bCYhO+6VI2S7T0PtUh3M1PYhbqYAp+WV+34ebULdq93Rf2YKcU7pXpuIaTu0
VG5ySwhUY535lu3z17ux62P6r203S3HYvHbP0w19oBcKbhFXK8FWJYF65dAB
pAaEyh3yqIDuBcW4EvVfkEUEw/moMhw39aG27P2NS5cEhw9pV4HtTn5Dj+EY
mIJKOJWtS/FjO/NIwfMJuJ0IuMavXYgn3trbJSomMfPjx6de1mKUyTCsGxWZ
XtW/4uBRp1ScDhCizX88g/ubPnXW+ofiy6RDbXLuLDJtFbQu3MpDqOmZQ8zc
8xDv8/d/6PgFS8ZZhhPXFjCWfoXKT/4N9jhU875h/3/6kO6FapoLS2inbRfQ
kLfHmKHatpbItd+b1O6rfT3NTksiN1r8/nTOH1Qj8feYk2hJef5G0RMKwYgR
duNd1KYji0mOfpyiaeBSTyjdu0RHjLfvElA3TIFoyvbL6YH0ZLCygO7xljzQ
7qtTHDvJQAaWnY8Jl2bhw1TF3J1JBpJT9eIMU0IiBG8f+CDwnpGUNEwIdBgl
4FLrpBLfQSYifu7pz0aZMCi7LOZf62IiDDvUogT6E/DvzH4fbRdmwsA6bszO
8BHnn4o/11JgISlh/3FYhDrAW0SxVreNhUQ5qPzMmHiOqIbnZoJOrMQt06RO
/MBX3CsX/C0qxUYcBTZ7vBIJxHYbyRNXKtgI1QtNR/v93/BB1CGmy4qdDAw8
ia0tz0As0/bpGH4OIuBVpeW9JQ33ViacCykcZOI9J9+2P6t+tV/K7ZJXEPbQ
6FLZl1VgtmddLkfwdzBenJZ1Ny5CY9BRv/M3SnEk/GqP3EI1DtaPUCK+16J5
nOGuqnQxFi/EVgX+asCpfi7REE0KRpXTrOh3tOFs1ryY16tyNETXmfUmdEFr
jr/7xKsyHGT/2+F3qxds+zSOBKqUgP+0XMMo7QDM6hujl/zK0Brcvms0YAgf
dasuHemmIH3nzmaxI78xfiONVlOmFOGvKjmLC0dBkcmgH/hRAuMf505YSk2g
wWy45I1jMZzteGUCnkxCmy7sLMvufAju4Sz+VDoFu8QDwqkRiUio6bFhFZ9B
XNPNNqEtcXDS/T5dbD6LJfqtevcTc1E2XyN0MWsOSscHKJPyCfi0I2Wclm0B
2wQzB/5Ih6PX5Iel89W1/iP1rpzrUdofZExeUgrgcUR4ObUrRXsZFbrh7bl0
r1b36OmOnh4aIrU4rtw/FoSqe8EnnrvQkj8vrtlsfRYMp/Qrqoek6MiZwP6M
72cS4ToTcnljLR05eXj5iY1FJC4u/SD2j+jJDA3PtpKlXHS8CrY/u5mB/BQc
y71dFQ+pvovvE0sYiLmiNmXjtSxk3//ivOs2I4nP3h4xXZmEgOmn7mUcTEQw
gX3G4WwslIny3elUJsLxzJt36lAagrmCA//TYybJOtIaIk2+oLl8r1eLjYUc
NGN+HdvvB+qPh52Vk9b6Tca1b46fLrOSa1GjLl/1dkNxnOqCMw3b/87/Jv9m
cfvCRjgUer03mXuC1fRGXZwaO0mj9WhesvyK3gnKXYNJdvK+8FvEweJcJMVZ
7ynx5SCBuQ94m+RSUe6z5dtEYwLoDth5B+6hgL6tbzTgaCG2tx3xnUiuXmVg
4uSzJ1VooFQEbJAoAIvt0f7Fgz+gYNR9l163CMG8PxeZPzWjUm/6bP7jCnzf
J65yMK4DX63sv1FblUFqj3kH8/oePJe6r3+6qRhH6r466ef1oTlM2bnweTX2
7KSp8T42iJMKx7s/DpSt+oun7JfFXwhQHqS2/F2J+hg6qVzHEVw229xWQ1MD
y1Op/v+oxxFDreCqz0SBypNs9w3NE+iyHvG//Csf9+LdRRIFp/AvPeAWY3sS
Hu1cOXjw0TR8+A4cfcObhKFbF90eVs/gc4iCkK96LgpfqsR+4ZwDB7sLb5nh
Nzj0ll/NujWP8WN87HPqMbgakt/YGrOAQqmBG9trAlHC3bdd++sSDvHoNx0R
e4/9S29zR9atYEh67OqNCgcouvGIpyvSEo901bvMGV+x51ae5/s2WiI2KiBc
IB2JhhfZfUlP6EiHnPare4Op8AnKVTi7nZ4Y0PAP3u3OwrCZzf3pEnpy+I4l
tRNfOqS61s28erDaX/jNPZQuxGOF6sgV8U2M5OgUz06PfYmw1a/5zJDBSDj3
qhbp2CSBt8Do1w1jJmJtKxjrzBIL0hDHX8LITGxp6+S57ONxxaXs7eZUZpJ0
mu03z9tEhAe3iGgZshDegyuqfnY+kAqX2/SElpXYJTw82X3aFZ81Ll/yjWcl
/LQueZZSYQj5qmD/XYeNPB755S1k6oWzh28+l5xhI8v3Xuc20YRAuMn3NWcg
O1n5cZbVXzIXNqJOj/8e4SBXUy+Wpd7KgMSpu525MxzkewidVrxFKuQ++/gn
8huhvbd8QLKiBHWOZr9aKUnwqWc0nHpessoLxhvaR4vwbt+LAzRnqyH+Q0p/
/b1qvI5q47CTLgBndKALc+oP7DDlubFzFwVf3GRd/wq2QEb+osxJ+yoEG/WX
F0t1onKRtvuNawnmYrJ5T53twXGnCmoZUoYvJgcyDan6wZ0gQXPJrhJOAar2
Ji8GIXvq6sryhnLsDWr+aaQ4DPVCftcx60oY+m3WkM8fwaSS6vEV0crVfntd
/goZh9zNqw8tacqgK8d9KXNhAip3YvsP/yuEQ+PhsJyDqzzkq1jodUmEvErv
kyKfaVwQP6RSIZIMy7d65T1jM2i+VH3v8bFMnOALjXywaw6HC7Zuer8+Ds8Z
pbSdXs2D0445gvNvOC7ut3VhrVpAsQDlXkroK+RKHTv1QWqtX0etG3CSe7nm
33t5NLXUipcw6JM/t/fKK4i8+dvXsmUFt+6HvF5nYYIzL9a9bjReu8+U00iy
1/Zfu8+8elSSMVSNlvia/OD/KBYOcWt1/qjftMS4eXfcev8QTH2VcmJwoSPp
W/9+DLBLw/03MY0i8vREJ9Ocl8s8A3ncGyysm+jJirhmPMvWLOSfEhz/z4mB
GB7kzppelwyjgppZDUlG8uFo/HBbfByYD6pcvFvKSBS+CPiJJX6FkfHFz8cf
MBEZqcwatsRYuMpqyVzlYyZZyWnPVNjisKTr9MySwkwyy0cshy4kIs726zue
+yzE7KZXueBXH8gqRv+a5F7Vb0GT+2+1wzCI0N7mlsdKhl5Q9elLB2P/ha+/
2w3ZyNyerE6dMXew02ewvqBhJxty9jxWXd13XxNTroFYdvLXQ3GXgHQWjM6O
bo3R4iCNf3xndZ9k47xjF7XYlVBc7EovTXxXjuHL8nSM0TnYEn3qVb8eBfrx
jzKfXioDne+byG2r+urhMq28uK8Otafv1NRQCpF2pzjF6k4jShYl95/wocDK
wf+KbEgbzJLSqOP8qhC23/3H65ku/Irf4v2AqxRLlneyOSN7MaZvXsa0tRTZ
x5mT2Y4MoPbR+HX64Qq40lM5bO4cAl7M/bNspOCMeJLEuqe/YdbU4HHkTRVk
dJlazanGoMh43NDtNwVx9/n7a05N4Ibnsx3ZB4ugctNNvfbjJGo9/UMatYvQ
USMleHV4CgOdbV8MPb/hbvvFN7IqM3gTTTHJz/qKuOQBp9w3s7il9qAzNSAX
SzSBv1ra5nBU6X4OG3ccyDOFg9d2LqDEpP/Zm/5guFktzd2yW/PzKubTOrlN
f7DYbmMr8fk6Cu/+k68TX/t/ab5Ku+M9q2XsVV/3uEbJD2nqvvmWhWt9iPvF
ycc7pmmI+Ee330kXgpB7SPV8si8tYQ38uGu2PxLWiEkWO0hH9qdePWO+czUP
6qgZKXfTkYWRk3K2/6JAS63D7PkfPeHy7Jxg5MwA222r/qhdDMR0UOfctaE0
eNyiTVtoZCDB+Skv7fMzIRq3xCrxmJG4l+LM7c/peMm8I55BhIkoWAsoVMom
wGCp+JQAhYk8MGGrTCpOg0rEY6EZM2bS4LvzniOfN4K/TmVbCLGQO2Mmj5Ov
6qPFxV/sdMGa3/PsvPp99DYrCd+o/HPZ9TEqrrucyediIyV8p+VnF4zg2ilq
YJPIRr4tN0mr3w7HZovxwp5L7OSihNXprLqvkPXdudmeioP0Lsm27k7NRvNo
b13YNw7yWm1j5AfORJzkiFTK9vdCKvdvqsmkVV6Za89bHMhA8ynWKxMihZj6
j3DeqqJAXNFau1avBjbZedmyczUoF3k1yfemAEauckFY3wD2Md/dferFYP1v
YHqDfitmavK9yekq2FodEXp4rAscfvv/VN8qxx9Oz9syKz3IOiX96NpyEeIu
iKalBfYjd6X1+p3VfMB49su/o7uHINetcFRr/Wo/6zn+L6F1GE8OR3j0xlJQ
YsuzQef6KNyUOD5vmCvBS1LmsDIyjk+8u9t+ShZD87Tm2eNqk8hmPRgt6pYL
2R/7utk8prDzzImhXenpqOMUpnsyNo3gA8cvzrfG4b2oWETt4VlUj7l/yTuQ
DtE3omUSTnNgjVksTZyNQY/KHopFyzwOThbbd29OgeU5pSOZWxfh/uKYRl+A
JSgCapqRz9d4+yTK6/cVoWXYnj+Zsv+aEkZGyuq33V/Tp9gt+6VsCg1J7nr1
MGXZG29yFXZJW9IS813NzwN2++N0i+3gTW46YtX3yzGsOgmPVw7MiqfQkaDx
QcFPE6k4qLpu8rIePRkLXDZ8HpSLwWyVnetpGYhzporEXY5E7Lzirk1iGYiV
Rm/Zn5rvyE83XqekxUiuu3AzKATGoUQ0lTZjhpG0G5uPsaSEwSieYy7uExO5
RhPsKP42GUN3+7dKqDCTkbTUtL1NdtB8oSRiOcVMDtgKmcU1hkOFNrhF1o+F
lB1qLEp1fQ/RhJf1ZmAl0Q2CVIZ/PeDjaJaxfXjtPlNfoH9blAsbkX13qFFs
1hPemT+GEmTYiZjJLtsOk0gYPavw2dPETvKWSsK3lmVic6CJbeRTDmLTM2xh
9zQDjDR3BwduxiL39lkma4sSZAa7MVW/zYeC1CfvmZUKVLTEGX/oq8BMgcA2
+QYKTt7ka3OwqodYRuJTLeFCsKpfqogoakLSj4dJxVYlaHt8tuDkQDuOy8zO
dSlXoHahw+VTSDcO/FJuzTctB9XPI1zT5/qw4MH6YNdAOcr2TcUbdA/gHaNv
TKJaOTgzr1D9df2FSdWeMvlPFWi5seWshsgIRDbxXopzq4AHVgLdPo/hDuvg
v/TTFAhTKl+Jhkxg+b7mhJ57AfY/K1O5OjyJ7kMb1pGYPLhWil2IPDKNu4bl
Ff1jCWCI9Ng48HEGt2zOdi1eiUWNaqRRbMcsumldvqxjTUPjYyEmN7l5DBc2
m/7+7Y3A74djVW0XwEo3pGtL3uHnoubFBpk1v9cUdXXfYr2E2TPDlEHzK2Bq
FxN5Vr4MK9a0w9vrjEETsGHOU5iWPBLjbOduCMZUxgW7QwW0xCqKquiSYgQC
vnS+6DSgI7ycHZfZvdLh+O1CvR4rPdljaxF2gykDlZlhYtWx9OTFz5Pav9iz
Ibfhy2fVKwykM7WsznNjFpYePhKMp2IkIy+43F9fTIRD2Hs+niBGwrB06lPb
/q8gU/7Xzqkzkdr4Cu1xp2Don3ga4jjORJTuuhdJ6CcguJ9tQ64fM/E36rw2
vCUSM+Xh1yxUWcj3WheXsUeBuMftfffWbxZiWbcvP48vGIxf5L7e8WIlHSFR
eo+EI0B9+GvP1YNshD/W7OaOnBCkhegHqLayEZ2W19nD74IQvo05iMuRnfhy
WQ5Obs7BUsLr0HIJDkIjyfMrmD4DHw7qSYY0cZCNQiFKsgbxkBU7FDez+RW0
6OM4f0tSwPfk+sS2Z6koaWY+oMlGgdL9Lwc6nItxw/DK6Q9qNTjOczfV/3wN
jHt2/5MMLkCG4G3erUY/sXitM37SuxgXX7PkOme3oGk/53h3ewUqt+190dLa
CRN/mV2b5yhY6Iwgh8J7cPGmkYBzajl26McovtHsR/2oZ+BTg0oUP3yA8y2D
MIl6n5YnUIY/R9yHXV4Pw1KC4ZjeBQp4WTclFK0fxQvjqqDaU+XgHd3QFuU1
juTZ7Q+SH5fhfG78T6otk9gY3mITsb8UTecyCoxvTkFUYOOnsyy5eBnpQAIL
pvGh7JUZ39U4UF86cqCFdxYV9UzdevLp2FtvmFF9eQ613RHeDsoJSNi2i20p
fh4bbQQ+8JUlov/Y1YHexQVMXHvd4SesjAv69z/VTS7hdcjmTxd1XsPpkGGb
w8k1Pu5s4z/MlEBDRthu54fbWWBmXbzAr2u0ZJuH5quL9V+Qvt2I6vU/WkK7
y6fW+lsk9tUnHvIKpCPLzZuW/3Kl4MLvC32H1OlJC7KXdr7Phc4vqTNHx+jJ
hCSX2AG1LMxrn9/S58tABErpe47LJOJDtt/fY4cYSTIfh132yWQMx9jJcHcy
EteIiZ05tUHoY0kqe/KaiYiWWpVs8o9FxhmBHcoyzETke2JQxEZXbLPo1pxq
YybZG056hftFwiZXPEX0PxbiIvGX3vvTG4TP+nTESbKS3L5iBZEDarDzvm7e
8pOVaL/QqdcXfQl1xeNMRQ/ZyNsvN8NT2j+gXp/yZxM/OzGz9ijxefkJ/2b8
z7EWspMdFnes7simQ3lxh5aUCQcZU5j9/Is2FzIq22ZfXo+EzM2fr55Jl4Iv
nMdJUi4PaUdncGG6BLzFPO+YPpfj77YNZbzOq9//9/wfIz/qYN7l+n5qtb8b
tL498pavCfuvvPFpKyqChN3Dt99V2uH8MziJDdXI8paP4znVDXpRWRHtoyVY
CTk/tI6qD0IOr+1owkqgcvipnMK7AbB7ravoFqlEVZc0Ydv/C6zNL4yTF0rB
U3T7kET1b8ySpLNTmVXoqqI5/E9jDHknnknQ/iuBccD91MWHE3hxomb4j0sh
lGZ2lvDmTyIpxeQ+920K9mqEK9LwTiMnXbZtlDsdGUfnzrKYzcBlw4gBm0Qo
iH3JbGrKLHYaX8/RWH3u4WzdRTnGefyr5JezuvgV5p8PztZpL6DMeVghR8MN
WtQa58tp1vj4mnKsb/HUEhwzOzcrc9mj352qfv7z2n0mC2ecfBcjLam7qc30
Q8cXl5eqby3G0JKQb4aet33DwDRV7L9Og47UGbV/PLMhBcoONQK1c3TkwCaG
9MqkZPzSXeZN8KMn8amtP+TvZiMQrvk2xxhI2gcXN9bwLFDMDw/rjDAQjfR1
P2fqE6H5jcIl7MZI1C9PsNNdSYLBU8P/YvYxkU6mGz22aeHoCRJ9pNnKRGwy
1dhMhhNgRTnK3+LITBZauAtNK96hIv30m8k9a/nxSzW/6pVGFuLApHjk7r8j
eDN4IiHKgZWgMGosbjEYgxoffTi2sxH2js7/ss28EJyXZ3+dwkYO0Js/m1iO
RW/5UoKNGTspNkoa+nUjBV7brhiE8nCQv7fOGTwVTUfKhy0r4vkc5IbPQPXV
vQl4WuzLmacTiANJzU9khCrx5caxlazpLHC+9U8vv1+ISP+2/mnuUkyuXDue
RleDGJONxYWeteD49qU653AR2JeWdl7ObkA2dWGL/6p/5r7I2x6yrg0/TOWo
Tp+twLufQwtUAV2wTbV7Uj7/f3jn8GGzTi/2DVLr2iRToKDhtb93oh+byQ4W
s9JSnJSqy9ntPAS2a5r72GRL4PximbtF6jesvBgf04xT8GSU/VFP3CiGxBw9
zpaUYEEthyt8ywQihNO5g64W42TLWJWLxSR8Twb9fiSeB6ez8StJ2VMQsf9T
NciVhs0PM0vP8c+gUpDrXrJEPERHaPlKjWdxObBmxfl+DjjUupufxc9BUlTw
j0lDPLgM9z0bpF6AQusKo82PCFDdEPR/r7XWf9S51c8mR/9BXLiStPRle3xe
SFfoV11GVP3u4UchDyEw15dh1U5DLpg+vOUjEggJ+1xlCydasp5hpO+KbCC6
XT2rjm2nIzf1j7987piELMn8qMRyOsLTw9WtdiIem0Mjlx/epyeKU5YvuD7n
wubDVcZOfoZVvpUXOmyMh55BmaN/AQM5LPu4PMUiC1NJuxn23GAk4UTThvZm
IsK8Jlr0mZnIeyoh/3MHotFz/s6WgQQm8gLr7d7tTgWvS+wW9svMpP3S8Yul
LO545Ok9PsnAQki9kuF5oyBwqG7+dzh2TZ/+98xLZM6xkkZ20iRkpIiE+3a0
1itr+fHB8gsVj89sxP/w7T6mG//hCm9Pw0kVdkIvHEGfWhKBMral1osj7GRQ
uHpISGa1bx4P+yrhyUG0voUvFLakYqKr6a64fAKaHyi93h1WDN0AejerkQLU
hZYVD1VU4/n4KaXNO6rQqBeyLFpSgKfr7/Xy8PzAz7CRZ21nC5GaIXqh0LIZ
O5bHahcbyuH+QHq+8b8O8GSnK8gHl2HgktNNib/d8Hzl36DUUQQqemmlvm99
YJ+0ZLK+UQ1NaWNZt92D2Pv90lf/4jJoer7KHer9Ba2m/m1so5UIpm8yfmAx
ArOqkNvdDKt5IW6BRnB8DLwnSmfkWorRMLH9qnrVBM5s4GTbpJIPWfZbeUFc
U8j5Yd3V9DMZPeqfrbRMp7Gxaoa3QSEBOpy723ILZ3DT0vhA0fh36HO51ofR
z2GvLZ9MjnoMCve28Q3ozoP1WpS3hnMcalqP3Mr+soDT+m3CR5S/gNeuTkkt
YAmhfHSpkjFvIS15wpR5fhkT7+btH+o44q/kkyT1vbTkp5Yiz1/Nr3B93On+
rJGWrNu52L3cHYXdFxZuf39AR8Se7DCf7ElBSUPH67Et9ORbM2/MrogsxPNp
yo4U0JM7dwf/XZVJB2U405bXgoH4bZJqcayIxW77hDNsGxiJk4MJxw/+JMQF
XRNmTmYkjGPa909EJELYuEFuSZ+JzG6zPKLWF42ukeaqDBpmMvi1RflK9+rz
0DRxhsUzk4qz+V2imQkQ7qCRnrzGQrrofipS93pD8QLPu4f/WMhEIrWqtvd7
OOhv9t8RxUp4CzbejNIOgaBUslSkBhsRWrEMSDz5EZWO/zJ2jbOROMcZ03cu
ITB9tvFtpC87MUxgKGDMy8F1ZAxNKq3mRUdxb4bTmbDo8dfZMs5BLJUd/LEj
CUsnDb2vb3sKyS/M687spsDaYejuM/EUFE1co2ZdpqDLpKGab6AIdLEHD/Pq
VUMKeYl19DV4kmZtKuZRgH4julpvtp+oq2g9qHWPghUW4W35pi3QO2Za0bqv
CqlFrl81X3bikfu5/R2NFDw6kfRNxa4HLywe7lPdVQljI6s/jyT6oasX2Mhm
W4Gw13p6nTGDeJErsxImVA6vyb36C9eHoTw8evqHSxmy6v0dVn6NgIfa+tb+
9RXQLchkenlnHMYCv07mK5Wj5bHBxg7WSZwfhsOkAwVRXkt7PbSmIDzUtv9I
Xjp053d37ImZRqGx/ExxUyIOWNU876CeRYb4q9MSq+fZ1i/3iB2bg1PtlKNZ
QTx8vaVl8wLmcTR3QdPvYhyED48oLPQu4MXJ+E8//jzAsYzueba2JQifLb/I
Z+KMHzdiu6T3ryA7gbGtMFMN4aKj6ynatCRrhO+NReLX1T1qZPWbpSXP/2sM
rnjwGR6HJrqrPOlIQWlDASNLCvqVaHR3HaEnzh591gcsMvF6JVDvai89saFa
Z6W3NRvXNBUZU9wZiKB8/M300EQskZSFk3KMRFymK/H0SgL+zOgX4AcjYX2g
Y/yIIwTiivT7rjswEeG/ztKts1EIxn4pDTFm8slCZNK94jO4huRu7aljJp3m
LXWKB+PhKTwQImDHQpjzA8uXdnjg7kYxo1rhNd6ZB14uTyxnJacEtV4+/+EB
UvLAptaUjaTc9n4ubfcGFom5NBrs7OS8wei+6iY/VMjQ7V1MZycf6vk1qujT
Ub/V9eDo1VX9MTZz2VLykG9Es6Td8RVDFrlm4XvKULzjYmHDy1wcE45nKWAo
QUbm8W0qS2WYuWS2cTyzHEuDG2tFHevg13/DZrtQPt6I7Vxal9+ImeUTZoE3
KahaeTU7N92G+Xn++SanauweNMzXEOnGBonEKRbHEjxlua7N9LMXIonVXW06
pXBQVpkRvTWAMqf0pR1KVYiZ5tX3Yv4FzvRRgY0uJYiz4kj8EPYbN0NPmXD+
rcJ/Xk6sChJj2O85dcGZqwSuzsfP3DCYAK/G6AuJukLkRrcxzURPQjnsucus
bjGY3Ycjd1FNo9Im6tajyJT/j4nzjsfyfd94Ze9oyciohKRFqeS4SkklSUuK
TxQhIYSoJIWWlTLK3iPjsffee2Qle6/srX6+f/X78/rjfp7nfl3ndRzv47zP
+8En59AJ71sziGNy0H0tEwQLr5syGQGzYDoW/5UU58BEw/qx/dQc2je+DBAf
jYTKxuOcHljA1+mqraVfPeFEq/jj7Pi/fo6wlyBrv9QKBENzo/a/fIj6YQOx
w+9WQU/vdkvY1Q5O55+r0PyhIteEb+FGiweYeZnvNgVRExbrZas49RhkexwP
5zhLQy5v2JDd3UGB3zBzDsMoDfH/mzRTdzMB5rFhzoEutMTst+2D/KwkNF5b
1/DpOB3pz/zs8t/1dOx7JFAr1E1HPBfvHesJTEbavm62nbb05HWIx4vgd8kw
LpDj+SnKQD5EZWjQmkZDsNq0W7KWgbCm2t8U4UjEnRR17gFLRhIWNzJ1L1UP
SQf8Qg4K//PfVhXX6UEeFlJpWFopuWyGL0pTE48yWYjq3tNf+aRjYbNjLj36
PivhZKRcs9nzHZp384krIxsR5Lhnq7ArHfK5rwb7ktgIV1B85zVVCgSrfovz
B35FjZb9eyvVCqx7WGG5zT0dX57f1jjtlg9FV1Yr8cclcL2WOTHDWQO3T/p5
S2drocOXq+6sn4/jZzz6Kx40IvCkkILzuWJo0zR8bIv9CcGXuzorVipBu3sL
k/TjTmSYducrfS6H6dU785UlfdDbXl14dVcJRJHekXZnEOO3ro0GVZZg1+GA
t3LUIxBh2q2o11AMwUQXOe63Y+AycXN961GCHZKu4ZuYJ7Bpq8vNDMtCVH3y
3airNgl76+tPxKtycOfTtGFX2BT2Sqf5jJ5Jw0K+/oNBqhkIBGu79B6Nhyqd
291K5VkI7nFNtH6RDo+R9co/vs7hM13drgmnGCzVHw6KGp9HFdvAlMuFOBxT
ixoPObGIfPGH5JCmKt5uu1C732MJM/R2zHXSmvioLOzKf3gVRh+N5oq878N3
P+WnZx0VGfr0p0W/3gutvitSl59Rk3BODlMXXne4H2b4eYOXhjg/uWSodT8J
XG5/lEZzaEjpPblYO4EUfJ+7bq6rS0tee2s8UyzORmx4zfYFVjpS+TQkr5Aj
FoXq3/UNUulI5NloLTquTKgeVaA+epueqGnMld/tikNSW73hx7/0JK20PyRh
Mhy7Xme+Lw9jICx3nO+ULibij1XZTu7LjETb0MTpvo4K7jMP0x1aZSTiLE8r
s2eCIRrSOXo0mImwebmsOj+wgbrz0qXLF5iJ9MrSV/sNNnj4ISHR9zMLCda4
85Z101Ms6vzseHGMlZS/yvl7hi8K7ufup53tZiU9IXurCpYz4WhC5zr0lo1s
aSFRdoUpOP743MT72ViE/pB3q1qrF2b+C+UCMvkQOdbG17JUDaG+F7W37CvR
7KSUeZK+EPel8zsuFNRDYnH4x8/VPHRvyGI/ytOCPbHSNg5uZTiyADX2o+34
rSR+1e9PGe6EU57eq+7CZoPnkvo+xXj56GjoyMteWL6pZ2oUrcaHg2KT5gwD
QGuGpd2afx4IM+58nDIEmRINZVeNSsgkPWvrlh9F6oUzzzbNVmLU3KruWvE4
uqtHClutirD0c2kqKWUC1tntixda8pBQvJ3K+s8klt/MOMj7ZSDlQ1ff85vT
iL6wm/dqWwzE1bqfXo2ZgZdSw7GkiER47OPmiZyaBaI8oxtYKFBsWnE+dn4e
rwyyd7N7hiJFgXywdV6AgrGRm7C5NxIux2hLvl2BQkup1/XvVuC2TSw627UK
Y+Wlss3utrC+J//DSISaqL7iut/2IgTEi9v+v0pqol7fknBsdxwGVh+aV+nT
kK9JjrQfM5IgdIp7/55ttETEjkM6USoD0FsO/5VKSwoNapcYVVOx+ne/435t
OiJ/KH+6c81/3a0+S3Yw0hO/LPtnYqXx4Nxlwc0WSU+CFs4cTH0TBfGo1BLh
GwxkXcVPdv194eDnEjvmt8hA2mS3zTGIxyFlZoojPoSRxN4Rq5DZFAfG6zfO
HrzKRMRCQ4IpfV9xLfHHC6NZprWztePo3bdfceZVuMBFf2ZS5+QjG93rBzbJ
aHvbsyxEsIvjsqSNL/I2HxCT7mMhHIIsfgI0gWBq2OjR7sRKDuWXb4v4lgXx
p4LF7YfYiPnHj5LPRzOwge2PTHcPG7E4yBCtUBqHtCetJhW/UvBj8kkTz5VC
eDw3Dg7cW4zZY1Ky05Qa3B3amq4dUoN9glde+8fkw7mh6jYl7Qdu1M3rcj8v
BIV+8dZltp+o4PcaWKauxGT+o/2U7Z1wjuK16jpTCgsL3x+S9d34y3aGospc
jPHbgxaBFn1QYwlpfmZdicH7H/kqaQaxy2b46LGjpVB3HTHlix9GdB2HKfda
fjY8497z4dgYjmzQ7TKXLEPFVqPoH7m/YR/9JOFtYwkaaNe77ZScxKZtI6df
xhWAeouF8vHnU2BjdcqIcspApFp1AEvLNKiPXqp+SheJspOUyR+is/Aol77Y
tTUVkQdkTz8zmsOp6+wJnY5xKEs8MHykaB4uCv6X+V8lIupSxadqtkWcoFt4
csNVH7q0NGfd6VZx2kn4aAH/C4QGKPD2ZlCRukqBtFF1Z5zuMt3NpENNOI/e
Ur9c4w8qm4lpCwYaYndL2Sh2hIImHXNPtUgacqGC/tElk2SUekbpKVynJbo0
9Uci1+WBtyFFWnSRlqg0cd/y402Fy02T4xzBdMTkHNPh3rV9EpO2+UPO0ROx
6BtmZn8paNbx8uwfWtO7J3dS2psDEdSucfeLGwOpdY6byX4Vjxq1dcKSxxiJ
rk75b+9mexxfcpSiDDASO77WAq75UNzVvFci4sJEEkQ5MseHXdBfz3rLWYKZ
5Ms7V+yhf4t3jjpb1ncyE2q5Etvy5Su4EbHFI8WGhWxlO/9QTsMbkqxVk/07
WYn/Zsnr9idCcChdwpyvipW84ZUoD/JORWxFqfZDEzaCLyonXGsy4LXz/Hhi
bxS0Eoa3RP4uge7u2nPPunIxXvRsvctYKYxquperTlXA4tl/Kgm9a3rk+qg5
aVc9DCi/Rh7lFEDq04wdj2EzXi8emGIPKsSr5fsirz//AtWNI4tZElWQk2fy
aTHvwq2NsvFL78rwQlrh+ZJoL2aPX6+REywB7fEU40up/Rg7Yt7dSbf2PVuK
itPnRzAyXpDKmlGJ43Q2hkXm45j2ct632lSC0xQ/fsePE6Bb39JzgKMAacet
7I41TuJlAPQ2eBSgc+5MosXrGYhPDHpWh4WB/v6x7/Fls7hQVPThYl427vLI
2HTyzkOIduuzTFd/OIifrGPRWQD7SEWxGZ8Txmd00lg0ViD/1iVlitMc80dc
n2Yk/uvf2Td2b03fRE1sih0rdW/4IOTnJxPuVGrSeDhUd6+bD65evOo8oUJD
+GjEvevE09Czxc3cYz0toZqrOJYul4zbLMreOcG0ZNPS8xSV8lzoinLGaSjR
kZ4TM6UTHzOgaXqbynaOjgj30pTwOsdjUPj7lu3u9KTt3vemFIFYKEm9nLIh
DETPz73kUHAgAkxrWB72MZBPHvIXq9d48F2j8LZKZ0Yi6WX/4amJHzpPLz+J
O8lEENv+a/9GF7x7rKKq2cVE/ks5bpJ91xVlhZliH94zk5+UXUkelpGYkfM7
eeQgC2E6p9h9mCEYUYdcWK/XspCivwfeshqGQO4pVYScJStp1JU1Sz2YjZLR
KduUHWxkOd/rWwl/Mnbr5Gy6X8lGrrX376jKiMNwcCbDVFMA9ip3v642r4Dc
3SwbTaUsrBe4EHbtVhGoQyOUUpNK8WFvf/bNj9UoOZlX6thXiyCJh/S13MXo
jdd4PLC5Cazcxx7aqRaDa0NMrq5yG+7c/5jv41QBHruM/sKSTux9x2Nyk7kM
z1qfiHBa96Dv1dddRfUl0N8+5BsWPwjDA05HR6qKMVyv4vPo+gjudm3rmF0o
Q8PuD+HhzWP4LSBTw2u/pl/qo1bSRycQW8vj5rOtCEX8Mh+j30yCOSci1ftk
Pijshh8dGqaQUD3bymwTDTlRRrF88Rmc/vJa4Ej8dwzXPKkusJwFPy/pkIjK
gV1IjoZ48RwOe+hxLb+Mg+jUEXXBbQvYomZeYGUfgiL9D+dfPPjXr2NmU6g/
nr+EUI6jWipM1oj1udgRrr4KuSHuwG6eT3DP2OZ1eZCKrHujw3MoMxB7+wXy
JA7SEMnO15ML2yhQy35Db9VIQ0aSGiQ1rgXA9epfW7vntGS70dJ66ks5kLUe
nCvcRUfomdLPaYslYFFrwKesko4EnN6XbyGfgXeHtjHuM6QnIdveSHLrJsFN
iUVOYgsDqT+4TuhGYiwCRLYnr8tkIF55vLHKF1Ih7uXGt16LkRTtYQw8URcA
xx1nm+I4mEjs6pZToec+YWZIjV0u9V8+aFboP816l5kUfjpirZkkiBy91+Ff
6f/NG740uFpvF85CapRcTsbu80Vm/mDl1susRG/kWdRp3mCs1H9afTjHSlbu
9Z/9tTcXD7nOZj7wYyPjHuu9c+sSEaKkN5RhEY9Dq5lBbNnFiOHKVyz2KoAv
Z0VqmWc12he5QnsrquDefnY2MCsPHv2cA+33GuAl0HjzgG4RPhjbf7tS2gJJ
h9i4g6KVGJ7hcvFpboffsVEKf38pHjOqXh8T6oZW9flhtbpivPIRrG1r7IWr
6qrBvTV+2yziZxhwawD/xR/idqcth/ErP7//2IahlO7Iei+/EtQ3D08yeI0i
pKBOi4+tGr6DTyR7tv7GAf9tpkElxaDQXC/s6JnA48YSsa+O+Yi6lmJdIDQF
8xf3jyQZJoCVSY1qt+00OO9ZG8rNJMIq31pGvHUG3zck/G0ryoLw/Mq7AK45
sEx8aLL+FokTrul+rqbzYKhrGlWwj8SgnqzcYsoCLKY6bnFneMEyYpZDLW4F
AUxOidvW/FKmunlTNfMfuLmVmoQ4WMB84vsnIVATofyU7xTaMDyLfa0e9ZKG
VI5aBYyMpEBXP6A/UYyWjKfZeD9Zq5+dxUFJS5W0JIVJyt5EJRXOP849XLWi
I7G7y44dKaGg/FX1gxN89GTd/Vw55SsUyPPJCtBk05PaKxqsF6PjwMo/7VP9
kIEs69xjvb89Fn7Z9vd/sDCSjRqlYqU8FPRzZLJ6ZjCSV7vBnOi3ts8P4jbH
6TARBaM9KhKcntixqBz4goGZ9BtrCosa2iJL5vNWxmRmwnP2D/cxmnCI7syo
rbnFQhpa77raO31C81zV+Z2LLGS/Cv8m/mcBqBbfYWcWzEqMHLWv/ceaAzca
ZUaac2zk7dCH1Qd2qehMPKF3d4mNeNO8p9mZmgZqWS6jju3XUHZYurPzUClE
z7k4UIwScCo2+JiPewl+/7zGGMBVCJEOwaib96rhoXtTXUyuGtbbrrGycOSD
y/rc8Qf+DSCfNX9r8BWDVTyxr5S+FUPTmr6zYlW482H5Wu/WDsxG7J952F+C
RnmbyY/nuvGyXMDswetSxA89fKg+14uoAdfKzt61fNB9uvidxQAexhzd0sxR
Du7K09PYPwzhlT1X/R0qoXAp59XZlFEUmDRFVX5b81e28g0ukr/xPgufxgxK
kaVhHU6ZnoB3y5OvMy8LkPTAKe/CkSlEfV9e3VkcDwP3yzv1Pk3juEnROWrj
RJAbtr96hmawxNTj+Zc3A8PkuwOT6BwaxARdU2ejkRE08tX89TxOBMz6D5uH
QluC38+lZAFK1AEdW3icUTNGPXpoz7/+yLUjai7i1v+ep8VGRO5pzlmB5WU+
Vge595DwYBUq4vkDiYL3vm8m9aGpdOBGm8a/+UI374Hib57/5gsdLqa84TlH
TfI4I/h8ecJQp65z58AQNXmt3mMv7RaEd3knYq470JAw6dfVp7lS0ai5/Yi3
BC1ZnyZyZVN3Gli3Gyem/6AlSzxiXZF66Whj+qGzYktHmHNP9pv2JeDPvW2S
tUL0hH36ffi+1Vg4Mj9/nlxETypO0++uT49AwuToYrYJAznWli+972Asikab
DHy3MBKjts2fKjZRkLziZZ9XwEgQOZU9oRuPIw3bKl2NmMi+dqO6wSVP+OWy
MR1nZya1U6GFr2kewHeE/TlVNjOZeGlWISwThGnLaToNDRZioqzy4IyqC5JU
F1hr1rGSO3m5seStP1jM6S5ofGcl7ZxfDlziz4SD95u77YpsROKO320p1kxY
VboX3Ehb+5wTUn5mQ+U4xXMrqP16Npqc44XHJYtRKl54t/JAGR686P19aH0V
vqm9UtAWqENr6OhuK+NC5J98pFV7vQlceY+omhyK0c4vkPjHsQ2POscokZxV
eH2B29NzqBPzD/irxpVK0cYs7qns2wPND83UW7aXorL4hBb90X7cWzBdx/2u
AmcuLhWfahjE++g2lis/iiGpxCvXZjKCSK7QkPGwSnBujGC1nhtDMOvrF485
SvBUvKrs4bkJWNwfPJO09nuCPi9+LXGbhHTzwWtPawqwSeO51EDvFCxbT956
uTsUAQcKJX/IzKB9YO7Gf8fD8eIZo2fu21nczNLhu+mfAx+xsGLDpjmc23Rw
61uDWFjyLtgqCi2gKoudPZMlCN+M/Zh+m//z6/Zy5hn1+iUURc87MWbqQ9/f
7HQl37/5QpmfUndWDVahYGM/2UfljYrr36nUs//NJ5jWPs81maAi91rfqJu7
BmDsbFO9mAc1OcKdU9OuFw5BkfKFUCka8uD+YcrVP3H4Yqjy0bmdhpxPZV33
bC4cOo1ZOuxvaIn9QFCiAyUdqoa1ItNidITHaNzlv9RkRAlnHnz0g44YKs1I
vxPJQIaSrEK4GT3Zysvu0FibAvo2zUZlXgZy1nw21OwcBRT726FuBQxEqcEg
oik+FS+01qkffcRIWgJ57j5k+Qa1s3SFuVxMhPOmt+JDvae428P8X3nOP39/
E5/VLqnDTA7UKimVP7oPhqDzwVIbWcg3JXPp/SZqOE9l+GI1loWs3xO9t0p7
jX8K9xXvv8lKwmKCmN4/D0FgWOGNpdW19e+bdNd8s/FH6hlLUxgbOfOrtp8v
Nx5uvpw5u29/xsG/suqOF8uQePDJF/meVES8tGjhPlOAOzQfE5ODi6GyqFXt
aVoDCYamkzLdNdgpcGKr1Zd8GKq3Xv62/AOTHjWBc0xFMNvz8FLvxZ8YDUp5
uH+5ErccKrreHO+E/n9Gqm6dZWiNuHnWaLobpTcXNQJqCpHTfFUn/ksf1F85
Zu8/Wo6cLz7ntIUGsf+8FinnKkUYayyPY+0w3gbmvz/ovubn4onymjfHMPs9
eP/42VJsTTqsINH9Gx7Sp+s2/ChCnFVGwMkzkwjRm1fxv5QLrft2qx4fp9Af
03THeDh1Lb+8i+IbmkaN8o6MQZrYtfwvl153bBbr+084lh5MRUGSaFjmyzkc
GbM9mPw3Bjxdk2z3fsxDP+Isj1BFEl5e7bxO+BcReXAjjvs+QWMb/YT88396
O3d6Knd42yoYT0VK86VqYN38r80cBv/q83Uy5Qx9IRUZjB9tl5d3R3pJcVSQ
ITXht75cq8big6V8T9HRjTSEc51LuZleAjZuv7DDJJ6GuClvXLjXmwwfHv3L
TXdoyY4liofCYs6abvsb3lxPRwpeWUosuibgDNf5yoQoOjIWXLXfSyATd1S/
k0xFenLoWm8AnVQcFGZ+i9BM0ZPneiN+OX+CkSAdpCT6jYEcfNR/2co0ce18
6Gs/PMVIAqXmq3712IBR4IpQ3m9GQhX8gfq9bxjKb3NsjfFgIju/nhIO7/iE
T8cHZpKlmUmsWzh70eXPaCjex+4z8O95yQ4clN3/loUcFjfvPdHlCZmNm0b+
7mUlWgIXf55ZDkezk3bN9x+shLXw3mMapOPMyLrkVqu1+rwsF7RhUzrELu4M
5yqOBl2NW0h7egm0bXfcOn4/D1y2X1MND1VAUmWVqSe9AlsoUcaNniWgpuy7
7Xi3HmrDfYMG2gXYxrvOija2GYO8/baeOcWQ42ri2V73C4cs3pirZFcgmllP
6btHF3hlXTRSSAU6DajHJC72Ii/TR0FytgwtSTs11Zr6IXzNZVnmaTlK/l6X
5301hD+PqX5IX6xAnss7Q9Gto7hcfWryXEsFnk36NHz9PI4tRlfKL8QWY8Dm
lWGm9wTgfmhfQ2w+3GOOfL7aNwmGpv++xurkIVfN1ERSehqTrrfaNsfEQ2b1
b9Y7txls5UxR3B/zHT5sVWaxLbM4Meu5w20xFZYBuwcExOdh89j9i8IlL7Te
+jN/zHwB91StjvmddEZv2sYFU5F/fr9wg+orj9EKHvuTczWNWnhtYj3HVrSK
MPMmO6mOK7g/Ii/TwU1NPqjMO5n1+IMvv38pIed/8zSzOQ6ZIbjguFJ07y4N
8eyfjDFQSANPkfbKdwZaYqcqz5S+xqMHnNlfXfxOS4x5k1V/GmXjJdf6XkcV
OtLP+dlZTDIDW48e/LL7Dx1RoD7/QlotHlznWm5+9qEn0wbO3estw1GQ/+OV
nzwDmR+W36X0yw+xdRx//owykGtJBk9joyho83e7TuXJSDYYvxVRTApFjG7m
vdyzTOTzMm2HppgPZvXowgYGmUi+Lt9L5UxfWIh9KYn/xEwCRWL7h8UiIfNS
61i9FAuhg+7NqqwgPCmOSi1vZiHK8qK0vJL+ULKSD/zvFSuxeVmStUEuG4a5
u37JCbGR3OrZ62KXUpFiN3+v/gcb0bosLFJ2Nw4FslzJ+d/sYDMUdv5eUhEM
pW2dVkWSUbQplkPtWTGCJyY6xO4WQX9dxXqOnTVY95/NkYjTNRhpylPV8clH
4fjGQhvFH+gkLbKh7UXIE3XefjOiFRaWD7Q7D1fCQfEC80JhB/RvLUw4jhej
+ak+t7V3N8SfRz252l2BY10dQw5yfTjyTsWgW7gSLzKM7C2qB2AYt8hw4k4Z
uh4t0j14OYz+ZmL/bFcJ1mWl9dXTjeE+S0r98PNyhGlah3a//w0BqERaRJQh
eZxXaIF7EkHnxUyPapaCpZ+xc1JjCtJ39I7fbMtC2urowJms6TVfSNx45kQc
avi0FH6yz4I+TGSl9tYa3y0/9Lh/fQ7pvNJXMwQpGM0bvz4WNQ9njcuOQ9Lx
mJFdt6wzs4Aa/dQFof4TqJurMtUYXcEup7IP8i1v4XXOjFf/7D99/CB6yU45
hooosb7v8Vi4DgFG4nn3NjV5H/6qTP19MLTZbWRZV6mJMcsPFqvOUFSM5Wn3
etOQW2p8/gNpiUjLzjudJk9L7r7+4uGcnI2A8beub0doybOOS+ayORnYuInt
q4oHHWFPeBD20Y8C8f+6jxcfX+NN9fwLAckJMHiZdFW9jZ5EfXtruU8gABLu
8rtn7RnIhsPHXubmfscMY4Dem72M5GXdPkf9PR/RxTp343QrI8kq2aV62zUK
6zk/T/q9ZiIJTFfcS7kdsf3F8t8FoX96mNbCV6xUz0zsNZiiuL46gF7Ndbf8
ExaSfD4muS7DFZaJNKsPtrKSH8W8Sst0X2FMdfSjfS4ryWfYtpdaKBXaZ/Lf
39FiIy1i0dKOT3Jw9cOvpJSccHRuqhGaly5FgUPwDze6XIwIulaXJJTAWlbj
iIpZOVLjH/5i/lyOGrrmq0s5dZiOlMrYlJ+HR9+PTIxsaEZfvrTjJfEiuPKu
DL4/8Au7fMibdVeq4RmZZ7rzVBdWNO4MXOYtQfvJ7fmysz0Ij/tTZdxQgqvZ
MT2H7Ptx0nU/Z8KDStjtFnbYv3cILFfa6y95l2J5ol6VqnAE7KpczanlVSh7
GfSYRW4c/F/VJPryS3BARdjbzXgC2m+3XbHzLoC3oAcna+YkPA4ZLl7cUwy9
joXrjhunEWQR1ZjXmoqJL5pLMboz4Nj0aVfkWBBY5UbpUuNm0dP6ZO4iZy4+
DGg3lWyYR4H6dJXm8zBEnFg+WaC4gF0sHLsvWDjjbj7rnO6ff359aCVjfObc
CubWv/yYnGmJu3vuhNt5/etP6qv3WIvQUpN+pzMeBtc8YUf934BRFDUZ9WO4
/Kw8DEk/ezreKNCQd9IMnmOsiWj16jjDN0NDgjZN0zmpJULhsM4TcU9aQgrf
pLa+zMD4mSHa3NN0ZBOfo6LG1Qx07p+/VzpER2h7+taNf0jA8EVWZd939OTV
o1bRMaFE9F/+FrV4iIEornbeaFofgUP7kutKmxnIYeqyk6xjFETblt3itWUk
jrYKfcfVP8DupqbbqQP/+HHvnne2LQ3/1n8NI+pnnjMTj5KqFbMWP+xyvfn7
zS4W4kCJldps74L/+li+9RawEJHebOuGA3F4x38isViflSgGKtHMHUoAg+Ss
Jz8HG6Fp8BieDEhFa0eq1PVsNnLt5/aG1pMUnOUNChp64IusD+7H7OQqsSz0
wPvTtwx8Ep18rruUj01cIu9Pj5TgVsOskT1jDXTixc7W2dTiO72JjVVxAbZX
BbYmhTXC3IUnebtCMUR3ydk8HvsJLcr+hdGMChgMmWSyuXaisv9LpRhfOVp/
njbUON8DhZw7+gOPinGuprj/V38fjM3qjwnfLcWGxxV0154PQu4O+06TmyUw
jNE+mCg4Av/4y+Jqg8W47xsTOREyhvh5+at3M0qQR226cJpnAg48Mb17dhUh
kv42n63+JLyu616c/5ODjO713CR1Cu/uq+55eS4NN8r2PF7aNIMamYEjNlFx
mKAIi5ZpzIJ5g02UnFkWKI+HkrdGzSFIdX9OhfIaf/2dKW1enYfFpReuYtcj
wXovJ3abwr/8o9rAOHU1bAl8eLFTuvwpuJy2sJnKrkI1e78Qk6Mxnp3hpMpq
pSKtimaLPcY+uGZ/OWfQlppcdtaWGGfzgaMZhb1sFw35lDM32MufiGtnan+s
L6Uh76m8DzkrxuPV0y13ZoxoibKuIOWoUQ5KPFMVdm+jIypPTlMrN8bCQsD2
78ZcOqL2oqilxjkDH65byMVr0pMfJamOX2niIaojsi6KjoF4f2iyGdOKwqHu
v1b/xTKQrB2KBzQik6B07ojmlZuMpDslOPXExTc4fDhq9hQNE8noKs80cgjA
F1+n45lRTOSQU4e7Evt1MM/XDZkpM5OPp3T/qGifxO/EE7dHlv/p5WGBmrtb
vVlIyTmL54OKVtjwkL/F/RQr6ROV4HWbjsBJni+bGoZYCbVH7sYdBdngd5Xp
VnFlI5VJjlpPtqRgw5uES1n9cfgRbJPholMExhfubR05+QhjZPt1v7kaI/qe
XY/WcnhTpON3Ec4CSN2x1RRc1wBheeMP5yrzkfehlEZArQXDunnP1ezKsbSV
ohRi0o7y7hvWV1LLUPCIXezoRBdEpeJcJDQK0en7e6uQfy9EtjJdqLxRjf+i
3Tvt9wwgwvoeo09SGehbbemZWoag0FDwWLysEm8PnXp95cEorpfQ/t36thoH
ND2PivaN48IQe7h3XhF8I9tO9ZdMYDY5t8ZfMQ8u0j/YPVmmwGrzuczUIRmc
bb+d2x5MY4NI3bql82vn9Z63rVb2DPKGTlnatKdDvCWmL3T9HOQOd6SmZsdA
W613zvLWPIwiDdooIrFgtFhPifFdwA7Ni+2blQKRFXf+3BmPFWxj9V45L/Ue
YdkBsp6TqxA988zlpYc97lhEr7gdpCZz3gd1THhCkWpjwLrYQE0mSgdkuaWj
0U62RJ8ypSFRO770UO4m4e7kWLw0Hy2pKfjMzv4xA5vH0hx1cmkJ9Zj/C/lj
qdg8wZl7x4COaF20+K21Ow4XZB6W2HDQE6+IjrFg3gRcOB2k9p6ytnYJzYi6
TEHAUbZb59QZiMTKt3fhSt9xwMJARGI9I/FeVC+xdl27nxz1K0PRjOTsj28/
Ra5Q0GLFefjUbSYSMuxS48rjgZzo1xWzK0xE3rfUtrHeDZODNpnG4cykSbD9
2PkBf9wyMLHlv8RCQu2O+r1I9cK78ItNlFEWwukSXvCoOhCbG6+7zLuzkndJ
UpyT5tlouHSN/9FxNjL68N3zmKx0fNkn6XRllI1scz2ZZ2dHwa4PvMF/+Z5i
64zlErVHMSpOMTKrVCbCMtzB682OElzoF3zyILMQZVJBfTQ7qlG+6btWTl81
Yh6aba60zsfEkSjrmfkGDM6IFNmrF0MnKsDa+VYr/joUyLa+r4LxWMABA4MO
PLvEt3CpZi2nd5nZ2Rl3IzOpIszGpAJmfcERJjv6cJV9ODBXrgLq1bdC1wcN
wFqwLNVwTT9f8Po8r785jACvPc6TKuUIeXMygblzFLNh6l8vn67AhNTuH6l3
f6P+/vaXbx6V40RY1YMfdJNwLfva8rqzCF1Cl67sUJiCbu53SSeWFLhd8HnT
FDYNp6P+x3btSwD9iRm3jtUZzC2E6Xj1pOKuz4eNKZiDEcubU5GBcWg4PGZB
8ZhHeHbyzu/50RCTdr70vH0BD+10opdYXyBH6WTVt8YVpJw0O0c/Zo8BwzyB
7Qf/IGOlwX24/Tp+iD5zkrlCTbapXKW3lwoDT8rMZb5paiJ7nlfEJd4Poip/
GXk/0ZDRzv8Wv4cmQZ7dICNShpZIePzZbEKdhmaqP4EBnbTEVjpDYO+1LJix
TdmIOtKRIymlK8Ur8fjStXK04gA9eWniZnPw4f/m5z0H39XSEzHdsYR+9UCY
Fng5tT5nIJr21xv3BH9H23KGvis/IzlqJ/9VZToQFW/kDV9VM5LMsmKJT0co
4DG70eFpyUTIXp9y6ndu+OX75s12nn96F9XNKShaykxWt528zjHnjj8jeV+u
PWQhKuHVLszXncBJ/5fmGxMreaTLFJx9wRvkpO9D02RWEk+za++bq6lYMNpl
xqvKRjQeFmroauRiICot0/5kKF5Xysg9fFcGY6ahTadv5WBlPWdk+a//vTf6
qdy1vgw9ox9a10+WI+nQPqUDj+sQhIHq2uI8eMzWRqhHNaHBT73KvagYUr6s
lws72uCak1xc7lEN1uVxO/UtXTDNtpzzDS2BevBO8YtlPXBrP8o9KF8K5/wn
Qbz/9WPjkrpdCUMVtKXYw1L+DoLjoPzbmP0l8PCzqDH8NoJXWZSxJsZqGMnv
IXI7xuE0WHVPt6kY12WXD69Tm8CKs8RwfE8BBNrkVUfCJiEk+JZdnKcI4D9R
nLY0ha0Lbfl2xgko69nkcfraDGQZ9u8VpA6CnIaVUqb3LPK/F9dJR+Vg6zv7
yzxjc3jkf0uGl/07XKMW7749vgDOERYOn9Bv8ClmedI7+I8Pq6s8ObsOr0Dh
0AYHriZNKNqUbch7vYrUqBhr2g+OmHCP9VNcpiK1Eed3/1T8imO7v/5SDKAm
LuJCClI3Y6D/6ubol9M05GVMs2ARhQIpGp6hm0M0pCvPWluGJR6trzf95nOi
JTrfnALeCidil6oaZ+tROnJK3kM5YV065MRaL3ztoCNsUVIK7yJTcK1K+HLQ
S3qSnvrK6+ONtZP02fqUkDADuSh9W+vh7xgYqzKcjKliIIO7hiQU/ibii2nf
bVELRuL7N/ZAqMlLPK5KiLLZ/Y8Ht35VuvAfFwu5nkTW2/80wTVTGZbJNBbS
+vKWRJ5pNIRNJLKWNViJrks3h1JdJBoN1CxY6NnI710ZN8r/pEOfmXvn1gQ2
wjDQ31t3jwJ9dXWKvYYXzl/pHORcqycVsfHt40jHg7jijkfJ+Uhmu83/XL4E
DgsBHeYCNVBstzlFf6gWuXwmtlOm+TizFZ9FlBuhN7bYGsVUjJpglYGIbz9B
KeBv1n9QhV4pv+oL2p1gDFreQskoh23Dx9CSrD5EmxTI7xArQbdt4p5fVwYh
HR5/sWemBEz/MYUKLA3jhrA+VUFlMZgfHLIUsR7DgJyKsvuHEgz8lnOKpp3A
0CZ7YdnThRDPY9K4qzKJ+m5F25HMHLjsPPNBP3AKkS95H68KpEF8Wwvrxz/T
KJ3MFNupHg/hqmTjqkuzaHA4fe+kTRqOb2Y8oPdlDqoWC7HJDtGQMJoe9R6a
hwg9X2OfNQXyt5WoxI4s4sVU2d+Cw/fg0czwuMp1CaRpV2+2lQLoh2x1Yvat
grrqlHq0tDrWvejb2VNNRXgeaJz6y+sFurD3SUVPqcldYuZ+x+cLzvAK7fjJ
RUMkXGYSJNf2mxLNYnk8i4bkFBm8V1jjn43lOT/6tGlJ0vucFg/dbPyJ3qcu
w0xH6BSOU4sHxqCdV7u/O4mOCDksyxScy8RMk6tsigo9eTf0X+e8dRyORzN/
bl6hJ9vbR9QU+MNhyqbcfyaEgXQVNgjxdyRCSurKfXUFRvJAeA8H2aQDvog/
LK+WGEkEN71wK2coYleVhJMCmIh+Pac//TU7VHOqGbqfYyavwxgl3bPtIBy7
rk7wEwtZZyDwX7LGa/hlbu8uP8JKWKTb1CPjIsF4489kTgcrOR+0oGj3MBOU
LN+K7fZsxLlXaPvRdalQ2LKzdndwLMaPvz8o5VqMlHU/uT5y5OPdnpCDtver
4axZbhamXonPizrk1vtC7LBvVleJrYeBCC9ZPJuP0Yb7OZ9oW9DDs3HfqGwZ
/DwKkjoE2xH8pNwzbUs5jmWelDEu6EJPxXj7KdcS3KVbstln1guPrTemeFOr
8I2i5m/8tx+1uxOK2dPLMDiqL+z2fQjHC4h3vEwldnf3LWbKjOKAGVXIA4NK
NIrw0N7LHMdWYwnLM/eLkP8lpvlK/AS+6w/esaXLx+a5N1fNFifhd2izSa9y
FsZ4Dm1gUJ5GWwO/j0p0LO7HKgoshK/5aXHMU2PPeGjPyIhHjc2ihO75TG0x
BRN/qQ2rZOdxp5zxwoXYIEwN/m0wfb+AlRus9s91vXD7tdDjA69XoJO3uPtL
rjG+bGf3bvi5CgWZPczGO16iM86KN02Impx4rVow8j0Y+gER1E1l1CTypIuO
9o1YuA04pCnr0RC+jwG3x4yTkXVbVOXJZlqS2DlqrsWdgQAZbXrV5DXe+0Nz
ctNQKi7QfKx7co+OBFsfnGWITkbsccWYq/T0ZNJQbz319/i1c52l6hxGT8ow
mm9bFw7K86kxk6sMRIhGpbvCNhRGwTmfts8zkJmPs+EulnGYin16dS6QkQh3
0BafDY9FwZTeRRslJvKsf8PpTGFvtDLLpY1PMREDxT7jnkJvJDIyy37yYSY/
NgeU8U8HQMFcv33xNAvhWmfrLpPjh5dSz+Szu1mIpHPUwNWwAFCEL3vt/chK
SkoMNLK/ZyHAPuPPrQNsxFrCMID2cAaEVL885ehiI7ejYlzexMSB4+gKR6Bd
Cmr3cseK5BRi/XLWhakNxVD8wHCAO7MGXBJix01da9C03nrU4Hs+vEKeMLIF
/wBJnFyuyS8ET/jzeN7lVhTOOKUPUypQ1bQwncPaiTGjmz+D00ugwqEZa17S
jcbdH5iFjpZgtW27iI9BHyI5FY9eZauCX7j9g99LAzjvrVZwXbUUZ7OuuS6F
DSPt6D59XYk1Hpw7uu3r/jGEmPx9rPSmDOofWp4yJf/Gqwa7iCSbUkhIPurl
OjCJx8v9zmV1hTgWXGJQaD4FnmazNr3HmeiOPXGBUj8NLVE2zr3PI+FB3UjV
tHsW5XkDEkMsqVC8dZGf/eEcMk0bH3RvooBaeeKQcO48ppuy7+7YnIi0i0Zh
1xgXQROp+SXCSRu93+5yC21YxYFCZsmcr69AP2mttS+NiljMWe/nzHq3lu+p
Al9pUZOoy2mFZyMDEKvHcnSVloZklhixHraLg4GtXV5kGA0JuczCfow7GWIG
20pLlGmJp7rDwycqedBr2WJjNEdLPvlc0drnn4aIrWIJdgF05POesvaVx8ko
ais+mXeGnqya7eGQc4/HneP1WQcH1tYWTXqfBAIxozuXxubKQHILPyl9+kwB
I5e9jsURRlL6/Gzb3UEHzLoHymzoYyT35M+rzmaFoj+1nirMkYnMU38fpznj
ght3Hls2H2Qm7Fcuq9LutUVxjZC++S9mUvs1e1dlpx42VWkknLBmITIJzpaa
5CvaNJlnDguwkoaTSx5Sz4MQXFoV7VXOSm6F6ij5X05FwzZN/69GbGQxze3T
vFYmsh+uix2SjcI2jT4K/98SbKbVdB9IzAV/CJfLhphStF7a78+7vQI5L9md
JTTKMdz26mbBxnpMPn+7xUm1AKe1vko+vdWMmNO+ub2/CzD6deiVss0v/PYt
enokrgq77nzRHNTvQvm1F1UbF0uh3siqIs3fC6uRfW8TuUqwNX1IUD6mHw7+
5gN6ChX479T+vi9jIxAMmrgSQrd2fapAYMOjcXz6s7Tw8XgpmB5dpxVxmMCF
Xen8wYcKwKU70HigdhKVJ95RmygXYuuFuDu81jN4/1GRnmYlBI2iatkJhbNQ
/qlH9bspBxvOyv33hHMe8k9ufeBiDkRe2QrXX80FWCtv7nWIdFyDhc4C+jsr
2HTu6DC/sBWMK8cuX4z9178b3LX1P2p2avL5t/Ud6hveqO8RnHRNWvPPqsc6
knR+WCdpVG96g4Y0td369lg4FZYHAv36/9CQlX2yFW/TkpDVlbEsHUhLsooM
Pu3Zloek/U9mQy/RkeFvWfb2kRmwOrz5+fw0HTFpOfN+k388XpVOX/NyoyfK
vNVPL8qu5RuG1G2VJxkI1TLjZZrhNT3+e1+nt5uBXOoqsXrSTUGBa8zNjY6M
pD/wTop60Dd87WR7tv4EE/GyDdAa1HyLjaUlnzvbmcj4XNsvnpb3OKHIr9jg
wEwkkuUK1FXDcfCtuluUOAuRj0tKa3cLgN6NX6LNVSxkMIfQFdeFYazyVNQn
c1aiHtbhWvgnA9LLH9IP87ARdrH3pTv9k3EhXkXRrYyNeKdYcVv+jAPbuGn5
7qMBiBb1O73HvwI+Ap38xxYz8SbDR3+qoxAGu+Zn6RxLYbQq9vHzeDVeOTTJ
f6utxWnXY2kfgoow/oae/8zfRrjeSDsrpFyM1wGHuaVk2qDqnGfixVyBRc9z
kQ2ZnZAh3BHVF8pwx1SKWtW0Byu3Zw8dXuOxXeo9A2Vhg8i4/eRsaUUx6v7m
pstfHEH8zsHJgE1lyGoS+5VcNYbbws9G1keXwHu7v0bTwQnk+9lGf1Eswp7L
Eb+CX04iVlPY7lpyHgb8s8M3VU8hqrK1cMeTODx7blb/QGQGn2ri2eoPxCDF
3bOr8MksWF0P8TXE5EC4ugT5uXOQMhR+bNYWh/uOcyGbOBbgI+15PV01FA16
B9SpNP/163hqmExaMpdgn2mZvOvSK4hJhiZK3VpFFOcEe76vExYYL3Z79FGR
rYiKYWoMQHO1DE2qOA3RIJI3bsdTMNPidrC0nobcXh5sHtMMweweve4NVrQk
ZLtar+yOXDi/PnuCWZCOJH+69lpnlQKO3X6cKKcjTDLkbIlyBnbVq52P1qcn
ex/eMLT/mghOQbmH1hwMRKWQSuni/lhMJXxnt0xjIA3+qvcEC1Kgc4P77hlN
RrJRV6lvN58f5DNu/Vq/kYnIHnXWivziDqtTVQoFSf/ywfkf8vdvqDETzDmU
N6eJYiXq9DoO2n/zhTKuvr8ZQlmI3tk0vT5FL9zn3FNzT4GVyC/Q5fPJh8Co
e5/kwDQrMd/G9e4Cx9r9aP2ad/dmI2FiGS0KtklImTlbdkM4Hl+/8u5otiiG
6vJVn0OGBVA2X7U1jajGOfMHCoeDqtBo1TXG2pwH5YPi2qOXGzCWd1vza08h
3M+IX4yOb8H6mSsblmorcO2z77B+QTs0hRMdmI+VQXFH3/YV7m6MP1cPvn69
GJpSfZE7KnqRbRNxTt+lGjsjavm8Lw+g4Yn0C4+5MogWew3aUA9j7k+ag15T
JUZffWPtcxpFSC2909331XDw2qo7yfwb1f0uN/JQDKschkjL9gkIh7T2Lp3I
B4vtrpp0gSmc4Fmv9F9IAmS/fueLfT6N5sw7t/Ro1vh862hfXcMMOoM4vOlj
sjGXye8duGUOXn9uXPSwi0B7Wv6LPYbzaGOyeO4/FAVBOiqn4fgFrBNq5JAU
94FAhz6vStQKfjvNF0URF6RpSQyr0f3BoYW6Lykbn6NZpuunoTQ1MX6kxOk6
HgoRL3//Ay9oyA3ngS3fdVOwzj6OjVqUlpyQviIUkpcBu69sW8zLaUn4cLKt
15qft7cGxcg+pSNhfN7aqWwU9J5y6IrhoSdSe0dSjPMp6M5+e9cug55M5DUM
Xd4cD9fJvQVcugzkSOiklrBvDCYu8GQrMjGSIsolylhlHPirZS+3pTKSLuNu
pk3x8RijLuJar81E4n641gyUeSBYKb99hZaZUDgepb5pt4d48fxR5QRmcjOo
YPyHRyi0tSyFz91kIb/v7f6s/McNn7m4tUPmWMiXez90V7IDYGZ7xyE/gJX8
Uk7r2qOYA7rNo6denmEjJjVTPWwLqaBe3xDkPM9Gvl+T36u3JRVWBZcu0PAl
ooervcxCowQ8XenZ1PqFWHzfUxJNqhEns0Fz7nM1vpzSYh+TzwfNz8W27xUN
2Hy2qHVGphjHxyIP7TvYCmPLS5k+tVUYkK4+HX66AxHyrZVxh9b8ccvKCUa1
brCcMneaWS5b42V6Jl3GPrx+liVVu6USVSqKR+UcBzA7+HJg5/ZyKDwxSnkr
O4z3y16bxaYrYDn0glukYhQ7aFM7xMMrsHXXwsPdF3/jJ9vT2/PuZVilDqUv
WJ0A/furHyJ9C3Hx3PhbiVNT+Gty+fDetXpbN2m2lhSmYfojnrhVJyCo5ERq
1/QMkkPTZaf10xD0+1tFl8QcOIyOPzwXFgt5fX3Gz47zGD95Zo/XYAQuSDWb
2dcvoO75iHYgtx1Sns9YppWv4Fq3VkeXoT32n/B6t0+Bmhik/Nn0STQM5u/F
G/eMU5Peqy+b+wMDoPqRVy31Iw0pYzW+v9CZjI1psk+DjtGSsIzknxv/pMKU
NUVs/09aQrXP1OZhRwbCP957suktHTmftiTUF5GAMsF3SVV71+rtzwrP4pk4
2OkyHRaooCdBNPvZTSOCoGxaNsbJvaZfO1I7LViicDr3sZVgGSM5ONq/u/Ns
PER2H73x5QnT2vUe5Zvl3ZEde6EkfOu//prQg8/VWwuYCZvdu2UPHj9YHL5d
rarNQoI38atovXLGgzgrxiO0rORteuAppW1+a7xf36pHYSUWbL/2DR1LB6G7
PvL8Ghux8vzs9GZw7fweFtt64FUZ1lRfi2uxAsIlNxUvnq9D8fSQpRBvAaI9
+eg5bZpgfrBfJzm0GIyd2zZoJrfByMFWOWFHNUoFaTY++9uJ/eMMf4pH1+qx
JaynKqEHlpL0zn8OlCK6sJl608V+SC7q5k+er0RDLo3U6tAgpm9unHJrKYb2
wgUmIYcRpE+8WNAWrcaZKJ1QTcZxVK2nlw8vKMZAyv2/ksoTKN2cn1RGW4ge
KYHlFp9JjG3/wuv7pRDhpO1vze8pREydtAjcEIsj70b735+fwUkTD8vdCEH3
eJ5p9qdZWDXY+nJ65UD1pzuTXPcc5vOYzZZUY0DbZzH18MACGMbOUgf954+s
8x8TBNqXECuxELid5gJ4pRz2NYmsYN07iUGqy8KQi7aJ6Xi6Cven01pdcAdF
YtvBrlkq0n/zs8XU2n58kkxtPulNTXp2mTgyaUSh5LqLse9JGkLDaDf8QYUC
nePHT8z00JCrzrKHZahj4b9vKJLzHS2ZP8Ul9vZRCnLub/PXPkRHstTTOW9v
S4NlxEWZ1610RGxj9+PmtDQ4sCVVhljRE5HOG3Vq46lYd2zyfYbgml/uU0ji
MokD49hUW6wxI2lwOf7Md6crBhjaUwT4/9//tQQsfg1+xEwO9O9b//7xazjz
Vc5f3MJCkt+r1yhLPYQFT1ze5zushM5f1mlsTzgy3rsMUFGxEUtGxhi26kwk
BFz0MItmIwP6l8aqzCigjTmo8tUlDQzb/doKVvPxlnFGj2u+GBMWr5voL9Yg
xyQKOxlrYczfVJH0Jh+qaR+muoUasV9WK7v2fREC+jW8zpn+xMpKRf4V3yr4
3E1S0VHqRHDjiifTdDn8GyfosiL6sNFKhDo0rhRKLBHJAtKDOPqUWa6JrhQt
Sb+6mvqG13hp6ZF5TjHay0y6zj4cw+5yC9aTISWYKrubWDL/G4ETfP1hLwox
saN3/WXFSRiHn/LV8s7BsmxfwSuPKUQy9G7ha0vFt8w4tcbpaTwRNJihocSh
4PbfLzWys/g235eWKpuKl1pco5/ez6HHwFAzduQ7wsKMX7zsmEfnguO3j8MJ
uH/TQ+zI3kUMR8xm8RwzxLqtJ7ZUCq4i1oj2VftzAo2U8LhEU2qS06Ep8eu6
F/wm/gvq2UJDqktOk0aJRHT37K1oTKEhMR+yTzWvJKPZ5Itru8Yav5+T359y
PgdeqQP9ZbR05NIMK0/H+7X8/q2ppTyOjiwyf5k8GZgJ4e38eWlX6Unf4iEG
ocxYRMeq9/XKMRLXdTb13wfN8blvD5fgLCNRuxrd8oMtHFlRB30p3kyEx3/T
jNVWZ8SJCFL2nGYmb9d9PvyTxwWB8x6MIo4sxHOKqoyJwRUT2l/6tQ6ykq7o
TbwWjRFYulZzytKGjcQ+WWPFoVQYq7W63lqr66c0G/WZ9pRgY95K6r30PNz8
4ffkaXklNNXu555lqUTzj3ct7hzFcOahUjNxqMfQW5vNEo352PCUwnvpZzPe
vmfomxYuhXFLpe6zpV9Q7b1vpltUjpneq8VO0V3Qe1d7cOxpGfhPWB+Nu9uL
fXqWviJNFUhLyFmvM9KPvxkBGsJc5VAx00hpdh9CL19uzqHJCkwfS5EwFR0F
b6XNIptGBSI+qj2yDh9HXtgzCZGRIlxn3h5kH7bmT8XLgjP38nHzZP1xvnPT
GDh8MjNJnIKaG3uMTvnOQN1gTkrzdSw2vLJTju6Zhf3mZ6KGO5IgcWXL3gWp
eQgyyu5+mukNbQFr7Zs2C7jDf0F/j6Ibwsc22wlZrsAzJmSDuo4cHOVKzk/V
rMJBfAPvLVVjBCh2f1cQoCb3xoVF40oCUUQp+VtYSE04pphKRRMjMZGWR25r
0RDXY2U00R0pGHeWj2BnoyUd3l6nNq7pg97AiUJlCi1x+9h+cT4qA/1s525v
UF/Tj+2sC7en0tCTkh0gTUVPvtXtZ4o3jUc/jUKLayA94X7LoJo8HYQM/vtS
jIoMJMpCydbxQBA2ZgzJM08xkF2CFHb/TWv6JWLf8MyHkUjelHS1+xiF4+Ju
NwUuMhHR++mWddG+GEwXOjgyxkScXI/NmvL5w5279s1OT2byc0d4M83GUCxZ
b7Yp/MVCDuqPmKWM+2N9XblPoT0rCQri3ti1mAWHoIlHSnvZyLLNoWfbc9Jg
NFE0bvyTjUgErKjMW8UhJxVXlJqTUeGrpSHrU4T62ZufneKKoFY07LHVqAYf
Sm9IOenVoGvUL3AkOB+xF/IflDz9ATarPj7pK2v5bshOO62uFVLTKeY99hXg
+Mu7lDHZgXsd9x/FrBaDU27g/wq573Cq37AB4MY5h4NzDrKyqaTSJKS4n6KM
omxFSINSSSlSympoIMkmMyN7b8c69t6yZyJ7Zr29f/xO73/vn5/rub7X9b2+
z3Xfz30/z3N9b66nDoGzJn9x/odq4Ot/7vb5yig80Gxp5g2qA6Lk8xXJ0XEw
iz5grvKjCnZw7a1L9v4FTbRmRlj6CpC48vRFFt9vCCsascrmqwFX23hW27AZ
UI1fQfMq1bD86ewrvNgc5Jb2SZhwVkJE+e3oH3fnQebuOf5xqSLQ0OfwX69c
gJ+U/KCutUSQ8hIQ7+Jbgk/bE+W/OXLAK86wR850GcaiuHuUzFLB7p1VGVPW
CmRObzjzyqZDu3J2k/H2KkiNWiVGcehCTxV3peLKBmwXbpo/T3WD6o9jS0Xp
9OiMwdz5Aw4OULkmEmJtikG2zwVVtPgigUVBuQBLh0U+lwy/PHiSACHZkRwq
EVgUpsd1mdUyExa5fr8qVschF/mjCR4qxYAbacBvzuLQdZv2+iPNedDnHRxt
FcyAVn8qSx8KSIc/Arr5ZcCIQhmrVEcp6XCrVwlfOciIyhzrGjZSw8DRy3ti
6wgTKo4+kTHG8B4sW2rVwvuZUKGZVfNSZAwsWqTbR7oxI6xNeYTFlAfI3pMu
sJBgQau+xzsIpfcA6UbsvNHJghTUTi6pa78Ed84/U6ftCchiW8g/YMsHJFjc
Vuv4iMj1k6twIE0YfBijE/xEISLPzqKCZrkcEEz04tq4Q0K4d3a4d+JFgN+4
L6lJ9x2e5XZPMQtWwd0KF+lC42J4dUMvefRoFcSrVE7mVtSAfEBhpvCzGjB6
mKDb/7MZfnMMWjS5l4IBfsLr2KFOcJrvD7e8Wg6FPfPHZwx64TcLdoT3YAP0
ucRPYvUHwbt3ESPfVgmCTN4EMtMIeGlwSXjbVoJUwQUX+cAxGPNveUnqroWD
/rTC6l2T4EFUcW4LqYdl/utMc5enwWwxkn+XXBUEDxU2GTvMQsOdlwEfH5VB
T3mRrVDFHPDfFzqhU0EB11m377dsFgHLczbMyiwKHmZHDmfmLcGjuQtvtTWK
QcVHj+8rYQVotAfiW7eiQJr+efygwd98JRLBn1D6EYa96ru2NP/Wz9eKvylE
OMGdP5EbFlH/9qfiip/P+DBjUCGY2Z/QDYSDi2jKKQWDZLIKfhjcjgQjxrjL
DppYxPsxJSCJLwvibhbPO69hUaMw3x0Wlkx4/c4r+3gIDrG18dhVHyCDltzh
F1IqDGjQWJs+YywfElNePRiYZkCYshK27ZI0yGRyagnyYEQKnuyFD17/7d+4
3AU6evGI/LCqp3g8FeSYCzp93jIhcRsnzsLbX4CN/8TbsOPMSGVv2ujYVysQ
tItl6e1iRq0cBv4prDYgYDLqecOFBY0VvRv4tTMK4gg/TvvvIyBvPKnDwiAQ
TtkWJh98SEQKYjy1vX7ZIMpTvH8/NwntoWHvZgrPBi9Vt9LFMhJSvBfF0cyT
CpdfDGt8XAqFzB98he1/+yEk5ImiTlWB2z4K3wRNIywK0ClnxTaBtXq7ACaz
HDD79Rw2W9oBa2O5JXSxAvSGT9W3cvaA0j4ZxoTxGkgvvio1Hz0AJvE8POSK
auCNKcjpNR4GQWLsRcLffOU13mFL+vwT2q56KEczVkKovvfylvQkSMS85d5U
qQSvk/eVWnN/A/+l4hal1ko47MF0kLB3FlqES8/wfqHAxHfnF95P5mAlepdQ
SVwxaJaYDu0rmwcN/4AnF/sy4Oeui6IpgotQ8+dU1ERkMujsGcRWWi6BjpBn
zE1ZMtwV7lqfylyGxAlGKeyVVOikPJZdZliFpPUeWznaWJi/ZfeGoP9vv+mU
1vtUrrQ/IOLmwOdh4wy7zYzN9DQ2YSrSNLbQ0hlyo1MeHhigR6fTJNsLGcJA
KsLuffE+LDpF4yMk/CsNdpPSXG7WY5GsE5sQg2Mi5DfC1/XHOCT8rFTndx0Z
JDy2S/34GdAkv+6rJIMUOBfBxiJOYUBtUrdUzc3zwYBjsiLZnBFJs68NmdCk
g2h5VgYnAY/cujhVLM8lQk+9+GC1ERNS7chpWbT+AoUrzhNhTMwoQPtMx2Xe
UHg7m1hKTvk/9xPHCNFj+iwooJcrdeja8b/zFdG6eY6IxNkEZ7uCY0Bv+1pk
7zQRJVjLV0nYk6FznXBv1ZeE2r+WvOcIzYK+U5vv371JBavOHtbbUxRIzX8s
j+cpg030OvlucQPsfEjj26hVDx07stX57UqhjGJwg0G8FVyw5rbWnWUg1h4T
jA/qA2N//nn+99WAP7cevhM3BCw/3vCdNaSA8N0718IzR2ChpruS36YBTsdL
OXqdHIeiPxeVAturwe+Shx1legLOvt7h8HS7DnK776sGPpuCgce5D+ZON4LR
ln4jYW0ahiIdUfUcBQjSj54kt8yC79ktnVyfEmjo33gQxz0PJfpyLik7MiAh
T8OA8nAB9B9xH0zdmwaCBWVS/NWL8NrhrIMrDRm8zlsURzEvg0i5ZnhZRzyI
srTKad5YAYxjdohaYhL4gLNwXewqvD137YyUWzhYqRge0wjfAGavzGwMuxcE
/FC+SyeDQenY02TnV9FwJL/hWuhuHHoz7aumUZ4PGkqjTVYUHGqelHCy3pUD
9qPGso2PGJD/DkVyUUgy8JDXWv24GZFGjkJwWnQacNFy97/NYkSP1Wj2D9Fl
QIB3MDHlOh5laCqv/rRNBM9rZ21O45jQMT29AukjKeCjrNlols6EtBvHR/n2
pMF1NCMWZsqMnoXeLtY44gesnfn2Q4ksqPu6pjeJHAkDE8ttkloERP84MeDn
D19gNUsLiZ8jIFV74M5Q/lvfSXR9uBpMREL6k9KsWDJMHxFOeQIktDOkMNnk
Ry5c8MXwzs2RUO18yZPVugz45dpads3HCU7pBDD4VlNAsIhSF/csE1hlJe94
/agA20m3/dVECizbXGnjjW+Ah4vfpcp5G2G5ZIRt1KcUur2MRU/uaoNUXJ05
+90K2Ah+IigZ0A82Le9t7vdXgF/CXCPd2yFQkxAtIU7Wgf7wGbUXx0ZhvaQX
H5dRC9Nnb3IX5IzD87yK+IO91VCrrqWg8WQG/jRlc24z18DT88uUMbY54GMa
ETMWqQTxyHJp97QFiNhm1g5cSwV+9ec67mrLEPTFtFpyOAVM1++NN4SvQGoo
J6vpxRRgRSq7H02sgqzAosDVOisgGwZ9PXNyC6AwWKR57BA84zX2vqiHQfrt
Yxcs179ByUhuFdcqBrnXarx+pRYOG6KD2Y5+WBSQqu5+/X4GOFv4bacq4tAP
9+p22r58OLWmyMc1hkO/1cqF9BILQOmTo/vpzwyINtOvOU4jDVoTrLvHnfGo
+36+q/u5eLBwSZpkFmNCDe1J3x+k+gKx4rFF8Etm1GIQUbNY8wkkjYNs5OtZ
UJdH/iFliie4RO431nhAQAUHTB5pRH2EamNnWjo2IgLDBkrfrQC4LGy54ZBP
RH/k7vsdZ8uBxO4FmgKTv/0Th/CTDr1iCOa/ICf8MgbUuc74j3ZXAa9ahY1l
Mhk0Buumv8tUgqbCH8el3TUgXceDWUusgTPBdFqc/s0wc8aTpLdSDC6arupR
HR2g9MX/6eFtCtwwxgaJM/aC0eHnYmN/41+npXMTHRiETM/JaVuzSgixDrGr
6B8GMse4tebf+sa6mF1J/NEYBL57n2ywVAet2/7ukdgF4Nt8RrozlA1G8idV
14wXQYg4GD1mFwmCNvYN35RWQXDDg2/RwwcMdHboRXpsQjxl9pb3EQc4tK7K
mk+DQcQBscwIbV8Y4HAYMonGoDI33ZKvBxOAPUnglrsyFgnpHjDcZkkDxsZN
n7xpLJLB1USxJaUDR4/8sb3eODQ22OUsHJcNzYoDb/Jb8Oi4upg9bs/f/L3R
0R3hwIS85SVgoekZBHO1Bj0UIqAjt1Rvb7W/gC6Jb62/iggoyUefv08+Bbqr
snKumRPRtiK7A39AEsxo7sNzE0iIJ0ZovTMiFzrlnb5njwSBnv2hQ32ltRAb
G/cDTecBRXVmiMu6FEY5Str6/Sth38s9lD0cjdCtoq/4+3IT9JSSRuc7S+Hw
wzmZBw7t8CuxzmqHagXcbN6v3NI8CtzDe3wDPlbCwz9kXz/zn5B55fOWwrdK
uHdTkmxtNgey/Ebm1n1kEKOP0NZLnIeoFb3aH+a5UPKAhqyIXwScy6dKnvRU
IMvYGOYtrMBD7iSSAmcy7Ddh7BY5vQZsc450GTkXwF7v3dFPwX+Ap4dOOP3K
PWDPr837JLsJfZLkAmmBO6Aw+OLzpTZ6lEEOfNj9NhASfe/ldbzAoOc+LnjD
+/7wS3XKt1kIi+456qfG6meC89OZvSGlWLShnNLGfzUL1EQneX5b4lCsvhPJ
mZ0MZpGP2lLYGJBP3WGXRe1kaF0VP6r1HY9OzJ/3esiRCWVFisMdmkzIs4hN
W0gVCxEaD1JyopmRVjlH+rFlO5hm8JNgUGdBKYHt2Nl3TyDRwsKf34+AvtRP
xhiVm4EWR3Dv0VNE9K4qMrTvQzzcEbfSz/lAQgF1V6D9XTaI11mS5s+mwLUH
uJUbmxQwhZxnmbdLQbvVF391pgEKzI9JMCfXQYfiTYJMdhnEzSWYyne2QOE7
hzCBkhKo1c+jVzzfByckPrG8Hq+GF1/2Zuh0D4IhieWDTxwFQltsamPfj4CJ
6ckahxMN4JD8BznsGAdvjG1jqE810FG6Q841TUPiwQg2688UOCpyjsBfOAua
7G0+7N9LwHnDs2reaAEwBTtjXToTofrWCj5uZQkyL2VadGinQHziYmqkxgpE
s9nQdjrFwYtkR0WvL6tQf26i8faZUAidujybObYJAbfq3LJIb0CQk/PjXgkM
kpUWZb2R9g12eH3A/2zAoHGXIfoDdskgx3FRSs0Ki3gG7FMkcJngLsaC69qJ
Q5jAz50tOvnQ88Xz/LV8HDo4zfVc6GIOvMjvybtDYESXCFErOqNpENftGNFr
8Df/eZmcZu6Ig0Z33z6xDTwqW5M94zyYDC9k7zZbxTIhmW7NJhmHFLiYdRoG
dZmRroUaPiY8AFrWztHQR7KgjLK2QqxACDTPzxwhqBDQBT9yFIdvMGDnhkk5
4wTEkX7PYOZaBNx42fzlkxcRsRQFlBSPFkLenbce14+T0OcTemrbYfnQV3oT
kzpGQl8yzap3/F0vrqdnty5J5UBnVuMWaagMDtGI0ejqVEDxU+WK/SGN8C2E
9tTl3EZoE/lqAtGl8IpOPEG3se1vf3zyLd+HcvDr6/mz0DsE+/6s63sMlkNf
d2ZljPMokN0W7LPza+GI8OeOONafIL6zUK7oYBU86vRWlJCbg5ljM4vHPUuh
wXWvdJLzPNAqRQdNJ+SBDdP1dYu+BTDABTP4psWD507rsLM1K3C42FlBdDYD
Qi6Kv1TjXIPsFMp+JzVrOKezsy2giB6Zh7oY1Rl/Bj3fluRFZixKk+nX4w5N
A6Rh8YCUiEXTKpiqazVZcKv8NEujPg7JxgvQDcYUQ2O94erwOg4JsI5d2BGQ
BXZ+ueTgaAZ0yfzCmxrVXNDRrsMK+OLRoGGD35RVOviEPR2fO8mEmLQ16X9U
voYupoUP3z8zo0OXbN93fPKCx+fjZVRkWNAFhSYF1VF30LgQV/hu6N95g9/r
qmfHXQlox21ao/3OX8E9x2PGX4yI7k9asbWvRUNhfABENhKRrK4/Xbl4Lnxw
Oipx8gkJnd63yUg4lQ9PfnyScH6VAGkMs3bHByqhUAmtshJKYOyIz+ZN/2pg
0PbRc7xTC/ru9cycItXwRNngcqxsC3SqqRXELpfBwWL1ziLXTriUXCIKBhS4
LeXYVe08CIs1DH4j/DUQEu4Wnn18BA6wla6hHVWwkv26RKt0DPQmX37R7ayB
S7oDJ7OdpkFHRszs7uNKkAvmDExtWILZtiz2nNYC0PBycOO/twoRLq++3/js
AWJvk+qtuTDo9qv3k7YbX+FpC2Y5Ig+DPvb1ZY+Vh8G3a9Lqdw2xyOIgXYjk
8Ty4sO6qoYbBoWTu5dabK1mwKjuuoBSDQ3ztFekmvH/764xwN+IaAxqepmDE
X6ZB7S3lOmlFPGo8u/uMqWk4aE2cTJsb/xtvFyt59/WmwiXe8Ha3z0yo/kMv
mbM/HPZEjVldQ8woRXDq7eT9L3BF3pBZyZ0FnU+ii2kOSIBszNBYkSQB8Rgb
yXAVfoMZ4tn5phYCSpQXYdZjjoSQ3eXRa8+J6K7R43u7vYpAt8/ggrwICckL
5ByG7iygERDvkmwkIRaMlqhoSAqUX8WpFNpFQPTT3RW2GrUwExI09D66EF68
WhrObKZA4D7j73f6//e/Jp725/ENQFyIV3Naa4JNw5nGhgoKdA3mlrzb3wEF
WkvBy7crIAilabS7DcP54ZinB2irIL11Wv914U/YhY3dR2iqAAcnQevNrnlg
x0jv7+GOg1ldW86j/KvwwUFX8lR6FEgxzjLy3dgEaQoUDN/2Aen7I5q4SXr0
q3q3m0FkJLzYwLxMlsSiqcKBp7yRKUCJfNIv0YVFB3V8/J+NRMChl957mBxx
KP/jYXi7UggD3w7t0WtkQCeUeU/vU8gH1petwhPceKQRsrFuejIFtEJcjd4U
4ZHp8MCGc2MOLPYS+gvMmZDQ5e2wwPVwMC9zEaGYsSAfs8qbndc5wUWcorWH
mYAG5Cimw+1HgcsqrqZKk4je9819uTkfAW7la+Wzq0QU8Kv5cG0WGbzj3Rl3
VaVBlbHxAWVsJWDkjm0bUsog6VKF5ck3DWDzvJ7WZ6keXJMZnUK7S6AvkN6i
ybYVVBwvqZdPU8B7ud6z7+gQ9AgfP3zrYiWEY0yXAwZHYPKkA/2tvHrAxNwv
ir4+DiaHNZaqWWogU7qNtk14BjwNgz+91qyEn2qh/UoTsxCHy7I5OVgKXfYs
4/5vF+CGjozvCmcmXDnSZRcmtAxOgyXXzVPjwe92Wsnm0xWQ9pMxWt0dByWy
DvKIfQuWj5AvedPYAFe4/fne0xjEdC5o4gAxBuop5nziLljEpsp6eP/9HGjW
/FxgfhiHQk+kcpytzwPy/AmDF404FMAqXGuCyYUzjb/Esl4woOwDKyxpjmmQ
Wso1TRFhRJVBvq1H+1PgnUbuU9f7eGS4VTcheT0ZLkkt4I1YmZAh6Wx0pGUq
xOtJ1+sWMSHRzkAWffc0sKsKIl6zZEb0zPn9jjf9QT3z2FJxDgtiTPOe0nkV
A78HNu2vGBGQnraPp7qUF/C2OB8MXSeg4QuW+Yqy4SDe3e+yL4aIhHtNfgvy
FIHwSlazmyoJMcYZcC1fzoX8OxGHj2yS0MfMuv4fRvmgdvNnE3nisYJaEEmU
rowMToxpe912psN/NrgcljQ7V0Y187aTkbJgA9V7NKd/lr5vpdq2/gT4LXZR
zZ3O1kdL20915pBibcOpIapL7gTzXZ4aoXpJTJ6UcG+carq176x8e35RLb1t
mqmdOEV1ratUPWX/DNVCnpNrsdOzVE+u9Pe1HZmnOvJXXjXRfYFqokD0zMjI
ItUfbmfcCt29TPUy+j5i8XKFaptjZelcpatU9yeWvW8S+UP1+p3WwH3261Qf
OM2wdStvg2rlcBHzFO6tf99LwER00GibaokpXeYOdRr0n3eQZhnL/vwzpigw
aVcQLdWWUnld+PN0VH9XNQstXP7npUle1jEfeqoztJXpvZUwVL9UefU1feyf
RXrVOiNeYamWk3H13nkMR7WRYMMabcs/L1V/HHrgxEC1H8bYRms347/378sI
pyv7Z6yDk84JazzVNLHGSUPsTFQ/DEj6yF7yzwUH3jKy3Wemmk3toYQzkYXq
noONLU/z/zk5BHaPGBOovpokzSaw9c+Or8KceuKIVCf8FAgkXiBR7SvEvLS9
/c+hnBdfv9sZSZ0fUVcOFYZv/8b/i5//6o3/nv/P/9/4/wAljs22
         "], {{{}, 
           {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[{
              PolygonBox[{{459, 416, 2031, 749, 1395, 71, 1272, 1918, 624, 
               2213, 957, 1603, 289, 2331, 1116, 1762}}], 
              PolygonBox[{{161, 205, 2280, 1039, 1685, 375, 708, 1354, 24, 
               2465, 1312, 1958, 665, 998, 1644, 332, 2360, 1156, 1802, 502, 
               2102, 835, 1481}, {1576, 2008, 723, 1369, 44, 1324, 1970, 678, 
               1011, 1657, 345, 1169, 1815, 515, 2115, 848, 1494, 175, 1246, 
               1892, 597, 2189, 930}}], 
              PolygonBox[{{929, 971, 1617, 304, 2341, 1130, 1776, 474, 2078, 
               807, 1453, 132, 2397, 1208, 1854, 556, 2152, 889, 1535, 219, 
               2289, 1051, 1697, 389, 2007, 722, 1368, 43, 2475, 1323, 1969, 
               677, 2258, 1010, 1656, 344, 2370, 1168, 1814, 514, 2114, 847, 
               1493, 174, 2424, 1245, 1891, 596, 2188}}], 
              PolygonBox[{{750, 1563, 248, 2307, 1079, 1725, 418, 2033, 751, 
               1397, 73, 2440, 1273, 1919, 625, 2214, 958, 1604, 290, 2332, 
               1117, 1763, 460, 2068, 793, 1439, 117, 1195, 1841, 542, 2140, 
               875, 1521, 204, 1038, 1684, 374, 1996, 707, 1353, 23, 1311, 
               1957, 664, 2248, 997, 1643, 331, 1155, 1801, 501, 2101, 834, 
               1480, 160, 1232, 1878, 583, 2176, 916, 1562, 247, 1078, 1724, 
               417, 2032}}], 
              PolygonBox[{{1536, 2399, 1210, 1856, 558, 2154, 891, 1537, 221, 
               2290, 1053, 1699, 391, 2009, 724, 1370, 45, 2476, 1325, 1971, 
               679, 2259, 1012, 1658, 346, 2371, 1170, 1816, 516, 2116, 849, 
               1495, 176, 2425, 1247, 1893, 598, 2190, 931, 1577, 263, 433, 
               2045, 766, 1412, 89, 2449, 1286, 1932, 639, 2226, 972, 1618, 
               305, 2342, 1131, 1777, 475, 2079, 808, 1454, 133, 2398, 1209, 
               1855, 557, 2153, 890}}], PolygonBox[CompressedData["
1:eJwV0slTz3Ecx/FPpeWnuJOlXJB2yx0tzlHhV9lm7HKnZeyVGaHwD2ixt2LG
8gfYzSihyHJxpcIFj++B3/f9fbyezPwqe+fhivrEEEKCP5n+Sk0O4XsshGJ3
f/Tpvp8awk2jsbQQ/iSF0JwSwjbbDfzKrBAW8hjfwKv4uGZY38S/8f08zi/y
Xp6vz4h69sLzXc8JLIm1auu06T4v6E7qhtlrVm27xna5f/ewdto96V7C8/ig
pk27iz/mJfpifT1v5sn2n/mMO5v3uM/qJ+zG7Or0RbxPX+T5nvc3vH9r/1vf
ZF9nX84v6xfwNF7OK/kHzZC+kX/l+/hWfoH38Dx9un4uL+fP3cPRF88TeYu+
1tnJZ3s+rz+hH+KveJX9avt67ZTnT55zvR+wbdXt1D1i63VFukO6Jj4r+p74
tDuLd7vbtON2b+1q9YX8jr7Q813vr3s/av9L32hfa1/GL+kzeSov45v4e82g
voF/4Xv5Fn6ed/Nc/Wz9HF7Gn7mH3P/sEvgZfY2+g8c8t3t/XD+of8kr7VfZ
L+OH9D/dH93ZfAXv17Tod/CHfJ2+UH+QN/Kk6LviU+7FvMvdqv9gN2pXoy/g
t/UF0e+u99e8H7Gf0TfY19iX8k79fJ7CS/lG/k4zoD/KP/M9fDPvYiu0MW0G
K2VP3YPRz5yd1sWjH7/Pc5pjmhfeb7JZabNUc1Dzwz3hzvL/5fA++zO67fwB
X6st0B7gDTwx+n74T/ciftXdon9vN2IX1+fzW/r86HfW+17v39hP64/ax+1L
eId+Hk/mFWzMvl97hE2y3ayatWuv8hxtmjadl/An7gH3X7t/dqf0W/UX+X9d
e45E
               "]], PolygonBox[CompressedData["
1:eJwl1lV01mUAx/GXEMUECQGJNWWcY9EIHgGJBaNFGkQvpGF01wDFK1AatrFg
hH0nIEgzVqReqkh3bYSf53jB2f95Pr/vlO3dy6KHj00dUzESiVTw50cPJ3x8
+LQ/nuc/FYn0c67s4zJ3s9zteiYSOVIpEkmpEom8Kfq8ciRyzfNZzw1YAsu3
X6D7hbXTNdeNZlPZY3aO1WObdAt1p2yKbPqxZiyvqo+ed7nPdF+kvaFNs+9n
35Gv1NfiFXhHnsRLNdv1afxPPpz34sv5Jp6gr6x/ln/ADznvcC63K7ebp++r
/5pX8pzufqb7nfrD+mT7N+zj+Gf6q85nnOvzeL5NM1//Cf+Zt9U303/K0/gj
fpZfd67LN+oX6E/aFdr15U15rr6p553uM9wX2l/XT7Hva9+Bf6WvySO8A0/k
JZp8V1P4H3wYT+XL+EYer6+kr8o78oPO253LbOZq+2hXsoqel2pnuD+kS7J7
3S6WjdZdcT4dvg4sz3aebiD7ibXRNdVNYQ/ZGXbNf78O26CbrzvB+7AmLEfX
xPMO3Zbw+rO9pp1s28f2ff6ltgZ/Es68By/WbNNP5uf4UN5Tv4HFaSuGr5P7
A57zw9+RP+BzdL11X+kqeF7ifrr7HT7vQW2i/Wv2n2ovez4V/t7uc23nhp8R
9601TTSjNJNZOTvNXmHrNfM0pTYFNr1ZY9Y4vDbdbXZXoLuqm2Tb23aF7mX2
2HN71p0V2efpzrIhLEWXztazWF2F8LVgv3ve5vmBzX2b2bpeuoiPi91Nc7dd
d0DXw7a57SjdJc8nPb/KYliO/RzZD6yVrrFuJJvEytgpVput083Vldgct+nF
Eli2r2dCeP253+T+uPaKdqJ9r/D34sv11fkj53a8Gy/U5Oon8TN8ME/WL+Xr
eEyV/9+c2rP9nvM837e5ZzNLm4q/1D7hi9xPdZ+v/V3b3b6Z/Uh20XOp53os
mmVrZ2s/1n7PW2oTtCP4RP6An+RXnWvxtfo5+mK7Y3apPJ5v1ceH16L7je6P
2V/WT7BPtV+mrRbeTz23ZV3ZCfsc7Wk2iCXplrC1LFr3hLVj+zzn6u7Z3LWZ
qevJHrOF7tLcbdPt13WzbWob4/9nBL/gXOJcl0fxrdpZ2gH8O95CH68fzifw
+7yUX3GuydfoZ+uL7I7a9eRxPEsfF16b7je4P2p/ST/evmf4vvJ0/UvhPdW5
Df+IF2iy9RP5Kf4JT9Qv5mt4lP4xf4a35b855+jv2t2xm6FP4Sv4I77A/RT3
efp9+q72Teyj+XD+r3Oxcx3eiGfpZ+r78138PX2cfhgfz+/xEn7ZuQb/Vj9L
X2h3xC6Fx/JMfWx4zbpf7/6I/UX9OPuU8D3mS/Uv8jLn1rwLP67Zqp/AT/KB
vId+Ef+WN9I/4k/zNnyvc7b+jt1tu+n6ZL6cP+Tz3U92n6v/Tf+RfWP7KD6M
n3cucn6FN+SZ+hn6fnwnf1cfqx/Kx/G7vJhfcn6Zf6OfGd6r7Q7bJfMYnqGP
Ca9f9+vcX9COtU0O32u2RPtCeK91buVzdebH7LO043kp/5h31y7k3/CG+oe8
Cm/N9zhv1d+2u2U3TZ/El/FyPs/9JPc5+r36LvYJ9o34UP6Pc6Fzbd6AZ+in
6/vyHfwdfYx+CB/L7/AiftG5Ol+tn6EvsDtkl8Sj+VrP/9qP4Unhe+vzLbZ/
Prz3OrfUd+JH7TPtx/ESPoB30y7gq3kDfXl4i+at+G7nLP0tu5t2U/WJ4WfF
8x77zjyeN7QfYv+38wnnWj5ffb7Ffpr9dva2zxGtG8zGsNuskF1wrsZXaadr
j9sdtEvkUXyLzx0dfkbdr3F/2P68/gv7xPC95Iv0z4X3XucW/EN+RJOhH8uL
eX/eNfzuyFfx+vqy8Dskb8l/dc7U37S7YZem78HTeRmf636C+2z9bn0n+7jw
uyUfzP9yLgj/brHN2qnaPiyfvaWN0g7SfsFv8f8AVwltgA==
               "]], 
              PolygonBox[CompressedData["
1:eJwl2AWU1WUagPErMPT0kHaholIzMHSj0qkSKjAwSYOdgAJKd6e6uzYGMAXM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               "]]}]}, {}, 
           {RGBColor[0.880722, 0.611041, 0.142051], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[
             PolygonBox[{{2482, 2534, 2535, 2531, 2533, 2530, 2529, 2528, 
              2527, 2526, 2525, 2524, 2523, 2522, 2521, 2520, 2519, 2518, 
              2517, 2516, 2515, 2514, 2513, 2512, 2511, 2510, 2509, 2508, 
              2507, 2506, 2505, 2504, 2503, 2502, 2501, 2500, 2499, 2498, 
              2497, 2496, 2495, 2494, 2493, 2492, 2491, 2490, 2489, 2488, 
              2487, 2486, 2485, 2484, 2483, 
              2532}}]]}, {}, {}, {}, {}, {}, {}}, {{}, {}, 
           TagBox[
            {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
             Opacity[1.], LineBox[CompressedData["
1:eJwl2gW0lNUehvFDg0h3SXd3g5R0d3c3CCIt3V0SCgLSpYKkhEgJAkqJhIAC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              "]]},
            Annotation[#, "Charting`Private`Tag$3766620#1"]& ], 
           TagBox[
            {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
             Opacity[1.], 
             LineBox[{2482, 2532, 2483, 2484, 2485, 2486, 2487, 2488, 2489, 
              2490, 2491, 2492, 2493, 2494, 2495, 2496, 2497, 2498, 2499, 
              2500, 2501, 2502, 2503, 2504, 2505, 2506, 2507, 2508, 2509, 
              2510, 2511, 2512, 2513, 2514, 2515, 2516, 2517, 2518, 2519, 
              2520, 2521, 2522, 2523, 2524, 2525, 2526, 2527, 2528, 2529, 
              2530, 2533, 2531}]},
            Annotation[#, "Charting`Private`Tag$3766620#2"]& ]}}], {}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Frame->{{False, False}, {False, False}},
       FrameLabel->{{None, None}, {None, None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->{{15.13265306122449, 1.4999999999999432`}, {36., 
        22.99999999999997}},
       Method->{
        "DefaultBoundaryStyle" -> Automatic, 
         "DefaultGraphicsInteraction" -> {
          "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
           "Effects" -> {
            "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2},
              "Droplines" -> {
              "freeformCursorMode" -> True, 
               "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
         "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
         None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& )}, "AxesInFront" -> True},
       PlotLabel->FormBox["\"T[0,4] = 0.70653\"", TraditionalForm],
       PlotRange->{{0., 3.999999918367347}, {0, All}},
       PlotRangeClipping->True,
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {0, 
          Scaled[0.05]}},
       Ticks->{Automatic, Automatic}], {957.4509554303127, -197.34852259912216},
       ImageScaled[{0.5, 0.5}], {529.3907757153739, 375.90194780785174}]}, {}},
   ImageSize->1200,
   PlotRange->{{0, 1241.5454915941582`}, {-394.6970451982443, 0}},
   PlotRangePadding->{6, 5}],
  StripOnInput->False,
  Magnification->0.5 Inherited]], "Output",
 CellChangeTimes->{3.8207272843945637`*^9, 3.820813182932118*^9, 
  3.8281374468856497`*^9, 3.8281618486199827`*^9},
 CellLabel->
  "Out[1111]=",ExpressionUUID->"fb373562-1b2d-4704-b8e1-0f8ec5610d24"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BK vs U-BK", "Subsection",
 CellChangeTimes->{{3.828131598129963*^9, 
  3.828131601392784*^9}},ExpressionUUID->"0b44c793-5115-4989-807f-\
57605517071f"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"maxpos", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"td", "=", 
   RowBox[{
    RowBox[{".1", 
     RowBox[{"RandomFunction", "[", 
      RowBox[{
       RowBox[{"FractionalBrownianMotionProcess", "[", ".3", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "maxpos", ",", "0.01"}], "}"}]}], "]"}]}], "+", 
    "1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"TimeSeriesMap", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Max", "[", 
       RowBox[{"0", ",", "#"}], "]"}], "&"}], ",", "td"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "f", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "=", 
   RowBox[{"Interpolation", "[", "data", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maxT", "=", 
   RowBox[{"Exp", "[", 
    RowBox[{"-", 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "maxpos"}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maj", "=", 
   RowBox[{"Max", "[", "data", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"min", "=", 
   RowBox[{"Min", "[", "data", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"midcontrol", "=", 
   RowBox[{
    RowBox[{"maj", "/", "2"}], "+", 
    RowBox[{"min", "/", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MCn", "=", "100"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rate", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"K", "=", 
   RowBox[{"c", "=", "5"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Magnify", "[", 
  RowBox[{
   RowBox[{"GraphicsRow", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"LogLogPlot", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", " ", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"FoM", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"TRatioTracking", "[", 
               RowBox[{"#1", ",", "maj", ",", "#2"}], "]"}], "&"}], ",", "f", 
             ",", "pos", ",", "MCn"}], "]"}], " ", 
           RowBox[{"(*", " ", 
            RowBox[{"RT", " ", "-", " ", 
             RowBox[{"tight", " ", "majorant"}]}], " ", "*)"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"FoM", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"TBK", "[", 
               RowBox[{"#1", ",", "maj", ",", "#2", ",", "K", ",", "c"}], 
               "]"}], "&"}], ",", "f", ",", "pos", ",", "MCn"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"FoM", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"TUBK", "[", 
               RowBox[{"#1", ",", "maj", ",", "#2", ",", "K", ",", "c"}], 
               "]"}], "&"}], ",", "f", ",", "pos", ",", "MCn"}], "]"}], 
           "\[IndentingNewLine]", 
           RowBox[{"(*", " ", 
            RowBox[{"RRT", " ", "-", " ", 
             RowBox[{"mid", " ", "control"}]}], " ", "*)"}], ","}], 
          "\[IndentingNewLine]", "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"pos", ",", 
           RowBox[{".01", " ", "maxpos"}], ",", "maxpos"}], "}"}], ",", 
         RowBox[{"MaxRecursion", "\[Rule]", "1"}], ",", 
         RowBox[{"PlotPoints", "\[Rule]", "22"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Red", ",", "Dashed", ",", "Black"}], "}"}]}], ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\"\<lookups * Variance\>\"", ","}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\"\<depth\>\"", ","}], "}"}]}], "}"}]}], ",", 
         RowBox[{"PlotLabels", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<RT\>\"", ",", "\"\<BK\>\"", ",", "\"\<U-BK (ours)\>\""}], 
           "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"f", "[", "x", "]"}], ",", "midcontrol"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "maxpos"}], "}"}], ",", 
         RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"0", ",", "All"}], "}"}]}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"\"\<T[0,\>\"", "<>", 
           RowBox[{"ToString", "[", "maxpos", "]"}], "<>", "\"\<] = \>\"", "<>", 
           RowBox[{"ToString", "[", "maxT", "]"}]}]}]}], "]"}]}], 
      "\[IndentingNewLine]", "}"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "1200"}]}], "\[IndentingNewLine]", "]"}],
    ",", "0.5"}], "]"}]}], "Input",
 CellChangeTimes->{
  3.8281316054449263`*^9, {3.828131642480135*^9, 3.828131677856579*^9}},
 CellLabel->
  "In[286]:=",ExpressionUUID->"90bae6dc-4413-4561-9ced-dcab7620cb66"],

Cell[BoxData[
 StyleBox[
  GraphicsBox[{{}, {InsetBox[
      GraphicsBox[{{{}, {}, 
         TagBox[
          {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
           LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAYKx+2kHACcAwQJn8o/sVwCgW/xVH
6AjARDD5YnyUGcDwf39RTBAIwN8l4CnTyRbAbCxdyiYmB8DjrSL/vtIWwOfY
OkMBPAbA6LDwhoJSE8BErVD1X2EFwFo5g8YZ7BPAoIFmp76GBMBNabFZ8tQU
wCTcwD5nsAPAgvUe5HZ/FcCoNhvWD9oCwFwSwe9+rRHA4NPSqo3xAcDd3BM+
ACURwBdxin8LCQHAtJi9g173F8AwNnqNDTAAwMzua7qSpBTAkvbTNh+u/r9Q
1vrrvl8OwCsGbs3N1/y/86bnRH9YDMDEFQhkfAH7v+aLisS/KgnArDErxb4z
+b8bJlChbNkKwJRNTiYBZve/3Ajrr6wDCcA+ueH5S7f1v2j1SJmZpwfA6SR1
zZYI9L8lm664dbsHwPoVwxuMNfK/KngrD6WfB8AMBxFqgWLwv4MVO9rb3QPA
wI+eVf5c7b/ZS6sldtwAwGgRG9f59Om/ssF0zrFKAMCuq6ntHJ7mv5Us8msH
9/2/9EU4BEBH478BhnfMdMr8vxDWdyBwT9+/XGoqvu/v+783IH84YBDYv4ND
9P1dr/q/aqlHGnJN0b9uuDBKhQX6vzllIPgHFcW/8kmaLoz/9b9aixZG/rGp
v3Jz7ghkVPi/GD8qqhF4sD+QaRoCkJX2v3h/Z+fyn8Y/B4ECAzSe9L+y79x8
7oHSPx+n4sE2hPW/neBEvME32T/jP+Dg3e3zv4jRrPuU7d8/NIE2wIM4979s
VhUoX5rjPy6pEnCcCvq/E0RU0vM95z+Z9SvQr5r8vzWSspd3o+o/Tz8zhKly
+b9X4BBd+wjuPwWvzywKvALA1hF9FpXb8D8LeUsSH2T/v4CzcX6ssvI/luPP
1Y2yA8DkFUehd3D0P0BagDBsOQjASHgcxEIu9j8UPfEQdIkZwLXnZl4=
            "]]},
          Annotation[#, "Charting`Private`Tag$660405#1"]& ], 
         TagBox[
          {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
           Opacity[1.], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAYKx+2kHACcCQwBcolWwmwCgW/xVH
6AjA05dt5brEJcDwf39RTBAIwOe9evBsAyXAbCxdyiYmB8C69fkGfd0kwOfY
OkMBPAbAW9/boUh8JMBErVD1X2EFwHX3bNxtmiPAoIFmp76GBMBKE3reyYoj
wCTcwD5nsAPAMVU3fzkbI8CoNhvWD9oCwNkIz7fqCiPA4NPSqo3xAcDRiLCw
I+QiwBdxin8LCQHAS8mH2Nk/IsAwNnqNDTAAwGN7AWv8/SDAkvbTNh+u/r+0
++aC//4gwCsGbs3N1/y/vTlcYwuAIMDEFQhkfAH7v2kJsqDAQiDArDErxb4z
+b8rJphJA+MewJRNTiYBZve/jG1waozUH8A+ueH5S7f1vyrQzLyDHh/A6SR1
zZYI9L+wbTqZJywfwPoVwxuMNfK/dQ2V/HG7HsAMBxFqgWLwv5l1C1aFPB7A
wI+eVf5c7b8nGfFrgAYewGgRG9f59Om/LgbTLokyHsCuq6ntHJ7mvwa062+l
EB3A9EU4BEBH479x4ylZH9wbwBDWdyBwT9+/5W+MfTaKGsA3IH84YBDYv/G1
ZhcwqxvAaqlHGnJN0b9pJ/tSVVYbwDllIPgHFcW/D6bqrcV5G8BaixZG/rGp
v+Qo6FWGAh3AGD8qqhF4sD+bkgAWn0YawHh/Z+fyn8Y/OZUEwRUDG8Cy79x8
7oHSP9J0VznJhx3AneBEvME32T/nJUDNuUsewIjRrPuU7d8/azUgC1vTHMBs
VhUoX5rjP9/ZulN1Zx/AE0RU0vM95z/lxFLWwW0gwDWSspd3o+o/7VsSlvqV
IMBX4BBd+wjuP0KKcDBg2CHA1hF9FpXb8D8sMSHChTQiwICzcX6ssvI/Hu3W
hrVII8DkFUehd3D0P3qAPydHVCPASHgcxEIu9j9cM4k36LojwK7YU68=
            "]]},
          Annotation[#, "Charting`Private`Tag$660405#2"]& ], 
         TagBox[
          {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
           LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAYKx+2kHACcAIF/us5dEpwCgW/xVH
6AjAjwGw4gdSKcDwf39RTBAIwMqZuo35NSnAbCxdyiYmB8ChTQAOZWwowOfY
OkMBPAbAtNK7MywtKMBErVD1X2EFwDaWMEfTTifAoIFmp76GBMA9R86bh60n
wCTcwD5nsAPALUY2ue0lJ8CoNhvWD9oCwDk9d92H4CbA4NPSqo3xAcDChog0
vmcmwBdxin8LCQHAwMei1R6XJcAwNnqNDTAAwE4gbQ7xTCXAkvbTNh+u/r92
I9ixz34kwCsGbs3N1/y/y73SpeHlI8DEFQhkfAH7v8JCT+qVwiPArDErxb4z
+b/nVAWeiSwkwJRNTiYBZve/xYIcX7STI8A+ueH5S7f1v7MGFJpWpiLA6SR1
zZYI9L/KStNZMC0jwPoVwxuMNfK/9n8UE+j2IsAMBxFqgWLwvyDwVfbziSLA
wI+eVf5c7b8HQRSjjDgjwGgRG9f59Om/6VXEp+eLIsCuq6ntHJ7mv7Wzf2P7
GyLA9EU4BEBH47/3h2IXiN8hwBDWdyBwT9+/Qqo7BwDuIcA3IH84YBDYv6ac
2VRebSHAaqlHGnJN0b+T2ls1RJAhwDllIPgHFcW/E/CwubYRIcBaixZG/rGp
v4E8qNHriCHAGD8qqhF4sD97yKoSOfQgwHh/Z+fyn8Y/MLMrLwnuIcCy79x8
7oHSP1mMwc11IiLAneBEvME32T95wr+Exb0iwIjRrPuU7d8/PJrd8RxvIsBs
VhUoX5rjP+nteQg4eCPAE0RU0vM95z+205DxI4wjwDWSspd3o+o/Q7e9Lyjd
I8BX4BBd+wjuP2nL0vxe/iPA1hF9FpXb8D+xhefnSWwlwICzcX6ssvI/dcbr
3p+sJsDkFUehd3D0Pyh0Azc8UibASHgcxEIu9j9EHkfo6GwmwGWJWzw=
            "]]},
          
          Annotation[#, "Charting`Private`Tag$660405#3"]& ]}, {{{}, {
           GraphicsGroupBox[{
             {GrayLevel[1], AbsoluteThickness[4], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], 
              JoinForm["Round"], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -6.384231819843325}], 
                Offset[{0, 0}, {1.482235406661309, -6.384231819843325}], 
                Offset[{0., 0.}, {1.52828710852119, -6.384231819843325}], 
                Offset[{0., 0.}, {1.52828710852119, -6.384231819843325}], 
                Offset[{0., 0.}, {1.574338810381071, -6.384231819843325}], 
                Offset[{0, 0}, {1.6675187430257747`, -6.384229103479996}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.6675187430257747`, -6.384229103479996}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.6675187430257747`, -6.384229103479996}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.6675187430257747`, -6.384229103479996}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -6.384231819843325}], 
                Offset[{0, 0}, {1.482235406661309, -6.384231819843325}], 
                Offset[{0., 0.}, {1.52828710852119, -6.384231819843325}], 
                Offset[{0., 0.}, {1.52828710852119, -6.384231819843325}], 
                Offset[{0., 0.}, {1.574338810381071, -6.384231819843325}], 
                Offset[{0, 0}, {1.6675187430257747`, -6.384229103479996}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.6675187430257747`, -6.384229103479996}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.6675187430257747`, -6.384229103479996}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.6675187430257747`, -6.384229103479996}]}]}, 
             {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]}], 
              PolygonBox[{
               Offset[{29., 6.500000000000006}, {
                 1.6675187430257747`, -6.384229103479996}], 
                Offset[{29., -6.499999999999994}, {
                 1.6675187430257747`, -6.384229103479996}], 
                Offset[{10.000000000000002`, -6.499999999999997}, {
                 1.6675187430257747`, -6.384229103479996}], 
                Offset[{9.999999999999998, 6.500000000000003}, {
                 1.6675187430257747`, -6.384229103479996}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
              StyleBox[
               RotationBox["\<\"RT\"\>",
                BoxRotation->0.],
               StripOnInput->False,
               LineOpacity->1,
               FrontFaceOpacity->1,
               BackFaceOpacity->1,
               Opacity->1,
               FontOpacity->1], 
              Offset[{19.5, 4.3298697960381105*^-15}, \
{1.6675187430257747, -6.384229103479996}], 
              ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}], 
           GraphicsGroupBox[{
             {GrayLevel[1], AbsoluteThickness[4], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], 
              JoinForm["Round"], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -9.865052924631236}], 
                Offset[{0, 0}, {1.482235406661309, -9.865052924631236}], 
                Offset[{0., 0.}, {1.52828710852119, -9.865052924631236}], 
                Offset[{0., 0.}, {1.52828710852119, -9.865052924631236}], 
                Offset[{0., 0.}, {1.574338810381071, -9.865052924631236}], 
                Offset[{0, 0}, {1.6675187430257747`, -9.856000070125294}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.6675187430257747`, -9.856000070125294}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.6675187430257747`, -9.856000070125294}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.6675187430257747`, -9.856000070125294}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -9.865052924631236}], 
                Offset[{0, 0}, {1.482235406661309, -9.865052924631236}], 
                Offset[{0., 0.}, {1.52828710852119, -9.865052924631236}], 
                Offset[{0., 0.}, {1.52828710852119, -9.865052924631236}], 
                Offset[{0., 0.}, {1.574338810381071, -9.865052924631236}], 
                Offset[{0, 0}, {1.6675187430257747`, -9.856000070125294}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.6675187430257747`, -9.856000070125294}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.6675187430257747`, -9.856000070125294}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.6675187430257747`, -9.856000070125294}]}]}, 
             {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]}], 
              PolygonBox[{
               Offset[{29., 6.500000000000006}, {
                 1.6675187430257747`, -9.856000070125294}], 
                Offset[{29., -6.499999999999994}, {
                 1.6675187430257747`, -9.856000070125294}], 
                Offset[{10.000000000000002`, -6.499999999999997}, {
                 1.6675187430257747`, -9.856000070125294}], 
                Offset[{9.999999999999998, 6.500000000000003}, {
                 1.6675187430257747`, -9.856000070125294}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
              StyleBox[
               RotationBox["\<\"BK\"\>",
                BoxRotation->0.],
               StripOnInput->False,
               LineOpacity->1,
               FrontFaceOpacity->1,
               BackFaceOpacity->1,
               Opacity->1,
               FontOpacity->1], 
              Offset[{19.5, 4.3298697960381105*^-15}, \
{1.6675187430257747, -9.856000070125294}], 
              ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}], 
           GraphicsGroupBox[{
             {GrayLevel[1], AbsoluteThickness[4], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], 
              JoinForm["Round"], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -11.212714441949295`}], 
                Offset[{0, 0}, {1.482235406661309, -11.212714441949295`}], 
                Offset[{0., 0.}, {1.52828710852119, -11.212714441949295`}], 
                Offset[{0., 0.}, {1.52828710852119, -11.212714441949295`}], 
                Offset[{0., 0.}, {1.574338810381071, -11.212714441949295`}], 
                Offset[{0, 0}, {1.6675187430257747`, -11.221768140200814`}], 
                Offset[{5., 1.1102230246251565`*^-15}, {1.6675187430257747`,
                  -11.221768140200814`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.6675187430257747`, -11.221768140200814`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.6675187430257747`, -11.221768140200814`}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -11.212714441949295`}], 
                Offset[{0, 0}, {1.482235406661309, -11.212714441949295`}], 
                Offset[{0., 0.}, {1.52828710852119, -11.212714441949295`}], 
                Offset[{0., 0.}, {1.52828710852119, -11.212714441949295`}], 
                Offset[{0., 0.}, {1.574338810381071, -11.212714441949295`}], 
                Offset[{0, 0}, {1.6675187430257747`, -11.221768140200814`}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.6675187430257747`, -11.221768140200814`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.6675187430257747`, -11.221768140200814`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.6675187430257747`, -11.221768140200814`}]}]}, 
             {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]}], 
              PolygonBox[{
               Offset[{68., 7.500000000000015}, {
                 1.6675187430257747`, -11.221768140200814`}], 
                Offset[{68., -7.499999999999985}, {
                 1.6675187430257747`, -11.221768140200814`}], 
                Offset[{10., -7.499999999999997}, {
                 1.6675187430257747`, -11.221768140200814`}], 
                Offset[{10., 7.500000000000003}, {
                 1.6675187430257747`, -11.221768140200814`}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
              StyleBox[
               RotationBox["\<\"U-BK (ours)\"\>",
                BoxRotation->0.],
               StripOnInput->False,
               LineOpacity->1,
               FrontFaceOpacity->1,
               BackFaceOpacity->1,
               Opacity->1,
               FontOpacity->1], Offset[{39., 8.659739592076221*^-15}, 
              {1.6675187430257747, -11.221768140200814}], 
              ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}]}}, {}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{-3.2188758248682006`, -12.909955411577826`},
       CoordinatesToolOptions:>{"DisplayFunction" -> ({
           Exp[
            Part[#, 1]], 
           Exp[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Exp[
            Part[#, 1]], 
           Exp[
            Part[#, 2]]}& )},
       DisplayFunction->Identity,
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox["\"lookups * Variance\"", TraditionalForm], ""}, {
          FormBox["\"depth\"", TraditionalForm], ""}},
       FrameTicks->FrontEndValueCache[{{Quiet[
            Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
           Charting`ScaledFrameTicks[{Log, Exp}]}, {Quiet[
            Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
           
           Charting`ScaledFrameTicks[{
            Log, Exp}]}}, {{{{-11.512925464970229`, 
             FormBox[
              TemplateBox[{"10", 
                RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox], TraditionalForm], {0.01, 
             0.}}, {-9.210340371976182, 
             FormBox[
              TemplateBox[{"10", 
                RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox], TraditionalForm], {0.01, 
             0.}}, {-6.907755278982137, 
             FormBox["0.001`", TraditionalForm], {0.01, 
             0.}}, {-4.605170185988091, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.010\"", ShowStringCharacters -> False], 0.01, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 
             0.}}, {-2.3025850929940455`, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.100\"", ShowStringCharacters -> False], 0.1, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 0.}}, {
            0., 
             FormBox["1", TraditionalForm], {0.01, 
             0.}}, {-13.815510557964274`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-13.122363377404328`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-12.716898269296165`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-12.429216196844383`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-12.206072645530174`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-12.02375108873622, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-11.86960040890896, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-11.736069016284437`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-11.618285980628055`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-10.819778284410283`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-10.41431317630212, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-10.126631103850338`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.903487552536127, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.721165995742174, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.567015315914915, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.433483923290392, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.315700887634009, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-8.517193191416238, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-8.111728083308073, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.824046010856292, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.600902459542082, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.418580902748128, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.264430222920869, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.1308988302963465`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.013115794639964, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-6.214608098422191, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.809142990314028, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.521460917862246, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.298317366548036, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.115995809754082, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-4.961845129926823, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-4.8283137373023015`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-4.710530701645918, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.912023005428146, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.506557897319982, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.2188758248682006`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.995732273553991, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.8134107167600364`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.659260036932778, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.5257286443082556`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.4079456086518722`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.2039728043259361`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.916290731874155, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.5108256237659907, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.35667494393873245`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.2231435513142097, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.10536051565782628`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.0986122886681098`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.3862943611198906`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.791759469228055, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.9459101490553132`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.0794415416798357`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.1972245773362196`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.302585092994046, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.995732273553991, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {3.4011973816621555`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {3.6888794541139363`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}}, {{-11.512925464970229`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-9.210340371976182, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-6.907755278982137, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-4.605170185988091, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-2.3025850929940455`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {0., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-13.815510557964274`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-13.122363377404328`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-12.716898269296165`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-12.429216196844383`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-12.206072645530174`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-12.02375108873622, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-11.86960040890896, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-11.736069016284437`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-11.618285980628055`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-10.819778284410283`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-10.41431317630212, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-10.126631103850338`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.903487552536127, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.721165995742174, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.567015315914915, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.433483923290392, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.315700887634009, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-8.517193191416238, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-8.111728083308073, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.824046010856292, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.600902459542082, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.418580902748128, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.264430222920869, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.1308988302963465`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.013115794639964, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-6.214608098422191, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.809142990314028, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.521460917862246, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.298317366548036, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.115995809754082, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-4.961845129926823, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-4.8283137373023015`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-4.710530701645918, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.912023005428146, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.506557897319982, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.2188758248682006`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.995732273553991, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.8134107167600364`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.659260036932778, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.5257286443082556`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.4079456086518722`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.2039728043259361`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.916290731874155, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.5108256237659907, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.35667494393873245`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.2231435513142097, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.10536051565782628`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.0986122886681098`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.3862943611198906`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.791759469228055, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.9459101490553132`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.0794415416798357`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.1972245773362196`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.302585092994046, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.995732273553991, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {3.4011973816621555`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {3.6888794541139363`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}}}, {{{-2.995732273553991, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.05\"", ShowStringCharacters -> False], 0.05, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 
             0.}}, {-2.3025850929940455`, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.10\"", ShowStringCharacters -> False], 0.1, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 
             0.}}, {-0.6931471805599453, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.50\"", ShowStringCharacters -> False], 0.5, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 0.}}, {
            0., 
             FormBox["1", TraditionalForm], {0.01, 0.}}, {-4.605170185988091, 
             
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.912023005428146, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.506557897319982, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.2188758248682006`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.8134107167600364`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.659260036932778, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.5257286443082556`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.4079456086518722`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.2039728043259361`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.916290731874155, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.5108256237659907, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.35667494393873245`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.2231435513142097, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.10536051565782628`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.0986122886681098`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.3862943611198906`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.791759469228055, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.9459101490553132`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.0794415416798357`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.1972245773362196`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.302585092994046, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.3978952727983707`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.4849066497880004`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}}, {{-2.995732273553991, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-2.3025850929940455`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {0., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-4.605170185988091, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.912023005428146, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.506557897319982, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.2188758248682006`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.8134107167600364`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.659260036932778, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.5257286443082556`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.4079456086518722`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.2039728043259361`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.916290731874155, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.5108256237659907, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.35667494393873245`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.2231435513142097, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.10536051565782628`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.0986122886681098`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.3862943611198906`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.791759469228055, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.9459101490553132`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.0794415416798357`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.1972245773362196`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.302585092994046, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.3978952727983707`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.4849066497880004`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}}}}],
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->{{47.00000000000003, 86.48415550290804}, {36., 
        22.99999999999997}},
       Method->{
        "DefaultBoundaryStyle" -> Automatic, 
         "DefaultGraphicsInteraction" -> {
          "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
           "Effects" -> {
            "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2},
              "Droplines" -> {
              "freeformCursorMode" -> True, 
               "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
         "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
         None},
       PlotRange->NCache[{{-3.2188758248682006`, 
           Log[4]}, {-12.909955411577826`, 0.}}, {{-3.2188758248682006`, 
         1.3862943611198906`}, {-12.909955411577826`, 0.}}],
       PlotRangeClipping->False,
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.05], 
          Scaled[0.08090169943749476]}},
       Ticks->{Quiet[
          Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , Quiet[
          Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& }], {342.0735818895269, -197.01001701476258},
       ImageScaled[{0.5, 0.5}], {645.1990142696758, 375.25717526621446}], 
     InsetBox[
      GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJwUm3c8lm8bh+09MkNCkmQlDT+S8woVSZHdkJAio6RSdkUaRkVJZIZUdoRI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         "], {{{}, 
           {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl2mW4lkUbheEt3d3d3aB0pzRId0uIKGBLd3d3d3d3SBhISjcIImFLfOf4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              
              "]]]}, {}, 
           {RGBColor[0.880722, 0.611041, 0.142051], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[
             PolygonBox[{{2911, 2963, 2964, 2960, 2962, 2959, 2958, 2957, 
              2956, 2955, 2954, 2953, 2952, 2951, 2950, 2949, 2948, 2947, 
              2946, 2945, 2944, 2943, 2942, 2941, 2940, 2939, 2938, 2937, 
              2936, 2935, 2934, 2933, 2932, 2931, 2930, 2929, 2928, 2927, 
              2926, 2925, 2924, 2923, 2922, 2921, 2920, 2919, 2918, 2917, 
              2916, 2915, 2914, 2913, 2912, 
              2961}}]]}, {}, {}, {}, {}, {}, {}}, {{}, {}, 
           TagBox[
            {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
             Opacity[1.], LineBox[CompressedData["
1:eJwl2mWgUEXbheEDSCpId5d0d3d3d4M0AgpISKN0KKG0dAhKSgoCKlLSHdIl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              "]]},
            Annotation[#, "Charting`Private`Tag$673951#1"]& ], 
           TagBox[
            {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
             Opacity[1.], 
             LineBox[{2911, 2961, 2912, 2913, 2914, 2915, 2916, 2917, 2918, 
              2919, 2920, 2921, 2922, 2923, 2924, 2925, 2926, 2927, 2928, 
              2929, 2930, 2931, 2932, 2933, 2934, 2935, 2936, 2937, 2938, 
              2939, 2940, 2941, 2942, 2943, 2944, 2945, 2946, 2947, 2948, 
              2949, 2950, 2951, 2952, 2953, 2954, 2955, 2956, 2957, 2958, 
              2959, 2962, 2960}]},
            Annotation[#, "Charting`Private`Tag$673951#2"]& ]}}], {}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Frame->{{False, False}, {False, False}},
       FrameLabel->{{None, None}, {None, None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->{{10.03061224489796, 1.5}, {36., 22.99999999999997}},
       Method->{
        "DefaultBoundaryStyle" -> Automatic, 
         "DefaultGraphicsInteraction" -> {
          "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
           "Effects" -> {
            "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2},
              "Droplines" -> {
              "freeformCursorMode" -> True, 
               "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
         "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
         None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& )}, "AxesInFront" -> True},
       PlotLabel->FormBox["\"T[0,4] = 0.0116376\"", TraditionalForm],
       PlotRange->{{0., 3.999999918367347}, {0, All}},
       PlotRangeClipping->True,
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {0, 
          Scaled[0.05]}},
       Ticks->{Automatic, Automatic}], {965.2439740395756, -197.01001701476258},
       ImageScaled[{0.5, 0.5}], {523.2454710116657, 375.25717526621446}]}, {}},
   ImageSize->1200,
   PlotRange->{{0, 1246.3407843000975`}, {-394.02003402952516`, 0}},
   PlotRangePadding->{6, 5}],
  StripOnInput->False,
  Magnification->0.5 Inherited]], "Output",
 CellChangeTimes->{
  3.828131609061944*^9, {3.828131644992709*^9, 3.828131651394149*^9}, 
   3.828131681504861*^9},
 CellLabel->
  "Out[298]=",ExpressionUUID->"6521c30d-39fd-462e-bb28-1ed5bb98f5fa"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["compare p-series NF, pCMF, pCumulative", "Subsection",
 CellChangeTimes->{{3.820727449370482*^9, 
  3.8207274564376993`*^9}},ExpressionUUID->"c0a70a6f-3e06-4d98-9ae5-\
52a642aca76b"],

Cell["\<\
RRT uses half the tight majorant (for the entire interval) as a control:\
\>", "Text",
 CellChangeTimes->{{3.820728225300791*^9, 
  3.8207282581165743`*^9}},ExpressionUUID->"67d413ba-a247-435f-8385-\
3223fe6633bf"],

Cell["\<\
p-series Cumulative can perform very poorly for optically thin intervals such \
as this case:\
\>", "Text",
 CellChangeTimes->{{3.820728592564699*^9, 
  3.8207286044467087`*^9}},ExpressionUUID->"b619ddbb-ec96-41cd-9c53-\
86dfa8bcd999"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"maxpos", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"td", "=", 
   RowBox[{
    RowBox[{".1", 
     RowBox[{"RandomFunction", "[", 
      RowBox[{
       RowBox[{"FractionalBrownianMotionProcess", "[", ".3", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "maxpos", ",", "0.01"}], "}"}]}], "]"}]}], "+", 
    "1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"TimeSeriesMap", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Max", "[", 
       RowBox[{"0", ",", "#"}], "]"}], "&"}], ",", "td"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "f", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "=", 
   RowBox[{"Interpolation", "[", "data", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maxT", "=", 
   RowBox[{"Exp", "[", 
    RowBox[{"-", 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "maxpos"}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maj", "=", 
   RowBox[{"Max", "[", "data", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"min", "=", 
   RowBox[{"Min", "[", "data", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"midcontrol", "=", 
   RowBox[{
    RowBox[{"maj", "/", "2"}], "+", 
    RowBox[{"min", "/", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MCn", "=", "1000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rate", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Magnify", "[", 
  RowBox[{
   RowBox[{"GraphicsRow", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"LogLogPlot", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", " ", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"FoM", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"TPoissonEstimator", "[", 
               RowBox[{"#1", ",", 
                RowBox[{"midcontrol", "+", "rate"}], ",", "#2", ",", "rate"}],
                "]"}], "&"}], ",", "f", ",", "pos", ",", "MCn"}], "]"}], " ", 
           
           RowBox[{"(*", " ", 
            RowBox[{"RRT", " ", "-", " ", 
             RowBox[{"mid", " ", "control"}]}], " ", "*)"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"FoM", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"TpNF", "[", 
               RowBox[{"#1", ",", "midcontrol", ",", "#2", ",", "rate"}], 
               "]"}], "&"}], ",", "f", ",", "pos", ",", "MCn"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"FoM", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"TpCMF", "[", 
               RowBox[{"#1", ",", "maj", ",", "#2", ",", "0.99"}], "]"}], 
              "&"}], ",", "f", ",", "pos", ",", "MCn"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"FoM", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"TpCumulative", "[", 
               RowBox[{"#1", ",", "maj", ",", "#2"}], "]"}], "&"}], ",", "f", 
             ",", "pos", ",", "MCn"}], "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"FoM", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"TURM", "[", 
               RowBox[{"#1", ",", "#2", ",", "maj"}], "]"}], "&"}], ",", "f", 
             ",", "pos", ",", "MCn"}], "]"}]}], 
          RowBox[{"(*", " ", 
           RowBox[{"unbiased", " ", "ray", " ", "marching"}], " ", "*)"}], 
          "\[IndentingNewLine]", "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"pos", ",", 
           RowBox[{".01", " ", "maxpos"}], ",", "maxpos"}], "}"}], ",", 
         RowBox[{"MaxRecursion", "\[Rule]", "1"}], ",", 
         RowBox[{"PlotPoints", "\[Rule]", "22"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
           "Blue", ",", "Dashed", ",", "Red", ",", "DotDashed", ",", "Black", 
            ",", 
            RowBox[{"{", 
             RowBox[{"Red", ",", "Dashed"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"Green", ",", "Dashed"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"Orange", ",", "DotDashed"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\"\<lookups * Variance\>\"", ","}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\"\<depth\>\"", ","}], "}"}]}], "}"}]}], ",", 
         RowBox[{"PlotLabels", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<RRT\>\"", ",", "\"\<pNF\>\"", ",", "\"\<pCMF\>\"", ",", 
            "\"\<pCumu\>\"", ",", "\"\<URM (ours)\>\""}], "}"}]}]}], "]"}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"f", "[", "x", "]"}], ",", "midcontrol"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "maxpos"}], "}"}], ",", 
         RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"0", ",", "All"}], "}"}]}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"\"\<T[0,\>\"", "<>", 
           RowBox[{"ToString", "[", "maxpos", "]"}], "<>", "\"\<] = \>\"", "<>", 
           RowBox[{"ToString", "[", "maxT", "]"}]}]}]}], "]"}]}], 
      "\[IndentingNewLine]", "}"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "1200"}]}], "\[IndentingNewLine]", "]"}],
    ",", ".5"}], "]"}]}], "Input",
 CellChangeTimes->{{3.816670088781345*^9, 3.8166701886333303`*^9}, {
   3.816670236762436*^9, 3.816670286874357*^9}, 3.81667031789732*^9, {
   3.816670379762103*^9, 3.816670406946143*^9}, {3.820727463535879*^9, 
   3.82072747336513*^9}, {3.820727513786354*^9, 3.820727528570558*^9}, 
   3.820727608238599*^9, {3.820727731678915*^9, 3.820727755508183*^9}, {
   3.820727853625332*^9, 3.820727862140225*^9}, {3.820728158941854*^9, 
   3.820728159673534*^9}, {3.820813267706645*^9, 3.820813280726412*^9}, 
   3.8208133497243023`*^9, {3.828161888119609*^9, 3.828161895825745*^9}},
 CellLabel->
  "In[1112]:=",ExpressionUUID->"15c9f25f-84a8-4519-814c-7d11a3558956"],

Cell[BoxData[
 StyleBox[
  GraphicsBox[{{}, {InsetBox[
      GraphicsBox[{{{}, {}, 
         TagBox[
          {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
           LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAYKx+2kHACcB6lbMD3ZYnwCgW/xVH
6AjAar5is7eAJsDwf39RTBAIwNjWJ+HlxibAbCxdyiYmB8DPPYCph0wmwOfY
OkMBPAbAlK7QtS4cJsBErVD1X2EFwKl12vwHoSXAoIFmp76GBMD9LdzQ0FAl
wCTcwD5nsAPAFQdIlErUJMCoNhvWD9oCwEZwkp8wJiTA4NPSqo3xAcArsPZb
8hwjwBdxin8LCQHAlerlZJV2IsAwNnqNDTAAwAHIKLeSPyLAkvbTNh+u/r88
kzKpqmQhwCsGbs3N1/y/llEcolKvIMDEFQhkfAH7v8R+NfI3YiDArDErxb4z
+b9xkwx4ANIfwJRNTiYBZve/GtJwhg+NH8A+ueH5S7f1v2dcvU2rpB7A6SR1
zZYI9L8P7MjsWogewPoVwxuMNfK/M5DnlLgAHsAMBxFqgWLwv0K6Hj8N7xzA
wI+eVf5c7b+IEqkSlascwGgRG9f59Om/Uqew2T7KHMCuq6ntHJ7mvzwnb3cj
cBzA9EU4BEBH47/9ShvD37AcwBDWdyBwT9+/t3gXVgiSHMA3IH84YBDYvyzH
rD1tTRzAaqlHGnJN0b9n5vbXrf0bwDllIPgHFcW/o6JuPlgAHMBaixZG/rGp
vx+J74VweRzAGD8qqhF4sD98iJ7S6f8cwHh/Z+fyn8Y/k75vD+mhHcCy79x8
7oHSP8sBbzmn7h3AneBEvME32T9x9cIhLp8ewIjRrPuU7d8/I18/AYkIH8Bs
VhUoX5rjP1BacXUnSh/AE0RU0vM95z/CYukJxC8gwDWSspd3o+o/1tx4Swbs
IMBX4BBd+wjuPy+lmj5ojSHA1hF9FpXb8D+MBxM/DF0iwICzcX6ssvI/S5hs
BMeBI8DkFUehd3D0P3c50pMXyyTASHgcxEIu9j9eFHeYiUYmwPv0Uno=
            "]]},
          Annotation[#, "Charting`Private`Tag$3776152#1"]& ], 
         TagBox[
          {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
           Opacity[1.], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAYKx+2kHACcABSkNJ0UAqwCgW/xVH
6AjARSb59aeBKcDwf39RTBAIwJJ+GjNdZCnAbCxdyiYmB8Dg4IeBleUowOfY
OkMBPAbAu1Ed4TDWJ8BErVD1X2EFwLkbn43mNifAoIFmp76GBMACStri/h8n
wCTcwD5nsAPA/IZjE3K4JsCoNhvWD9oCwOT+co7obyXA4NPSqo3xAcB3hgbI
fO4iwBdxin8LCQHAdUboBKH7IcAwNnqNDTAAwGJshLogayHAkvbTNh+u/r81
A8LCMDkhwCsGbs3N1/y/tfr04ROrIMDEFQhkfAH7v0BFv6N0MiDArDErxb4z
+b+lhCKM2fwfwJRNTiYBZve/HkAy8JLQH8A+ueH5S7f1v7smQ4KwWB/A6SR1
zZYI9L83kaGtfA0fwPoVwxuMNfK/ClD9ssOMHsAMBxFqgWLwv9yGLS66OB7A
wI+eVf5c7b+kfJTjx9MdwGgRG9f59Om/Uheb/EH6G8Cuq6ntHJ7mv5qKEqxG
nhrA9EU4BEBH47/73fvIN8QawBDWdyBwT9+/EX9C44C3GsA3IH84YBDYv9NE
HMvFNBrAaqlHGnJN0b+4vp+e7z4awDllIPgHFcW/S4q8Fpw6GsBaixZG/rGp
vxK5YRGNcRjAGD8qqhF4sD/dEjCASVsXwHh/Z+fyn8Y/gQfo/vxEF8Cy79x8
7oHSPwbikrN2FhfAneBEvME32T9LYyyVTlsWwIjRrPuU7d8/+ri+Wc5oFsBs
VhUoX5rjP1UUJJ8qhxbAE0RU0vM95z8YUATz1BAXwDWSspd3o+o/3hsaIKuL
GMBX4BBd+wjuP4CFQJOuGhrA1hF9FpXb8D+agFOuDpUbwICzcX6ssvI/eS+u
fyPZHcDkFUehd3D0P4xGCQMAFiDASHgcxEIu9j9bIn06eK8hwMa2UtQ=
            "]]},
          Annotation[#, "Charting`Private`Tag$3776152#2"]& ], 
         TagBox[
          {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
           LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAYKx+2kHACcBj0oLdlG4twCgW/xVH
6AjAzvZBHzO+LMDwf39RTBAIwNlAAqqziyzAbCxdyiYmB8BuBA5KrA0swOfY
OkMBPAbAHqtA4T33KsBErVD1X2EFwP/yfwq7iSrAoIFmp76GBMCNymfvYCcq
wCTcwD5nsAPA4M8rUNMHKsCoNhvWD9oCwBpWfQEVSijA4NPSqo3xAcDK2W9W
vz0mwBdxin8LCQHABT43FHwzJcAwNnqNDTAAwKe+UJ8E7yPAkvbTNh+u/r+M
fIbo64sjwCsGbs3N1/y/xIxvbBMZI8DEFQhkfAH7v3ZcykEwsyLArDErxb4z
+b+59bG8s4YiwJRNTiYBZve/2RrtMEI+IsA+ueH5S7f1v5VlnA/TISLA6SR1
zZYI9L+ba3EQ1fMhwPoVwxuMNfK/Jxe89JmuIcAMBxFqgWLwvzAXtjtlGiHA
wI+eVf5c7b99kZ0HON4gwGgRG9f59Om/7GR1mwy1H8Cuq6ntHJ7mv4fm9O/L
yx7A9EU4BEBH47/8s4Ir5pIewBDWdyBwT9+/Xo1sf4hYHsA3IH84YBDYv3LB
CmbOUh3AaqlHGnJN0b8fzrtyl5sdwDllIPgHFcW/QRAhXyEKHcBaixZG/rGp
v3kbt6zjdBvAGD8qqhF4sD+mXOy89nEZwHh/Z+fyn8Y//i3kxbcxGsCy79x8
7oHSP+Bk18DpuBnAneBEvME32T8VecdFWHwYwIjRrPuU7d8/kitULOtyGMBs
VhUoX5rjP3jAX/wA4RjAE0RU0vM95z/r+dHHLRgZwDWSspd3o+o/uJzzz9eI
GsBX4BBd+wjuP7SpO7OLuRvA1hF9FpXb8D9Z4TVyQDsdwICzcX6ssvI/l4zX
4M5WH8DkFUehd3D0P+1b8X+88iDASHgcxEIu9j+MBdRZIkAiwFEUWjU=
            "]]},
          Annotation[#, "Charting`Private`Tag$3776152#3"]& ], 
         TagBox[
          {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[1.6], 
           Opacity[1.], Dashing[{0, Small, Small, Small}], 
           LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAYKx+2kHACcAGzzcjA9sUwCgW/xVH
6AjAUUPoiax5EsDwf39RTBAIwH/o2Wkr2xHAbCxdyiYmB8DYEtLqTuoRwOfY
OkMBPAbAe6WcOb8mEcBErVD1X2EFwAJbDFaAehHAoIFmp76GBMDm4a6lFw4R
wCTcwD5nsAPAyeBF2bvhDsCoNhvWD9oCwOhFNrgbtQ/A4NPSqo3xAcCxU+PM
vGsOwBdxin8LCQHA7ATvdTAcDsAwNnqNDTAAwKbEZV1Gqg7AkvbTNh+u/r82
QeRhBC4OwCsGbs3N1/y/ghYyQvraDcDEFQhkfAH7v5obtu5+QA7ArDErxb4z
+b9u/4Q/SA4KwJRNTiYBZve/ZHyeA7sbC8A+ueH5S7f1v/vtboFHOgrA6SR1
zZYI9L+MPrQlVmkKwPoVwxuMNfK/2SXMW2t3CsAMBxFqgWLwv8Z/p8cpkwfA
wI+eVf5c7b+9Xt/ZOEkJwGgRG9f59Om/wFLjHbrqCMCuq6ntHJ7mv4qr1vEd
+QrA9EU4BEBH47/q7Hn/rggKwBDWdyBwT9+/ytY3MrbTCsA3IH84YBDYv7/u
R4x4KArAaqlHGnJN0b+LfGq09LwKwDllIPgHFcW/+f41G/iHC8BaixZG/rGp
v/x3WmR40wzAGD8qqhF4sD/ZWJs2ZJYNwHh/Z+fyn8Y/l/2aimYSEMCy79x8
7oHSPx6y4uZbxhDAneBEvME32T/FflOJrQgSwIjRrPuU7d8/86XE+UOdE8Bs
VhUoX5rjPz0xvmi+VRXAE0RU0vM95z84N0tgVQMXwDWSspd3o+o/TPPais5N
GcBX4BBd+wjuP9/QvRJ9EBvA1hF9FpXb8D84mAFNVfUcwICzcX6ssvI/LXWm
cI4nH8DkFUehd3D0Px7pHYIuXCHASHgcxEIu9j+4j2ZQsxwjwITOVv8=
            "]]},
          Annotation[#, "Charting`Private`Tag$3776152#4"]& ], 
         TagBox[
          {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
           LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAYKx+2kHACcA1ooQ0ydIswCgW/xVH
6AjAWz0RPKFELMDwf39RTBAIwAmt9RpIsivAbCxdyiYmB8CYHvBIyM4rwOfY
OkMBPAbAn3IM/6lmK8BErVD1X2EFwMSK8jDwUCrAoIFmp76GBMBBabrrR9Qp
wCTcwD5nsAPASzs7G68oKMCoNhvWD9oCwLILpcHkbybA4NPSqo3xAcBnaB+7
kJ4lwBdxin8LCQHAu+HBzkR4KcAwNnqNDTAAwJmmpj7tkSfAkvbTNh+u/r+6
ZDLsmNYlwCsGbs3N1/y/tarEp3qzJMDEFQhkfAH7v+7CCJnX/yTArDErxb4z
+b+rth9eJRklwJRNTiYBZve/xy/R1pUzJsA+ueH5S7f1v0Mujnzz/yXA6SR1
zZYI9L+480nf0l4kwPoVwxuMNfK/cPCKkTQuI8AMBxFqgWLwv3nIdrM9fiLA
wI+eVf5c7b958BXs/uQhwGgRG9f59Om/mGMOzmQQJcCuq6ntHJ7mv+vFAKGG
PSPA9EU4BEBH478s4THPixghwBDWdyBwT9+/07HVnrF3IcA3IH84YBDYv0Uv
Fo/28CDAaqlHGnJN0b8iqoYVufAhwDllIPgHFcW/uHhG9f8vIMBaixZG/rGp
v5h7mjNiliHAGD8qqhF4sD+Lpdb9Kr0iwHh/Z+fyn8Y/Fc8k/WraIsCy79x8
7oHSP6kCYhcN1iLAneBEvME32T+iMordmX4jwIjRrPuU7d8/nmzp9QD1IsBs
VhUoX5rjP+VhDCIArCPAE0RU0vM95z+11QxaW20kwDWSspd3o+o/iiCbt9/N
JMBX4BBd+wjuP2BmsreLvCXA1hF9FpXb8D/UcSxsGX8lwICzcX6ssvI/a8OR
ioxsJcDkFUehd3D0P+v4yh7FsifASHgcxEIu9j+/I2vNoHkowMcQX9I=
            "]]},
          
          Annotation[#, "Charting`Private`Tag$3776152#5"]& ]}, {{{}, {
           GraphicsGroupBox[{
             {GrayLevel[1], AbsoluteThickness[4], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], 
              JoinForm["Round"], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -11.13776852086647}], 
                Offset[{0, 0}, {1.482235406661309, -11.13776852086647}], 
                Offset[{0., 0.}, {1.52828710852119, -11.13776852086647}], 
                Offset[{0., 0.}, {1.52828710852119, -11.13776852086647}], 
                Offset[{0., 0.}, {1.574338810381071, -11.13776852086647}], 
                Offset[{0, 0}, {1.8303774922396658`, -11.468973236261037`}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8303774922396658`, -11.468973236261037`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8303774922396658`, -11.468973236261037`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8303774922396658`, -11.468973236261037`}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -11.13776852086647}], 
                Offset[{0, 0}, {1.482235406661309, -11.13776852086647}], 
                Offset[{0., 0.}, {1.52828710852119, -11.13776852086647}], 
                Offset[{0., 0.}, {1.52828710852119, -11.13776852086647}], 
                Offset[{0., 0.}, {1.574338810381071, -11.13776852086647}], 
                Offset[{0, 0}, {1.8303774922396658`, -11.468973236261037`}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8303774922396658`, -11.468973236261037`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8303774922396658`, -11.468973236261037`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8303774922396658`, -11.468973236261037`}]}]}, 
             {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]}], 
              PolygonBox[{
               Offset[{36., 6.500000000000008}, {
                 1.8303774922396658`, -11.468973236261037`}], 
                Offset[{36., -6.499999999999992}, {
                 1.8303774922396658`, -11.468973236261037`}], 
                Offset[{10.000000000000002`, -6.499999999999997}, {
                 1.8303774922396658`, -11.468973236261037`}], 
                Offset[{9.999999999999998, 6.500000000000003}, {
                 1.8303774922396658`, -11.468973236261037`}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
              StyleBox[
               RotationBox["\<\"RRT\"\>",
                BoxRotation->0.],
               StripOnInput->False,
               LineOpacity->1,
               FrontFaceOpacity->1,
               BackFaceOpacity->1,
               Opacity->1,
               FontOpacity->1], 
              Offset[{23., 5.10702591327572*^-15}, \
{1.8303774922396658, -11.468973236261037}], 
              ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}], 
           GraphicsGroupBox[{
             {GrayLevel[1], AbsoluteThickness[4], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], 
              JoinForm["Round"], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -8.842714145445987}], 
                Offset[{0, 0}, {1.482235406661309, -8.842714145445987}], 
                Offset[{0., 0.}, {1.52828710852119, -8.842714145445987}], 
                Offset[{0., 0.}, {1.52828710852119, -8.842714145445987}], 
                Offset[{0., 0.}, {1.574338810381071, -8.842714145445987}], 
                Offset[{0, 0}, {1.8303774922396658`, -7.585839184776895}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8303774922396658`, -7.585839184776895}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8303774922396658`, -7.585839184776895}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8303774922396658`, -7.585839184776895}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -8.842714145445987}], 
                Offset[{0, 0}, {1.482235406661309, -8.842714145445987}], 
                Offset[{0., 0.}, {1.52828710852119, -8.842714145445987}], 
                Offset[{0., 0.}, {1.52828710852119, -8.842714145445987}], 
                Offset[{0., 0.}, {1.574338810381071, -8.842714145445987}], 
                Offset[{0, 0}, {1.8303774922396658`, -7.585839184776895}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8303774922396658`, -7.585839184776895}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8303774922396658`, -7.585839184776895}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8303774922396658`, -7.585839184776895}]}]}, 
             {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]}], 
              PolygonBox[{
               Offset[{34., 7.500000000000007}, {
                 1.8303774922396658`, -7.585839184776895}], 
                Offset[{34., -7.499999999999993}, {
                 1.8303774922396658`, -7.585839184776895}], 
                Offset[{10.000000000000002`, -7.499999999999998}, {
                 1.8303774922396658`, -7.585839184776895}], 
                Offset[{9.999999999999998, 7.500000000000002}, {
                 1.8303774922396658`, -7.585839184776895}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
              StyleBox[
               RotationBox["\<\"pNF\"\>",
                BoxRotation->0.],
               StripOnInput->False,
               LineOpacity->1,
               FrontFaceOpacity->1,
               BackFaceOpacity->1,
               Opacity->1,
               FontOpacity->1], 
              Offset[{22., 4.884981308350689*^-15}, \
{1.8303774922396658, -7.585839184776895}], 
              ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}], 
           GraphicsGroupBox[{
             {GrayLevel[1], AbsoluteThickness[4], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], 
              JoinForm["Round"], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -9.125262076503326}], 
                Offset[{0, 0}, {1.482235406661309, -9.125262076503326}], 
                Offset[{0., 0.}, {1.52828710852119, -9.125262076503326}], 
                Offset[{0., 0.}, {1.52828710852119, -9.125262076503326}], 
                Offset[{0., 0.}, {1.574338810381071, -9.125262076503326}], 
                Offset[{0, 0}, {1.8303774922396658`, -8.906591080106537}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8303774922396658`, -8.906591080106537}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8303774922396658`, -8.906591080106537}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8303774922396658`, -8.906591080106537}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -9.125262076503326}], 
                Offset[{0, 0}, {1.482235406661309, -9.125262076503326}], 
                Offset[{0., 0.}, {1.52828710852119, -9.125262076503326}], 
                Offset[{0., 0.}, {1.52828710852119, -9.125262076503326}], 
                Offset[{0., 0.}, {1.574338810381071, -9.125262076503326}], 
                Offset[{0, 0}, {1.8303774922396658`, -8.906591080106537}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8303774922396658`, -8.906591080106537}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8303774922396658`, -8.906591080106537}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8303774922396658`, -8.906591080106537}]}]}, 
             {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]}], 
              PolygonBox[{
               Offset[{43., 7.50000000000001}, {
                 1.8303774922396658`, -8.906591080106537}], 
                Offset[{43., -7.49999999999999}, {
                 1.8303774922396658`, -8.906591080106537}], 
                Offset[{10., -7.499999999999997}, {
                 1.8303774922396658`, -8.906591080106537}], 
                Offset[{10., 7.500000000000003}, {
                 1.8303774922396658`, -8.906591080106537}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
              StyleBox[
               RotationBox["\<\"pCMF\"\>",
                BoxRotation->0.],
               StripOnInput->False,
               LineOpacity->1,
               FrontFaceOpacity->1,
               BackFaceOpacity->1,
               Opacity->1,
               FontOpacity->1], 
              Offset[{26.5, 5.88418203051333*^-15}, \
{1.8303774922396658, -8.906591080106537}], 
              ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}], 
           GraphicsGroupBox[{
             {GrayLevel[1], AbsoluteThickness[4], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], 
              JoinForm["Round"], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -9.556055557746603}], 
                Offset[{0, 0}, {1.482235406661309, -9.556055557746603}], 
                Offset[{0., 0.}, {1.52828710852119, -9.556055557746603}], 
                Offset[{0., 0.}, {1.52828710852119, -9.556055557746603}], 
                Offset[{0., 0.}, {1.574338810381071, -9.556055557746603}], 
                Offset[{0, 0}, {1.8303774922396658`, -10.2273424417545}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8303774922396658`, -10.2273424417545}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8303774922396658`, -10.2273424417545}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8303774922396658`, -10.2273424417545}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -9.556055557746603}], 
                Offset[{0, 0}, {1.482235406661309, -9.556055557746603}], 
                Offset[{0., 0.}, {1.52828710852119, -9.556055557746603}], 
                Offset[{0., 0.}, {1.52828710852119, -9.556055557746603}], 
                Offset[{0., 0.}, {1.574338810381071, -9.556055557746603}], 
                Offset[{0, 0}, {1.8303774922396658`, -10.2273424417545}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8303774922396658`, -10.2273424417545}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8303774922396658`, -10.2273424417545}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8303774922396658`, -10.2273424417545}]}]}, 
             {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]}], 
              PolygonBox[{
               Offset[{48., 7.500000000000011}, {
                 1.8303774922396658`, -10.2273424417545}], 
                Offset[{48., -7.499999999999989}, {
                 1.8303774922396658`, -10.2273424417545}], 
                Offset[{10., -7.499999999999998}, {
                 1.8303774922396658`, -10.2273424417545}], 
                Offset[{10., 7.500000000000002}, {
                 1.8303774922396658`, -10.2273424417545}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
              StyleBox[
               RotationBox["\<\"pCumu\"\>",
                BoxRotation->0.],
               StripOnInput->False,
               LineOpacity->1,
               FrontFaceOpacity->1,
               BackFaceOpacity->1,
               Opacity->1,
               FontOpacity->1], 
              Offset[{29., 6.439293542825908*^-15}, \
{1.8303774922396658, -10.2273424417545}], 
              ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}], 
           GraphicsGroupBox[{
             {GrayLevel[1], AbsoluteThickness[4], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], 
              JoinForm["Round"], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -12.237554950073784`}], 
                Offset[{0, 0}, {1.482235406661309, -12.237554950073784`}], 
                Offset[{0., 0.}, {1.52828710852119, -12.237554950073784`}], 
                Offset[{0., 0.}, {1.52828710852119, -12.237554950073784`}], 
                Offset[{0., 0.}, {1.574338810381071, -12.237554950073784`}], 
                Offset[{0, 0}, {1.8303774922396658`, -12.710608043704399`}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8303774922396658`, -12.710608043704399`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8303774922396658`, -12.710608043704399`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8303774922396658`, -12.710608043704399`}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -12.237554950073784`}], 
                Offset[{0, 0}, {1.482235406661309, -12.237554950073784`}], 
                Offset[{0., 0.}, {1.52828710852119, -12.237554950073784`}], 
                Offset[{0., 0.}, {1.52828710852119, -12.237554950073784`}], 
                Offset[{0., 0.}, {1.574338810381071, -12.237554950073784`}], 
                Offset[{0, 0}, {1.8303774922396658`, -12.710608043704399`}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8303774922396658`, -12.710608043704399`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8303774922396658`, -12.710608043704399`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8303774922396658`, -12.710608043704399`}]}]}, 
             {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]}], 
              PolygonBox[{
               Offset[{67., 7.500000000000015}, {
                 1.8303774922396658`, -12.710608043704399`}], 
                Offset[{67., -7.499999999999985}, {
                 1.8303774922396658`, -12.710608043704399`}], 
                Offset[{10., -7.499999999999997}, {
                 1.8303774922396658`, -12.710608043704399`}], 
                Offset[{10., 7.500000000000003}, {
                 1.8303774922396658`, -12.710608043704399`}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
              StyleBox[
               RotationBox["\<\"URM (ours)\"\>",
                BoxRotation->0.],
               StripOnInput->False,
               LineOpacity->1,
               FrontFaceOpacity->1,
               BackFaceOpacity->1,
               Opacity->1,
               FontOpacity->1], 
              Offset[{38.5, 8.548717289613705*^-15}, \
{1.8303774922396658, -12.710608043704399}], 
              ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}]}}, {}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{-3.2188758248682006`, -14.715979501933537`},
       CoordinatesToolOptions:>{"DisplayFunction" -> ({
           Exp[
            Part[#, 1]], 
           Exp[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Exp[
            Part[#, 1]], 
           Exp[
            Part[#, 2]]}& )},
       DisplayFunction->Identity,
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox["\"lookups * Variance\"", TraditionalForm], ""}, {
          FormBox["\"depth\"", TraditionalForm], ""}},
       FrameTicks->FrontEndValueCache[{{Quiet[
            Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
           Charting`ScaledFrameTicks[{Log, Exp}]}, {Quiet[
            Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
           
           Charting`ScaledFrameTicks[{
            Log, Exp}]}}, {{{{-13.815510557964274`, 
             FormBox[
              TemplateBox[{"10", 
                RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox], TraditionalForm], {0.01, 
             0.}}, {-11.512925464970229`, 
             FormBox[
              TemplateBox[{"10", 
                RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox], TraditionalForm], {0.01, 
             0.}}, {-9.210340371976182, 
             FormBox[
              TemplateBox[{"10", 
                RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox], TraditionalForm], {0.01, 
             0.}}, {-6.907755278982137, 
             FormBox["0.001`", TraditionalForm], {0.01, 
             0.}}, {-4.605170185988091, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.010\"", ShowStringCharacters -> False], 0.01, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 
             0.}}, {-2.3025850929940455`, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.100\"", ShowStringCharacters -> False], 0.1, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 
             0.}}, {-16.11809565095832, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-15.424948470398375`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-15.01948336229021, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-14.73180128983843, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-14.508657738524219`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-14.326336181730264`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-14.172185501903007`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-14.038654109278484`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-13.9208710736221, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-13.122363377404328`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-12.716898269296165`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-12.429216196844383`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-12.206072645530174`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-12.02375108873622, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-11.86960040890896, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-11.736069016284437`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-11.618285980628055`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-10.819778284410283`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-10.41431317630212, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-10.126631103850338`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.903487552536127, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.721165995742174, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.567015315914915, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.433483923290392, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.315700887634009, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-8.517193191416238, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-8.111728083308073, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.824046010856292, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.600902459542082, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.418580902748128, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.264430222920869, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.1308988302963465`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.013115794639964, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-6.214608098422191, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.809142990314028, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.521460917862246, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.298317366548036, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.115995809754082, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-4.961845129926823, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-4.8283137373023015`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-4.710530701645918, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.912023005428146, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.506557897319982, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.2188758248682006`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.995732273553991, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.8134107167600364`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.659260036932778, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.5257286443082556`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.4079456086518722`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.2039728043259361`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.916290731874155, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.5108256237659907, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.35667494393873245`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.2231435513142097, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.10536051565782628`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.09531017980432493, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.1823215567939546, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.26236426446749106`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.3364722366212129, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.4054651081081644, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.47000362924573563`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}}, {{-13.815510557964274`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-11.512925464970229`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-9.210340371976182, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-6.907755278982137, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-4.605170185988091, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-2.3025850929940455`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-16.11809565095832, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-15.424948470398375`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-15.01948336229021, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-14.73180128983843, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-14.508657738524219`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-14.326336181730264`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-14.172185501903007`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-14.038654109278484`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-13.9208710736221, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-13.122363377404328`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-12.716898269296165`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-12.429216196844383`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-12.206072645530174`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-12.02375108873622, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-11.86960040890896, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-11.736069016284437`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-11.618285980628055`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-10.819778284410283`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-10.41431317630212, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-10.126631103850338`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.903487552536127, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.721165995742174, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.567015315914915, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.433483923290392, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-9.315700887634009, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-8.517193191416238, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-8.111728083308073, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.824046010856292, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.600902459542082, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.418580902748128, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.264430222920869, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.1308988302963465`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.013115794639964, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-6.214608098422191, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.809142990314028, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.521460917862246, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.298317366548036, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.115995809754082, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-4.961845129926823, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-4.8283137373023015`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-4.710530701645918, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.912023005428146, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.506557897319982, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.2188758248682006`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.995732273553991, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.8134107167600364`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.659260036932778, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.5257286443082556`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.4079456086518722`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.2039728043259361`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.916290731874155, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.5108256237659907, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.35667494393873245`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.2231435513142097, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.10536051565782628`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.09531017980432493, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.1823215567939546, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.26236426446749106`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.3364722366212129, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.4054651081081644, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.47000362924573563`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}}}, {{{-2.995732273553991, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.05\"", ShowStringCharacters -> False], 0.05, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 
             0.}}, {-2.3025850929940455`, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.10\"", ShowStringCharacters -> False], 0.1, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 
             0.}}, {-0.6931471805599453, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.50\"", ShowStringCharacters -> False], 0.5, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 0.}}, {
            0., 
             FormBox["1", TraditionalForm], {0.01, 0.}}, {-4.605170185988091, 
             
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.912023005428146, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.506557897319982, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.2188758248682006`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.8134107167600364`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.659260036932778, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.5257286443082556`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.4079456086518722`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.2039728043259361`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.916290731874155, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.5108256237659907, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.35667494393873245`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.2231435513142097, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.10536051565782628`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.0986122886681098`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.3862943611198906`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.791759469228055, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.9459101490553132`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.0794415416798357`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.1972245773362196`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.302585092994046, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.3978952727983707`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.4849066497880004`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}}, {{-2.995732273553991, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-2.3025850929940455`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {0., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-4.605170185988091, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.912023005428146, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.506557897319982, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.2188758248682006`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.8134107167600364`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.659260036932778, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.5257286443082556`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.4079456086518722`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.2039728043259361`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.916290731874155, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.5108256237659907, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.35667494393873245`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.2231435513142097, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.10536051565782628`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.0986122886681098`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.3862943611198906`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.791759469228055, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.9459101490553132`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.0794415416798357`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.1972245773362196`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.302585092994046, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.3978952727983707`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.4849066497880004`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}}}}],
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->{{47.00000000000003, 98.21531360329459}, {36., 
        23.000000000000014`}},
       Method->{
        "DefaultBoundaryStyle" -> Automatic, 
         "DefaultGraphicsInteraction" -> {
          "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
           "Effects" -> {
            "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2},
              "Droplines" -> {
              "freeformCursorMode" -> True, 
               "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
         "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
         None},
       PlotRange->NCache[{{-3.2188758248682006`, 
           Log[
           4]}, {-14.715979501933537`, -2.94685703258435}}, \
{{-3.2188758248682006`, 
         1.3862943611198906`}, {-14.715979501933537`, -2.94685703258435}}],
       PlotRangeClipping->False,
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.05], 
          Scaled[0.08090169943749476]}},
       Ticks->{Quiet[
          Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , Quiet[
          Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& }], {347.14772575718905, -196.40957640155943},
       ImageScaled[{0.5, 0.5}], {655.0796327121793, 374.1134788601132}], 
     InsetBox[
      GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJwUmnk4VV8Xx83zUEhIk0yVyi9KMqwtKZJIRCkkqURJKhJRZopKkiFCkiFD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         "], {{{}, 
           {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl2mXYENUWQOEP6e4Q6e4WpaUbBOlSWkEFpUFB6e6S7pTuku4u6S4JCQUU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              "]]]}, {}, 
           {RGBColor[0.880722, 0.611041, 0.142051], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[
             PolygonBox[{{2903, 2955, 2956, 2952, 2954, 2951, 2950, 2949, 
              2948, 2947, 2946, 2945, 2944, 2943, 2942, 2941, 2940, 2939, 
              2938, 2937, 2936, 2935, 2934, 2933, 2932, 2931, 2930, 2929, 
              2928, 2927, 2926, 2925, 2924, 2923, 2922, 2921, 2920, 2919, 
              2918, 2917, 2916, 2915, 2914, 2913, 2912, 2911, 2910, 2909, 
              2908, 2907, 2906, 2905, 2904, 
              2953}}]]}, {}, {}, {}, {}, {}, {}}, {{}, {}, 
           TagBox[
            {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
             Opacity[1.], LineBox[CompressedData["
1:eJwl2mXAFkTahuGXlJDu7u5O6e7ublBSpKSUbgxAJAwUkO7uDpEUEKRDBelU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              "]]},
            Annotation[#, "Charting`Private`Tag$4099006#1"]& ], 
           TagBox[
            {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
             Opacity[1.], 
             LineBox[{2903, 2953, 2904, 2905, 2906, 2907, 2908, 2909, 2910, 
              2911, 2912, 2913, 2914, 2915, 2916, 2917, 2918, 2919, 2920, 
              2921, 2922, 2923, 2924, 2925, 2926, 2927, 2928, 2929, 2930, 
              2931, 2932, 2933, 2934, 2935, 2936, 2937, 2938, 2939, 2940, 
              2941, 2942, 2943, 2944, 2945, 2946, 2947, 2948, 2949, 2950, 
              2951, 2954, 2952}]},
            Annotation[#, "Charting`Private`Tag$4099006#2"]& ]}}], {}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Frame->{{False, False}, {False, False}},
       FrameLabel->{{None, None}, {None, None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->{{10.030612244897956`, 1.5}, {36., 23.000000000000014`}},
       
       Method->{
        "DefaultBoundaryStyle" -> Automatic, 
         "DefaultGraphicsInteraction" -> {
          "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
           "Effects" -> {
            "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2},
              "Droplines" -> {
              "freeformCursorMode" -> True, 
               "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
         "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
         None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& )}, "AxesInFront" -> True},
       PlotLabel->FormBox["\"T[0,4] = 0.013735\"", TraditionalForm],
       PlotRange->{{0., 3.999999918367347}, {0, All}},
       PlotRangeClipping->True,
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {0, 
          Scaled[0.05]}},
       Ticks->{Automatic, Automatic}], {974.600826592369, -196.40957640155943},
       ImageScaled[{0.5, 0.5}], {521.3949313537827, 374.1134788601132}]}, {}},
   
   ImageSize->1200,
   PlotRange->{{0, 1254.9062016703597`}, {-392.81915280311887`, 0}},
   PlotRangePadding->{6, 5}],
  StripOnInput->False,
  Magnification->0.5 Inherited]], "Output",
 CellChangeTimes->{
  3.8207275715221653`*^9, 3.820727612087047*^9, {3.820727733201665*^9, 
   3.820727759378636*^9}, 3.820727857625187*^9, 3.82072790154605*^9, 
   3.820728190703171*^9, 3.820813331106222*^9, 3.82081340432526*^9, 
   3.8281619427317333`*^9},
 CellLabel->
  "Out[1123]=",ExpressionUUID->"9f41137f-0aaa-4114-aaf3-1fa766a9d830"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["verify correctness/bias", "Subsection",
 CellChangeTimes->{{3.8281619736729794`*^9, 
  3.8281619805980864`*^9}},ExpressionUUID->"8dc2c423-937d-4971-9f0e-\
31cfde53c87f"],

Cell[CellGroupData[{

Cell["pCMF vs URM (unbiased ray marching) vs RT", "Subsubsection",
 CellChangeTimes->{{3.828161994306781*^9, 
  3.828162005230579*^9}},ExpressionUUID->"bfb3a0bd-b3ee-4b0b-9961-\
f0bf9f639cc3"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"maxpos", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"td", "=", 
   RowBox[{
    RowBox[{".3", 
     RowBox[{"RandomFunction", "[", 
      RowBox[{
       RowBox[{"FractionalBrownianMotionProcess", "[", ".5", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "maxpos", ",", "0.01"}], "}"}]}], "]"}]}], "+", 
    "1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"TimeSeriesMap", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Max", "[", 
       RowBox[{"0", ",", "#"}], "]"}], "&"}], ",", "td"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "f", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "=", 
   RowBox[{"Interpolation", "[", "data", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maxT", "=", 
   RowBox[{"Exp", "[", 
    RowBox[{"-", 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "maxpos"}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maj", "=", 
   RowBox[{"Max", "[", "data", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"min", "=", 
   RowBox[{"Min", "[", "data", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"midcontrol", "=", 
   RowBox[{
    RowBox[{"maj", "/", "2"}], "+", 
    RowBox[{"min", "/", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MCn", "=", "1000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rate", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"K", "=", 
   RowBox[{"c", "=", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"M", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pM", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Magnify", "[", 
  RowBox[{
   RowBox[{"GraphicsRow", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"LogLogPlot", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", " ", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"checkMean", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"TRatioTracking", "[", 
               RowBox[{"#1", ",", "maj", ",", "#2"}], "]"}], "&"}], ",", "f", 
             ",", "pos", ",", "MCn"}], "]"}], " ", 
           RowBox[{"(*", " ", 
            RowBox[{"RT", " ", "-", " ", 
             RowBox[{"tight", " ", "majorant"}]}], " ", "*)"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"checkMean", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"TpCMF", "[", 
               RowBox[{"#1", ",", "maj", ",", "#2", ",", "0.99"}], "]"}], 
              "&"}], ",", "f", ",", "pos", ",", "MCn"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"checkMean", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"TURM", "[", 
               RowBox[{"#1", ",", "#2", ",", "maj"}], "]"}], "&"}], ",", "f", 
             ",", "pos", ",", "MCn"}], "]"}]}], "\[IndentingNewLine]", "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"pos", ",", 
           RowBox[{".01", " ", "maxpos"}], ",", "maxpos"}], "}"}], ",", 
         RowBox[{"MaxRecursion", "\[Rule]", "1"}], ",", 
         RowBox[{"PlotPoints", "\[Rule]", "22"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Red", ",", "Dashed", ",", "Black"}], "}"}]}], ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\"\<lookups * Variance\>\"", ","}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\"\<depth\>\"", ","}], "}"}]}], "}"}]}], ",", 
         RowBox[{"PlotLabels", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<RT\>\"", ",", "\"\<pCMF\>\"", ",", "\"\<URM\>\""}], 
           "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"f", "[", "x", "]"}], ",", "midcontrol"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "maxpos"}], "}"}], ",", 
         RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"0", ",", "All"}], "}"}]}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"\"\<T[0,\>\"", "<>", 
           RowBox[{"ToString", "[", "maxpos", "]"}], "<>", "\"\<] = \>\"", "<>", 
           RowBox[{"ToString", "[", "maxT", "]"}]}]}]}], "]"}]}], 
      "\[IndentingNewLine]", "}"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "1200"}]}], "\[IndentingNewLine]", "]"}],
    ",", "0.5"}], "]"}]}], "Input",
 CellChangeTimes->{{3.828159491330165*^9, 3.828159495436466*^9}, 
   3.828159710427897*^9, {3.828162082133699*^9, 3.8281620827618093`*^9}},
 CellLabel->
  "In[1154]:=",ExpressionUUID->"361c3a76-3723-4506-96bf-820a8c8d8d41"],

Cell[BoxData[
 StyleBox[
  GraphicsBox[{{}, {InsetBox[
      GraphicsBox[{{{}, {}, 
         TagBox[
          {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
           LineBox[CompressedData["
1:eJwBsQJO/SFib1JlAgAAACoAAAACAAAAYKx+2kHACcBKKPF73KqkvygW/xVH
6AjA7VLBHDo2pb/wf39RTBAIwOyi7zTSoqm/bCxdyiYmB8CdyRD1WAWsv+fY
OkMBPAbAtzW0gcxarr9ErVD1X2EFwF3FwnNP2bG/oIFmp76GBMAzvn10nPm0
vyTcwD5nsAPACTRSjIQbtb+oNhvWD9oCwKozTrnRDbu/4NPSqo3xAcB99bYO
9sK9vxdxin8LCQHAio0xSEAAv78wNnqNDTAAwBjh7jl9h8C/kvbTNh+u/r94
BcdRPSHDvysGbs3N1/y/YtuBV/R6xr/EFQhkfAH7v5Zr4cMZy8i/rDErxb4z
+b//8UIhs07Ov5RNTiYBZve/IjFROehjz78+ueH5S7f1v2aXi1WuPtG/6SR1
zZYI9L/+EjDovZ/Vv/oVwxuMNfK/d0x1Bfaj178MBxFqgWLwv0+ha6apdtm/
wI+eVf5c7b++ebIBnP3ev2gRG9f59Om/F5XpcAhy4b+uq6ntHJ7mv+98V1rM
4eK/9EU4BEBH479mkNfhVoDlvxDWdyBwT9+/1/pfrCta6L83IH84YBDYv+m8
k90WI+2/OWUg+AcVxb9uhq2xAMLyv1qLFkb+sam/q654Cfj3878YPyqqEXiw
P53PeKeIePe/eH9n5/Kfxj/lbwSIdYH6v7Lv3HzugdI/o+SgYbtT/b+d4ES8
wTfZPxjbwLhLy/+/iNGs+5Tt3z+zFF96LD4CwGxWFShfmuM/8EOwOzvMA8AT
RFTS8z3nP3BTI4wz/AXANZKyl3ej6j/BLjxoElcJwFfgEF37CO4/G3BH3/xz
C8DWEX0WldvwP4yrs7TSDxHAgLNxfqyy8j9Ff0ufdCkUwOQVR6F3cPQ/zMzK
g2TaFsBIeBzEQi72P1vBGW7OORfAsKhm/g==
            "]]},
          Annotation[#, "Charting`Private`Tag$4369187#1"]& ], 
         TagBox[
          {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
           Opacity[1.], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAYKx+2kHACcDUsYhEqR+lvygW/xVH
6AjAPxnbF6p0p7/wf39RTBAIwEDsEc+9Baq/bCxdyiYmB8BfEpgSjhCtv+fY
OkMBPAbAEgkz52NDsL9ErVD1X2EFwDpipy1ICrK/oIFmp76GBMDdmYd/kQC0
vyTcwD5nsAPAFGW1Yyoptr+oNhvWD9oCwNyUfQlFlLi/4NPSqo3xAcB6ASfF
3527vxdxin8LCQHACZPDrqoKv78wNnqNDTAAwBZ15Sc7VcG/kvbTNh+u/r8R
Fpj4EkfDvysGbs3N1/y/VQ7tsUSsxb/EFQhkfAH7v4D/TRoKj8i/rDErxb4z
+b9Vqwukdu/Lv5RNTiYBZve/qbXcqrXKz78+ueH5S7f1v8zPJRuc0tG/6SR1
zZYI9L+ZoJPtQEDUv/oVwxuMNfK/jmF4P20V178MBxFqgWLwv7pwl/UhOdq/
wI+eVf5c7b9+74RU8IPdv2gRG9f59Om/O0dMC47e4L+uq6ntHJ7mvzezC2TZ
CuO/9EU4BEBH47/LKsE2ZrDlvxDWdyBwT9+/TcTMP6i+6L83IH84YBDYv8VH
qyqlcuy/aqlHGnJN0b8RcZ0x6//vvzllIPgHFcW/XM5V827v8b9aixZG/rGp
v51YtPU+g/S/GD8qqhF4sD/3P5+B/gb3v3h/Z+fyn8Y/hiyFMhbL+b+y79x8
7oHSP7sw8/OQGP2/neBEvME32T+DJMgt2BAAwIjRrPuU7d8/DyVg5zfGAcBs
VhUoX5rjP7SNm6PV/wPAE0RU0vM95z8DF4Yx2msGwDWSspd3o+o/ljTYd6Y0
CcBX4BBd+wjuP2zDRNNMlAzA1hF9FpXb8D+dGtrqFcEQwICzcX6ssvI/jl94
QSmpE8DkFUehd3D0Pzrd2MRkdxbASHgcxEIu9j/RA4OcZVAZwPKFZP0=
            "]]},
          Annotation[#, "Charting`Private`Tag$4369187#2"]& ], 
         TagBox[
          {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
           LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAYKx+2kHACcDMWgvRoR+lvygW/xVH
6AjAxAoRfel0p7/wf39RTBAIwPpA+Gx7Bqq/bCxdyiYmB8Be11MamBCtv+fY
OkMBPAbAAVob+PtCsL9ErVD1X2EFwB2iFyLtB7K/oIFmp76GBMA4MxfxCwK0
vyTcwD5nsAPAHPCxnN0rtr+oNhvWD9oCwGJk0V11mbi/4NPSqo3xAcCOcQkw
vZ27vxdxin8LCQHAfDhAb4UTv78wNnqNDTAAwANdtpQyWMG/kvbTNh+u/r+f
fzPuMkXDvysGbs3N1/y/u5wIAnW5xb/EFQhkfAH7v9nTyYPUj8i/rDErxb4z
+b/KIvF8V+fLv5RNTiYBZve/akNFL7m6z78+ueH5S7f1v8E1U35I3dG/6SR1
zZYI9L8JCzOari3Uv/oVwxuMNfK/FH42C1z81r8MBxFqgWLwvxmR5GH1RNq/
wI+eVf5c7b8QVZR0Lqrdv2gRG9f59Om/YNl4DbTU4L+uq6ntHJ7mv8Wc5+i3
DeO/9EU4BEBH479fP1BzzKXlvxDWdyBwT9+/pDyvHnnS6L83IH84YBDYv6r+
qCbWk+y/aqlHGnJN0b+sqW05jhLwvzllIPgHFcW/MUVtVjYA8r9aixZG/rGp
v02d3Sy9c/S/GD8qqhF4sD8ZRj3qFgH3v3h/Z+fyn8Y/JuaPtvPH+b+y79x8
7oHSP1qj1IS2BP2/neBEvME32T8jHeWnVRAAwIjRrPuU7d8/LI7BSenIAcBs
VhUoX5rjP8S9BYfHBgTAE0RU0vM95z/ixqfoq2cGwDWSspd3o+o/yDnSnGQm
CcBX4BBd+wjuPyLjW5CmjgzA1hF9FpXb8D+cYzMkiMQQwICzcX6ssvI/m7kY
R7C0E8DkFUehd3D0Pwjpt3jGaBbASHgcxEIu9j+98ELJwnIZwDijZTE=
            "]]},
          
          Annotation[#, "Charting`Private`Tag$4369187#3"]& ]}, {{{}, {
           GraphicsGroupBox[{
             {GrayLevel[1], AbsoluteThickness[4], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], 
              JoinForm["Round"], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -5.8064515307636055`}], 
                Offset[{0, 0}, {1.482235406661309, -5.8064515307636055`}], 
                Offset[{0., 0.}, {1.52828710852119, -5.8064515307636055`}], 
                Offset[{0., 0.}, {1.52828710852119, -5.8064515307636055`}], 
                Offset[{0., 0.}, {1.574338810381071, -5.8064515307636055`}], 
                Offset[{0, 0}, {1.8437764727044752`, -5.071486396257996}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8437764727044752`, -5.071486396257996}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8437764727044752`, -5.071486396257996}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8437764727044752`, -5.071486396257996}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -5.8064515307636055`}], 
                Offset[{0, 0}, {1.482235406661309, -5.8064515307636055`}], 
                Offset[{0., 0.}, {1.52828710852119, -5.8064515307636055`}], 
                Offset[{0., 0.}, {1.52828710852119, -5.8064515307636055`}], 
                Offset[{0., 0.}, {1.574338810381071, -5.8064515307636055`}], 
                Offset[{0, 0}, {1.8437764727044752`, -5.071486396257996}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8437764727044752`, -5.071486396257996}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8437764727044752`, -5.071486396257996}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8437764727044752`, -5.071486396257996}]}]}, 
             {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]}], 
              PolygonBox[{
               Offset[{29., 6.500000000000006}, {
                 1.8437764727044752`, -5.071486396257996}], 
                Offset[{29., -6.499999999999994}, {
                 1.8437764727044752`, -5.071486396257996}], 
                Offset[{10.000000000000002`, -6.499999999999997}, {
                 1.8437764727044752`, -5.071486396257996}], 
                Offset[{9.999999999999998, 6.500000000000003}, {
                 1.8437764727044752`, -5.071486396257996}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
              StyleBox[
               RotationBox["\<\"RT\"\>",
                BoxRotation->0.],
               StripOnInput->False,
               LineOpacity->1,
               FrontFaceOpacity->1,
               BackFaceOpacity->1,
               Opacity->1,
               FontOpacity->1], 
              Offset[{19.5, 4.3298697960381105*^-15}, \
{1.8437764727044752, -5.071486396257996}], 
              ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}], 
           GraphicsGroupBox[{
             {GrayLevel[1], AbsoluteThickness[4], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], 
              JoinForm["Round"], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -6.328512616631046}], 
                Offset[{0, 0}, {1.482235406661309, -6.328512616631046}], 
                Offset[{0., 0.}, {1.52828710852119, -6.328512616631046}], 
                Offset[{0., 0.}, {1.52828710852119, -6.328512616631046}], 
                Offset[{0., 0.}, {1.574338810381071, -6.328512616631046}], 
                Offset[{0, 0}, {1.8437764727044752`, -5.7426818104302955`}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8437764727044752`, -5.7426818104302955`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8437764727044752`, -5.7426818104302955`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8437764727044752`, -5.7426818104302955`}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -6.328512616631046}], 
                Offset[{0, 0}, {1.482235406661309, -6.328512616631046}], 
                Offset[{0., 0.}, {1.52828710852119, -6.328512616631046}], 
                Offset[{0., 0.}, {1.52828710852119, -6.328512616631046}], 
                Offset[{0., 0.}, {1.574338810381071, -6.328512616631046}], 
                Offset[{0, 0}, {1.8437764727044752`, -5.7426818104302955`}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8437764727044752`, -5.7426818104302955`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8437764727044752`, -5.7426818104302955`}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8437764727044752`, -5.7426818104302955`}]}]}, 
             {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]}], 
              PolygonBox[{
               Offset[{43., 7.50000000000001}, {
                 1.8437764727044752`, -5.7426818104302955`}], 
                Offset[{43., -7.49999999999999}, {
                 1.8437764727044752`, -5.7426818104302955`}], 
                Offset[{10., -7.499999999999997}, {
                 1.8437764727044752`, -5.7426818104302955`}], 
                Offset[{10., 7.500000000000003}, {
                 1.8437764727044752`, -5.7426818104302955`}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
              StyleBox[
               RotationBox["\<\"pCMF\"\>",
                BoxRotation->0.],
               StripOnInput->False,
               LineOpacity->1,
               FrontFaceOpacity->1,
               BackFaceOpacity->1,
               Opacity->1,
               FontOpacity->1], 
              Offset[{26.5, 5.88418203051333*^-15}, \
{1.8437764727044752, -5.7426818104302955}], 
              ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}], 
           GraphicsGroupBox[{
             {GrayLevel[1], AbsoluteThickness[4], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], 
              JoinForm["Round"], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -6.362071175299374}], 
                Offset[{0, 0}, {1.482235406661309, -6.362071175299374}], 
                Offset[{0., 0.}, {1.52828710852119, -6.362071175299374}], 
                Offset[{0., 0.}, {1.52828710852119, -6.362071175299374}], 
                Offset[{0., 0.}, {1.574338810381071, -6.362071175299374}], 
                Offset[{0, 0}, {1.8437764727044752`, -6.413874463727442}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8437764727044752`, -6.413874463727442}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8437764727044752`, -6.413874463727442}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8437764727044752`, -6.413874463727442}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], 
              BSplineCurveBox[{
               Offset[{0, 0}, {1.482235406661309, -6.362071175299374}], 
                Offset[{0, 0}, {1.482235406661309, -6.362071175299374}], 
                Offset[{0., 0.}, {1.52828710852119, -6.362071175299374}], 
                Offset[{0., 0.}, {1.52828710852119, -6.362071175299374}], 
                Offset[{0., 0.}, {1.574338810381071, -6.362071175299374}], 
                Offset[{0, 0}, {1.8437764727044752`, -6.413874463727442}], 
                Offset[{5., 1.1102230246251565`*^-15}, {
                 1.8437764727044752`, -6.413874463727442}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8437764727044752`, -6.413874463727442}], 
                Offset[{10., 2.220446049250313*^-15}, {
                 1.8437764727044752`, -6.413874463727442}]}]}, 
             {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]}], 
              PolygonBox[{
               Offset[{38., 6.500000000000009}, {
                 1.8437764727044752`, -6.413874463727442}], 
                Offset[{38., -6.499999999999991}, {
                 1.8437764727044752`, -6.413874463727442}], 
                Offset[{10.000000000000002`, -6.499999999999998}, {
                 1.8437764727044752`, -6.413874463727442}], 
                Offset[{9.999999999999998, 6.500000000000002}, {
                 1.8437764727044752`, -6.413874463727442}]}]}, 
             {RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
              StyleBox[
               RotationBox["\<\"URM\"\>",
                BoxRotation->0.],
               StripOnInput->False,
               LineOpacity->1,
               FrontFaceOpacity->1,
               BackFaceOpacity->1,
               Opacity->1,
               FontOpacity->1], 
              Offset[{24., 5.329070518200751*^-15}, \
{1.8437764727044752, -6.413874463727442}], 
              ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}]}}, {}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{-3.2188758248682006`, -6.362071175299374},
       CoordinatesToolOptions:>{"DisplayFunction" -> ({
           Exp[
            Part[#, 1]], 
           Exp[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Exp[
            Part[#, 1]], 
           Exp[
            Part[#, 2]]}& )},
       DisplayFunction->Identity,
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox["\"lookups * Variance\"", TraditionalForm], ""}, {
          FormBox["\"depth\"", TraditionalForm], ""}},
       FrameTicks->FrontEndValueCache[{{Quiet[
            Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
           Charting`ScaledFrameTicks[{Log, Exp}]}, {Quiet[
            Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
           Charting`ScaledFrameTicks[{Log, Exp}]}}, {{{{-5.298317366548036, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.005\"", ShowStringCharacters -> False], 0.005, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 
             0.}}, {-4.605170185988091, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.010\"", ShowStringCharacters -> False], 0.01, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 
             0.}}, {-2.995732273553991, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.050\"", ShowStringCharacters -> False], 0.05, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 
             0.}}, {-2.3025850929940455`, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.100\"", ShowStringCharacters -> False], 0.1, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 
             0.}}, {-0.6931471805599453, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.500\"", ShowStringCharacters -> False], 0.5, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 0.}}, {
            0., 
             FormBox["1", TraditionalForm], {0.01, 0.}}, {-7.600902459542082, 
             
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.418580902748128, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.264430222920869, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.1308988302963465`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.013115794639964, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-6.907755278982137, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-6.214608098422191, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.809142990314028, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.521460917862246, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.115995809754082, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-4.961845129926823, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-4.8283137373023015`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-4.710530701645918, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.912023005428146, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.506557897319982, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.2188758248682006`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.8134107167600364`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.659260036932778, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.5257286443082556`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.4079456086518722`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.2039728043259361`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.916290731874155, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.5108256237659907, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.35667494393873245`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.2231435513142097, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.10536051565782628`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.0986122886681098`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.3862943611198906`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.791759469228055, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.9459101490553132`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.0794415416798357`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.1972245773362196`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.302585092994046, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.3978952727983707`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.4849066497880004`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.5649493574615367`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.6390573296152584`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.70805020110221, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.772588722239781, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}}, {{-5.298317366548036, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-4.605170185988091, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-2.995732273553991, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-2.3025850929940455`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {0., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-7.600902459542082, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.418580902748128, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.264430222920869, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.1308988302963465`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-7.013115794639964, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-6.907755278982137, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-6.214608098422191, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.809142990314028, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.521460917862246, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-5.115995809754082, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-4.961845129926823, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-4.8283137373023015`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-4.710530701645918, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.912023005428146, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.506557897319982, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.2188758248682006`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.8134107167600364`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.659260036932778, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.5257286443082556`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.4079456086518722`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.2039728043259361`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.916290731874155, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.5108256237659907, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.35667494393873245`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.2231435513142097, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.10536051565782628`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.0986122886681098`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.3862943611198906`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.791759469228055, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.9459101490553132`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.0794415416798357`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.1972245773362196`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.302585092994046, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.3978952727983707`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.4849066497880004`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.5649493574615367`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.6390573296152584`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.70805020110221, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.772588722239781, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}}}, {{{-2.995732273553991, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.05\"", ShowStringCharacters -> False], 0.05, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 
             0.}}, {-2.3025850929940455`, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.10\"", ShowStringCharacters -> False], 0.1, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 
             0.}}, {-0.6931471805599453, 
             FormBox[
              TagBox[
               InterpretationBox[
                StyleBox["\"0.50\"", ShowStringCharacters -> False], 0.5, 
                AutoDelete -> True], NumberForm[#, {
                 DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 0.}}, {
            0., 
             FormBox["1", TraditionalForm], {0.01, 0.}}, {-4.605170185988091, 
             
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.912023005428146, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.506557897319982, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.2188758248682006`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.8134107167600364`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.659260036932778, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.5257286443082556`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.4079456086518722`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.2039728043259361`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.916290731874155, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.5108256237659907, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.35667494393873245`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.2231435513142097, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.10536051565782628`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.0986122886681098`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.3862943611198906`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.791759469228055, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.9459101490553132`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.0794415416798357`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.1972245773362196`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.302585092994046, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.3978952727983707`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.4849066497880004`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}}, {{-2.995732273553991, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-2.3025850929940455`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {0., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
             0.}}, {-4.605170185988091, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.912023005428146, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.506557897319982, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-3.2188758248682006`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.8134107167600364`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.659260036932778, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.5257286443082556`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-2.4079456086518722`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-1.2039728043259361`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.916290731874155, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.5108256237659907, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.35667494393873245`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.2231435513142097, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {-0.10536051565782628`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {0.6931471805599453, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.0986122886681098`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.3862943611198906`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.6094379124341003`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.791759469228055, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {1.9459101490553132`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.0794415416798357`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.1972245773362196`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.302585092994046, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.3978952727983707`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}, {2.4849066497880004`, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}}}}}],
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->{{47.00000000000003, 75.26275219351385}, {36., 
        23.000000000000014`}},
       Method->{
        "DefaultBoundaryStyle" -> Automatic, 
         "DefaultGraphicsInteraction" -> {
          "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
           "Effects" -> {
            "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2},
              "Droplines" -> {
              "freeformCursorMode" -> True, 
               "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
         "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
         None},
       PlotRange->NCache[{{-3.2188758248682006`, 
           Log[4]}, {-6.362071175299374, 0.}}, {{-3.2188758248682006`, 
         1.3862943611198906`}, {-6.362071175299374, 0.}}],
       PlotRangeClipping->False,
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.05], 
          Scaled[0.08090169943749476]}},
       Ticks->{Quiet[
          Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , Quiet[
          Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& }], {337.22558847563715, -197.58781209143575},
       ImageScaled[{0.5, 0.5}], {635.7583577652139, 376.35773731702045}], 
     InsetBox[
      GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJwUmnk4lG8bhmfsOyFRIksSwq9IKPdjTVkiu0oIlRSJUogkKaRFkmzRgspS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         "], {{{}, 
           {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl2nWcVVUXh/EBpbtBusMEEelU6e4uAQER6Rakpbs7BGlpFenuFKQ7pEMk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              "]]]}, {}, 
           {RGBColor[0.880722, 0.611041, 0.142051], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[
             PolygonBox[{{2867, 2919, 2920, 2916, 2918, 2915, 2914, 2913, 
              2912, 2911, 2910, 2909, 2908, 2907, 2906, 2905, 2904, 2903, 
              2902, 2901, 2900, 2899, 2898, 2897, 2896, 2895, 2894, 2893, 
              2892, 2891, 2890, 2889, 2888, 2887, 2886, 2885, 2884, 2883, 
              2882, 2881, 2880, 2879, 2878, 2877, 2876, 2875, 2874, 2873, 
              2872, 2871, 2870, 2869, 2868, 
              2917}}]]}, {}, {}, {}, {}, {}, {}}, {{}, {}, 
           TagBox[
            {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
             Opacity[1.], LineBox[CompressedData["
1:eJwl2mW4VlW7QOEN0t0d0t0gIC1d0t1d0t0hDaJIl6IYKEh3KaF0g4RSSncJ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              "]]},
            Annotation[#, "Charting`Private`Tag$4602832#1"]& ], 
           TagBox[
            {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
             Opacity[1.], 
             LineBox[{2867, 2917, 2868, 2869, 2870, 2871, 2872, 2873, 2874, 
              2875, 2876, 2877, 2878, 2879, 2880, 2881, 2882, 2883, 2884, 
              2885, 2886, 2887, 2888, 2889, 2890, 2891, 2892, 2893, 2894, 
              2895, 2896, 2897, 2898, 2899, 2900, 2901, 2902, 2903, 2904, 
              2905, 2906, 2907, 2908, 2909, 2910, 2911, 2912, 2913, 2914, 
              2915, 2918, 2916}]},
            Annotation[#, "Charting`Private`Tag$4602832#2"]& ]}}], {}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0},
       DisplayFunction->Identity,
       Frame->{{False, False}, {False, False}},
       FrameLabel->{{None, None}, {None, None}},
       FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->{{10.030612244897956`, 1.5}, {36., 23.000000000000014`}},
       
       Method->{
        "DefaultBoundaryStyle" -> Automatic, 
         "DefaultGraphicsInteraction" -> {
          "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
           "Effects" -> {
            "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2},
              "Droplines" -> {
              "freeformCursorMode" -> True, 
               "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
         "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
         None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& )}, "AxesInFront" -> True},
       PlotLabel->FormBox["\"T[0,4] = 0.00172739\"", TraditionalForm],
       PlotRange->{{0., 3.999999918367347}, {0, All}},
       PlotRangeClipping->True,
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {0, 
          Scaled[0.05]}},
       Ticks->{Automatic, Automatic}], {956.3106954526036, -197.58781209143575},
       ImageScaled[{0.5, 0.5}], {525.026217816598, 376.35773731702045}]}, {}},
   
   ImageSize->1200,
   PlotRange->{{0, 1238.1702139539327`}, {-395.1756241828715, 0}},
   PlotRangePadding->{6, 5}],
  StripOnInput->False,
  Magnification->0.5 Inherited]], "Output",
 CellChangeTimes->{3.828162024987468*^9, 3.828162103301087*^9},
 CellLabel->
  "Out[1168]=",ExpressionUUID->"cec93254-e7ed-43aa-9fbb-859553bce9b7"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Minimum number of lookups K of p-series CMF with 99% mass setting:\
\>", "Section",
 CellChangeTimes->{{3.820730855789216*^9, 
  3.8207308650260687`*^9}},ExpressionUUID->"47b1afe0-afc5-4772-9d86-\
f5ac5b3bf9ad"],

Cell["Exact result follows from:", "Text",
 CellChangeTimes->{{3.820731007541519*^9, 3.820731010990563*^9}, 
   3.820731286590766*^9},ExpressionUUID->"94aa8856-d1e1-40b6-bd11-\
426fcc5a1b38"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Exp", "[", 
   RowBox[{"-", "\[Tau]bar"}], "]"}], 
  RowBox[{"Sum", "[", 
   RowBox[{
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", "\[Tau]bar", ")"}], "i"], 
     RowBox[{"i", "!"}]], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "0", ",", "k"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.816067221978948*^9, 3.816067316690641*^9}, {
  3.81606747539429*^9, 3.816067477893834*^9}, {3.8207310185576982`*^9, 
  3.820731020672179*^9}},
 CellLabel->
  "In[9716]:=",ExpressionUUID->"4f9b9b40-50b8-4d84-a5fc-bf7e9da356c2"],

Cell[BoxData[
 FractionBox[
  RowBox[{"Gamma", "[", 
   RowBox[{
    RowBox[{"1", "+", "k"}], ",", "\[Tau]bar"}], "]"}], 
  RowBox[{"k", "!"}]]], "Output",
 CellChangeTimes->{
  3.816067287176692*^9, 3.816067317357295*^9, {3.816067475753957*^9, 
   3.8160674782401*^9}, 3.820731024439698*^9},
 CellLabel->
  "Out[9716]=",ExpressionUUID->"6b2d915f-e2b5-4ae7-9d12-958c70c93084"]
}, Open  ]],

Cell["routine that returns K:", "Text",
 CellChangeTimes->{{3.8207310647127542`*^9, 
  3.8207310779120827`*^9}},ExpressionUUID->"984c916c-e64e-4ca3-a41c-\
1e19241f504b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"KpCMF", "[", "tau_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "runningCDF", ",", "i", ",", "exponent", ",", "goal", ",", "lastPDF", 
      ",", "invI"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"runningCDF", "=", "0"}], ";", "\[IndentingNewLine]", 
     RowBox[{"i", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"exponent", "=", 
      RowBox[{"Exp", "[", 
       RowBox[{"-", "tau"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"goal", "=", "0.99"}], ";", "\[IndentingNewLine]", 
     RowBox[{"lastPDF", "=", "exponent"}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"runningCDF", "<", "goal"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"runningCDF", "+=", "lastPDF"}], ";", "\[IndentingNewLine]", 
        RowBox[{"invI", " ", "=", " ", 
         RowBox[{"1.0", " ", "/", " ", "i"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"lastPDF", " ", "*=", " ", 
         RowBox[{"tau", " ", "invI"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"i", "+=", "1"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"i", "-", "1"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.820731052333906*^9, 3.820731053304446*^9}, {
  3.820731095761959*^9, 3.8207311235275393`*^9}, {3.820731207433237*^9, 
  3.82073121539262*^9}},
 CellLabel->
  "In[9724]:=",ExpressionUUID->"36eb9445-6cd2-40b8-9609-4116f6574264"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Ceiling", "[", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"0.8", "+", 
        RowBox[{"19", " ", "m"}], "+", 
        RowBox[{"1.5", " ", 
         SuperscriptBox["m", "2"]}]}], "]"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"FindRoot", "[", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{"Gamma", "[", 
           RowBox[{"k", ",", "m"}], "]"}], 
          RowBox[{"Gamma", "[", "k", "]"}]], "-", "0.99"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "m"}], "}"}]}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "1"}]}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"KpCMF", "[", "m", "]"}]}], "\[IndentingNewLine]", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"m", ",", "0", ",", "12"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.820728018312999*^9, 3.8207281434275713`*^9}, {
   3.82072826773563*^9, 3.82072831598253*^9}, 3.820730031184532*^9, {
   3.820730133430389*^9, 3.820730137295226*^9}, {3.8207301798731403`*^9, 
   3.8207301860801163`*^9}, {3.820730273941855*^9, 3.820730277258514*^9}, {
   3.8207303849441643`*^9, 3.8207303852143097`*^9}, {3.8207305291683607`*^9, 
   3.8207305378786993`*^9}, {3.820730597319758*^9, 3.820730606512145*^9}, {
   3.8207307720213213`*^9, 3.820730791687896*^9}, {3.820731142382955*^9, 
   3.8207311580653267`*^9}, {3.820731230196014*^9, 3.820731257654133*^9}},
 CellLabel->
  "In[9728]:=",ExpressionUUID->"e67e4fe5-adef-4279-9be6-484ea121bd65"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[{{2.4489795918367347`*^-7, 1.}, {0.003680615046715521, 
       1.}, {0.006691052055241877, 1.}}], 
      LineBox[{{0.17006583280229995`, 3.}, {0.17665801203826337`, 3.}, {
       0.20610097322831405`, 3.}, {0.23554393441836477`, 3.}, {
       0.29938302207014955`, 3.}, {0.3632221097219343, 3.}, {
       0.37918188163488054`, 3.}, {0.3951416535478267, 3.}, {
       0.4031215395042998, 3.}, {0.4111014254607729, 3.}, {0.4139717284452691,
        3.}}], LineBox[{{0.4216247896697589, 4.}, {0.42307125439548254`, 
       4.}, {0.42706119737371906`, 4.}, {0.4589807411996114, 4.}, {
       0.4909002850255038, 4.}, {0.6101174439336645, 4.}, {0.7293346028418252,
        4.}, {0.7366395148100966, 4.}, {0.7439444267783681, 4.}, {
       0.7475968827625039, 4.}, {0.7511717059264497, 4.}}], 
      LineBox[{{0.7588247671509395, 5.}, {0.773164074651454, 5.}, {
       0.787773898587997, 5.}, {0.8169935464610829, 5.}, {0.8462131943341689, 
       5.}, {0.9046524900803408, 5.}, {0.9630917858265126, 5.}, {
       1.0264842468443678`, 5.}, {1.089876707862223, 5.}, {
       1.1215729383711506`, 5.}, {1.1532691688800782`, 5.}, {
       1.1572311976936942`, 5.}, {1.1611932265073102`, 5.}, {
       1.1624697565386524`, 5.}}], 
      LineBox[{{1.1701228177631422`, 6.}, {1.177041341761774, 6.}, {
       1.184965399389006, 6.}, {1.2008135146434697`, 6.}, {
       1.2166616298979334`, 6.}, {1.334985535538235, 6.}, {
       1.4533094411785366`, 6.}, {1.5174245592703706`, 6.}, {
       1.5815396773622048`, 6.}, {1.5975684568851634`, 6.}, {
       1.613597236408122, 6.}, {1.6216116261696012`, 6.}, {
       1.6296260159310805`, 6.}, {1.6336332108118201`, 6.}, {
       1.6364075796631972`, 6.}}], 
      LineBox[{{1.644060640887687, 7.}, {1.645654795454039, 7.}, {
       1.6777123544999561`, 7.}, {1.7097699135458733`, 7.}, {
       1.8356615823137248`, 7.}, {1.961553251081576, 7.}, {
       2.0202685772677973`, 7.}, {2.0789839034540187`, 7.}, {
       2.1083415665471295`, 7.}, {2.1376992296402397`, 7.}, {
       2.1450386454135173`, 7.}, {2.152378061186795, 7.}, {2.156047769073434, 
       7.}, {2.159717476960073, 7.}, {2.1625133323864105`, 7.}}], 
      LineBox[{{2.1701663936109004`, 8.}, {2.181735724279906, 8.}, {
       2.196414555826461, 8.}, {2.32375153874227, 8.}, {2.4510885216580793`, 
       8.}, {2.5699644881784796`, 8.}, {2.6888404546988802`, 8.}, {
       2.703407629586953, 8.}, {2.717974804475026, 8.}, {2.7252583919190627`, 
       8.}, {2.7317124167982882`, 8.}}], 
      LineBox[{{2.739365478022778, 9.}, {2.7434673605291535`, 9.}, {
       2.747109154251172, 9.}, {2.7762435040273177`, 9.}, {
       2.8053778538034635`, 9.}, {2.863646553355755, 9.}, {2.921915252908047, 
       9.}, {3.0483589825559974`, 9.}, {3.1748027122039475`, 9.}, {
       3.2337940688302185`, 9.}, {3.292785425456489, 9.}, {
       3.3075332646130566`, 9.}, {3.3222811037696243`, 9.}, {
       3.3296550233479083`, 9.}, {3.33640089607334, 9.}}], 
      LineBox[{{3.3440539572978296`, 10.}, {3.3480898222936175`, 10.}, {
       3.3517767820827595`, 10.}, {3.381272460395895, 10.}, {3.41076813870903,
        10.}, {3.538657182504938, 10.}, {3.666546226300846, 10.}, {
       3.792096702680937, 10.}, {3.917647179061028, 10.}, {
       3.9322833615591133`, 10.}, {3.9469195440571987`, 10.}, {
       3.9542376353062414`, 10.}, {3.961555726555284, 10.}, {
       3.9652147721798054`, 10.}, {3.968873817804327, 10.}, {
       3.9703347125479955`, 10.}}], 
      LineBox[{{3.9779877737724854`, 11.}, {4.005464274049539, 11.}, {
       4.03473663904571, 11.}, {4.093281369038051, 11.}, {4.151826099030393, 
       11.}, {4.278821889558442, 11.}, {4.405817680086491, 11.}, {
       4.4650850671528115`, 11.}, {4.524352454219131, 11.}, {
       4.5539861477522905`, 11.}, {4.583619841285451, 11.}, {
       4.598436688052031, 11.}, {4.613253534818611, 11.}, {4.620661958201901, 
       11.}, {4.628070381585191, 11.}, {4.628442921330043, 11.}}], 
      LineBox[{{4.636095982554533, 12.}, {4.642887228351771, 12.}, {
       4.771328333027778, 12.}, {4.899769437703785, 12.}, {5.025871974963975, 
       12.}, {5.151974512224165, 12.}, {5.210795272656556, 12.}, {
       5.269616033088947, 12.}, {5.284321223197045, 12.}, {5.299026413305143, 
       12.}, {5.3027027108321665`, 12.}, {5.306379008359191, 12.}, {
       5.30662722521823, 12.}}], 
      LineBox[{{5.314280286442719, 13.}, {5.321084198467289, 13.}, {
       5.3284367935213375`, 13.}, {5.357847173737532, 13.}, {
       5.387257553953728, 13.}, {5.5148054053618765`, 13.}, {
       5.642353256770024, 13.}, {5.761440091782763, 13.}, {5.880526926795502, 
       13.}, {5.938901060593963, 13.}, {5.997275194392424, 13.}, {
       6.000923577754827, 13.}, {6.00157769078199, 13.}}], 
      LineBox[{{6.00923075200648, 14.}, {6.019165494566847, 14.}, {
       6.0264622612916545`, 14.}, {6.04105579474127, 14.}, {6.055649328190885,
        14.}, {6.084836395090116, 14.}, {6.114023461989347, 14.}, {
       6.240678060129635, 14.}, {6.367332658269924, 14.}, {6.485526240014805, 
       14.}, {6.603719821759684, 14.}, {6.6357447998317465`, 14.}, {
       6.667769777903808, 14.}, {6.683782266939838, 14.}, {6.699794755975869, 
       14.}, {6.703797878234877, 14.}, {6.707801000493885, 14.}, {
       6.710615595666089, 14.}}], 
      LineBox[{{6.7182686568905785`, 15.}, {6.723813489529916, 15.}, {
       6.7318197340479315`, 15.}, {6.795869690192054, 15.}, {
       6.859919646336178, 15.}, {6.985680991208608, 15.}, {7.111442336081038, 
       15.}, {7.228742664558059, 15.}, {7.34604299303508, 15.}, {
       7.377844657790177, 15.}, {7.4096463225452736`, 15.}, {
       7.417596738734048, 15.}, {7.425547154922822, 15.}, {7.42952236301721, 
       15.}, {7.431564760280799, 15.}}], 
      LineBox[{{7.439217821505289, 16.}, {7.4414479873003705`, 16.}, {
       7.457348819677919, 16.}, {7.473249652055467, 16.}, {7.536852981565661, 
       16.}, {7.600456311075855, 16.}, {7.719201953700834, 16.}, {
       7.837947596325813, 16.}, {7.954354671534975, 16.}, {8.070761746744136, 
       16.}, {8.102340098182268, 16.}, {8.1339184496204, 16.}, {
       8.149707625339465, 16.}, {8.162648563907684, 16.}}], 
      LineBox[{{8.170301625132172, 17.}, {8.173391388918064, 17.}, {
       8.177338682847832, 17.}, {8.181285976777598, 17.}, {8.18918056463713, 
       17.}, {8.197075152496664, 17.}, {8.260231855372929, 17.}, {
       8.323388558249192, 17.}, {8.44124094760631, 17.}, {8.55909333696343, 
       17.}, {8.686852056863916, 17.}, {8.814610776764402, 17.}, {
       8.844435202640671, 17.}, {8.874259628516942, 17.}, {8.889171841455077, 
       17.}, {8.90240851722731, 17.}}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQfXd65PTPFxUdGMDAyCHfipdz3hUEX2b1obVt1xD8
sh7d7+G3EPwLuTMcNO8h+PMq3ndv/oPg5zS7XbeVVoLzf5UsfyEfjuB3pHH8
YpyM4Csd2lLz7TKCv1c28f8rEWU4/87Np/eFVBD8P1OzDlgZI/g8X9ZsOGeF
4MsEvV+Q5ITgqzQKzNRxQ/B1NhhO/OaJ4G9wd+q97Y3gz6mrXjrXB8EHAEK8
TRU=
       "]], 
      LineBox[{{9.657293307925748, 19.}, {9.718462064574158, 19.}, {
       9.777664289692767, 19.}, {9.905975070473353, 19.}, {
       10.034285851253937`, 19.}, {10.160258064618706`, 19.}, {
       10.286230277983472`, 19.}, {10.34498587646815, 19.}, {
       10.403343248101098`, 19.}}], 
      LineBox[{{10.410996309325586`, 20.}, {10.414758149668708`, 20.}, {
       10.418430374574001`, 20.}, {10.425774824384586`, 20.}, {
       10.433119274195171`, 20.}, {10.447808173816341`, 20.}, {
       10.462497073437511`, 20.}, {10.491874872679851`, 20.}, {
       10.521252671922191`, 20.}, {10.648670199434918`, 20.}, {
       10.776087726947644`, 20.}, {10.895044238064962`, 20.}, {
       11.014000749182278`, 20.}, {11.07230972103303, 20.}, {
       11.130618692883779`, 20.}, {11.145195935846466`, 20.}, {
       11.159773178809154`, 20.}, {11.162681405175821`, 20.}}], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQHaTiKmIWrubAAAamDlOk40tdIhH8H0/fnPofg+DH
bKhS2J2A4L+5ubFsRT6CX8P88szUOgT/pLDg9Nj9CL6YimWiKoM6nO928rjW
DBsEvzwv7AtXJYJ/7IWR6YlZCL5IMn9Z6x4Ef0Wj27EvRxB86wW1YilnEfwW
/Zn7Zl9E8M/t25J2+SqCX9x2yOr9dQRfwu8CH/ctBP8Tw/n8mUh8AFdkSy0=

       "]], 
      LineBox[{{0.014344113279731674`, 2.}, {0.02208246579049721, 2.}, {
       0.029443206088009884`, 2.}, {0.044164686683035234`, 2.}, {
       0.058886167278060585`, 2.}, {0.08832912846811128, 2.}, {
       0.11777208965816198`, 2.}, {0.13249357025318734`, 2.}, {
       0.14721505084821268`, 2.}, {0.15457579114572534`, 2.}, {
       0.16193653144323802`, 2.}, {0.16241277157781017`, 2.}}], 
      LineBox[{{11.934604940743956`, 22.}, {11.967051248311027`, 22.}, {
       11.99999975510204, 22.}}]},
     Annotation[#, "Charting`Private`Tag$69601294#1"]& ], 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVknk41IkfxyfDjiNX7jNmzHzHWOuY+cpo6/NBT6hsl3PYJEeSkF9FFDnX
MiNH9SOK7FakJO0qx0rlrF2UIu0PuXK1KjfzyK/94/28nte/r+dteChsX4AE
hUI5+nX/cmln6JU9YZlbu9+cz3z4sgtS/Al2BysUijoyHRKLJ+Gv6ZFgESsW
OAFP3zrRp6FM7e+i3oIUaKy7Xp3n/Ak+3bcXhrAyYPbEe+bDXZ9B27i7dq0n
G2iW9zlaxAxsiUqzaCu4BP+ITB0vjM/AwZatN7N9L0PQcc/hgf/OQoL6rK43
6yow/dbqLPlz8LJyf1v2fBFsO/I83K9jDvzfmiYt9hSDVm6xz0nveUgxHlpu
KLgBLqcXRV0HF0Bjb91vzLgSSK4cu8V4uwAlUZfC0nxvQfxBj6qff1iE5y07
RvezykFp6IR9K2cJyiM37PGWrID4pbu/xuYsQWR63J2M+QqQ4C82KS0vgfR9
z6DZnkpoLu8pHKxdBo6EQn9dQRXI/uQqkmeJIazoVNtuVj1MHK6u6bu1Cta/
DbMSNB4Bz882rnl+FSj+bDuBZAN41zDVi+ELtEVeLBTON8CdseN0/84vICgM
E3zueQJ2N7TO24+twZlpRmdNQTPMSTi2jC1R8LFQWOvMaofUbmEjdEpg/WTv
n3Kl7dAUcczcYVoC6xyJ/jaTDlCTDTXTXk9FLwlfyi+anVCIfG+2AxVd68X0
jfovYLvsjSzpWirusLII0jDugg+CsYpnlyWRyyqYoUEPrFgJXxrgNyj1TQRt
IngAMjzplfkgg+NOcYqzNwcgKcl+osdFBp+JhBqrIwPw+4eNL6SCZbAlrSsn
1ewdRK8M+Wy6IIPpG6Z/KSh9B1aKdVILYzKoSmc0Nl4ZhK7Npd5UkSyybEWS
ainDoJbIuLuzXQ6d4nyTf3cbA32Fz7cCuAr44HRA3/UX01At9+R1uqMy9gqO
mkVEzsLp6cjRjmgVVHYQBT7GRaCJ8U5xsBoqvQqo3OQlBv49cXhiiAYyDEJK
kw+tgeRARuipfVpo3XfsuW32OlQGvpGHrA4+Xjm361U+FZvYrQOmf+ti0KPW
1voEKSzrk9pxNFEf8/xuaqsdpKHe2/KiankDNPUYXPgSIIPeT/xVbMYMsH92
dzs6yWF4rsp3S+WGODOgZa7uKo/UpP1aPkl0zCyLPuzurog5PnVUuf0MZClK
O0flK6HkVEvuOWUjrAo/V5ZRqIwPFA7sau8zwlfMHNre7A0o3WBPpF9molFi
F/vHPBVc7U59rRnAQv6eAV5hvio6vnTUoXMI7AtP3ioSqmGPE6qGvSOwku8p
35Sljqu2ry2Fv7JR3a2ltyRZA0t6F9jOAmOEIUrWkxOaqOOtd2qXHAfz1IPk
WVFayGUHRyo942DC1SM/kcHa+CxWtmkl2gSvtOc2Z4TroJewq+Ei/1s8G5rz
SS9CF0vjPaBw9luc8mVreh7SQ/tRWpN1kSmmr05K9gfq450fz5QeF3yHNR8c
PioINuKnzknPYzQz7GZaD9kYGaBLu8GbLRVmGGTsZ5Zz/aun2j9w5prjYzev
GFt9Q5wVk7bUVHPkekyWql4zRI2w1JmTw+YYkri9Z4sOHSVceHsSrC0wNVB6
ZV0OHfNsCtsupFvgH3q+a5OqDAxMXvcfr1ELrP6SQuVkMNA1yjP5jbUltt+3
nxR97R5j6mC3LscSmwwCm4XZRviPzffvraYsMemB67VBWSamS9rs/X4LF73p
/zvgJWLiuUu6nSMXuSiuMtMxobHQZXyt9sg4F89QJ/68GMvCH1SS5lX5PFQ3
4vsyKQRG0OTYXpk8jAx1m5M9TWDTm331WYM81LXyb2XFEHi3hTIqHuJhw+rx
AruzBK7ExtICR3goKxJti44nMEg0BTZjPLxa1nhh4mcCQ1ULYoc+8LB53JJs
vUzg6t3XXMslHqr6KZ5KriMwNTc/vl2BxGqO3o5r9QRezRIwrJVIPDDD0f+j
gcCdzuKGa8oklsRvb55rJFDbfuTjCVUSNxedVff/i0BOsZ+ujjaJh/qmquz6
CdQ7n1MRyCSRdn057cDXX7X0VSh1ski8HULziR4i0KTuYQifTeKCmE6rfE+g
vnua5noTEtO0Be6GHwnkO26De+Ykmg0dNtnymcBe96ZYbUsSX5WeXPOYJVB9
H1mTyCVRn591M3ORwDMWI0ZuViQ+pRTG3F4mcNjEyOXRJhKDWm/vbhUTGLPZ
NY7NJ3F9Zg1jZJXAxMnIG1k2JN5zb11cWyPQ6qmwbWUzif8HPY/zvA==
       "]]},
     Annotation[#, "Charting`Private`Tag$69601294#2"]& ], 
    TagBox[
     {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJxNzGk41XkDxnGVUBLqOB11yFiOJSpbylj+VESJFkSUPVSUMcggYxuyjCgp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       "]]},
     Annotation[#, "Charting`Private`Tag$69601294#3"]& ], {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 12}, {0., 22.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.820728043884757*^9, 3.82072804756573*^9}, 
   3.820728097100333*^9, {3.820728130870473*^9, 3.820728144017239*^9}, {
   3.820728268328298*^9, 3.820728316684895*^9}, 3.82073003197421*^9, 
   3.82073013849296*^9, 3.820730208963831*^9, 3.820730330850095*^9, 
   3.820730437266272*^9, {3.820730592169395*^9, 3.820730603647682*^9}, 
   3.8207306635842857`*^9, {3.820730775776215*^9, 3.820730794860038*^9}, 
   3.820731158804665*^9, {3.820731224985982*^9, 3.820731276405396*^9}},
 CellLabel->
  "Out[9728]=",ExpressionUUID->"8ae13bb2-c178-4310-a175-aad580507ca2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The mean number of lookups N of p-series CMF with 99% mass setting:\
\>", "Section",
 CellChangeTimes->{{3.820730084889202*^9, 3.820730098118999*^9}, {
  3.8207306399773483`*^9, 3.820730662190786*^9}, {3.8207307498559713`*^9, 
  3.82073076452841*^9}},ExpressionUUID->"faf3413d-cc7f-4d16-9086-\
81d461802e51"],

Cell[TextData[{
 "Validating our approximation in the paper:\[LineSeparator]",
 Cell[BoxData[
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJztnQewJUX1h5EMFqAUFKGQklBCAVKkghUKBKVwUfhLEEHAgiWtZGVRkigK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     "], {{0, 39.}, {368., 0}}, {0, 255},
     ColorFunction->RGBColor,
     ImageResolution->144],
    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
    Selectable->False],
   DefaultBaseStyle->"ImageGraphics",
   ImageSize->Automatic,
   ImageSizeRaw->{368., 39.},
   PlotRange->{{0, 368.}, {0, 39.}}]], "Input",ExpressionUUID->
  "0feb95b2-a3b8-4955-a1d2-051f800c6db9"]
}], "Text",
 CellChangeTimes->{{3.82073012098214*^9, 3.8207301596910553`*^9}, {
  3.8281626049129066`*^9, 
  3.8281626407086143`*^9}},ExpressionUUID->"e31147cd-6d80-443a-aee5-\
3f6d87dbbdb3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pCMFMeanN", "[", "m", "]"}], "\[IndentingNewLine]", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", "0", ",", "12"}], "}"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m", ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Mean", "[", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"TpCMF", "[", 
             RowBox[{
              RowBox[{"1", "&"}], ",", "1", ",", "m", ",", "0.99"}], "]"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", 
              RowBox[{"Range", "[", "1000", "]"}]}], "}"}]}], "]"}], "]"}], 
         "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", "}"}], ",", 
      
      RowBox[{"{", 
       RowBox[{"m", ",", "0.1", ",", "12.0", ",", "0.5"}], "}"}]}], "]"}], 
    "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.820728018312999*^9, 3.8207281434275713`*^9}, {
   3.82072826773563*^9, 3.82072831598253*^9}, 3.820730031184532*^9, {
   3.820730133430389*^9, 3.820730137295226*^9}, {3.8207301798731403`*^9, 
   3.8207301860801163`*^9}, {3.820730273941855*^9, 3.820730277258514*^9}, {
   3.8207303849441643`*^9, 3.8207303852143097`*^9}, {3.8207305291683607`*^9, 
   3.8207305378786993`*^9}, {3.820730597319758*^9, 3.820730606512145*^9}, {
   3.8207307720213213`*^9, 3.820730791687896*^9}},
 CellLabel->
  "In[9715]:=",ExpressionUUID->"d1ae8451-c0be-41de-9a1b-9e3d30f1a422"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], 
       LineBox[{{2.4489795918367347`*^-7, 1.}, {0.003680615046715521, 1.}, {
        0.0062916470806787155`, 1.}}], 
       LineBox[{{0.15417874032848508`, 3.}, {0.15825616129448167`, 3.}, {
        0.16193653144323802`, 3.}, {0.1692972717407507, 3.}, {
        0.17665801203826337`, 3.}, {0.20610097322831405`, 3.}, {
        0.23554393441836477`, 3.}, {0.29938302207014955`, 3.}, {
        0.3632221097219343, 3.}, {0.37918188163488054`, 3.}, {
        0.3951416535478267, 3.}, {0.3991315965260632, 3.}, {
        0.40230185315016753`, 3.}}], 
       LineBox[{{0.40995491437465736`, 4.}, {0.4111014254607729, 4.}, {
        0.41908131141724597`, 4.}, {0.42706119737371906`, 4.}, {
        0.4589807411996114, 4.}, {0.4909002850255038, 4.}, {
        0.6101174439336645, 4.}, {0.7293346028418252, 4.}, {
        0.7329870588259608, 4.}, {0.7357306729199904, 4.}}], 
       LineBox[{{0.7433837341444802, 5.}, {0.7512493387466396, 5.}, {
        0.758554250714911, 5.}, {0.773164074651454, 5.}, {0.787773898587997, 
        5.}, {0.8169935464610829, 5.}, {0.8462131943341689, 5.}, {
        0.9046524900803408, 5.}, {0.9630917858265126, 5.}, {
        1.0264842468443678`, 5.}, {1.089876707862223, 5.}, {
        1.1057248231166867`, 5.}, {1.1215729383711506`, 5.}, {
        1.125069790916749, 5.}}], 
       LineBox[{{1.132722852141239, 6.}, {1.1334590248119985`, 6.}, {
        1.1374210536256144`, 6.}, {1.1453451112528463`, 6.}, {
        1.1532691688800782`, 6.}, {1.184965399389006, 6.}, {
        1.2166616298979334`, 6.}, {1.334985535538235, 6.}, {
        1.4533094411785366`, 6.}, {1.4853670002244534`, 6.}, {
        1.5174245592703706`, 6.}, {1.5334533387933291`, 6.}, {
        1.5494821183162877`, 6.}, {1.5534893131970273`, 6.}, {
        1.557496508077767, 6.}, {1.5590362946210035`, 6.}}], 
       LineBox[{{1.5666893558454933`, 7.}, {1.5735252876007255`, 7.}, {
        1.5815396773622048`, 7.}, {1.645654795454039, 7.}, {
        1.7097699135458733`, 7.}, {1.8356615823137248`, 7.}, {
        1.961553251081576, 7.}, {1.9909109141746866`, 7.}, {
        2.0202685772677973`, 7.}, {2.0239382851544363`, 7.}, {
        2.027607993041075, 7.}, {2.0308161483486677`, 7.}}], 
       LineBox[{{2.0384692095731576`, 8.}, {2.0422868245876304`, 8.}, {
        2.049626240360908, 8.}, {2.064305071907463, 8.}, {2.0789839034540187`,
         8.}, {2.1376992296402397`, 8.}, {2.196414555826461, 8.}, {
        2.32375153874227, 8.}, {2.4510885216580793`, 8.}, {
        2.4808075132881795`, 8.}, {2.5105265049182792`, 8.}, {
        2.517956252825804, 8.}, {2.525386000733329, 8.}, {2.5291008746870918`,
         8.}, {2.5328157486408545`, 8.}, {2.53570134256753, 8.}}], 
       LineBox[{{2.5433544037920197`, 9.}, {2.5551049923634297`, 9.}, {
        2.5699644881784796`, 9.}, {2.62940247143868, 9.}, {
        2.6888404546988802`, 9.}, {2.8053778538034635`, 9.}, {
        2.921915252908047, 9.}, {2.9851371177320223`, 9.}, {
        3.0483589825559974`, 9.}, {3.0562617156589944`, 9.}, {
        3.064164448761991, 9.}, {3.0681158153134893`, 9.}, {
        3.0701311629637837`, 9.}}], 
       LineBox[{{3.0777842241882736`, 10.}, {3.079969914967985, 10.}, {
        3.0957753811739788`, 10.}, {3.1115808473799724`, 10.}, {
        3.1431917797919597`, 10.}, {3.1748027122039475`, 10.}, {
        3.292785425456489, 10.}, {3.41076813870903, 10.}, {3.474712660606984, 
        10.}, {3.538657182504938, 10.}, {3.5706294434539148`, 10.}, {
        3.602601704402892, 10.}, {3.6185878348773803`, 10.}, {
        3.6312511339681177`, 10.}}], 
       LineBox[{{3.6389041951926075`, 11.}, {3.642567030589113, 11.}, {
        3.646563563207735, 11.}, {3.6505600958263575`, 11.}, {
        3.658553161063602, 11.}, {3.666546226300846, 11.}, {3.792096702680937,
         11.}, {3.917647179061028, 11.}, {4.03473663904571, 11.}, {
        4.151826099030393, 11.}, {4.183575046662405, 11.}, {4.215323994294417,
         11.}, {4.216684039201318, 11.}}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQ/TLv2/wdTwUcGMBAw0HmjPDHdS8Q/MVre732v0Hw
NxQ0/r3/BcHfY1y6geEvgn91Z4yYE68gnP/O3qWmWRbBD4p4JNwZh+BvK2hY
3TcfwXc93XnzvYQQnH9FdTJ74CQEX8P2Mb/IFQS/JsRY4rqoMJwfGOV+y10N
wVdLiJ6zwwzBF0hO/fvBDsH/nZofp+mO4Bekf+lz9Ubw9b+Ii+v7IPgAmXFG
9Q==
        "]], 
       LineBox[{{4.832051446116979, 13.}, {4.835548885365782, 13.}, {
        4.8676591615347835`, 13.}, {4.899769437703785, 13.}, {
        5.025871974963975, 13.}, {5.151974512224165, 13.}, {5.269616033088947,
         13.}, {5.387257553953728, 13.}, {5.4191445168057655`, 13.}, {
        5.451031479657802, 13.}, {5.452626383412949, 13.}}], 
       LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQPfnLsrrg66IODGCg41AT8Oa85C0Ef8F89fV69xD8
Z7bzciOeIfi6d0R0mt4h+LskmFZe/Yfge4S+V9XkF4Pza92XSJYHIPibLCN5
j05E8J+4T/i8jVsczhcLO35zRSuCr7Bzqnv+QQRfSyZlq+lfBH+9r/cbCWkJ
ON+k3kj5jwWC/1182b637gj+rg2SUffDEHzp2svqEXEIfo1n79cLqQh+sFVo
lkkagg8Ae+JK1Q==
        "]], 
       LineBox[{{6.1074623849663014`, 15.}, {6.114023461989347, 15.}, {
        6.240678060129635, 15.}, {6.367332658269924, 15.}, {6.485526240014805,
         15.}, {6.603719821759684, 15.}, {6.667769777903808, 15.}, {
        6.7318197340479315`, 15.}, {6.747832223083963, 15.}, {
        6.763844712119993, 15.}, {6.764559190970433, 15.}}], 
       LineBox[{{6.772212252194922, 16.}, {6.775854078897016, 16.}, {
        6.779857201156023, 16.}, {6.787863445674039, 16.}, {6.795869690192054,
         16.}, {6.827894668264117, 16.}, {6.859919646336178, 16.}, {
        6.985680991208608, 16.}, {7.111442336081038, 16.}, {7.228742664558059,
         16.}, {7.34604299303508, 16.}, {7.377844657790177, 16.}, {
        7.4096463225452736`, 16.}, {7.425547154922822, 16.}, {
        7.4414479873003705`, 16.}, {7.445423195394758, 16.}, {
        7.445630507826525, 16.}}], 
       LineBox[{{7.453283569051015, 17.}, {7.457348819677919, 17.}, {
        7.465299235866693, 17.}, {7.473249652055467, 17.}, {7.536852981565661,
         17.}, {7.600456311075855, 17.}, {7.719201953700834, 17.}, {
        7.837947596325813, 17.}, {7.954354671534975, 17.}, {8.070761746744136,
         17.}, {8.102340098182268, 17.}, {8.1339184496204, 17.}, {
        8.137865743550165, 17.}, {8.141813037479931, 17.}, {8.141898930516785,
         17.}}], 
       LineBox[{{8.149551991741273, 18.}, {8.149707625339465, 18.}, {
        8.157602213198999, 18.}, {8.16549680105853, 18.}, {8.181285976777598, 
        18.}, {8.197075152496664, 18.}, {8.260231855372929, 18.}, {
        8.323388558249192, 18.}, {8.44124094760631, 18.}, {8.55909333696343, 
        18.}, {8.686852056863916, 18.}, {8.814610776764402, 18.}, {
        8.829522989702536, 18.}, {8.844435202640671, 18.}, {8.848163255875205,
         18.}, {8.851891309109739, 18.}, {8.852344497202399, 18.}}], 
       LineBox[{{8.859997558426887, 19.}, {8.866803522047874, 19.}, {
        8.874259628516942, 19.}, {8.904084054393211, 19.}, {8.93390848026948, 
        19.}, {8.993557332022018, 19.}, {9.053206183774556, 19.}, {
        9.170165319863816, 19.}, {9.287124455953077, 19.}, {9.413989922585703,
         19.}, {9.540855389218331, 19.}, {9.555655945497982, 19.}, {
        9.570456501777635, 19.}, {9.574156640847548, 19.}, {9.576038197480688,
         19.}}], 
       LineBox[{{9.583691258705176, 20.}, {9.592657336197114, 20.}, {
        9.60005761433694, 20.}, {9.629658726896245, 20.}, {9.65925983945555, 
        20.}, {9.718462064574158, 20.}, {9.777664289692767, 20.}, {
        9.905975070473353, 20.}, {10.034285851253937`, 20.}, {
        10.160258064618706`, 20.}, {10.286230277983472`, 20.}, {
        10.30091917760464, 20.}, {10.312130986233418`, 20.}}], 
       LineBox[{{10.319784047457906`, 21.}, {10.326624751941688`, 21.}, {
        10.33029697684698, 21.}, {10.337641426657566`, 21.}, {
        10.34498587646815, 21.}, {10.374363675710491`, 21.}, {
        10.403741474952831`, 21.}, {10.462497073437511`, 21.}, {
        10.521252671922191`, 21.}, {10.648670199434918`, 21.}, {
        10.776087726947644`, 21.}, {10.895044238064962`, 21.}, {
        11.014000749182278`, 21.}, {11.028577992144967`, 21.}, {
        11.043155235107655`, 21.}, {11.050443856588998`, 21.}, {
        11.057732478070342`, 21.}, {11.059844645172909`, 21.}}], 
       LineBox[{{11.067497706397397`, 22.}, {11.07230972103303, 22.}, {
        11.101464206958404`, 22.}, {11.130618692883779`, 22.}, {
        11.188927664734528`, 22.}, {11.247236636585278`, 22.}, {
        11.373760910830145`, 22.}, {11.500285185075011`, 22.}, {
        11.618348442924468`, 22.}, {11.736411700773926`, 22.}, {
        11.76936020756494, 22.}, {11.802308714355956`, 22.}, {
        11.81054584105371, 22.}, {11.818464073891256`, 22.}}], 
       LineBox[{{0.013944708305168512`, 2.}, {0.02208246579049721, 2.}, {
        0.029443206088009884`, 2.}, {0.044164686683035234`, 2.}, {
        0.058886167278060585`, 2.}, {0.08832912846811128, 2.}, {
        0.11777208965816198`, 2.}, {0.13249357025318734`, 2.}, {
        0.1465256791039953, 2.}}], 
       LineBox[{{11.826117135115744`, 23.}, {11.827020094449217`, 23.}, {
        11.831138657798093`, 23.}, {11.83525722114697, 23.}, {
        11.851731474542476`, 23.}, {11.868205727937983`, 23.}, {
        11.934102741520011`, 23.}, {11.99999975510204, 23.}}]},
      Annotation[#, "Charting`Private`Tag$69563320#1"]& ], {}}, {}}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQPWsmCOy0F2o+cGqhK4ODMRg8tmcAgQYBB4j8R3vd
TXPfLz8mAuX/tM8HaVCUdDh7BgQYHJRv/6zLspGF8lkcQNw9WxSgfA4HHibt
drGbSlA+jwNb41Tn7jcqDmlgIOBwsmzffCl9VShfyEEzpv/QVw11KF/Ewd40
bpenjyaUL+Ywzbk757m1NpQv4RDQOz1PyFkXypeCyFfD+DIO4jfPfQ9O1ofy
5SDqDxtA/asAdR+Mr+iQtadkssQTQyhfyWHi2xp703tGUL6yQ+lkCZawdzC+
isNdFaCPHhtD+aoOhbZc1xd/MIHy1RzAwffaFMpXd3ipZsix5o+pAwArKZcw

      "]]}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 12}, {0., 23.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.820728043884757*^9, 3.82072804756573*^9}, 
   3.820728097100333*^9, {3.820728130870473*^9, 3.820728144017239*^9}, {
   3.820728268328298*^9, 3.820728316684895*^9}, 3.82073003197421*^9, 
   3.82073013849296*^9, 3.820730208963831*^9, 3.820730330850095*^9, 
   3.820730437266272*^9, {3.820730592169395*^9, 3.820730603647682*^9}, 
   3.8207306635842857`*^9, {3.820730775776215*^9, 3.820730794860038*^9}},
 CellLabel->
  "Out[9715]=",ExpressionUUID->"3cd2bde7-454a-4c89-8ffa-3727e4eb052f"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Residual Ratio Tracking and Poisson Estimator relationship", "Section",
 CellChangeTimes->{{3.820731529108492*^9, 
  3.820731536860579*^9}},ExpressionUUID->"f9cafc14-e540-4c6e-a77c-\
b3a827454312"],

Cell["\<\
These two equivalent estimators are written in a different and potentially \
confusing way.  This arises because the use of \[OpenCurlyQuote]control\
\[CloseCurlyQuote] has different meanings.\
\>", "Text",
 CellChangeTimes->{{3.820731539010037*^9, 
  3.820731570927732*^9}},ExpressionUUID->"b375b14f-9f4c-47d5-977d-\
b755d8686b41"],

Cell["\<\
In graphics, [Novak et al. 2014] presented residual ratio tracking as:\
\>", "Text",
 CellChangeTimes->{{3.820731575133787*^9, 
  3.820731587016223*^9}},ExpressionUUID->"30feef3a-ae3d-4532-8e6c-\
396f0cb920ef"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TResidualRatioTracking", "[", 
   RowBox[{"f_", ",", "d_", ",", "maj_", ",", "control_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\[Lambda]", ",", "Yprod", ",", "n"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Lambda]", "=", 
      RowBox[{"d", 
       RowBox[{"(", 
        RowBox[{"maj", "-", "control"}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"n", "=", 
      RowBox[{"RandomVariate", "[", 
       RowBox[{"PoissonDistribution", "[", "\[Lambda]", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Yprod", "=", 
      RowBox[{"Product", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox[
           RowBox[{
            RowBox[{"f", "[", 
             RowBox[{"RandomReal", "[", 
              RowBox[{"{", 
               RowBox[{"0", ",", "d"}], "}"}], "]"}], "]"}], "-", "control"}], 
           RowBox[{"maj", "-", "control"}]]}], ")"}], "\[IndentingNewLine]", 
        ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Range", "[", "n", "]"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "d"}], " ", "control"}], "]"}], " ", "Yprod"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.8207315972850733`*^9, 
  3.820731601089324*^9}},ExpressionUUID->"4499e83f-7894-4ec0-8d19-\
98d0a5695090"],

Cell["\<\
where maj is a majorant function, and control is the control function.  The \
Poisson estimator is written:\
\>", "Text",
 CellChangeTimes->{{3.820731606882916*^9, 
  3.8207316250030203`*^9}},ExpressionUUID->"11c7e4c3-a8d3-4607-bdb1-\
3550c25fba85"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PoissonEstimator", "[", 
   RowBox[{"f_", ",", "d_", ",", "control_", ",", "\[Lambda]_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"n", ",", "Yprod"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"n", "=", 
      RowBox[{"RandomVariate", "[", 
       RowBox[{"PoissonDistribution", "[", "\[Lambda]", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Yprod", "=", 
      RowBox[{"Product", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "d"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"f", "[", 
            RowBox[{"RandomReal", "[", 
             RowBox[{"{", 
              RowBox[{"0", ",", "d"}], "}"}], "]"}], "]"}], "-", "control"}], 
          ")"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Range", "[", "n", "]"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "d"}], " ", "control"}], "]"}], " ", 
      FractionBox["1", 
       RowBox[{
        RowBox[{
         RowBox[{"PDF", "[", 
          RowBox[{"PoissonDistribution", "[", "\[Lambda]", "]"}], "]"}], "[", 
         "n", "]"}], 
        RowBox[{"n", "!"}], " "}]], "Yprod"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.820731646931975*^9, 
  3.8207316608181057`*^9}},ExpressionUUID->"3572aed8-4a48-47bc-8c0c-\
a516791d271e"],

Cell[TextData[{
 "where control is the control variate in the sense of our Eq.(9), ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Mu]", "c"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "be47cd84-4b19-4572-8277-72ea74c77d3d"],
 ".  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[Tau]", "c"], " ", "follows", " ", "from", " ", "the", 
     " ", "interval", " ", "width", " ", "being", " ", "d"}], ",", " ", 
    RowBox[{
     RowBox[{
     "assuming", " ", "the", " ", "control", " ", "variate", " ", "is", " ", 
      "just", " ", "a", " ", 
      RowBox[{"constant", ":", " ", 
       SubscriptBox["\[Tau]", "c"]}]}], " ", "=", " ", 
     RowBox[{"d", " ", 
      RowBox[{
       SubscriptBox["\[Mu]", "c"], "."}]}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "686d6ab1-902a-4f96-8fc4-9aa992e9fb97"]
}], "Text",
 CellChangeTimes->{{3.820731670465518*^9, 
  3.820731749712634*^9}},ExpressionUUID->"8e56bcae-a956-4a65-9021-\
ff1943aadc52"],

Cell["\<\
The two align when \[Lambda] = d(maj - RT.control), and Poisson.control = \
maj.  
In this case the terms of the Poisson estimator expand into:\
\>", "Text",
 CellChangeTimes->{{3.82073180186285*^9, 3.820731863564661*^9}, {
   3.820731904700832*^9, 3.820731914229968*^9}, {3.820731946343965*^9, 
   3.820731948721346*^9}, 
   3.820732017924752*^9},ExpressionUUID->"e697a1c4-41dc-45b7-a6e4-\
d07723ffe200"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"d", ",", "maj"}], "]"}], ";", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "d"}], " ", "maj"}], "]"}], " ", 
      FractionBox["1", 
       RowBox[{
        RowBox[{
         RowBox[{"PDF", "[", 
          RowBox[{"PoissonDistribution", "[", 
           RowBox[{"d", 
            RowBox[{"(", 
             RowBox[{"maj", "-", "RTcontrol"}], ")"}]}], "]"}], "]"}], "[", 
         "n", "]"}], 
        RowBox[{"n", "!"}], " "}]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "d"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Mu]", "[", "x", "]"}], "-", "maj"}], ")"}]}], ")"}], 
       "n"]}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", 
       RowBox[{
        RowBox[{"Range", "[", "4", "]"}], "-", "1"}]}], "}"}]}], "]"}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.8207319207842913`*^9, 3.820731973805046*^9}, {
  3.8207320264849157`*^9, 3.820732073272338*^9}},
 CellLabel->
  "In[9736]:=",ExpressionUUID->"9f47a73c-81cd-4f2d-b62f-e5334f4344c2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "d"}], " ", "RTcontrol"}]], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "d"}], " ", "RTcontrol"}]], " ", 
     RowBox[{"(", 
      RowBox[{"maj", "-", 
       RowBox[{"\[Mu]", "[", "x", "]"}]}], ")"}]}], 
    RowBox[{"maj", "-", "RTcontrol"}]], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "d"}], " ", "RTcontrol"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"maj", "-", 
        RowBox[{"\[Mu]", "[", "x", "]"}]}], ")"}], "2"]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"maj", "-", "RTcontrol"}], ")"}], "2"]], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "d"}], " ", "RTcontrol"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"maj", "-", 
        RowBox[{"\[Mu]", "[", "x", "]"}]}], ")"}], "3"]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"maj", "-", "RTcontrol"}], ")"}], "3"]]}], "}"}]], "Output",
 CellChangeTimes->{{3.820731917725878*^9, 3.820731974180148*^9}, {
  3.820732038709502*^9, 3.8207320736862926`*^9}},
 CellLabel->
  "Out[9736]=",ExpressionUUID->"597e721b-8054-4365-a3de-c4077a33982c"]
}, Open  ]],

Cell["which is the [Novak et al. 2014] form of RRT.", "Text",
 CellChangeTimes->{{3.820732095235029*^9, 
  3.820732115364132*^9}},ExpressionUUID->"b1331508-ca37-4592-b860-\
837095e716c9"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generalized Bhanot Kennedy", "Section",
 CellChangeTimes->{{3.817150337173039*^9, 
  3.817150341365082*^9}},ExpressionUUID->"ae9b587d-781f-41e8-90f4-\
9c70cf77a9e2"],

Cell["K = Floor[c]", "Text",
 CellChangeTimes->{{3.817150731526861*^9, 3.817150776328342*^9}, {
  3.817150994211282*^9, 3.817151019723936*^9}, {3.817269155679291*^9, 
  3.817269246621654*^9}, {3.820811608331603*^9, 
  3.820811626083949*^9}},ExpressionUUID->"1d3ccdd4-c06c-42e0-8720-\
6ac298476398"],

Cell["Verification of the roulette weights:", "Text",
 CellChangeTimes->{{3.820732972996586*^9, 
  3.820732977065319*^9}},ExpressionUUID->"3cf6a867-7881-4e28-bbe3-\
8851f0356dea"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"K", ",", "c", ",", "k", ",", "X", ",", "p", ",", "d", ",", "x"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"-", "p"}], " ", "d"}], "]"}], 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["c", "k"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox["c", 
           RowBox[{"1", "+", "K", "+", "k"}]]}], ")"}]}], 
       RowBox[{"Pochhammer", "[", 
        RowBox[{
         RowBox[{"1", "+", "K"}], ",", "k"}], "]"}]], 
      RowBox[{"(", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Sum", "[", 
          RowBox[{
           FractionBox[
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"d", 
               RowBox[{"(", 
                RowBox[{"p", "-", "x"}], ")"}]}], ")"}], "n"], 
            RowBox[{"n", "!"}]], ",", 
           RowBox[{"{", 
            RowBox[{"n", ",", "0", ",", "K"}], "}"}]}], "]"}], "+", 
         RowBox[{"Sum", "[", 
          RowBox[{
           FractionBox[
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"d", 
               RowBox[{"(", 
                RowBox[{"p", "-", "x"}], ")"}]}], ")"}], 
             RowBox[{"K", "+", "i"}]], 
            RowBox[{
             SuperscriptBox["c", "i"], " ", 
             RowBox[{"K", "!"}]}]], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "k"}], "}"}]}], "]"}]}], ")"}], 
       ")"}]}], "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", "Infinity"}], "}"}], ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{
       RowBox[{"c", ">", "0"}], "&&", 
       RowBox[{"K", ">", "0"}], "&&", 
       RowBox[{"x", ">", "0"}], "&&", 
       RowBox[{"p", ">", "0"}], "&&", 
       RowBox[{"d", ">", "0"}]}]}]}], "]"}]}], "//", 
  "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.8171506678438263`*^9, 3.81715068920509*^9}, {
   3.8171508074734507`*^9, 3.817150944683105*^9}, {3.817266275233636*^9, 
   3.817266286208069*^9}, 3.817266327007045*^9, 3.817266370715623*^9, 
   3.81726642789727*^9, {3.8173093211400137`*^9, 3.817309342329318*^9}, 
   3.8193141613030767`*^9, {3.8208116735938663`*^9, 3.82081171747379*^9}, {
   3.820811771965085*^9, 3.820811772461157*^9}},
 CellLabel->"In[58]:=",ExpressionUUID->"61fc9065-4d95-4ded-94de-81697118ccc2"],

Cell[BoxData[
 SuperscriptBox["\[ExponentialE]", 
  RowBox[{
   RowBox[{"-", "d"}], " ", "x"}]]], "Output",
 CellChangeTimes->{{3.817150869954068*^9, 3.817150949964357*^9}, 
   3.817266292243528*^9, 3.81726633096854*^9, 3.817266373161973*^9, 
   3.817266431339319*^9, {3.817309337781356*^9, 3.817309347134604*^9}, {
   3.8208117128044662`*^9, 3.8208117208846397`*^9}, 3.82081177627283*^9},
 CellLabel->"Out[59]=",ExpressionUUID->"234d6ee6-14fa-4504-b8f5-3115e6c9fe52"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Derivation of (54) for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     RowBox[{"E", "[", "N", "]"}], "BK"], ":"}], TraditionalForm]],
  ExpressionUUID->"ab07354b-8bfb-4b47-a106-9d6721fd4a93"]
}], "Subsection",
 CellChangeTimes->{{3.820733010901519*^9, 3.820733024530342*^9}, {
  3.820812139435111*^9, 3.820812153395399*^9}, {3.828162697544405*^9, 
  3.828162697666369*^9}},ExpressionUUID->"b74c77f1-766b-422e-8ffc-\
6efe45d7fcd8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"c", ",", "K"}], "]"}], ";", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["c", "k"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           FractionBox["c", 
            RowBox[{"1", "+", "K", "+", "k"}]]}], ")"}]}], 
        RowBox[{"Pochhammer", "[", 
         RowBox[{
          RowBox[{"1", "+", "K"}], ",", "k"}], "]"}]], 
       RowBox[{"(", 
        RowBox[{"k", "+", "K"}], ")"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "0", ",", "Infinity"}], "}"}]}], "]"}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{
      RowBox[{"c", ">", "0"}], "&&", 
      RowBox[{"K", ">", "0"}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.816387180902796*^9, 3.81638720091582*^9}, {
  3.8163872386570253`*^9, 3.8163872422402287`*^9}, {3.820811830094716*^9, 
  3.820811847617117*^9}},
 CellLabel->"In[85]:=",ExpressionUUID->"e0cdb83f-1be8-4228-a306-af120946b99e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1"}], "+", "K", "+", 
  RowBox[{
   SuperscriptBox["c", 
    RowBox[{"-", "K"}]], " ", 
   SuperscriptBox["\[ExponentialE]", "c"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Gamma", "[", 
      RowBox[{"1", "+", "K"}], "]"}], "-", 
     RowBox[{"K", " ", 
      RowBox[{"Gamma", "[", 
       RowBox[{"K", ",", "c"}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.820733069690475*^9, 3.820811848716145*^9},
 CellLabel->"Out[85]=",ExpressionUUID->"ecd8182b-f9f6-4aa8-b343-caabd2cfcdb0"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"costGBK", "[", 
   RowBox[{"K_", ",", "c_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"-", "1"}], "+", "K", "+", 
   RowBox[{
    SuperscriptBox["c", 
     RowBox[{"-", "K"}]], " ", 
    SuperscriptBox["\[ExponentialE]", "c"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{"1", "+", "K"}], "]"}], "-", 
      RowBox[{"K", " ", 
       RowBox[{"Gamma", "[", 
        RowBox[{"K", ",", "c"}], "]"}]}]}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.820811883651924*^9, 3.8208118892946787`*^9}},
 CellLabel->
  "In[759]:=",ExpressionUUID->"27a476b1-7cc6-483e-b472-51d56737f7f5"],

Cell[CellGroupData[{

Cell[TextData[{
 "Verify ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"(", "54", ")"}], " ", 
     SubscriptBox[
      RowBox[{"E", "[", "N", "]"}], "BK"]}], ":"}], TraditionalForm]],
  ExpressionUUID->"4a39b703-a88d-42f9-9c36-0c952d36c74a"]
}], "Subsubsection",
 CellChangeTimes->{{3.820733100799305*^9, 3.820733107258407*^9}, {
  3.820812161743649*^9, 3.820812161965645*^9}, {3.8281627036566057`*^9, 
  3.828162703842454*^9}},ExpressionUUID->"1193d636-da14-4bae-acee-\
79934e82b462"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"f", "=", 
   RowBox[{"1", "&"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"LogPlot", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Mean", "[", 
      RowBox[{"Last", "/@", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"TBK", "[", 
          RowBox[{"f", ",", "1.1", ",", "d", ",", 
           RowBox[{"Floor", "[", "c", "]"}], ",", 
           RowBox[{".5", "c"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Range", "[", "1000", "]"}]}], "}"}]}], "]"}]}], "]"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"costGBK", "[", 
      RowBox[{
       RowBox[{"Floor", "[", "c", "]"}], ",", 
       RowBox[{".5", "c"}]}], "]"}]}], "\[IndentingNewLine]", "}"}], 
   "\[IndentingNewLine]", ",", 
   RowBox[{"{", 
    RowBox[{"c", ",", ".5", ",", "5"}], "}"}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", "50"}], ",", 
   RowBox[{"MaxRecursion", "\[Rule]", "1"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<cost\>\"", ","}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<c\>\"", ","}], "}"}]}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "\[IndentingNewLine]", 
  "]"}]}], "Input",
 CellChangeTimes->{{3.816387279760874*^9, 3.816387320145578*^9}, {
  3.8163873771787724`*^9, 3.816387404017681*^9}, {3.816387442007779*^9, 
  3.816387499465114*^9}, {3.8199082899627047`*^9, 3.819908309996633*^9}, {
  3.820733113242997*^9, 3.820733113946808*^9}, {3.820811917286915*^9, 
  3.820811925610365*^9}},
 CellLabel->"In[87]:=",ExpressionUUID->"089fe7a8-5a30-4fe8-a66f-b4d8ab1d9b14"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJw9kGlQk4cahUPYghASEgSxyCaLYJUim2mHvK+ibHWhEQu1WCkFU2vBiyBc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       "]]},
     Annotation[#, "Charting`Private`Tag$182737#1"]& ], 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[{{0.5000000918367347, -1.2586913418577583`}, {
       0.5441645336218107, -1.1625270424704361`}, {
       0.5883289754068868, -1.0729310075883496`}, {
       0.6840876068845639, -0.8969245635093156}, {
       0.7735004760656844, -0.7503764822446296}, {
       0.8611594196849421, -0.6196199072791583}, {
       0.9087037654483335, -0.5531206317982699}, {
       0.9540816326530612, -0.49216873423233654`}}], 
      LineBox[{{1.0459183673469388`, 0.27284899642223254`}, {
       1.0930773790108268`, 0.2856845325935814}, {1.1411637175797023`, 
       0.2988194681531358}, {1.2355824691555908`, 0.32474809243575}, {
       1.3236554584349227`, 0.3490983709531573}, {1.4191581956217796`, 
       0.3756814905524028}, {1.5083151705120799`, 0.4006655455516401}, {
       1.5957182198405175`, 0.42531438568378366`}, {1.6905510170764801`, 
       0.45223292734205867`}, {1.7790380520158862`, 0.4775133229763307}, {
       1.874954834862817, 0.5050935239669856}, {1.9220362635053512`, 
       0.5186986623950991}, {1.9540816326530612`, 0.5279840674032591}}], 
      LineBox[{{2.045918367346939, 0.895917282949135}, {2.1045582085844154`, 
       0.9027788833467906}, {2.152181630032434, 0.9083985632799073}, {
       2.241082710631914, 0.9190030309270499}, {2.3374135391389195`, 
       0.9306627417668116}, {2.431990442084062, 0.9422829817223966}, {
       2.5202215827326477`, 0.9532795377461585}, {2.6158824712887587`, 
       0.965373947957136}, {2.705197597548313, 0.9768290416360721}, {
       2.7927587982460045`, 0.9882134216088776}, {2.887749746851221, 
       1.0007380836449955`}, {2.9320723400055515`, 1.0066445996421116`}, {
       2.954081632653061, 1.0095924643901173`}}], 
      LineBox[{{3.045918367346939, 1.2624339330713694`}, {3.0724698673760664`,
        1.2642488596669141`}, {3.1196303717032277`, 1.2674919701692822`}, {
       3.166790876030389, 1.2707601367428767`}, {3.2547661223881543`, 
       1.276924330246413}, {3.350171116653445, 1.2837098207019884`}, {
       3.4392303486221794`, 1.2901399065877137`}, {3.5265356550290505`, 
       1.2965345408328475`}, {3.621270709343447, 1.3035769233374406`}, {
       3.709660001361287, 1.3102461265095906`}, {3.805479041286652, 
       1.3175849188368316`}, {3.8949523189154602`, 1.3245414816227972`}, {
       3.938811994948933, 1.3279886113838761`}, {3.954081632653061, 
       1.3291944808885259`}}], 
      LineBox[{{4.045918367346939, 1.5245745413852392`}, {4.077820770956876, 
       1.5260376963396793`}, {4.122222439795833, 1.5280862265061226`}, {
       4.166624108634791, 1.530148952047704}, {4.26285719422023, 
       1.5346687876739782`}, {4.357336354243806, 1.5391726480579924`}, {
       4.445469751970826, 1.543434238230418}, {4.541032897605371, 
       1.5481218029579753`}, {4.630250280943359, 1.5525616984920352`}, {
       4.717713738719485, 1.5569748269421584`}, {4.812606944403136, 
       1.5618316176796114`}, {4.90115438779023, 1.5664291447669279`}, {
       4.950577147976748, 1.5690231110786812`}, {4.999999908163265, 
       1.5716372378721903`}}]},
     Annotation[#, "Charting`Private`Tag$182737#2"]& ], {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.5000000918367347, -1.3547956940605195`},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox["\"cost\"", TraditionalForm], ""}, {
     FormBox["\"c\"", TraditionalForm], ""}},
  FrameTicks->FrontEndValueCache[{{Quiet[
       Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
      Charting`ScaledFrameTicks[{Log, Exp}]}, {
     Automatic, Automatic}}, {{{{-0.6931471805599453, 
        FormBox[
         TagBox[
          InterpretationBox[
           StyleBox["\"0.5\"", ShowStringCharacters -> False], 0.5, 
           AutoDelete -> True], NumberForm[#, {
            DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}}, {0., 
        FormBox["1", TraditionalForm], {0.01, 0.}}, {0.6931471805599453, 
        FormBox["2", TraditionalForm], {0.01, 0.}}, {1.6094379124341003`, 
        FormBox["5", TraditionalForm], {0.01, 0.}}, {-1.6094379124341003`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-1.2039728043259361`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.916290731874155, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.5108256237659907, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.35667494393873245`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.2231435513142097, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.10536051565782628`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.4054651081081644, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.0986122886681098`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.3862943611198906`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.791759469228055, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.9459101490553132`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.0794415416798357`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.1972245773362196`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.302585092994046, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}}, {{-0.6931471805599453, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}}, {0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}}, {
       0.6931471805599453, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}}, {
       1.6094379124341003`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
        0.}}, {-1.6094379124341003`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-1.2039728043259361`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.916290731874155, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.5108256237659907, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.35667494393873245`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.2231435513142097, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.10536051565782628`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.4054651081081644, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.0986122886681098`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.3862943611198906`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.791759469228055, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.9459101490553132`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.0794415416798357`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.1972245773362196`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.302585092994046, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}}}, {
     Automatic, Automatic}}],
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{459.3125, Automatic},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Quiet[
     Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& }]], "Output",
 CellChangeTimes->{
  3.8163873221395016`*^9, {3.8163873801053267`*^9, 3.816387406076366*^9}, {
   3.816387445197209*^9, 3.816387502431756*^9}, {3.819908296852676*^9, 
   3.819908314083507*^9}, 3.820733119217012*^9, 3.820811929120203*^9},
 CellLabel->"Out[89]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>", "ImageResolution" -> \
144.],ExpressionUUID->"d5ece37e-9433-4d77-8347-9504cea78620"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Roulette variance for BK estimator - C.2.1 - derivation and validation\
\>", "Subsection",
 CellChangeTimes->{{3.820733157061285*^9, 3.820733180090844*^9}, {
  3.8208121816273193`*^9, 3.8208122127859573`*^9}, {3.828554327289329*^9, 
  3.828554334592636*^9}},ExpressionUUID->"353c503d-c520-4476-931a-\
77f17b3d83d8"],

Cell["\<\
Here we derive and validate the exact variance for the BK and U-BK estimators \
for the case of a constant-density medium (or any medium where the optical \
depth is estimated with zero variance).  In this case all Y estimates are the \
same constant, and so U-BK is identical to BK.\
\>", "Text",
 CellChangeTimes->{{3.8285543369326468`*^9, 
  3.82855437674507*^9}},ExpressionUUID->"4b4b3ede-b690-4263-a9f8-\
864c5528f13d"],

Cell[TextData[{
 "First, compute the expectation of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["T", "2"], ":"}], TraditionalForm]],ExpressionUUID->
  "6f26d78a-d8b1-47e2-94d4-774bf8b940e8"]
}], "Text",
 CellChangeTimes->{{3.820733244543127*^9, 3.82073325036504*^9}, {
  3.8285543818204327`*^9, 
  3.8285543824368143`*^9}},ExpressionUUID->"791b3672-5d85-401a-aa41-\
f4a28fae6f0e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"c", ",", "k", ",", "K", ",", "Y", ",", "\[Tau]c"}], "]"}], ";", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["c", "k"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           FractionBox["c", 
            RowBox[{"1", "+", "K", "+", "k"}]]}], ")"}]}], 
        RowBox[{"Pochhammer", "[", 
         RowBox[{
          RowBox[{"1", "+", "K"}], ",", "k"}], "]"}]], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"-", "\[Tau]c"}], "]"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Sum", "[", 
             RowBox[{
              FractionBox[
               SuperscriptBox[
                RowBox[{"(", "Y", ")"}], "n"], 
               RowBox[{"n", "!"}]], ",", 
              RowBox[{"{", 
               RowBox[{"n", ",", "0", ",", "K"}], "}"}]}], "]"}], "+", 
            RowBox[{"Sum", "[", 
             RowBox[{
              FractionBox[
               SuperscriptBox[
                RowBox[{"(", "Y", ")"}], 
                RowBox[{"K", "+", "i"}]], 
               RowBox[{
                SuperscriptBox["c", "i"], " ", 
                RowBox[{"K", "!"}]}]], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "1", ",", "k"}], "}"}]}], "]"}]}], ")"}]}], 
         ")"}], "2"]}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "0", ",", "Infinity"}], "}"}], ",", 
      RowBox[{"Assumptions", "\[Rule]", 
       RowBox[{
        RowBox[{"K", ">", "0"}], "&&", 
        RowBox[{"Y", ">", "0"}], "&&", 
        RowBox[{"0", "<", "c", "<", 
         RowBox[{"K", "+", "1"}]}]}]}]}], "]"}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{
      RowBox[{"K", ">", "0"}], "&&", 
      RowBox[{"Y", ">", "0"}], "&&", 
      RowBox[{"g", ">", "0"}], "&&", 
      RowBox[{"0", "<", "c", "<", 
       RowBox[{"K", "+", "1"}]}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.819947134350935*^9, 3.8199471461647577`*^9}, {
  3.819947321687564*^9, 3.819947354599063*^9}, {3.819947386875215*^9, 
  3.819947397024193*^9}, {3.820733194796626*^9, 3.820733197295703*^9}, {
  3.82081221694018*^9, 3.8208122333943*^9}, {3.8208123007483883`*^9, 
  3.8208123362061987`*^9}},
 CellLabel->"In[93]:=",ExpressionUUID->"4a0e42d9-1d37-481a-b6d2-babac2958a99"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"c", "-", "Y"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"Gamma", "[", 
      RowBox[{"1", "+", "K"}], "]"}], "2"]}]], 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "2"}], " ", "\[Tau]c"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "c", " ", 
      SuperscriptBox["\[ExponentialE]", "Y"], " ", "K", " ", 
      SuperscriptBox["Y", "K"], " ", 
      RowBox[{"Gamma", "[", 
       RowBox[{"K", ",", "Y"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", "Y"}]], " ", 
      SuperscriptBox["K", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "c"}], "+", "Y"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"Gamma", "[", 
        RowBox[{"K", ",", "Y"}], "]"}], "2"]}], "+", 
     RowBox[{
      RowBox[{"Gamma", "[", 
       RowBox[{"1", "+", "K"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "c", " ", 
         SuperscriptBox["\[ExponentialE]", "Y"], " ", 
         SuperscriptBox["Y", "K"]}], "-", 
        RowBox[{
         SuperscriptBox["c", "K"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           SuperscriptBox["Y", "2"], "c"]], " ", 
         RowBox[{"(", 
          RowBox[{"c", "+", "Y"}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", "Y"}]], " ", "K", " ", 
         RowBox[{"(", 
          RowBox[{"c", "-", "Y"}], ")"}], " ", 
         RowBox[{"Gamma", "[", 
          RowBox[{"K", ",", "Y"}], "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["c", "K"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        SuperscriptBox["Y", "2"], "c"]], " ", "K", " ", 
      RowBox[{"(", 
       RowBox[{"c", "+", "Y"}], ")"}], " ", 
      RowBox[{"Gamma", "[", 
       RowBox[{"K", ",", 
        FractionBox[
         SuperscriptBox["Y", "2"], "c"]}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.82073321978399*^9, {3.820812297421994*^9, 3.820812347995633*^9}},
 CellLabel->"Out[93]=",ExpressionUUID->"6eaad146-dda8-4782-a504-c2b54fbab827"]
}, Open  ]],

Cell[TextData[{
 "then subtract ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"E", "[", "T", "]"}], "2"], TraditionalForm]],ExpressionUUID->
  "93aa706b-2c3e-44ac-b27c-35e3451eeceb"]
}], "Text",
 CellChangeTimes->{{3.820733261668415*^9, 3.8207332659357233`*^9}, 
   3.820733825981485*^9},ExpressionUUID->"d915a68d-ba9a-4143-a208-\
a45cf585d4ac"],

Cell[BoxData[
 RowBox[{
  RowBox[{"varGBK", "[", 
   RowBox[{"K_", ",", "c_", ",", "Y_", ",", "\[Tau]_", ",", "\[Tau]c_"}], 
   "]"}], ":=", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"c", "-", "Y"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"Gamma", "[", 
        RowBox[{"1", "+", "K"}], "]"}], "2"]}]], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "2"}], " ", "\[Tau]c"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "c", " ", 
       SuperscriptBox["\[ExponentialE]", "Y"], " ", "K", " ", 
       SuperscriptBox["Y", "K"], " ", 
       RowBox[{"Gamma", "[", 
        RowBox[{"K", ",", "Y"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", "Y"}]], " ", 
       SuperscriptBox["K", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "c"}], "+", "Y"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"Gamma", "[", 
         RowBox[{"K", ",", "Y"}], "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"Gamma", "[", 
        RowBox[{"1", "+", "K"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "c", " ", 
          SuperscriptBox["\[ExponentialE]", "Y"], " ", 
          SuperscriptBox["Y", "K"]}], "-", 
         RowBox[{
          SuperscriptBox["c", "K"], " ", 
          SuperscriptBox["\[ExponentialE]", 
           FractionBox[
            SuperscriptBox["Y", "2"], "c"]], " ", 
          RowBox[{"(", 
           RowBox[{"c", "+", "Y"}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", "Y"}]], " ", "K", " ", 
          RowBox[{"(", 
           RowBox[{"c", "-", "Y"}], ")"}], " ", 
          RowBox[{"Gamma", "[", 
           RowBox[{"K", ",", "Y"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["c", "K"], " ", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         SuperscriptBox["Y", "2"], "c"]], " ", "K", " ", 
       RowBox[{"(", 
        RowBox[{"c", "+", "Y"}], ")"}], " ", 
       RowBox[{"Gamma", "[", 
        RowBox[{"K", ",", 
         FractionBox[
          SuperscriptBox["Y", "2"], "c"]}], "]"}]}]}], ")"}]}], "-", 
   SuperscriptBox[
    RowBox[{"Exp", "[", 
     RowBox[{"-", "\[Tau]"}], "]"}], "2"]}]}]], "Input",
 CellChangeTimes->{{3.819947472747068*^9, 3.819947490383367*^9}, {
   3.81994756898695*^9, 3.819947570791462*^9}, {3.8199477154317017`*^9, 
   3.819947734375885*^9}, 3.820733230859291*^9, {3.820733274794158*^9, 
   3.8207333080825768`*^9}, 3.820733357139925*^9, {3.8207337539268847`*^9, 
   3.8207337566660843`*^9}, {3.820812353963457*^9, 3.820812359471064*^9}},
 CellLabel->"In[47]:=",ExpressionUUID->"f18866d0-e09e-4e54-a92a-d1a55f2b1b0f"],

Cell["But the expectation of Y (a constant) is \[Tau]c - \[Tau]:", "Text",
 CellChangeTimes->{{3.820733360837015*^9, 3.8207333771267653`*^9}, {
  3.820733852716549*^9, 
  3.820733854039575*^9}},ExpressionUUID->"b8cd4337-9f7b-4473-9073-\
7f04468e80bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"varGBK", "[", 
   RowBox[{"K_", ",", "c_", ",", "\[Tau]_", ",", "\[Tau]c_"}], "]"}], ":=", 
  RowBox[{"varGBK", "[", 
   RowBox[{"K", ",", "c", ",", 
    RowBox[{"\[Tau]c", "-", "\[Tau]"}], ",", "\[Tau]", ",", "\[Tau]c"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.820733383506864*^9, 3.820733448816473*^9}, {
  3.820733655121628*^9, 3.820733657112855*^9}, {3.820733856055811*^9, 
  3.820733859793302*^9}, {3.820812365227192*^9, 3.820812366973757*^9}},
 CellLabel->"In[57]:=",ExpressionUUID->"a9a612e0-2865-457d-ad61-a5bce4c74b6c"],

Cell["\<\
Monte Carlo validation of roulette variance formula for generalized BK:\
\>", "Text",
 CellChangeTimes->{{3.8207339622360363`*^9, 
  3.820733973702055*^9}},ExpressionUUID->"72c29d71-3bba-4db8-a3fc-\
2fd9672f8f4f"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"x", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "=", 
   RowBox[{"x", "&"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c", "=", "2"}], ";", 
  RowBox[{"K", "=", 
   RowBox[{"Floor", "[", "c", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MCn", "=", "1000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maxplot", "=", 
   RowBox[{"7", "x"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ppointsdx", "=", 
   RowBox[{"2", 
    RowBox[{"x", "/", "40"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pts1000", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p", ",", 
       RowBox[{"Variance", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"TBK", "[", 
            RowBox[{"f", ",", "p", ",", "d", ",", "K", ",", "c"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Range", "[", "MCn", "]"}]}], "}"}]}], "]"}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"p", ",", "0", ",", "maxplot", ",", "0.1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ListLogPlot", "[", "\[IndentingNewLine]", 
    RowBox[{"pts1000", ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}]}], "\[IndentingNewLine]", "]"}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"LogPlot", "[", 
    RowBox[{
     RowBox[{"varGBK", "[", 
      RowBox[{"K", ",", "c", ",", 
       RowBox[{"x", " ", "d"}], ",", 
       RowBox[{"d", " ", "p"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"p", ",", "0", ",", "maxplot"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Dashed", ",", "Red"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<variance\>\"", ","}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<pivot: p\>\"", ",", "\"\<U-BK c = 2\>\""}], "}"}]}], 
     "}"}]}]}], "\[IndentingNewLine]", "]"}]}], "Input",
 CellChangeTimes->{{3.820733558871067*^9, 3.820733621036845*^9}, {
   3.8207338880034237`*^9, 3.820733908828536*^9}, {3.820733951207693*^9, 
   3.820734023571875*^9}, {3.820812376263912*^9, 3.820812414039604*^9}, {
   3.82122751525933*^9, 3.82122755469595*^9}, 3.821227594419693*^9, {
   3.8212276727601357`*^9, 3.8212277154954042`*^9}, {3.828554089453553*^9, 
   3.8285541513594837`*^9}, {3.828554195778463*^9, 3.828554310154036*^9}, {
   3.828554432380232*^9, 3.8285544663842297`*^9}},
 CellLabel->
  "In[130]:=",ExpressionUUID->"2c80dc98-2268-41b8-97ed-6e91de3a0267"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6], 
      LineBox[{{0., -4.510777453889276}, {0.1, -5.377865489839612}, {
       0.2, -6.283103557520425}, {0.30000000000000004`, -7.256660153561429}, {
       0.4, -8.362778184680968}, {0.5, -9.625934889465418}, {
       0.6000000000000001, -11.126387257079164`}, {
       0.7000000000000001, -13.026039174538036`}, {
       0.8, -15.612511502362869`}, {0.9, -19.9599362638903}}], 
      LineBox[CompressedData["
1:eJwtz2tIk1EYB/DXNXPq5q7OXbwtvJKgtAUOV+dJsyKJwEtJijrzEpSkH0JX
kGYSI6kMETKNRZqFecliQgptpQiSomWRNa9dzRm55laauZrv84fD+XLO7/k/
ivzTqYUMiqI0/4/7vtnojo3URM2qIzUqs0rpjp3YDaQ0JCHOPDrizgrRhi96
RY5vNxcXueMktlJ9XGxblJnazG+iSh7j/9gZYaa9VXK043aUdF8Yen+IIdum
HTJuQ2+dtAy29z7JUaC3QSbG9zjkylD0KGhzjasdu4LxPQXG59faO88Gou8B
jtHuurTXMvzPgI7rvzgdqVKctwVygtqyFZ0B6DFhrmxJm1EpRo8JiQ7DwM94
f/Q8IbpHkVkeL0JvKxwvm88r1AjR84LhtVctIUIBeiw4Yru64Cfjo8cCXb43
dyGWh543xB3beiDTwkHPBwooiZJVwkbPFya6VpspHhs9NtQe6piQyn3QY0N7
8JlRhcEbPQ7UJRS2vjF4oecHc6cGKlvyvNDjQlFCj1Pf6YEeD+xVqkud35n4
ngeetfcaOKkM9HmQxZpM0inXTZvflXzQDzI8XY8pnMeHhfCH9Rd2bJhoTwAp
g2XT8XtdJtoTQF1P//RlltNEewIYe6TTW14sm+g+Qkiv1tbnGp+ZaE8IH85/
q5rqvUtoTwShVZbDb08soyeCyhG9TqO2oicC9sWSxjtaK3r+0KQud+QaJ9Dz
hxVzkzrs5CfsJwaeNb2hy2EjtCeG+73F3a2BdkJ7YqiOGq5Za3YS2gsASPvs
/bHvBqG9AIjYbS+oaJhHTwJFjJlJX2sf9pPALdsVTvrUA+wnAeZSYowh2Y6e
FIRf9p8bYvSjJ4WgjHfzaUk23FcGoYvJf6llC/aTQdZTTdfXNSv2kwFTEC4O
4dpxXzmUKw9Oumbt6MnhJbc4V5oyg14gKJYKYiqi35N/aumflQ==
       
       "]]}}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
       Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxFlmk4FAz7xZE9S0l4ymMZNFkbjH25x06pRFIqTaWxV6Io8hSFSElMT0Sv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        "]], LineBox[CompressedData["

1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAASZIkSZIECECqspOmYiYRwABZRh76
IwlAe0S5qY7HD8D4bT06u1QKQPZLbWdmQQ3AwTkT/kRxC0B87BVROQILwEVd
1lM4iAxAOAIu4eziCMBZGqQP17YNQCigkwripgbAPo5Qcz7RDkBnoQTqipwE
wNnNg56oARBAhlzia/xtAsBxAFbM5pcQQIDdPS+bTADAco4XTgkkEUDzGm1m
QZ38vzpp3oIBvBFA4R8vhRVA+L9rn5QL3kkSQJcF7Z5xG/S/eYFBXe/UEkBy
NNq7oOjvv0+w82HWaxNAf+nMIHGi5r+NOpW6ofgTQNDiP65OXtu/kxE8xkKR
FEAtJcQUL8+8vwJE0iXIHxVAdreJdpzhyD9OIl9OgqsVQDjcR9ncReA/Yk3x
KRJDFkDMl5FU3LHrP97TclmG0BZACa0SC1Rw8z8ip/k70GkXQLnpoM/4zPk/
QyZ3504AGECQiI2aGS8AQM0A5OaxjBhAaM8tjWRlA0AfKFaZ6iQZQKFbFk/K
CwdA2aq3nwezGUCpZNksI50KQHHZD29ZPhpAlVpq+IFDDkDQVG3xgNUaQMGa
jZmnMhFAmCu6x4xiG0AxBpoY/DQTQNjpdJQCZRtAY0zLZyI+E0AYqC9heGcb
QGqfokhKRxNAmSSl+mNsG0CetlC/nlkTQJodkC07dhtAgpcEgVp+E0CbD2aT
6YkbQNvTbFgdyBNAnvMRX0axG0CVm4xp0FwUQN6xzCu8sxtAznHt8ihmFEAe
cIf4MbYbQFEMRQ6DbxRAn+z8kR27G0BaXN/6O4IUQKDl58T0xBtAmILtq8Cn
FECh170qo9gbQNGPs24V8xRA4pV49xjbG0DePTUYh/wUQCJUM8SO3RtA4svD
U/oFFUCi0KhdeuIbQA2SC4HlGBVAosmTkFHsG0AUyV+0zj4VQOKHTl3H7htA
XMNi7kxIFUAiRgkqPfEbQGKmebrMURVAo8J+wyj2G0Az6+UI0WQVQOSAOZCe
+BtAnpY8i1VuFUAkP/RcFPsbQDC+qZ/bdxVAZP2uKYr9G0Bn7i1GY4EVQKS7
afb//xtAM6rJfuyKFUCrZWRq
        "]]},
      Annotation[#, "Charting`Private`Tag$965499#1"]& ], {}}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, -21.929075746183887`},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox["\"variance\"", TraditionalForm], ""}, {
     FormBox["\"pivot: p\"", TraditionalForm], 
     FormBox["\"U-BK c = 2\"", TraditionalForm]}},
  FrameTicks->FrontEndValueCache[{{
      Charting`ScaledTicks[{Log, Exp}], 
      Charting`ScaledFrameTicks[{Identity, Identity}]}, {
     Automatic, Automatic}}, {{{{-36.841361487904734`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "16"}]}, "Superscript", SyntaxForm -> SuperscriptBox],
          TraditionalForm], {0.01, 0.}}, {-25.328436022934504`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "11"}]}, "Superscript", SyntaxForm -> SuperscriptBox],
          TraditionalForm], {0.01, 0.}}, {-13.815510557964274`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm], {0.01, 0.}}, {-2.3025850929940455`, 
        FormBox[
         TagBox[
          InterpretationBox[
           StyleBox["\"0.1\"", ShowStringCharacters -> False], 0.1, 
           AutoDelete -> True], NumberForm[#, {
            DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}}, {
       9.210340371976184, 
        FormBox[
         TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
          SuperscriptBox], TraditionalForm], {0.01, 
        0.}}, {-34.538776394910684`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-32.23619130191664, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-29.933606208922594`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-27.631021115928547`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-23.025850929940457`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-20.72326583694641, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-18.420680743952367`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-16.11809565095832, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-11.512925464970229`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-9.210340371976182, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-6.907755278982137, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-4.605170185988091, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.302585092994046, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.605170185988092, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       6.907755278982137, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}}, {{-30., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
        0.}}, {-20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
        0.}}, {-10., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}}, {0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
        0.}}, {-40., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-38., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-36., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-34., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-32., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-28., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-26., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-24., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-22., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-18., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-16., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-14., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-12., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-8., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-6., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       6., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       8., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       10., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}}}, {
     Automatic, Automatic}}],
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Exp[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Exp[
         Part[#, 2]]}& )}},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-36.841361487904734`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "16"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}}, {-25.328436022934504`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "11"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}}, {-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}}, {-2.3025850929940455`, 
       FormBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"0.1\"", ShowStringCharacters -> False], 0.1, AutoDelete -> 
          True], NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}}, {
      9.210340371976184, 
       FormBox[
        TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm], {0.01, 0.}}, {-34.538776394910684`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-32.23619130191664, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-29.933606208922594`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-27.631021115928547`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-23.025850929940457`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-20.72326583694641, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-18.420680743952367`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-16.11809565095832, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-6.907755278982137, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.605170185988091, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {0., 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.302585092994046, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      4.605170185988092, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      6.907755278982137, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}}}]]], "Output",
 CellChangeTimes->{{3.820733562581377*^9, 3.8207335811736917`*^9}, 
   3.8207336220257063`*^9, {3.820733875354533*^9, 3.8207339094178753`*^9}, {
   3.820733951896296*^9, 3.820734024161194*^9}, 3.820811459803516*^9, {
   3.820812370178841*^9, 3.820812414580896*^9}, 3.821227503647106*^9, {
   3.821227536606059*^9, 3.82122756831362*^9}, 3.8212276024499893`*^9, {
   3.821227679727687*^9, 3.8212277083487053`*^9}, 3.821227882542465*^9, {
   3.8285542092219877`*^9, 3.828554314376223*^9}, {3.82855443634534*^9, 
   3.828554468949582*^9}},
 CellLabel->
  "Out[138]=",ExpressionUUID->"5f6d5780-bfca-417c-bea1-5860f80f582a"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Derivation: variance of BK at optimal pivot ", "Section",
 CellChangeTimes->{{3.820814338506942*^9, 3.820814362413395*^9}, {
  3.828162725372163*^9, 3.828162727714245*^9}, {3.828506384056508*^9, 
  3.8285063855124617`*^9}},ExpressionUUID->"98f96aab-f24a-4d2e-812a-\
11831d89e96d"],

Cell[TextData[{
 "Here we consider the BK and U-BK estimators with optimal pivot p = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", 
    SubscriptBox["\[Tau]", "c"]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "8592892f-b34c-4128-a541-c84b71bd91dd"],
 ", where truncation is fixed to deterministic order N.  Despite the \
truncation, the estimators still have the correct expectation, because the \
pivot is optimal (therefore the expectation of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["Y", "k"], " ", "is", " ", "0"}], ")"}], "."}], 
   TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "c6adaf6f-76a5-4384-b578-cc96727ab161"],
 "\nT",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
    "his", " ", "comparison", " ", "clearly", " ", "and", " ", 
     "quantitatively", " ", "shows", " ", "the", " ", "benefit", " ", "of", 
     " ", "using", " ", "U"}], "-", 
    RowBox[{"statistics", "."}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "4d41218f-017d-4df6-899f-a0d6d6a9e80c"],
 "  We will show that the two estimators BK and U-BK have variances:"
}], "Text",
 CellChangeTimes->{{3.828506391691951*^9, 3.8285064802641582`*^9}, {
  3.828506542239861*^9, 3.828506553806696*^9}, {3.828562425639968*^9, 
  3.828562503020816*^9}},ExpressionUUID->"045b95ed-c7f2-4cc6-bcec-\
8f8ed96f9ab8"],

Cell[BoxData[
 RowBox[{
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJztnQm8bWP9h68hSRIqUZShVJqEyph70+AmmUml7jVdV4bM8ywUJbMi15Am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     "], {{0, 112.}, {169., 0}}, {0, 255},
     ColorFunction->RGBColor,
     ImageResolution->144],
    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
    Selectable->False],
   DefaultBaseStyle->"ImageGraphics",
   ImageSize->{133.35546875, Automatic},
   ImageSizeRaw->{169., 112.},
   PlotRange->{{0, 169.}, {0, 112.}}], 
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJzt3QecbVV1x3GNxmia3QBCRKQEpYhUgSi9SBUQaQHpSHkUKSK9dyVKka4Q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     "], {{0, 121.}, {222., 0}}, {0, 255},
     ColorFunction->RGBColor,
     ImageResolution->144],
    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
    Selectable->False],
   DefaultBaseStyle->"ImageGraphics",
   ImageSize->{163.71875, Automatic},
   ImageSizeRaw->{222., 121.},
   PlotRange->{{0, 222.}, {0, 121.}}]}]], "Input",
 CellChangeTimes->{{3.8285626505538054`*^9, 
  3.828562665143022*^9}},ExpressionUUID->"988a2fdb-05a8-485d-a2ae-\
eb7aa753214a"],

Cell["and", "Text",
 CellChangeTimes->{{3.8285065670990753`*^9, 
  3.828506567298485*^9}},ExpressionUUID->"edca093d-6afc-490b-b169-\
210425108d7b"],

Cell[BoxData[
 RowBox[{
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJztnQe0XEUZgENRUVGxYwfsDRFQo6AQsEVREUTEShCIQQkKEUSkI2BHxIoS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     
     "], {{0, 125.}, {194., 0}}, {0, 255},
     ColorFunction->RGBColor,
     ImageResolution->144],
    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
    Selectable->False],
   DefaultBaseStyle->"ImageGraphics",
   ImageSize->{128.375, Automatic},
   ImageSizeRaw->{194., 125.},
   PlotRange->{{0, 194.}, {0, 125.}}], 
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJzt3QeYbVV5/3ETEyXF2AkIiAUhqKAiRKpSLBQpEpCOdBClyUVAubRLERBR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     "], {{0, 123.}, {254., 0}}, {0, 255},
     ColorFunction->RGBColor,
     ImageResolution->144],
    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
    Selectable->False],
   DefaultBaseStyle->"ImageGraphics",
   ImageSize->{178.203125, Automatic},
   ImageSizeRaw->{254., 123.},
   PlotRange->{{0, 254.}, {0, 123.}}]}]], "Input",
 CellChangeTimes->{{3.8285626836210957`*^9, 
  3.8285626996705723`*^9}},ExpressionUUID->"2065b404-73c5-41fc-9791-\
d0ba93167aa0"],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsnQe4HkX1h1ERVECaKFjoRCkKgmCjl9B77xJpCRCpUqSJQOg19F4D0qQT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    "], {{0, 203.}, {739., 0}}, {0, 255},
    
    ColorFunction->RGBColor,
    ImageResolution->144],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  DefaultBaseStyle->"ImageGraphics",
  ImageSize->{553.234375, Automatic},
  ImageSizeRaw->{739., 203.},
  PlotRange->{{0, 739.}, {0, 203.}}]], "Input",ExpressionUUID->"e7036c96-1447-\
471e-8ba3-653efa7924ae"],

Cell[CellGroupData[{

Cell["fixed-order truncated (biased) estimator:", "Subsection",
 CellChangeTimes->{{3.817149865503132*^9, 
  3.817149876249484*^9}},ExpressionUUID->"7c897bc2-5bcf-44a8-8b88-\
4e61501e75a5"],

Cell["pivot p", "Text",
 CellChangeTimes->{{3.817268604083415*^9, 
  3.8172686048524427`*^9}},ExpressionUUID->"f44ce09a-e827-4c0e-9dfb-\
073d39c0e21e"],

Cell[TextData[{
 "Let V = ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", "d"], TraditionalForm]],ExpressionUUID->
  "e69d5940-261d-4c1b-9c78-5f6747302aba"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     SubscriptBox["\[Integral]", "0"], "d"], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"d", "(", 
        RowBox[{"p", "-", 
         RowBox[{"f", "[", "x", "]"}]}], ")"}], ")"}], "2"], "dx"}]}], 
   TraditionalForm]],ExpressionUUID->"144db982-a69f-40db-a3c7-3f95a70de99f"],
 "\[LineSeparator]Compute the expectation Z = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"E", "[", 
     SuperscriptBox["T", "2"], "]"}], " ", "/", " ", 
    SuperscriptBox["T", "2"]}], TraditionalForm]],ExpressionUUID->
  "51c51b49-fc8c-4b67-bfdf-b42224ff0a27"],
 ": look at the pattern for various orders:"
}], "Text",
 CellChangeTimes->{{3.816474948903453*^9, 3.816475055425926*^9}, {
  3.817268282727162*^9, 3.8172682841057873`*^9}, {3.817268601041705*^9, 
  3.817268601042001*^9}, {3.8172689623387623`*^9, 3.817268964175672*^9}, {
  3.817269804079101*^9, 3.8172698062766943`*^9}, {3.817450424879829*^9, 
  3.817450424880047*^9}, {3.82081443681569*^9, 3.8208144598760033`*^9}, {
  3.820814509358285*^9, 3.8208145150063066`*^9}, {3.828562894627469*^9, 
  3.8285629204466963`*^9}},ExpressionUUID->"4c46bc99-4342-4d91-9ce8-\
9a884524d651"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"K", ",", "p", ",", "d", ",", "X", ",", "X2", ",", "V"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"K", ",", "\[IndentingNewLine]", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Expand", "[", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"(", 
                 RowBox[{"Sum", "[", 
                  RowBox[{
                   FractionBox[
                    RowBox[{"Product", "[", 
                    RowBox[{
                    RowBox[{"d", 
                    RowBox[{"(", 
                    RowBox[{"p", "-", 
                    RowBox[{"X", "[", "i", "]"}]}], ")"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", 
                    RowBox[{"Range", "[", "n", "]"}]}], "}"}]}], "]"}], 
                    RowBox[{"n", "!"}]], ",", 
                   RowBox[{"{", 
                    RowBox[{"n", ",", "0", ",", "K"}], "}"}]}], "]"}], ")"}], 
                ")"}], "2"], "\[IndentingNewLine]", "]"}], "/.", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"X", "[", "_", "]"}], "2"], "\[Rule]", "X2"}]}], "/.", 
            
            RowBox[{
             RowBox[{"X", "[", "_", "]"}], "\[Rule]", "X"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"p", ",", "0"}], "}"}]}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"K", ",", 
         RowBox[{"Range", "[", "8", "]"}]}], "}"}]}], "\[IndentingNewLine]", 
      "]"}], "/.", 
     RowBox[{"X2", "\[Rule]", 
      FractionBox[
       RowBox[{"V", "-", 
        RowBox[{
         SuperscriptBox["d", "2"], " ", 
         SuperscriptBox["p", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["d", "2"], " ", "p", " ", "X"}]}], 
       SuperscriptBox["d", "2"]]}]}], "/.", 
    RowBox[{"p", "\[Rule]", "X"}]}], "//", "Expand"}], "//", 
  "TableForm"}]}], "Input",
 CellChangeTimes->{
  3.817273385211125*^9, {3.817273430767249*^9, 3.817273468855318*^9}, {
   3.8172735109349623`*^9, 3.817273656335657*^9}, {3.817273723823934*^9, 
   3.817273732113783*^9}, {3.8173093662612267`*^9, 3.817309381175981*^9}, {
   3.828562810960327*^9, 3.828562819558774*^9}},
 CellLabel->
  "In[775]:=",ExpressionUUID->"d26a36bf-128c-4b48-8bac-fcd9a4ef64fd"],

Cell[BoxData[
 TagBox[GridBox[{
    {"1", 
     RowBox[{"1", "+", "V"}]},
    {"2", 
     RowBox[{"1", "+", "V", "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "4"]}]},
    {"3", 
     RowBox[{"1", "+", "V", "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "4"], "+", 
      FractionBox[
       SuperscriptBox["V", "3"], "36"]}]},
    {"4", 
     RowBox[{"1", "+", "V", "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "4"], "+", 
      FractionBox[
       SuperscriptBox["V", "3"], "36"], "+", 
      FractionBox[
       SuperscriptBox["V", "4"], "576"]}]},
    {"5", 
     RowBox[{"1", "+", "V", "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "4"], "+", 
      FractionBox[
       SuperscriptBox["V", "3"], "36"], "+", 
      FractionBox[
       SuperscriptBox["V", "4"], "576"], "+", 
      FractionBox[
       SuperscriptBox["V", "5"], "14400"]}]},
    {"6", 
     RowBox[{"1", "+", "V", "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "4"], "+", 
      FractionBox[
       SuperscriptBox["V", "3"], "36"], "+", 
      FractionBox[
       SuperscriptBox["V", "4"], "576"], "+", 
      FractionBox[
       SuperscriptBox["V", "5"], "14400"], "+", 
      FractionBox[
       SuperscriptBox["V", "6"], "518400"]}]},
    {"7", 
     RowBox[{"1", "+", "V", "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "4"], "+", 
      FractionBox[
       SuperscriptBox["V", "3"], "36"], "+", 
      FractionBox[
       SuperscriptBox["V", "4"], "576"], "+", 
      FractionBox[
       SuperscriptBox["V", "5"], "14400"], "+", 
      FractionBox[
       SuperscriptBox["V", "6"], "518400"], "+", 
      FractionBox[
       SuperscriptBox["V", "7"], "25401600"]}]},
    {"8", 
     RowBox[{"1", "+", "V", "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "4"], "+", 
      FractionBox[
       SuperscriptBox["V", "3"], "36"], "+", 
      FractionBox[
       SuperscriptBox["V", "4"], "576"], "+", 
      FractionBox[
       SuperscriptBox["V", "5"], "14400"], "+", 
      FractionBox[
       SuperscriptBox["V", "6"], "518400"], "+", 
      FractionBox[
       SuperscriptBox["V", "7"], "25401600"], "+", 
      FractionBox[
       SuperscriptBox["V", "8"], "1625702400"]}]}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.817273605134099*^9, 3.817273657455496*^9}, {
   3.8172737251102037`*^9, 3.8172737335350733`*^9}, {3.817309378175845*^9, 
   3.817309382375227*^9}, 3.828562820619445*^9},
 CellLabel->
  "Out[776]//TableForm=",ExpressionUUID->"feeb1988-d4cc-48a5-abbb-\
ba255ba91cf7"]
}, Open  ]],

Cell["Note that this is generated simply by:", "Text",
 CellChangeTimes->{{3.820814463999134*^9, 
  3.820814467702529*^9}},ExpressionUUID->"ddf6af73-9be2-4a36-8118-\
30b3698171ad"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      FractionBox[
       SuperscriptBox["V", "k"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"k", "!"}], ")"}], "2"]], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "0", ",", "i"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Range", "[", "6", "]"}]}], "}"}]}], "]"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.816472433807004*^9, 3.816472484785096*^9}, {
   3.816472519013836*^9, 3.816472532410986*^9}, {3.816472633290134*^9, 
   3.8164726562845488`*^9}, {3.816475219155549*^9, 3.8164752223710423`*^9}, 
   3.8172682889542713`*^9},
 CellLabel->
  "In[7838]:=",ExpressionUUID->"dfb42619-c71f-4390-b97a-1d21b0fd5d94"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      RowBox[{"1", "+", "V"}]},
     {
      RowBox[{"1", "+", "V", "+", 
       FractionBox[
        SuperscriptBox["V", "2"], "4"]}]},
     {
      RowBox[{"1", "+", "V", "+", 
       FractionBox[
        SuperscriptBox["V", "2"], "4"], "+", 
       FractionBox[
        SuperscriptBox["V", "3"], "36"]}]},
     {
      RowBox[{"1", "+", "V", "+", 
       FractionBox[
        SuperscriptBox["V", "2"], "4"], "+", 
       FractionBox[
        SuperscriptBox["V", "3"], "36"], "+", 
       FractionBox[
        SuperscriptBox["V", "4"], "576"]}]},
     {
      RowBox[{"1", "+", "V", "+", 
       FractionBox[
        SuperscriptBox["V", "2"], "4"], "+", 
       FractionBox[
        SuperscriptBox["V", "3"], "36"], "+", 
       FractionBox[
        SuperscriptBox["V", "4"], "576"], "+", 
       FractionBox[
        SuperscriptBox["V", "5"], "14400"]}]},
     {
      RowBox[{"1", "+", "V", "+", 
       FractionBox[
        SuperscriptBox["V", "2"], "4"], "+", 
       FractionBox[
        SuperscriptBox["V", "3"], "36"], "+", 
       FractionBox[
        SuperscriptBox["V", "4"], "576"], "+", 
       FractionBox[
        SuperscriptBox["V", "5"], "14400"], "+", 
       FractionBox[
        SuperscriptBox["V", "6"], "518400"]}]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.816472434306073*^9, 3.8164724850590878`*^9}, {
   3.816472521203164*^9, 3.816472532838519*^9}, {3.816472634050213*^9, 
   3.8164726571272697`*^9}, 3.816475223010419*^9, 3.8172682896358423`*^9},
 CellLabel->
  "Out[7838]//TableForm=",ExpressionUUID->"b00834ed-fa86-4c5b-b4fe-\
85d62069b7f2"]
}, Open  ]],

Cell["Which  generates the function", "Text",
 CellChangeTimes->{{3.816475057868379*^9, 
  3.8164750720017643`*^9}},ExpressionUUID->"613b0265-6b9d-4aaa-9873-\
2289c26abc90"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ZFixedBKOptPivot", "[", 
   RowBox[{"n_", ",", "V_"}], "]"}], ":=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"BesselI", "[", 
     RowBox[{"0", ",", 
      RowBox[{"2", " ", 
       SqrtBox["V"]}]}], "]"}], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["V", 
       RowBox[{"1", "+", "n"}]], " ", 
      RowBox[{"HypergeometricPFQ", "[", 
       RowBox[{
        RowBox[{"{", "1", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"2", "+", "n"}], ",", 
          RowBox[{"2", "+", "n"}]}], "}"}], ",", "V"}], "]"}]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "n"}], ")"}], "!"}], ")"}], "2"]]}], 
   ")"}]}]], "Input",
 CellChangeTimes->{{3.8164750747985764`*^9, 3.816475085156945*^9}, {
  3.817268302328458*^9, 3.817268308409273*^9}, {3.817269834590246*^9, 
  3.8172698596650457`*^9}},
 CellLabel->
  "In[784]:=",ExpressionUUID->"4bc23063-a2ca-4d51-8cbf-b2840bec1b3d"]
}, Open  ]],

Cell[CellGroupData[{

Cell["fixed order UBK estimator:", "Subsection",
 CellChangeTimes->{{3.820814667647264*^9, 
  3.820814674528844*^9}},ExpressionUUID->"e3fb112a-5889-44e6-9ef8-\
e82d93a6757a"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "K", ",", "p", ",", "X", ",", "V", ",", "d", ",", "X2", ",", "Y", ",", 
    "w"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"list", "=", "\[IndentingNewLine]", 
   RowBox[{"Table", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Expand", "[", "\[IndentingNewLine]", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"(", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{
               FractionBox["1", 
                RowBox[{"n", "!"}]], 
               RowBox[{"Mean", "[", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"Product", "[", 
                   RowBox[{
                    RowBox[{"Y", "[", "i", "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", "s"}], "}"}]}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"s", ",", 
                    RowBox[{"Subsets", "[", 
                    RowBox[{
                    RowBox[{"Range", "[", "K", "]"}], ",", 
                    RowBox[{"{", "n", "}"}]}], "]"}]}], "}"}]}], "]"}], 
                "]"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"n", ",", "0", ",", "K"}], "}"}]}], "]"}], ")"}], 
           ")"}], "2"], "\[IndentingNewLine]", "]"}], "/.", 
        RowBox[{
         RowBox[{"Mean", "[", 
          RowBox[{"{", "}"}], "]"}], "\[Rule]", "1"}]}], "/.", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Y", "[", "_", "]"}], "2"], "\[Rule]", "V"}]}], "/.", 
      RowBox[{
       RowBox[{"Y", "[", "_", "]"}], "\[Rule]", "0"}]}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"K", ",", 
       RowBox[{"Range", "[", "6", "]"}]}], "}"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"list", "//", "Expand"}], "//", "TableForm"}]}], "Input",
 CellChangeTimes->{{3.820814686564238*^9, 3.820814721719006*^9}, {
  3.8285629470276203`*^9, 3.828562958983808*^9}},
 CellLabel->
  "In[780]:=",ExpressionUUID->"e338d327-3e3b-4f22-932a-e4bc47db9506"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      RowBox[{"1", "+", "V"}]},
     {
      RowBox[{"1", "+", 
       FractionBox["V", "2"], "+", 
       FractionBox[
        SuperscriptBox["V", "2"], "4"]}]},
     {
      RowBox[{"1", "+", 
       FractionBox["V", "3"], "+", 
       FractionBox[
        SuperscriptBox["V", "2"], "12"], "+", 
       FractionBox[
        SuperscriptBox["V", "3"], "36"]}]},
     {
      RowBox[{"1", "+", 
       FractionBox["V", "4"], "+", 
       FractionBox[
        SuperscriptBox["V", "2"], "24"], "+", 
       FractionBox[
        SuperscriptBox["V", "3"], "144"], "+", 
       FractionBox[
        SuperscriptBox["V", "4"], "576"]}]},
     {
      RowBox[{"1", "+", 
       FractionBox["V", "5"], "+", 
       FractionBox[
        SuperscriptBox["V", "2"], "40"], "+", 
       FractionBox[
        SuperscriptBox["V", "3"], "360"], "+", 
       FractionBox[
        SuperscriptBox["V", "4"], "2880"], "+", 
       FractionBox[
        SuperscriptBox["V", "5"], "14400"]}]},
     {
      RowBox[{"1", "+", 
       FractionBox["V", "6"], "+", 
       FractionBox[
        SuperscriptBox["V", "2"], "60"], "+", 
       FractionBox[
        SuperscriptBox["V", "3"], "720"], "+", 
       FractionBox[
        SuperscriptBox["V", "4"], "8640"], "+", 
       FractionBox[
        SuperscriptBox["V", "5"], "86400"], "+", 
       FractionBox[
        SuperscriptBox["V", "6"], "518400"]}]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.820814683653573*^9, 3.820814721839674*^9}, {
  3.828562953402183*^9, 3.828562959618915*^9}},
 CellLabel->
  "Out[782]//TableForm=",ExpressionUUID->"ae8d7ab7-de08-4cd7-ace9-\
73b46c220f79"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Sum", "[", 
      RowBox[{
       FractionBox[
        SuperscriptBox["V", "k"], 
        RowBox[{
         RowBox[{"Binomial", "[", 
          RowBox[{"i", ",", "k"}], "]"}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"k", "!"}], ")"}], "2"]}]], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "i"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Range", "[", "6", "]"}]}], "}"}]}], "]"}], "//", "Expand"}], "//",
   "TableForm"}]], "Input",
 CellChangeTimes->{{3.816472570071064*^9, 3.816472658830449*^9}, {
   3.8164727412028093`*^9, 3.816472756031238*^9}, {3.816472809681447*^9, 
   3.816472840644063*^9}, 3.81726829435919*^9},
 CellLabel->
  "In[783]:=",ExpressionUUID->"6bb61bc3-107d-46b5-897f-5cb3537d204c"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      RowBox[{"1", "+", "V"}]},
     {
      RowBox[{"1", "+", 
       FractionBox["V", "2"], "+", 
       FractionBox[
        SuperscriptBox["V", "2"], "4"]}]},
     {
      RowBox[{"1", "+", 
       FractionBox["V", "3"], "+", 
       FractionBox[
        SuperscriptBox["V", "2"], "12"], "+", 
       FractionBox[
        SuperscriptBox["V", "3"], "36"]}]},
     {
      RowBox[{"1", "+", 
       FractionBox["V", "4"], "+", 
       FractionBox[
        SuperscriptBox["V", "2"], "24"], "+", 
       FractionBox[
        SuperscriptBox["V", "3"], "144"], "+", 
       FractionBox[
        SuperscriptBox["V", "4"], "576"]}]},
     {
      RowBox[{"1", "+", 
       FractionBox["V", "5"], "+", 
       FractionBox[
        SuperscriptBox["V", "2"], "40"], "+", 
       FractionBox[
        SuperscriptBox["V", "3"], "360"], "+", 
       FractionBox[
        SuperscriptBox["V", "4"], "2880"], "+", 
       FractionBox[
        SuperscriptBox["V", "5"], "14400"]}]},
     {
      RowBox[{"1", "+", 
       FractionBox["V", "6"], "+", 
       FractionBox[
        SuperscriptBox["V", "2"], "60"], "+", 
       FractionBox[
        SuperscriptBox["V", "3"], "720"], "+", 
       FractionBox[
        SuperscriptBox["V", "4"], "8640"], "+", 
       FractionBox[
        SuperscriptBox["V", "5"], "86400"], "+", 
       FractionBox[
        SuperscriptBox["V", "6"], "518400"]}]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.816472605355565*^9, 3.816472659043818*^9}, {
   3.816472742534511*^9, 3.816472756535254*^9}, {3.816472818122892*^9, 
   3.81647284083678*^9}, 3.817268294724537*^9, 3.828562969911098*^9},
 CellLabel->
  "Out[783]//TableForm=",ExpressionUUID->"22b2b146-508f-40e6-97f8-\
bacdee49a5af"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ZFixedUBKOptPivot", "[", 
   RowBox[{"n_", ",", "V_"}], "]"}], ":=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    FractionBox[
     SuperscriptBox["V", "k"], 
     RowBox[{
      RowBox[{"Binomial", "[", 
       RowBox[{"n", ",", "k"}], "]"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "!"}], ")"}], "2"]}]], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "0", ",", "n"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.817269886620082*^9, 3.817269919386777*^9}, {
  3.828564183429509*^9, 3.828564186762635*^9}},
 CellLabel->
  "In[1177]:=",ExpressionUUID->"cea09984-f253-4ce5-9f33-034b2afe6f0b"],

Cell[CellGroupData[{

Cell["numerical validation", "Subsubsection",
 CellChangeTimes->{{3.8285629927175817`*^9, 
  3.828562995345747*^9}},ExpressionUUID->"fd83eaa1-0a00-4ce3-aacc-\
c5c72b5d1bab"],

Cell[BoxData[
 RowBox[{
  RowBox[{"varBKOptPivot", "[", 
   RowBox[{"X_", ",", "V_", ",", "K_", ",", "d_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", "2"}], "d", " ", "X"}], "]"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"ZFixedBKOptPivot", "[", 
        RowBox[{"K", ",", "V"}], "]"}], "-", "1"}], ")"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.828563030229937*^9, 3.8285630787914057`*^9}, {
  3.828563207821653*^9, 3.828563222795958*^9}, {3.828563881448462*^9, 
  3.828563887017363*^9}},
 CellLabel->
  "In[933]:=",ExpressionUUID->"aef53a7a-120c-46a6-912f-fac26a2ad48b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"varUBKOptPivot", "[", 
   RowBox[{"X_", ",", "V_", ",", "K_", ",", "d_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", "2"}], "d", " ", "X"}], "]"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"ZFixedUBKOptPivot", "[", 
        RowBox[{"K", ",", "V"}], "]"}], "-", "1"}], ")"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.82856306079246*^9, 3.828563092731368*^9}, {
  3.828564168570757*^9, 3.828564191077923*^9}},
 CellLabel->
  "In[1178]:=",ExpressionUUID->"0193f2e9-bdf9-4025-8d26-b50d5bd1c6f7"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"maxpos", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"td", "=", 
   RowBox[{
    RowBox[{"3", 
     RowBox[{"RandomFunction", "[", 
      RowBox[{
       RowBox[{"FractionalBrownianMotionProcess", "[", ".3", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "maxpos", ",", "0.01"}], "}"}]}], "]"}]}], "+", 
    "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"TimeSeriesMap", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Max", "[", 
       RowBox[{"0", ",", "#"}], "]"}], "&"}], ",", "td"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "f", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "=", 
   RowBox[{"Interpolation", "[", "data", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d", "=", "3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"X", "=", 
   RowBox[{
    RowBox[{"NIntegrate", "[", 
     RowBox[{
      RowBox[{"f", "[", "x", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "d"}], "}"}]}], "]"}], "/", "d"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"X2", "=", 
   RowBox[{
    RowBox[{"NIntegrate", "[", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"d", 
         RowBox[{"(", 
          RowBox[{"X", "-", 
           RowBox[{"f", "[", "x", "]"}]}], ")"}]}], ")"}], "2"], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "d"}], "}"}]}], "]"}], "/", "d"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MCn", "=", "10000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"K", ",", 
           RowBox[{"Variance", "[", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"TBK", "[", 
                RowBox[{"f", ",", "X", ",", "d", ",", "K", ",", "0"}], "]"}], 
               "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", 
                RowBox[{"Range", "[", "MCn", "]"}]}], "}"}]}], "]"}], "]"}]}],
           "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"K", ",", 
           RowBox[{"Range", "[", "7", "]"}]}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"K", ",", 
           RowBox[{"Variance", "[", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"TUBK", "[", 
                RowBox[{"f", ",", "X", ",", "d", ",", "K", ",", "0"}], "]"}], 
               "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", 
                RowBox[{"Range", "[", "MCn", "]"}]}], "}"}]}], "]"}], "]"}]}],
           "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"K", ",", 
           RowBox[{"Range", "[", "7", "]"}]}], "}"}]}], "]"}]}], 
      "\[IndentingNewLine]", "}"}], "\[IndentingNewLine]", ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"PointSize", "[", ".02", "]"}]}]}], "\[IndentingNewLine]", 
    "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"varBKOptPivot", "[", 
        RowBox[{"X", ",", "X2", ",", "K", ",", "d"}], "]"}], ",", 
       RowBox[{"varUBKOptPivot", "[", 
        RowBox[{"X", ",", "X2", ",", "K", ",", "d"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"K", ",", "1", ",", "7"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<variance\>\"", ","}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"K", ","}], "}"}]}], "}"}]}]}], "\[IndentingNewLine]", 
  "]"}]}], "Input",
 CellChangeTimes->{{3.828563168587049*^9, 3.828563193852775*^9}, {
  3.828563235083782*^9, 3.8285632627586308`*^9}, {3.82856340222742*^9, 
  3.828563521941131*^9}, {3.8285638962909203`*^9, 3.8285639036110573`*^9}, {
  3.828563950808549*^9, 3.828564047189887*^9}, {3.8285640836385307`*^9, 
  3.828564112952141*^9}, {3.8285642146234503`*^9, 3.828564225453836*^9}, {
  3.828564276269505*^9, 3.8285642939089127`*^9}, {3.828564369688287*^9, 
  3.828564370295224*^9}, {3.828564434963106*^9, 3.828564470368024*^9}, {
  3.828564501670973*^9, 3.82856452113624*^9}},
 CellLabel->
  "In[1266]:=",ExpressionUUID->"cd3c9db6-422c-4e36-8299-74ff38067d23"],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
      AbsoluteThickness[1.6], 
      PointBox[{{1., 0.045843770408499164`}, {2., 0.2678738220874553}, {3., 
       0.6917216089743748}, {4., 1.4214074669228396`}, {5., 
       1.5845006998976419`}, {6., 1.7226450666449047`}, {7., 
       1.9564089699679335`}}]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.02], 
      AbsoluteThickness[1.6], 
      PointBox[{{1., 0.04696172400626005}, {2., 0.2353536422650894}, {3., 
       0.508235090869129}, {4., 0.7036045901931685}, {5., 
       0.5777522152624495}, {6., 0.473646444639924}, {7., 
       0.15492798302922198`}}]}}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwt0Hk41AkYB/BxDhKGyTG/ZaWQ6JpN0ar3TVaiknWmrUlEuZraRJTGtJQc
hfXsg3axzkLuo9BFIleHtpSVxtmojIk0GL+d3e19nvd5n88/3+f7vEsPHfvx
sDSFQvGQ7L/3++x+fQpFADEuFu2J5QXwSvFRZSxVAC4VF16y2gsg7ES1rYaq
AHYwWdM2wwVQtS0+0EhPADDC5DroFMLqEcu6nVYCEJlLj9lzC0HfNNUxLUwA
JnnjfQyPayBb7RDJnBRArUPK+BaNIuhorXvtw5uEt2nT3MS2G1D8R2fDFf4k
uHQu8t8xfgPiT/J+bxBOAifW9ILe4lJw0Fc+SJcRQvfxsctaTqXwKJQ11LRM
CPmEPc32VSm0Gcl/MDgsBN36DVbdYWXQ8ovzwsCoEJQoxrk26eVwFz/q7//w
CeLYYlGXfBU8YXl4lTyfBv35TP1hk5sQeGBv6NGqGYhc78Ai5O6Af0m11s16
EbgnPM1wM2uCmBzbyoNZc7DDSlRWRnsIcnxmb0aJGHR5KqYBz9pBRa2mx7qc
hAveNvTg6MdA+X+w92n+N3HTjyHjY82wfhsFk8+ZO+5iPoODZ9GI3ymFx9qP
GL/x/AuqWD4+rHvS+JTZ2jN6sRc6y50TlMpkkL8nn+C96gOtYnYEWSGLKOt0
yMR1AAQiY7+sXDm8LGQ0hTB5MDehrB13XR79xE5GsTuHoN21sbKoiIq+3D8D
nwaNgNR/dRQweh0zsmb5KJioKuwKy1DA5ykRFkMhY3CTzSlKzFRETtfuUVYF
H14YplCdkpUwJuk39q2O92B8/tmK/WmLMMd34JEufQKs9rxZn5mhjDGvE1vd
8wUwwI7ekhC/GE8kh8nxiiah2nLv4gdJKtjHdW7OuicEHbeHvYXRqnhmm+XG
z42fvv5HDTuuVjyOtZiCpcc5dl6b1PDOOE0jpmQKdi+qktdoUMOLtU727IJp
sO6uamKY07D50+U+15jP4Oi303t7HQ21FHUG2wNmYEvtji8qlurY9O6IrzF+
gem19HizcnWcMRPGOsx+gebIEOlj32mgbrfdzGiNCPZ9zgmllmgg7z795GnP
2a996Njjn8oR35uFHkML3qbldFRaZSi1bmIWfE2816Tk0XHCLjCn+fwc3HHb
F7FVbwkyJsuKq6TnYZ0H/xo9ewmmG8RnK3Lmwf+87YvNhCbK12xMV+bPQ4yv
wqxUiiYGP4myWGMnhnpdL5JP18KftURBMzliqF2IkVmZqIVL8h4KLwvEX/to
I9/ad3Xc2gXoqNzGT6BpIyZenzuyaQGa9H1b4pO1sbKxq98rfAG4ta7Zb5V0
sPbNtItm6QJ4GvQd2Jeggy0vKwad3i6AqGYNYUplYL1O9FZXJRLCZd51pEYy
MCCOLEpaRQJ9uaWXIYVAl0KqfdduEkKC3aaUThN4UbeOnnOUBMYGn1ajCAJz
lVOC1P1JuC0+ftX6LIEO/cbnoiRWSEiwCY8iUNVMs/NAAAlXi5p/fRdL4ED8
Mm3NIBKax5jmrekE3qh4EBfKJkHDW/VUdAOB24Y57+VDSahbqWuffZvA2pmG
3CCJfxKu1Gu8S6D2t06MHonzo2xbppoJTB2ibckKI2FT1llNn04Cy3sHA8zD
STj093iNdT+Bdm40jvNZEqh5oksHBgjsW5GmVyNxcSCVFc4jkNZWeUY7koTP
cwbUihECI39YHdYn8SWGp/vSCQI1xSpsLw4Ja3h+ppsnJXn+sqr3Je65FkJ6
fCJwkJ8bbBBFgp5lUsGVGQLvbj/B5kncRMmMKBYR2Js8pG7NJeFIa7Fj6xyB
Kt3xp7IlVr5ya9mQmMDJpIQMynkSyt1bZ0iSwERvRS5L4n8AXUOPgg==
        "]]},
      Annotation[#, "Charting`Private`Tag$3834763#1"]& ], 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVV3c8Fe4Xvkau7XLvdS83sppKA4VwToMUiSIjq4iSUlIp44uSBlpkFSGl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        "]]},
      Annotation[#, "Charting`Private`Tag$3834763#2"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.8750000000000002, 0},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox["\"variance\"", TraditionalForm], ""}, {
     FormBox["K", TraditionalForm], ""}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8285635227460833`*^9, {3.828563890252616*^9, 3.8285639006917*^9}, {
   3.828563937876066*^9, 3.828564056198015*^9}, {3.8285640869358807`*^9, 
   3.828564121809412*^9}, 3.828564226606436*^9, 3.828564296550029*^9, 
   3.828564385638893*^9, {3.828564463393276*^9, 3.828564471439814*^9}, {
   3.828564508559362*^9, 3.828564553661887*^9}},
 CellLabel->
  "Out[1275]=",ExpressionUUID->"cecbe101-762b-4da0-aa29-e67d3efaa040"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Variance at mean pivot - general BK:", "Section",
 CellChangeTimes->{{3.820815105146338*^9, 
  3.820815111065667*^9}},ExpressionUUID->"8dca8c1b-eb08-4140-9d5c-\
31df1f86e588"],

Cell[TextData[{
 "In future work, to rigorously analyze the gain in comb filtering the \
density/extinction field along a ray by increasing query size M, we need to \
know the change in variance at the mean/optimal pivot p, as a function of \
expansion parameter c.  This can be used to tell if the net gain in lowering \
c is made up for by the variance reduction Var[Y] that increasing M gives.  \
To aid this future work, we noted the follow expression for the variance of \
the UBK estimator at the optimal pivot (E[Y] = 0).  This was achieved by \
expanding the variance calculations up to a fixed order and noting patterns \
in the powers of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"E", "[", 
     SuperscriptBox["Y", "2"], "]"}], " ", "=", " ", "V"}], TraditionalForm]],
  
  FormatType->"TraditionalForm",ExpressionUUID->
  "c4448085-ff8f-4f21-b8ed-916a1919ee30"],
 " at various orders using FindSequenceFunction[]."
}], "Text",
 CellChangeTimes->{{3.8208185860141287`*^9, 
  3.820818739091975*^9}},ExpressionUUID->"26c70d74-8c93-4239-9da0-\
ba9195ee1998"],

Cell[CellGroupData[{

Cell["special case K = c = 1", "Subsection",
 CellChangeTimes->{{3.820817399931841*^9, 3.820817402858262*^9}, {
  3.821112104399383*^9, 
  3.821112104540627*^9}},ExpressionUUID->"42966fb6-441d-4b00-8afa-\
d9acc388b9a8"],

Cell["We first test a very simple result for K = c = 1:", "Text",
 CellChangeTimes->{{3.820818749144285*^9, 
  3.820818757593562*^9}},ExpressionUUID->"f575138e-acea-4c51-bd75-\
07bf12a3048e"],

Cell[TextData[{
 "For K = c = 1 - the variance of BK simplifies to a remarkably simple \
result:\[LineSeparator]Var[T] = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", 
     RowBox[{
      RowBox[{"-", "2"}], "\[Tau]"}]], "(", 
    SuperscriptBox["e", "V"]}], TraditionalForm]],ExpressionUUID->
  "d33bf0c5-d502-48a0-9db6-32ecc6e2ca5f"],
 "-1)"
}], "Text",
 CellChangeTimes->{{3.820815181181314*^9, 
  3.820815216960196*^9}},ExpressionUUID->"c4353726-6536-49e0-bdde-\
56a2f8a64c62"],

Cell[CellGroupData[{

Cell["MC check", "Subsubsection",
 CellChangeTimes->{{3.817330423324149*^9, 3.817330457410323*^9}, 
   3.817411737873501*^9},ExpressionUUID->"bbd94d80-68bd-4723-846f-\
d17059cb630f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MCn", "=", "1000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"points", "=", 
   RowBox[{"Table", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"d", "=", "2"}], ";", "\[IndentingNewLine]", 
       RowBox[{"td", "=", 
        RowBox[{
         RowBox[{".6", 
          RowBox[{"RandomFunction", "[", 
           RowBox[{
            RowBox[{"FractionalBrownianMotionProcess", "[", ".6", "]"}], ",", 
            
            RowBox[{"{", 
             RowBox[{"0", ",", "d", ",", "0.01"}], "}"}]}], "]"}]}], "+", 
         "0.2"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"data", "=", 
        RowBox[{"TimeSeriesMap", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Max", "[", 
            RowBox[{"0", ",", "#"}], "]"}], "&"}], ",", "td"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Clear", "[", "f", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"f", "=", 
        RowBox[{"Interpolation", "[", "data", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"X", "=", 
        RowBox[{
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{"f", "[", "x", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "0", ",", "d"}], "}"}]}], "]"}], "/", "d"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"V", "=", 
        RowBox[{
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"d", 
              RowBox[{"(", 
               RowBox[{"X", "-", 
                RowBox[{"f", "[", "x", "]"}]}], ")"}]}], ")"}], "2"], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "0", ",", "d"}], "}"}]}], "]"}], "/", "d"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"X", ",", "V", ",", 
         RowBox[{"Variance", "[", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"TBK", "[", 
              RowBox[{"f", ",", "X", ",", "d", ",", "1", ",", "1"}], "]"}], 
             "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", 
              RowBox[{"Range", "[", "MCn", "]"}]}], "}"}]}], "]"}], "]"}]}], 
        "}"}]}], "\[IndentingNewLine]", ")"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Range", "[", "10", "]"}]}], "}"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.81727060637638*^9, 3.8172706069889917`*^9}, {
   3.81727065064183*^9, 3.81727067381938*^9}, {3.817271240501174*^9, 
   3.817271309201717*^9}, 3.8172715151107903`*^9, 3.8172716051549873`*^9, {
   3.81727178803353*^9, 3.817271788191675*^9}, {3.817272283634284*^9, 
   3.817272316024352*^9}, {3.817412106965559*^9, 3.8174121238768377`*^9}, {
   3.817412163039263*^9, 3.8174121756361628`*^9}, {3.820815119605198*^9, 
   3.820815149405525*^9}, 3.820815372145259*^9},
 CellLabel->
  "In[304]:=",ExpressionUUID->"6c6054e4-b3bc-455f-8e10-f9d0f9deda3d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"LogLogPlot", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox["E", "V"], "-", "1"}], ",", 
     RowBox[{"{", 
      RowBox[{"V", ",", "0.01", ",", "3"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ListLogLogPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], ",", 
         FractionBox[
          RowBox[{"#", "[", 
           RowBox[{"[", "3", "]"}], "]"}], 
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{"-", "2"}], "d", " ", 
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}]]}], "}"}], "&"}], "/@", 
      "points"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.8172717045755873`*^9, 3.817271892520619*^9}, {
   3.817272233201095*^9, 3.8172722711350727`*^9}, {3.817272304627842*^9, 
   3.817272309148431*^9}, {3.8172723770699368`*^9, 3.817272393027216*^9}, 
   3.8174121397102833`*^9, {3.8174121852913513`*^9, 3.817412198958144*^9}},
 CellLabel->
  "In[285]:=",ExpressionUUID->"e6ac368b-93c8-4929-a5d1-8819b03b76c1"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwB4QQe+yFib1JlAgAAAE0AAAACAAAAF4jls7FrEsAK3urjkWYSwPCs8x/n
aRLAlMp/A8VkEsDK0QGMHGgSwCmCDCL4YhLAfhseZIdkEsAodwtcXl8SwOSu
VhRdXRLAy2uSwypYEsCw1cd0CE8SwBduW2DDSRLASCOqNV8yEsAMEobN8ywS
wHq+brcM+RHA8YHoWlHzEcDltmgNw3wRwDVWwyFKdhHA6f8T5LUIEcDXWZbm
dQERwKsUW4HvlhDA6SWiHtWOEMB16xJxhBsQwCvtWvRfEhDAryX4wqtQD8A/
kZ2UNDwPwIT4q0gFVw7A6EFQnuU/DsDVYpdb7GENwIlkw4XaRw3AWG7lb0x9
DMDrf+6KJGAMwOv9FCljhQvAYYwbPXhkC8CwLqfj8p0KwEYOhMMUeQrA8fZw
KxC7CcDBkm+m3JEJwEJDHBjkxAjAk3t7WGiWCMDFMCoGMd8HwOiwzPcqqwfA
WaIZmTTmBsAoxZ6ybKsGwGirQLnF8QXAUHOZEYCvBcCpVcrazw0FwBYsUcCw
wwTA+4M1oZAWBMC/i19Z3sIDwH5TA2nKLwPAW7KkQAnSAsASp7LVujUCwE7+
LEGyywHAIpKZzzhAAcDIkckYjsgAwGMe48ovWwDAkyze6mqq/79qXRzWusX+
v07wBwbRlv2/csA3GQj2/L88qcwmUqL7v3FSwnZwL/u/MXEeVUGz+b+R7A8e
RkL5vxv8wV6flPe/FckiyA1297/oI3mgWJT1v7qt+LtCg/W/X4zHF9hh879W
wT3Kkpnzv5wtPJY8MfG/VhdI29TQ8b+L26b+szvuv+3qKmwIw++/2AHQ5hum
6b/0K1AnSybsv6dfh2EcSOW/68pTF8Sb6L9Vi0KRNOjgvyN63ZoXxOS/nhWp
6wMV2L8irvEjTy7hv+jsXTKnfs2/xuQXgcKW2r+LY74+cD2xv9V2YcWuVNO/
0rwHg5wctz+Hic/mDm7Iv/kPq9YHCdA/18zoIVX8sb+GcDKCEaLbP1em8rqm
qKU/+b4tU6974z+QeFWgEwfFP3hct/zO8ek/5mc6X5It0j/Gdhn1/1TwP/YJ
NePSU9k/JhBdAySp8z/CxREgL4rgP258i3YvhPc/wYH+yJAo5D8L00ooUGL7
P9LfDD28tOc/1LB93IV3/z+gLZUdDY7rPz5vMi4iIwJAp/aS+Hkl7z9waXPK
7pUEQEQZjGODNe8//eX4zFyhBEDiO4XOjEXvPyjEwmPPrARAHoF3pJ9l7z8G
n8ZZwsMEQJYLXFDFpe8/H0piud/xBEBDkBJUCBPwP2tJF9v6TgVAM6Xbq1OT
8D970sKjxwwGQII2WGFYm/A/rUH68c0YBkDRx9QWXaPwP1rY0DTZJAZAb+rN
gWaz8D96D9uk/jwGQKsvwFd50/A/q01DhoVtBkAjuqQDnxPxP8V4LROGzwZA
ckshuaMb8T/i1vIl3dsGQMHcnW6oI/E/XegiYDnoBkBf/5bZsTPxPwZatFcB
AQdAm0SJr8RT8T87aJmuzzIHQOrVBWXJW/E/X8ykV1A/B0A5Z4IazmPxP9cF
LELWSwdA14l7hddz8T/MyNjo8WQHQCYb+Drce/E/c0CYq4dxB0B1rHTw4IPx
P8lqB70ifgdAxD3xpeWL8T9Vx3cgw4oHQBPPbVvqk/E/sKY82WiXB0A+R2mr

        "]]},
      Annotation[#, "Charting`Private`Tag$1254862#1"]& ]}, {}}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], 
     PointBox[{{-1.557664920541509, -1.4600874669217803`}, \
{-0.8813741337095248, -0.7017302353095175}, {-0.8619422836358692, \
-0.7212864141290091}, {-0.2981519026061774, 
      0.04132042825663381}, {-0.9579868759569872, -0.7888541570811392}, \
{-2.841510683737126, -2.7874966965937316`}, {0.11121832564675625`, 
      0.7409518010181945}, {-1.0122225401777, -0.9121440826559643}, \
{-1.4422809180853609`, -1.2880798640618414`}, {0.4431254048161088, 
      1.27997323147414}}]}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-4.605170069584367, -4.600165902338185},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& )},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Quiet[
      Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Quiet[
      Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
     Charting`ScaledFrameTicks[{Log, Exp}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Quiet[
      Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , Quiet[
      Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 
       6}]]& }, {{{-4.605170185988091, 
       FormBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"0.01\"", ShowStringCharacters -> False], 0.01, 
          AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 
       0.}}, {-2.995732273553991, 
       FormBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"0.05\"", ShowStringCharacters -> False], 0.05, 
          AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 
       0.}}, {-2.3025850929940455`, 
       FormBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"0.10\"", ShowStringCharacters -> False], 0.1, 
          AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 
       0.}}, {-0.6931471805599453, 
       FormBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"0.50\"", ShowStringCharacters -> False], 0.5, 
          AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 0.}}, {0., 
       FormBox["1", TraditionalForm], {0.01, 0.}}, {-5.298317366548036, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.115995809754082, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.961845129926823, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.8283137373023015`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.710530701645918, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-3.912023005428146, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-3.506557897319982, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-3.2188758248682006`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.8134107167600364`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.659260036932778, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.5257286443082556`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.4079456086518722`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-1.6094379124341003`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-1.2039728043259361`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.916290731874155, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.5108256237659907, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.35667494393873245`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.2231435513142097, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.10536051565782628`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      0.6931471805599453, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      1.0986122886681098`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      1.3862943611198906`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      1.6094379124341003`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      1.791759469228055, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      1.9459101490553132`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.0794415416798357`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.1972245773362196`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.302585092994046, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.3978952727983707`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.4849066497880004`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.5649493574615367`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.6390573296152584`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.70805020110221, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.772588722239781, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}}, {{-4.605170185988091, 
       FormBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"0.01\"", ShowStringCharacters -> False], 0.01, 
          AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 
       0.}}, {-2.995732273553991, 
       FormBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"0.05\"", ShowStringCharacters -> False], 0.05, 
          AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 
       0.}}, {-2.3025850929940455`, 
       FormBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"0.10\"", ShowStringCharacters -> False], 0.1, 
          AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 
       0.}}, {-0.6931471805599453, 
       FormBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"0.50\"", ShowStringCharacters -> False], 0.5, 
          AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 2}]& ], TraditionalForm], {0.01, 0.}}, {0., 
       FormBox["1", TraditionalForm], {0.01, 0.}}, {1.6094379124341003`, 
       FormBox["5", TraditionalForm], {0.01, 0.}}, {2.302585092994046, 
       FormBox["10", TraditionalForm], {0.01, 0.}}, {-5.298317366548036, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.115995809754082, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.961845129926823, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.8283137373023015`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.710530701645918, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-3.912023005428146, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-3.506557897319982, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-3.2188758248682006`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.8134107167600364`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.659260036932778, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.5257286443082556`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.4079456086518722`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-1.6094379124341003`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-1.2039728043259361`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.916290731874155, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.5108256237659907, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.35667494393873245`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.2231435513142097, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.10536051565782628`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      0.6931471805599453, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      1.0986122886681098`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      1.3862943611198906`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      1.791759469228055, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      1.9459101490553132`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.0794415416798357`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.1972245773362196`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.995732273553991, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      3.4011973816621555`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      3.6888794541139363`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      3.912023005428146, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      4.0943445622221, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      4.248495242049359, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      4.382026634673881, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      4.499809670330265, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      4.605170185988092, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      5.0106352940962555`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      5.298317366548036, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      5.521460917862246, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}}}]]], "Output",
 CellChangeTimes->{{3.817271783463286*^9, 3.8172718117834044`*^9}, {
   3.81727187074459*^9, 3.8172718929929*^9}, {3.817272238323863*^9, 
   3.817272309597494*^9}, {3.8172723671349697`*^9, 3.817272393369669*^9}, {
   3.8174121336789837`*^9, 3.8174121993747673`*^9}, 3.820815156514998*^9},
 CellLabel->"Out[285]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>", "ImageResolution" -> \
144.],ExpressionUUID->"0b36fbf4-cda4-4963-aea2-8bb287dbd295"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MCn", "=", "30000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"points", "=", 
   RowBox[{"Table", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"d", "=", "2"}], ";", "\[IndentingNewLine]", 
       RowBox[{"td", "=", 
        RowBox[{
         RowBox[{".8", 
          RowBox[{"RandomFunction", "[", 
           RowBox[{
            RowBox[{"FractionalBrownianMotionProcess", "[", ".5", "]"}], ",", 
            
            RowBox[{"{", 
             RowBox[{"0", ",", "d", ",", "0.01"}], "}"}]}], "]"}]}], "+", 
         "0.2"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"data", "=", 
        RowBox[{"TimeSeriesMap", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Max", "[", 
            RowBox[{"0", ",", "#"}], "]"}], "&"}], ",", "td"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Clear", "[", "f", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"c", "=", "0.5"}], ";", "\[IndentingNewLine]", 
       RowBox[{"f", "=", 
        RowBox[{"Interpolation", "[", "data", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"X", "=", 
        RowBox[{
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{"f", "[", "x", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "0", ",", "d"}], "}"}]}], "]"}], "/", "d"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"V", "=", 
        RowBox[{
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"d", 
              RowBox[{"(", 
               RowBox[{"X", "-", 
                RowBox[{"f", "[", "x", "]"}]}], ")"}]}], ")"}], "2"], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "0", ",", "d"}], "}"}]}], "]"}], "/", "d"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"X", ",", "V", ",", 
         RowBox[{"Variance", "[", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"TBK", "[", 
              RowBox[{"f", ",", "X", ",", "d", ",", "1", ",", "c"}], "]"}], 
             "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", 
              RowBox[{"Range", "[", "MCn", "]"}]}], "}"}]}], "]"}], "]"}]}], 
        "}"}]}], "\[IndentingNewLine]", ")"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Range", "[", "10", "]"}]}], "}"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.817412225598031*^9, 3.81741222993442*^9}, {
   3.817412306708542*^9, 3.817412308717156*^9}, {3.817412387368209*^9, 
   3.81741241688957*^9}, {3.820815236221627*^9, 3.8208152546339273`*^9}, 
   3.820815289551692*^9, {3.8208153210446463`*^9, 3.82081534003082*^9}, 
   3.8208153766920147`*^9},
 CellLabel->
  "In[306]:=",ExpressionUUID->"4a56d6da-f462-4c9e-b3cb-7562885c537a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"V", ",", "c"}], "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox["V", "c"]]}], ")"}], " ", "c"}]}], ")"}], "-", "1"}], "/.", 
   RowBox[{"c", "\[Rule]", 
    RowBox[{"1", "/", "2"}]}]}]}]], "Input",
 CellChangeTimes->{{3.817412348021003*^9, 3.817412357428336*^9}, {
  3.8208152610311747`*^9, 3.820815272411832*^9}},
 CellLabel->
  "In[293]:=",ExpressionUUID->"73c25399-5b18-490e-9a93-767347bc1f66"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"2", " ", "V"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.817412349755457*^9, 3.8174123577021847`*^9}, {
  3.820815267838546*^9, 3.820815272660654*^9}},
 CellLabel->
  "Out[293]=",ExpressionUUID->"8c7b5ab3-541d-4aba-9deb-01b274e262bd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"LogLogPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["E", "V"], "-", "1"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", " ", "V"}]]}], ")"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"V", ",", "0.001", ",", "4"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ListLogLogPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], ",", 
         FractionBox[
          RowBox[{"#", "[", 
           RowBox[{"[", "3", "]"}], "]"}], 
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{"-", "2"}], "d", " ", 
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}]]}], "}"}], "&"}], "/@", 
      "points"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{
  3.817412320319807*^9, {3.817412361563076*^9, 3.8174123656120996`*^9}, {
   3.8174124040914288`*^9, 3.81741240646045*^9}, 3.820815278358057*^9},
 CellLabel->
  "In[303]:=",ExpressionUUID->"7b1ab7b2-b413-4e9e-acea-f63f7a4c9840"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwB4QQe+yFib1JlAgAAAE0AAAACAAAAewY0joqhG8D/Jvh4B6EbwM6HELnv
nhvA42paTmyeG8AiCe3jVJwbwKLwhCPRmxvAyAumOR+XG8ArLzLNmpYbwBQR
GOWzjBvA/3rpHS6MG8CuG/w73XcbwO38qrRUdxvA4jDE6S9OG8ATPnK2oU0b
wEhbVEXV+hrA2sODAjv6GsBqMy00GkYawOYpoCliRRrAO7BNLVmdGcBEGr0o
gJwZwJzGMJXn9xjASyUxgej2GMBSYMw0cEQYwEXAxUFAQxjAt56v3vKcF8CN
9m7ljJsXwHFgS8Bv5xbACABlVcTlFsC7u6kQPDUWwGd5E2A/MxbAs7tPawKP
FcDzFT4KrIwVwAA/rv3C2hTAjapeZPnXFMD8ZlSafTIUwCg8unw0LxTAiCi9
pYeNE8AFnndqq4kTwGlt3uiL2hLAS6NhyvLVEsD5Vkc2ijMSwJ7NYGMgLhLA
3sNou4J+EcCe/EmkDHgRwFPKTK/KzBDAPsJkthrFEMB3dXitDCcQwERid3AC
HhDA4Ee5xpHmDsCZ0qSGA9EOwC7uEEf+lg3AqbIPg5d9DcAmm9k2XysMwMAZ
R/AFDQzAQHsnBF/GCsBR8HjjOaIKwLakBOZSeQnANX+jIsZOCcDW1FI3OxAI
wIjdSJFx3QfAU04wnRe/BsAOc3opLIMGwPH6kuCSdAXATLb+phkuBcA5rmaT
Ag4EwCQFRgD2uQPA3qrJWma/AsC+2IZ+UFwCwC2unZG+VAHAyBJHMUjeAMA5
ye1La+H/v5OXkMMAx/6/0si+nUFJ/b/sDBXnd/z7v7/Vcc4Aefq/xcJmOTvr
+L9ldUMoqNj3v83fryCeAva/TnsfPY1F9b+rYBBwrRvzv4uO3TBbevK/3ry0
ujXI778DaXSbIr7vv6Dx3lY/oOm/mM/xkmAX6r+LLSgRP8Div6FbrNxu0OS/
JhytKbM02L9caPc48Uffvwcfx1UhTsW/xk4eNKgO1L/F20DrFAKzPywAf6f/
KcO/kBUUx9Pu0z+mlHERUVCcP9TTngz2uuI/QzOIEybUyT+wr8BfpwHsPxLP
9l2AT9c/jqikP3Wz8j+Zp1AbpUrhP4d/DMAYTPg/NsJotbmN5j8o6U9wPBv+
P04QbNlStus/Ws+O+Hc9AkDgodUfjafwPxaO3GwlKwZA36jWqQhE8z8XeKbJ
PWEKQJB3dZKxT/M/3lc3vWt1CkBCRhR7WlvzP6HTtJymiQpApuNRTKxy8z+U
zZFNQ7IKQG4eze5PofM/4lh7uxkEC0D+k8Mzl/7zP8tuqAlFqgtAHX+wvSW5
9D8emK5F6QANQM5NT6bOxPQ/b751sMsWDUCAHO6Od9D0P0YopYi8LA1A5Lkr
YMnn9D+9NbuzyVgNQKz0pgJtFvU/Ny4uWJOxDUA8ap1HtHP1Py1D9BLvZQ5A
7jg8MF1/9T8tkKJRvnwOQKAH2xgGi/U/sPnEy5yTDkAEpRjqV6L1P+JqJaeH
wQ5AzN+TjPvQ9T+RwY1tFh4PQH6uMnWk3PU/XGXW+mA1D0AwfdFdTej1P0vO
/i27TA9AlBoPL5//9T9pjNK7nnsPQEbprRdIC/Y/QaWGMSiTD0D4t0wA8Rb2
P+IPLIPBqg9Aqobr6Jki9j9eL16+asIPQFtVitFCLvY/SZ/B8CPaD0BexloV

        "]]},
      Annotation[#, "Charting`Private`Tag$2385676#1"]& ], 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwB4QQe+yFib1JlAgAAAE0AAAACAAAAewY0joqhG8DSniRehKAbwM6HELnv
nhvALFgF3uidG8AiCe3jVJwbwHGLdl1NmxvAyAumOR+XG8C9OwlbFpYbwBQR
GOWzjBvAJcTnUKiLG8CuG/w73XcbwOzMSCfMdhvA4jDE6S9OG8AxhYt8E00b
wEhbVEXV+hrAB4b0t6D5GsBqMy00GkYawAkxDRSqRBrAO7BNLVmdGcCM39gU
p5sZwJzGMJXn9xjA4jMFWOn1GMBSYMw0cEQYwH5WrzAQQhjAt56v3vKcF8Bo
aHzCJpoXwHFgS8Bv5xbAtRUPrxjkFsC7u6kQPDUWwBVlT1tCMRbAs7tPawKP
FcDeBLU0VYoVwAA/rv3C2hTAxldyJS/VFMD8ZlSafTIUwGLjEnnqKxTAiCi9
pYeNE8An/bDxzYUTwGlt3uiL2hLAUHOG6VfREsD5Vkc2ijMSwHNmaiC0KBLA
3sNou4J+EcCYYWoUk3ERwFPKTK/KzBDAYyfv02W9EMB3dXitDCcQwOesNmnx
FBDA4Ee5xpHmDsCwq8X7YbsOwC7uEEf+lg3AKAwh+RVkDcAmm9k2XysMwDbE
8nmG7gvAQHsnBF/GCsDOfZGl3n0KwLakBOZSeQnATzvgde4jCcDW1FI3OxAI
wDsVv1Y9qgfAU04wnRe/BsBfWO+UrEYGwPH6kuCSdAXAyvCR4tPmBMA5rmaT
Ag4EwD9GXCfHZAPA3qrJWma/AsD9crI8qPcBwC2unZG+VAHAvdN4ipRlAMA5
ye1La+H/v+Z08Hc/pv2/0si+nUFJ/b/ceua96qb6v7/Vcc4Aefq/AsgorQJR
979ldUMoqNj3vwoalFZOG/S/TnsfPY1F9b9tH1z7/9nwv4uO3TBbevK/1B84
R1FY6r8DaXSbIr7vvziaVxg4JeO/mM/xkmAX6r9IrWEw7MnVv6FbrNxu0OS/
GdLPfz5qtb9caPc48Uffv3VeZZgJ4cc/xk4eNKgO1L/CTRGApCngPywAf6f/
KcO/8FnE0Yqe6j+mlHERUVCcP9YXVGq8nfM/QzOIEybUyT97sk2IwJ36PxLP
9l2AT9c/5aq3osIFAUCZp1AbpUrhPz4RtCKKqAVANsJotbmN5j+z5XMRWbAK
QE4QbNlStus/P5v/kEU2EEDgodUfjafwPxiXnIEl3hNA36jWqQhE8z8/HoI/
hOQXQJB3dZKxT/M/eR8+JgH4F0BCRhR7WlvzP8LeTSeMCxhApuNRTKxy8z+d
3DmjzDIYQG4eze5PofM/nXF8r/iBGED+k8Mzl/7zP3PyKpoGIxlAHX+wvSW5
9D/rgIgvR3AaQM5NT6bOxPQ/MVJqopyFGkCAHO6Od9D0P8J3pJMBmxpA5Lkr
YMnn9D+Cuo0f+sUaQKz0pgJtFvU/A0LUI6ccG0A8ap1HtHP1P+BBkyz7zBtA
7jg8MF1/9T+MApoFTuMbQKAH2xgGi/U/5TYsGrH5G0AEpRjqV6L1P3U2VCao
JhxAzN+TjPvQ9T8nOyAfW4EcQH6uMnWk3PU/Azy4KDGYHEAwfdFdTej1P4xZ
cc8XrxxAlBoPL5//9T8kjK0lF90cQEbprRdIC/Y/6bP47S/0HED4t0wA8Rb2
P8As9YRZCx1Aqobr6Jki9j+44xv3kyIdQFtVitFCLvY/gC7uUN85HUDXeldq

        "]]},
      Annotation[#, "Charting`Private`Tag$2385676#2"]& ]}, {}}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], 
     PointBox[{{-0.7177397148126529, -0.20973030877370505`}, \
{-1.7260136702005613`, -1.5181947714375341`}, {-0.24287357782932142`, 
      0.6244907615202915}, {-1.395225184326135, -1.1610033942746494`}, \
{-3.379555114310521, -3.3409626301181694`}, {-3.5094631125507987`, \
-3.4551261125699773`}, {-0.5479831095286092, 
      0.08444853748851902}, {-0.025505648266903876`, 
      1.073181909268135}, {-0.48554437301326187`, 
      0.16392887853961435`}, {-4.090787164615931, -4.06518524384242}}]}, {{}, \
{}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-6.907755109715818, -6.907255067964569},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& )},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Quiet[
      Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Quiet[
      Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
     Charting`ScaledFrameTicks[{Log, Exp}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Quiet[
      Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , Quiet[
      Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 
       6}]]& }, {{{-6.907755278982137, 
       FormBox["0.001`", TraditionalForm], {0.01, 0.}}, {-4.605170185988091, 
       FormBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"0.010\"", ShowStringCharacters -> False], 0.01, 
          AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 
       0.}}, {-2.3025850929940455`, 
       FormBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"0.100\"", ShowStringCharacters -> False], 0.1, 
          AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 0.}}, {0., 
       FormBox["1", TraditionalForm], {0.01, 0.}}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-8.517193191416238, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-8.111728083308073, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.824046010856292, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.600902459542082, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.418580902748128, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.264430222920869, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.1308988302963465`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.013115794639964, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-6.214608098422191, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.809142990314028, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.521460917862246, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.298317366548036, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.115995809754082, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.961845129926823, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.8283137373023015`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.710530701645918, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-3.912023005428146, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-3.506557897319982, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-3.2188758248682006`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.995732273553991, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.8134107167600364`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.659260036932778, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.5257286443082556`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.4079456086518722`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-1.6094379124341003`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-1.2039728043259361`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.916290731874155, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.6931471805599453, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.5108256237659907, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.35667494393873245`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.2231435513142097, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.10536051565782628`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      0.6931471805599453, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      1.0986122886681098`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      1.3862943611198906`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      1.6094379124341003`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      1.791759469228055, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      1.9459101490553132`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.0794415416798357`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.1972245773362196`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.302585092994046, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.995732273553991, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      3.4011973816621555`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}}, {{-6.907755278982137, 
       FormBox["0.001`", TraditionalForm], {0.01, 0.}}, {-4.605170185988091, 
       FormBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"0.010\"", ShowStringCharacters -> False], 0.01, 
          AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 
       0.}}, {-2.3025850929940455`, 
       FormBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"0.100\"", ShowStringCharacters -> False], 0.1, 
          AutoDelete -> True], NumberForm[#, {
           DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 0.}}, {0., 
       FormBox["1", TraditionalForm], {0.01, 0.}}, {2.302585092994046, 
       FormBox["10", TraditionalForm], {0.01, 0.}}, {4.605170185988092, 
       FormBox["100", TraditionalForm], {0.01, 0.}}, {6.907755278982137, 
       FormBox["1000", TraditionalForm], {0.01, 0.}}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-8.517193191416238, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-8.111728083308073, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.824046010856292, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.600902459542082, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.418580902748128, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.264430222920869, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.1308988302963465`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-7.013115794639964, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-6.214608098422191, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.809142990314028, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.521460917862246, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.298317366548036, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-5.115995809754082, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.961845129926823, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.8283137373023015`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-4.710530701645918, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-3.912023005428146, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-3.506557897319982, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-3.2188758248682006`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.995732273553991, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.8134107167600364`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.659260036932778, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.5257286443082556`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-2.4079456086518722`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-1.6094379124341003`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-1.2039728043259361`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.916290731874155, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.6931471805599453, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.5108256237659907, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.35667494393873245`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.2231435513142097, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}, {-0.10536051565782628`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      0.6931471805599453, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      1.0986122886681098`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      1.3862943611198906`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      1.6094379124341003`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      1.791759469228055, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      1.9459101490553132`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.0794415416798357`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.1972245773362196`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      2.995732273553991, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      3.4011973816621555`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      3.6888794541139363`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      3.912023005428146, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      4.0943445622221, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      4.248495242049359, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      4.382026634673881, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      4.499809670330265, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      5.298317366548036, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      5.703782474656201, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      5.991464547107982, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      6.214608098422191, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      6.396929655216146, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      6.551080335043404, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      6.684611727667927, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      6.802394763324311, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      7.600902459542082, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      8.006367567650246, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      8.294049640102028, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      8.517193191416238, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      8.699514748210191, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      8.85366542803745, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      8.987196820661973, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      9.104979856318357, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      9.210340371976184, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      9.615805480084347, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      9.903487552536127, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
      10.126631103850338`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
       0.}}}}]]], "Output",
 CellChangeTimes->{{3.817412245545268*^9, 3.8174122603234997`*^9}, {
   3.817412315156111*^9, 3.81741232073426*^9}, 3.8174123662425222`*^9, {
   3.817412397194415*^9, 3.817412428465783*^9}, {3.820815278763802*^9, 
   3.820815303394268*^9}, {3.8208153357987967`*^9, 3.820815353109923*^9}},
 CellLabel->
  "Out[303]=",ExpressionUUID->"36bd93f3-44bc-4971-b53d-ab60a10f6133"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["general K, c", "Subsection",
 CellChangeTimes->{{3.820817407723069*^9, 3.8208174138043823`*^9}, 
   3.8208176422410793`*^9},ExpressionUUID->"2753cc6d-4c2b-46f2-8930-\
6d1bbe11127b"],

Cell["We check the pattern in the expansion up to various orders:", "Text",
 CellChangeTimes->{{3.820817646252369*^9, 
  3.820817658885809*^9}},ExpressionUUID->"727a093d-9260-45ac-b7f9-\
6f61dfd28253"],

Cell["\<\
This gives a list of probabilities for terms of size N and their estimates:\
\>", "Text",
 CellChangeTimes->{{3.8208176779378366`*^9, 
  3.8208176949404573`*^9}},ExpressionUUID->"45b875d6-cb50-44fe-9a51-\
fe9a7d8957d3"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"K", ",", "c", ",", "p", ",", "X", ",", "V", ",", "d", ",", "X2"}],
    "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"list", "=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"K", "=", "3"}], ",", 
       RowBox[{"c", "=", "3"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox["c", "k"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             FractionBox["c", 
              RowBox[{"1", "+", "K", "+", "k"}]]}], ")"}]}], 
          RowBox[{"Pochhammer", "[", 
           RowBox[{
            RowBox[{"1", "+", "K"}], ",", "k"}], "]"}]], ",", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Expand", "[", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Sum", "[", 
                  RowBox[{
                   RowBox[{
                    FractionBox["1", 
                    RowBox[{"n", "!"}]], 
                    RowBox[{"Mean", "[", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"Product", "[", 
                    RowBox[{
                    RowBox[{"Y", "[", "i", "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", "s"}], "}"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"s", ",", 
                    RowBox[{"Subsets", "[", 
                    RowBox[{
                    RowBox[{"Range", "[", 
                    RowBox[{"k", "+", "K"}], "]"}], ",", 
                    RowBox[{"{", "n", "}"}]}], "]"}]}], "}"}]}], "]"}], 
                    "]"}]}], ",", 
                   RowBox[{"{", 
                    RowBox[{"n", ",", "0", ",", 
                    RowBox[{"Floor", "[", "c", "]"}]}], "}"}]}], "]"}], "+", 
                 RowBox[{"Sum", "[", 
                  RowBox[{
                   RowBox[{
                    FractionBox["1", 
                    RowBox[{
                    SuperscriptBox["c", "i"], " ", 
                    RowBox[{"K", "!"}]}]], 
                    RowBox[{"Mean", "[", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"Product", "[", 
                    RowBox[{
                    RowBox[{"Y", "[", "i", "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", "s"}], "}"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"s", ",", 
                    RowBox[{"Subsets", "[", 
                    RowBox[{
                    RowBox[{"Range", "[", 
                    RowBox[{"k", "+", "K"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Floor", "[", "c", "]"}], "+", "i"}], "}"}]}], 
                    "]"}]}], "}"}]}], "]"}], "]"}]}], ",", 
                   RowBox[{"{", 
                    RowBox[{"i", ",", "1", ",", "k"}], "}"}]}], "]"}]}], 
                ")"}], ")"}], "2"], "\[IndentingNewLine]", "]"}], "/.", 
            RowBox[{
             RowBox[{"Mean", "[", 
              RowBox[{"{", "}"}], "]"}], "\[Rule]", "1"}]}], "/.", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Y", "[", "_", "]"}], "2"], "\[Rule]", "V"}]}], "/.", 
          RowBox[{
           RowBox[{"Y", "[", "_", "]"}], "\[Rule]", "0"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", 
         RowBox[{
          RowBox[{"Range", "[", "9", "]"}], "-", "1"}]}], "}"}]}], "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"list", "//", "Expand"}], "//", "TableForm"}]}], "Input",
 CellChangeTimes->{{3.8208175681689653`*^9, 3.8208176010811443`*^9}, {
   3.820818431352131*^9, 3.8208184337554197`*^9}, 3.820818465733693*^9, {
   3.821116291020112*^9, 3.821116292208539*^9}, {3.82855398596408*^9, 
   3.828553987719648*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"5af02d75-973d-4dd9-b616-eae32e56b0d8"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     FractionBox["1", "4"], 
     RowBox[{"1", "+", 
      FractionBox["V", "3"], "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "12"], "+", 
      FractionBox[
       SuperscriptBox["V", "3"], "36"]}]},
    {
     FractionBox["3", "10"], 
     RowBox[{"1", "+", 
      FractionBox["V", "4"], "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "24"], "+", 
      FractionBox[
       SuperscriptBox["V", "3"], "144"], "+", 
      FractionBox[
       SuperscriptBox["V", "4"], "324"]}]},
    {
     FractionBox["9", "40"], 
     RowBox[{"1", "+", 
      FractionBox["V", "5"], "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "40"], "+", 
      FractionBox[
       SuperscriptBox["V", "3"], "360"], "+", 
      FractionBox[
       SuperscriptBox["V", "4"], "1620"], "+", 
      FractionBox[
       SuperscriptBox["V", "5"], "2916"]}]},
    {
     FractionBox["9", "70"], 
     RowBox[{"1", "+", 
      FractionBox["V", "6"], "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "60"], "+", 
      FractionBox[
       SuperscriptBox["V", "3"], "720"], "+", 
      FractionBox[
       SuperscriptBox["V", "4"], "4860"], "+", 
      FractionBox[
       SuperscriptBox["V", "5"], "17496"], "+", 
      FractionBox[
       SuperscriptBox["V", "6"], "26244"]}]},
    {
     FractionBox["27", "448"], 
     RowBox[{"1", "+", 
      FractionBox["V", "7"], "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "84"], "+", 
      FractionBox[
       SuperscriptBox["V", "3"], "1260"], "+", 
      FractionBox[
       SuperscriptBox["V", "4"], "11340"], "+", 
      FractionBox[
       SuperscriptBox["V", "5"], "61236"], "+", 
      FractionBox[
       SuperscriptBox["V", "6"], "183708"], "+", 
      FractionBox[
       SuperscriptBox["V", "7"], "236196"]}]},
    {
     FractionBox["27", "1120"], 
     RowBox[{"1", "+", 
      FractionBox["V", "8"], "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "112"], "+", 
      FractionBox[
       SuperscriptBox["V", "3"], "2016"], "+", 
      FractionBox[
       SuperscriptBox["V", "4"], "22680"], "+", 
      FractionBox[
       SuperscriptBox["V", "5"], "163296"], "+", 
      FractionBox[
       SuperscriptBox["V", "6"], "734832"], "+", 
      FractionBox[
       SuperscriptBox["V", "7"], "1889568"], "+", 
      FractionBox[
       SuperscriptBox["V", "8"], "2125764"]}]},
    {
     FractionBox["27", "3200"], 
     RowBox[{"1", "+", 
      FractionBox["V", "9"], "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "144"], "+", 
      FractionBox[
       SuperscriptBox["V", "3"], "3024"], "+", 
      FractionBox[
       SuperscriptBox["V", "4"], "40824"], "+", 
      FractionBox[
       SuperscriptBox["V", "5"], "367416"], "+", 
      FractionBox[
       SuperscriptBox["V", "6"], "2204496"], "+", 
      FractionBox[
       SuperscriptBox["V", "7"], "8503056"], "+", 
      FractionBox[
       SuperscriptBox["V", "8"], "19131876"], "+", 
      FractionBox[
       SuperscriptBox["V", "9"], "19131876"]}]},
    {
     FractionBox["81", "30800"], 
     RowBox[{"1", "+", 
      FractionBox["V", "10"], "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "180"], "+", 
      FractionBox[
       SuperscriptBox["V", "3"], "4320"], "+", 
      FractionBox[
       SuperscriptBox["V", "4"], "68040"], "+", 
      FractionBox[
       SuperscriptBox["V", "5"], "734832"], "+", 
      FractionBox[
       SuperscriptBox["V", "6"], "5511240"], "+", 
      FractionBox[
       SuperscriptBox["V", "7"], "28343520"], "+", 
      FractionBox[
       SuperscriptBox["V", "8"], "95659380"], "+", 
      FractionBox[
       SuperscriptBox["V", "9"], "191318760"], "+", 
      FractionBox[
       SuperscriptBox["V", "10"], "172186884"]}]},
    {
     FractionBox["729", "985600"], 
     RowBox[{"1", "+", 
      FractionBox["V", "11"], "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "220"], "+", 
      FractionBox[
       SuperscriptBox["V", "3"], "5940"], "+", 
      FractionBox[
       SuperscriptBox["V", "4"], "106920"], "+", 
      FractionBox[
       SuperscriptBox["V", "5"], "1347192"], "+", 
      FractionBox[
       SuperscriptBox["V", "6"], "12124728"], "+", 
      FractionBox[
       SuperscriptBox["V", "7"], "77944680"], "+", 
      FractionBox[
       SuperscriptBox["V", "8"], "350751060"], "+", 
      FractionBox[
       SuperscriptBox["V", "9"], "1052253180"], "+", 
      FractionBox[
       SuperscriptBox["V", "10"], "1894055724"], "+", 
      FractionBox[
       SuperscriptBox["V", "11"], "1549681956"]}]}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.820817586420195*^9, 3.820817601534162*^9}, 
   3.8208179873852453`*^9, 3.820818434617178*^9, 3.8208184705807877`*^9, 
   3.821116293747838*^9, 3.828553994196876*^9},
 CellLabel->
  "Out[3]//TableForm=",ExpressionUUID->"f002e5d8-6742-4514-8eb6-c7c7fb18a0eb"]
}, Open  ]],

Cell["We notice that these match the following relations:", "Text",
 CellChangeTimes->{{3.8208177034917307`*^9, 
  3.8208177115040073`*^9}},ExpressionUUID->"f134be73-936d-4911-ab5e-\
1cc1f9dafecc"],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvQe0FFW6vu+Yrlf/zFz9jQv1Khcx4Kh4BV0Kugwoo+OYFUQMg6CgmFDM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    "], {{0, 115.}, {653., 0}}, {0, 255},
    ColorFunction->RGBColor,
    ImageResolution->144],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  DefaultBaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{653., 115.},
  PlotRange->{{0, 653.}, {0, 115.}}]], "Input",ExpressionUUID->"c21ab1db-197e-\
4e3f-83ee-31e403f5008f"],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3QesLVX1P3C7qFF/Goli1KgYMSoGlShqFFvEGrGLaCyIHcSGgtgAwYIN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    "], {{0, 31.}, {401., 0}}, {0, 255},
    ColorFunction->RGBColor,
    ImageResolution->144],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  DefaultBaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{401., 31.},
  PlotRange->{{0, 401.}, {0, 31.}}]], "Input",ExpressionUUID->"9e2834c3-7fed-\
4005-b7fd-e8e22164bbd5"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"maxk", "=", "8"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"listtest", "=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"K", "=", "3"}], ",", 
       RowBox[{"c", "=", "3"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Table", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox["c", "k"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             FractionBox["c", 
              RowBox[{"1", "+", "K", "+", "k"}]]}], ")"}]}], 
          RowBox[{"Pochhammer", "[", 
           RowBox[{
            RowBox[{"1", "+", "K"}], ",", "k"}], "]"}]], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Sum", "[", 
           RowBox[{
            FractionBox[
             SuperscriptBox["V", 
              RowBox[{" ", "n"}]], 
             RowBox[{
              RowBox[{"Binomial", "[", 
               RowBox[{
                RowBox[{"k", "+", "K"}], ",", "n"}], "]"}], 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"n", "!"}], ")"}], "2"]}]], ",", 
            RowBox[{"{", 
             RowBox[{"n", ",", "0", ",", "K"}], "}"}]}], "]"}], "+", 
          RowBox[{"Sum", "[", 
           RowBox[{
            FractionBox[
             RowBox[{
              SuperscriptBox["c", 
               RowBox[{
                RowBox[{"-", "2"}], " ", "i"}]], 
              SuperscriptBox["V", 
               RowBox[{"K", "+", "i"}]]}], 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"K", "!"}], ")"}], "2"], 
              RowBox[{"Binomial", "[", 
               RowBox[{
                RowBox[{"k", "+", "K"}], ",", 
                RowBox[{"K", "+", "i"}]}], "]"}]}]], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", "k"}], "}"}]}], "]"}]}]}], 
        "\[IndentingNewLine]", "}"}], "\[IndentingNewLine]", ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "maxk"}], "}"}]}], "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"listtest", "//", "TableForm"}]}], "Input",
 CellChangeTimes->{{3.82081809011852*^9, 3.8208181333045197`*^9}, {
   3.820818308922348*^9, 3.820818456246133*^9}, 3.820818552288726*^9},
 CellLabel->"In[4]:=",ExpressionUUID->"3d99a911-6953-4774-8826-a5855a2ee86b"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     FractionBox["1", "4"], 
     RowBox[{"1", "+", 
      FractionBox["V", "3"], "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "12"], "+", 
      FractionBox[
       SuperscriptBox["V", "3"], "36"]}]},
    {
     FractionBox["3", "10"], 
     RowBox[{"1", "+", 
      FractionBox["V", "4"], "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "24"], "+", 
      FractionBox[
       SuperscriptBox["V", "3"], "144"], "+", 
      FractionBox[
       SuperscriptBox["V", "4"], "324"]}]},
    {
     FractionBox["9", "40"], 
     RowBox[{"1", "+", 
      FractionBox["V", "5"], "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "40"], "+", 
      FractionBox[
       SuperscriptBox["V", "3"], "360"], "+", 
      FractionBox[
       SuperscriptBox["V", "4"], "1620"], "+", 
      FractionBox[
       SuperscriptBox["V", "5"], "2916"]}]},
    {
     FractionBox["9", "70"], 
     RowBox[{"1", "+", 
      FractionBox["V", "6"], "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "60"], "+", 
      FractionBox[
       SuperscriptBox["V", "3"], "720"], "+", 
      FractionBox[
       SuperscriptBox["V", "4"], "4860"], "+", 
      FractionBox[
       SuperscriptBox["V", "5"], "17496"], "+", 
      FractionBox[
       SuperscriptBox["V", "6"], "26244"]}]},
    {
     FractionBox["27", "448"], 
     RowBox[{"1", "+", 
      FractionBox["V", "7"], "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "84"], "+", 
      FractionBox[
       SuperscriptBox["V", "3"], "1260"], "+", 
      FractionBox[
       SuperscriptBox["V", "4"], "11340"], "+", 
      FractionBox[
       SuperscriptBox["V", "5"], "61236"], "+", 
      FractionBox[
       SuperscriptBox["V", "6"], "183708"], "+", 
      FractionBox[
       SuperscriptBox["V", "7"], "236196"]}]},
    {
     FractionBox["27", "1120"], 
     RowBox[{"1", "+", 
      FractionBox["V", "8"], "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "112"], "+", 
      FractionBox[
       SuperscriptBox["V", "3"], "2016"], "+", 
      FractionBox[
       SuperscriptBox["V", "4"], "22680"], "+", 
      FractionBox[
       SuperscriptBox["V", "5"], "163296"], "+", 
      FractionBox[
       SuperscriptBox["V", "6"], "734832"], "+", 
      FractionBox[
       SuperscriptBox["V", "7"], "1889568"], "+", 
      FractionBox[
       SuperscriptBox["V", "8"], "2125764"]}]},
    {
     FractionBox["27", "3200"], 
     RowBox[{"1", "+", 
      FractionBox["V", "9"], "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "144"], "+", 
      FractionBox[
       SuperscriptBox["V", "3"], "3024"], "+", 
      FractionBox[
       SuperscriptBox["V", "4"], "40824"], "+", 
      FractionBox[
       SuperscriptBox["V", "5"], "367416"], "+", 
      FractionBox[
       SuperscriptBox["V", "6"], "2204496"], "+", 
      FractionBox[
       SuperscriptBox["V", "7"], "8503056"], "+", 
      FractionBox[
       SuperscriptBox["V", "8"], "19131876"], "+", 
      FractionBox[
       SuperscriptBox["V", "9"], "19131876"]}]},
    {
     FractionBox["81", "30800"], 
     RowBox[{"1", "+", 
      FractionBox["V", "10"], "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "180"], "+", 
      FractionBox[
       SuperscriptBox["V", "3"], "4320"], "+", 
      FractionBox[
       SuperscriptBox["V", "4"], "68040"], "+", 
      FractionBox[
       SuperscriptBox["V", "5"], "734832"], "+", 
      FractionBox[
       SuperscriptBox["V", "6"], "5511240"], "+", 
      FractionBox[
       SuperscriptBox["V", "7"], "28343520"], "+", 
      FractionBox[
       SuperscriptBox["V", "8"], "95659380"], "+", 
      FractionBox[
       SuperscriptBox["V", "9"], "191318760"], "+", 
      FractionBox[
       SuperscriptBox["V", "10"], "172186884"]}]},
    {
     FractionBox["729", "985600"], 
     RowBox[{"1", "+", 
      FractionBox["V", "11"], "+", 
      FractionBox[
       SuperscriptBox["V", "2"], "220"], "+", 
      FractionBox[
       SuperscriptBox["V", "3"], "5940"], "+", 
      FractionBox[
       SuperscriptBox["V", "4"], "106920"], "+", 
      FractionBox[
       SuperscriptBox["V", "5"], "1347192"], "+", 
      FractionBox[
       SuperscriptBox["V", "6"], "12124728"], "+", 
      FractionBox[
       SuperscriptBox["V", "7"], "77944680"], "+", 
      FractionBox[
       SuperscriptBox["V", "8"], "350751060"], "+", 
      FractionBox[
       SuperscriptBox["V", "9"], "1052253180"], "+", 
      FractionBox[
       SuperscriptBox["V", "10"], "1894055724"], "+", 
      FractionBox[
       SuperscriptBox["V", "11"], "1549681956"]}]}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.820818109127784*^9, 3.820818133560244*^9}, 
   3.8208183472462254`*^9, {3.8208183986271057`*^9, 3.820818420839467*^9}, 
   3.820818456875576*^9, 3.82081855280447*^9, 3.8285539991018333`*^9},
 CellLabel->
  "Out[6]//TableForm=",ExpressionUUID->"5d82db17-da67-48a8-8d7d-88499671adee"]
}, Open  ]],

Cell["We verify that they cancel:", "Text",
 CellChangeTimes->{{3.82081856986882*^9, 
  3.820818573656006*^9}},ExpressionUUID->"1a056954-2899-4787-b6f2-\
c3d2118d67d4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"list", "-", "listtest"}], "//", "Expand"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.82081848790164*^9, 3.820818499946371*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"af0fb45c-2197-40b5-b342-3c940a9f1664"],

Cell[BoxData[
 TagBox[GridBox[{
    {"0", "0"},
    {"0", "0"},
    {"0", "0"},
    {"0", "0"},
    {"0", "0"},
    {"0", "0"},
    {"0", "0"},
    {"0", "0"},
    {"0", "0"}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.820818489484181*^9, 3.820818500236176*^9}, 
   3.8208185547266893`*^9, 3.8285540015211267`*^9},
 CellLabel->
  "Out[7]//TableForm=",ExpressionUUID->"229d2eab-90d5-42b1-9d11-de675e3b2443"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Johnson estimator: efficiency", "Section",
 CellChangeTimes->{{3.820818791142177*^9, 
  3.8208187982915173`*^9}},ExpressionUUID->"ae1c5595-8de2-4222-8801-\
adee1e93f7f0"],

Cell[TextData[{
 "Here we compare the efficiency of standard delta-tracking to the \
generalization that we propose, which follows from [Johnson 1951] where the \
Poisson process N(t) is sampled n times over the interval and those values \
are combined to produce a non-binary estimate for n > 1.  This answers the \
question: ",
 StyleBox["if you have n estimates of N(t), can you do better than the mean \
of n binary estimates",
  FontSlant->"Italic"],
 "?  The answer turns out to be: yes (sometimes).\[LineSeparator]\
\[LineSeparator]The efficiency comparison requires the derivation by \
[Georgiev et al. 2019] for the mean number of lookups for the binary \
estimator that can terminate early at the first real collision.  The mean \
cost of Johnson\[CloseCurlyQuote]s n > 1 estimator is simply M n \[Tau].  \
Here we will assume M = 1.  The required variances are given in Appendix C, \
Eqs. (54) and (55).\n\nTo understand the relative efficiency, below we plot \
the ratio of the two efficiencies as a function of \[Tau].  This is \
completely general, as the variances do not depend on the specific variation \
in \[Mu](x).  We notice that Johnson\[CloseCurlyQuote]s estimator is always \
more efficient than the simple binary estimator as n increases ",
 StyleBox["provided \[Tau] is sufficiently large",
  FontSlant->"Italic"],
 ".  For small \[Tau] and small n, the early termination of the n = 1 \
estimator wins.  The large increase in efficiency at large \[Tau] makes sense \
given that a binary estimator has a hard time estimating a very low \
transmittance accurately."
}], "Text",
 CellChangeTimes->{{3.820818803761918*^9, 3.8208189755586033`*^9}, {
  3.82872163835157*^9, 3.8287216486847343`*^9}, {3.8287216957400723`*^9, 
  3.828721812957122*^9}, {3.828721920314651*^9, 3.828721947715435*^9}, {
  3.828722013317342*^9, 3.828722043240301*^9}, {3.828722091808915*^9, 
  3.828722301384838*^9}},ExpressionUUID->"afa6f004-1abb-4d65-9661-\
84392502cc62"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"LogPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", "\[Tau]"}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[ExponentialE]", "\[Tau]"]}], ")"}], "2"]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["\[ExponentialE]", 
            FractionBox["\[Tau]", "n"]]}], ")"}], " ", "n", " ", "\[Tau]"}]], 
       "/.", 
       RowBox[{"n", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"2", ",", "4", ",", "8", ",", "16"}], "}"}]}]}], "//", 
      "Evaluate"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Tau]", ",", "0", ",", "7"}], "}"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotLabels", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<n=2\>\"", ",", "\"\<n=4\>\"", ",", "\"\<n=8\>\"", ",", 
        "\"\<n=16\>\""}], "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*FractionBox[\(Eff[\*SubscriptBox[\(T\), \(J\)]]\), \(Eff[\
\*SubscriptBox[\(T\), \(dt\)]]\)]\)\>\"", ","}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Tau]", ","}], "}"}]}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"LogPlot", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "7"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Dashed"}]}], "]"}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.819753496471057*^9, 3.81975351592278*^9}, {
   3.819753568008935*^9, 3.819753686656145*^9}, {3.819779455380129*^9, 
   3.819779470205862*^9}, {3.819779742038671*^9, 3.819779744802288*^9}, {
   3.819779807004562*^9, 3.819779808289393*^9}, {3.8199149225409937`*^9, 
   3.819914922686302*^9}, 3.819915246486394*^9},
 CellLabel->
  "In[3216]:=",ExpressionUUID->"e22e9242-ea7c-4655-a42d-e1457fb10c9d"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVlXk8lF8bxmcsJSlbJGMvFZVSRMh9QkpFobK0WCqRJcpapB+FiIhGVEpS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        "]]},
      Annotation[#, "Charting`Private`Tag$22039778#1"]& ], 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVlnc81d8fxy9RUmbG5ZZR+hoZoYHi/YlSmVGKMlJZ6cpIwx4NKXuF7HE/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        "]]},
      Annotation[#, "Charting`Private`Tag$22039778#2"]& ], 
     TagBox[
      {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVVnc41f8XR1dGQ1ZuLhkpJG25fKvzDmkiq+xkS0jDyMj+XA1kVlI2GQ0k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        "]]},
      Annotation[#, "Charting`Private`Tag$22039778#3"]& ], 
     TagBox[
      {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVknk0FHwfxW2NLWsIU7KVrZJKofL9RQsl+1rGPjMkJEqhRMn6kIinpBoh
SUIeyvaLGWvUWEdl3ys7SZa8vX/cc8/943POPedeORcfczIHGxsb86/+7zTb
lyWRO2/piocez7+ZK1uZsSwR9izZGWKqV7rHg0XwmZgNKteTfcFpJ4HO4yqH
09uCVz2SQ6HmuatomLoGbgrQojglJ8D4mEtMQj3CA4YSqeeSaRDILiUd8tME
P40R56l6nQ4O11tEJPpMsVOz2OUdDc8g+YrWBc33ZrjXdJPJ7EomzA91Zn+8
aoG7bYQ5I5xzgLtbI8CTbo0n9oZr2iUXQKt6qLtppT1uauOa4FcoBJrTmVOa
PiSc6387vfJ1IRRdzVEe2uKAPYtvCSk2vIE9ZjvHH3g74u/aYd+mVv6DibKx
b+9+OuHGL+xPaZHFIN/kct30qDN+ERRqbSleAsXMqLTTMc7YveIm/d3ut3Ag
eC3GR9oFj6GQtNvOpaBQIkDy3u6Kawf+WBycKoXDESoJKm6uOCvsBt/3wDLI
K/J3NaS5YgrjeoBJUjlIu6GJYgk3fIK8totDrgK27Hv7nMvEDW8nXB8uelUB
sY9O8peEu+Hhk8Fm0nWVMD+h1GE45YYZ4yvczRYYEmyZSFWWjDOigipD+jHE
m+o7+piScSG54v5c8Hu4c5KOlXLJWP7A2sxp+nsgVcRyp7LI+B7hiFEmbxX0
BPwr4MdOwb7Pyzlsk6sgWTbIycyUgo/JhBx8NFgFrtb3DrpcpWDJ+0cv9O+u
hhPmx+jxjyn4fVhth3tdNWjUfOI5OkLBSb8j+V5tokMV30ojYwMVUy+ehllH
OliMe5iTFalY0IGZfW2JDmkiftWr56h4sP1eT8UxBpjGfnsz70/FxaetRDkS
GPBQzT6YO5aKo6s3nzzRw4AJO1dZLRoVk7S/BEWr1ADr0IuM8CIq3pP/KP/j
5Rr4N3ZcYKaGirmUHEdEq2ugwX7KKaCDirvS5KRtBGthMSIlnThExbliw8ap
Z2vBwb2V1T1FxTdjsm71ZdUCZ9yTDWVLVGzB4fFWYb4WrnAJahSzueMd19Qm
qVAHWw8hx48Ed7w8PSmXG1MHIkbu9zn53fFHSr71DKsOHCkfuqwE3HF6z6WY
/Yr1kPa4YnfN33zFUvP91Yv1sM6W+chsozs2/PBroby8Hop+Lymt8LjjLXql
Kuy8DfC4HXVWcbrjmbfBDsetGkDeVOJV5ioVM9QhMYrWAG6WCoVZ81T8bxZ7
ffNkAwTRFH4wxqn4wlbGqohOI3zOHiSxdVMxJN3RsL7TCJk0XWG7ZioW5Tek
PGxthIxn23k+lVPxaCh/aq/MB/h0JPm0Sw4Vly41f5L3/ABp59L7RZOpOM7n
Lhe15APQzp9v7g+hYpdRc+2XnE2wkicn2USlYk2SuPe0SRMIVvPVtZ+hYp52
Vvq+R03QcDKwf1mDirtPPWQFjDfBS+/O87piVHxba9tRttBm0PHWndjaRsG2
rwcuH2tuhsTz52fevaZgtR0ZOZFSHyHvVHWIXzQFt25SERMp/Ahr7+bOgg4F
Z0X/MLD68xEGEi8VmQlRcCB73vUHpz5BCY9PUeggGctN7x2TG/oEP0ijdJ1b
ZLxcuCzwZjMT+HQTBuh//+82dU654wgTqIGbq89vIWMtsgxJKpoJTV+Z4yJ5
brjP/FktTb4FXL46PKotdcUGcVwDdIMWEB3teqJ7zRUXNpBXRrxboGm3dHq7
piu+g5T3qJa1wD57teqzL1zw7t2vHhRatIJJY4Ux85ozvoT4Gs4EtMJMIA88
2e2Mi82pS+MPWyFX5YNK44AT1g2Qs9k22Aohmu28+/WdsPH7+2KxF9tgLIXd
o2CYhO+1zukrJbWBvdwNX+H9JNw5bOJXXdIGb2tne5Ru2mMHXr7WpT9toL2o
vOWm4DnsZX4jnvxPO1wss6xhcdrifLevlWwF7aAdYX17RcsGL1zRmkptb4fa
9bItXeetcXDqnFErsQNqL5+RKGdY4thhCh/kdICbt8OXPWZmOPeKSbhkXSeI
JbYyix/o45nI3KI33zuBXrBfSjn1KN6fyjtsLMgCgdU0WemdgMsxXS/cigUJ
BtvlyDMHcBOPFtvcEAtcrIZ9gn0244mHskEf2D7DaR1BX6cqXVDDsxdv6HyF
5djvfK8u2QMlOLaVQvoKqofLqkLaSJCurbTf5OZXEJr72X/5oCNIFtn/2lb7
FTxWWQQKlzMQXtRdrzLrBv+Ug9zx467Qfy8tmsujB6wlAr8prHpAMsUwIzql
DxwG35XwZvtBq8LwBr/SPtA25FY2lfIHgYEb1HM9fVAxGdXiEOMP1bvOiieL
9IPM2L3Sdt/LoJUd30Wx6YfoAHUjeYMA2JG27MAz1A85K8xkkA4C9gim5+nl
AWiU0ri8KycUtOL/mOsIDELS6Qon9Z+h4J2yU0dFdhDunRV+lYXCoPt5JA/3
iUGIW7po+7MrDIrrUWZ1wiBE+grEigrdBk++gl5tlSF4ujnxm0HCHej4J8FM
2XYYvLT7GyMnY2BjMtba7DkMT5VHfu0+GQt6jye3EW4MQ/9iDPspWizk5xlO
DT0bBvRO50Gv9T8Q/Yk95sn0MHSkvHAIrYsDELnEkIgYAe310VzLvrvwIsn8
4IbiUahAE+EaHElgFPknO79uFOgBNydb9ibBTFCOtP3nUTi789bvDNck0HLl
+FO4Ogq6RvOLgzVJUKtRyHDSH4OLqvymlbH3YfijiHk5cwysIsZLZxRSQJa3
5YLfj3HINfigfODqQ0i+bpI+IPsD7lz4fnz061NolbZv5N7/A7JovKJia09B
6K373K6TP+B4Nv2UowwNIudC9QK9foAnbfvqGWcaBFGLBkVLfwBx8pBm7DgN
nMykFI5ZTICMZFRh9Go6qG4fepYVPgmGy3StcJ1MwE1XMj2/T4OszJdgScEc
uArpFK21aZg9E7fO0swByc+jiRw8M3BBTPH6G1IOME+LWn2SnoFX6rEula9y
4KiGB8sdzcBLhsELBZOXIL8q0Z0aMwPlc7llqim5MJJwaYRdfhasuev8tx1+
DZ4VKkvNxnPAWgs+m36hECTDrLx+hSwAhzdRQf3wWxi6lpwX0L8IxzeOrAc5
YDDtS4Ioyd/A4GM7yk+hw74FrwWv4ytwh1GiGuJWB5qH7S+/oK3B1ix9mW9b
muDzLPeJKx3rICyg4J/jwwRjL7dZoy3sSG92zsBmfxuc1y40MzDgQLuujM7n
EDvBprzXbqMTJ9pAiszSXe6C9i7x+qB4LvSbTitt0OsG+Vy13jc5G1CN96kX
x4L6YF3S6GxKDwFZL7qZeiQMQEqPnfswHw86QP7YY+Y7BGx2J2SWFXiRRQjH
z269EVjyOqJTZsmHFA9p/0cxHoMq7U1/jvnyozVytrqewTc4Tuq00IrciJgS
7UaP/u5qJ50hxCoWQG7xMoNctyZBN87UT7dFEO2p7RezfT4Nn5tvPc5mF0Z7
R1w8y7hmwZfNumk0RRhtELnlPH1wDi7FbTbmVRRBtiSRTEnSPOh49Iaxl4sg
C5ut4ku0BfB8ksTfayiK7BSdLG6zfsK10KOk6XZRpJ+fUJa+8ReY5M87d3pu
QrEBWVJqLkvwj879UtrSJlTW0LtonfUbEkUO1+oliKHZekOnaP4V4DjWur1+
mzhivyeVZOywCsbyjsZhL8WRkiZZU/H1GricmVUR1ZdAm4S6HifKrUNv2yW7
O0wJVPak8NEssCH5578PMT02ozLGNislNnakvyNgzJhNEkVHjS5rYHbUzDY8
WhAridYHIvU9/DjQNmXrB98VpVAVzGRMaHGizzklT7jfSKE8N2K59jwn8v0s
5GOnK41aQ1+fvP+SCzEtvWZvdkgjYeYsy//yBvSvWmldrAsRqS8XHA7bR0Bd
3/yTOMhE1Gqk7td5gIAks9Wdr1KJiDP+U72qDgE9UMxcdr1ARDe0yS1tiIAe
br2769AVIjKtOmejZExAqUKUxG9RRPTq0a697e4E9HhexPFEAREhCRv2448J
qLegSa38DRHJz1WKptEISOZixJJGMRHpmeTp/cwgoCcTqwlby4gowFH4T+ZL
Ano6MsZYYBARuencIM87AqKxKlSfdRFRQsqgfXsbAQ3ev/pL8isR+W4Lt9zN
IiB5y32MuB4i4u1zOR/5hYDSmdmkwEEiWthUMXN44G9uSLxrNkFEn6eo1OdT
f/kIY1Ld1N8+9Y6mHHN/+RO8qkdmiShK0MuG9JOAnlXfoCsvEpGQ0H940yoB
Dd/Uvvt4iYjeOo/K+qwTkCIs2IutEFG0ufTTRg5u5LaWpxK9RkSye4yO7CBw
o4wyj8X1dSL6bRiwFMrLjf4HG0dEUA==
        "]]},
      Annotation[#, "Charting`Private`Tag$22039778#4"]& ]}, {{{}, {
       GraphicsGroupBox[{
         {GrayLevel[1], AbsoluteThickness[4], Opacity[
           NCache[
            Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], JoinForm[
          "Round"], 
          BSplineCurveBox[{
           Offset[{0, 0}, {7.145833333333333, 0.8897807416174579}], 
            Offset[{0, 0}, {7.145833333333333, 0.8897807416174579}], 
            Offset[{0., 0.}, {7.215833333333332, 0.8897807416174579}], 
            Offset[{0., 0.}, {7.215833333333332, 0.8897807416174579}], 
            Offset[{0., 0.}, {7.285833333333333, 0.8897807416174579}], 
            Offset[{0, 0}, {7.450139658433443, 0.8897760545647891}], 
            Offset[{5., 1.1102230246251565`*^-15}, {7.450139658433443, 
             0.8897760545647891}], 
            Offset[{10., 2.220446049250313*^-15}, {7.450139658433443, 
             0.8897760545647891}], 
            Offset[{10., 2.220446049250313*^-15}, {7.450139658433443, 
             0.8897760545647891}]}]}, 
         {RGBColor[
          0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
          AbsoluteThickness[1.25], 
          BSplineCurveBox[{
           Offset[{0, 0}, {7.145833333333333, 0.8897807416174579}], 
            Offset[{0, 0}, {7.145833333333333, 0.8897807416174579}], 
            Offset[{0., 0.}, {7.215833333333332, 0.8897807416174579}], 
            Offset[{0., 0.}, {7.215833333333332, 0.8897807416174579}], 
            Offset[{0., 0.}, {7.285833333333333, 0.8897807416174579}], 
            Offset[{0, 0}, {7.450139658433443, 0.8897760545647891}], 
            Offset[{5., 1.1102230246251565`*^-15}, {7.450139658433443, 
             0.8897760545647891}], 
            Offset[{10., 2.220446049250313*^-15}, {7.450139658433443, 
             0.8897760545647891}], 
            Offset[{10., 2.220446049250313*^-15}, {7.450139658433443, 
             0.8897760545647891}]}]}, 
         {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
           NCache[
            Rational[2, 3], 0.6666666666666666]]}], 
          PolygonBox[{
           Offset[{32., 6.500000000000007}, {7.450139658433443, 
             0.8897760545647891}], 
            Offset[{32., -6.499999999999993}, {7.450139658433443, 
             0.8897760545647891}], 
            Offset[{10.000000000000002`, -6.499999999999998}, {
             7.450139658433443, 0.8897760545647891}], 
            Offset[{9.999999999999998, 6.500000000000002}, {7.450139658433443,
              0.8897760545647891}]}]}, 
         {RGBColor[
          0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
          AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
          StyleBox[
           RotationBox["\<\"n=2\"\>",
            BoxRotation->0.],
           StripOnInput->False,
           LineOpacity->1,
           FrontFaceOpacity->1,
           BackFaceOpacity->1,
           Opacity->1,
           FontOpacity->1], 
          Offset[{21., 4.6629367034256575*^-15}, \
{7.450139658433443, 0.8897760545647891}], 
          ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}], 
       GraphicsGroupBox[{
         {GrayLevel[1], AbsoluteThickness[4], Opacity[
           NCache[
            Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], JoinForm[
          "Round"], 
          BSplineCurveBox[{
           Offset[{0, 0}, {7.145833333333333, 2.106857681068714}], 
            Offset[{0, 0}, {7.145833333333333, 2.106857681068714}], 
            Offset[{0., 0.}, {7.215833333333332, 2.106857681068714}], 
            Offset[{0., 0.}, {7.215833333333332, 2.106857681068714}], 
            Offset[{0., 0.}, {7.285833333333333, 2.106857681068714}], 
            Offset[{0, 0}, {7.450139658433443, 2.1068400148085122`}], 
            Offset[{5., 1.1102230246251565`*^-15}, {7.450139658433443, 
             2.1068400148085122`}], 
            Offset[{10., 2.220446049250313*^-15}, {7.450139658433443, 
             2.1068400148085122`}], 
            Offset[{10., 2.220446049250313*^-15}, {7.450139658433443, 
             2.1068400148085122`}]}]}, 
         {RGBColor[
          0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
          AbsoluteThickness[1.25], 
          BSplineCurveBox[{
           Offset[{0, 0}, {7.145833333333333, 2.106857681068714}], 
            Offset[{0, 0}, {7.145833333333333, 2.106857681068714}], 
            Offset[{0., 0.}, {7.215833333333332, 2.106857681068714}], 
            Offset[{0., 0.}, {7.215833333333332, 2.106857681068714}], 
            Offset[{0., 0.}, {7.285833333333333, 2.106857681068714}], 
            Offset[{0, 0}, {7.450139658433443, 2.1068400148085122`}], 
            Offset[{5., 1.1102230246251565`*^-15}, {7.450139658433443, 
             2.1068400148085122`}], 
            Offset[{10., 2.220446049250313*^-15}, {7.450139658433443, 
             2.1068400148085122`}], 
            Offset[{10., 2.220446049250313*^-15}, {7.450139658433443, 
             2.1068400148085122`}]}]}, 
         {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
           NCache[
            Rational[2, 3], 0.6666666666666666]]}], 
          PolygonBox[{
           Offset[{32., 6.500000000000007}, {7.450139658433443, 
             2.1068400148085122`}], 
            Offset[{32., -6.499999999999993}, {7.450139658433443, 
             2.1068400148085122`}], 
            Offset[{10.000000000000002`, -6.499999999999998}, {
             7.450139658433443, 2.1068400148085122`}], 
            Offset[{9.999999999999998, 6.500000000000002}, {7.450139658433443,
              2.1068400148085122`}]}]}, 
         {RGBColor[
          0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
          AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
          StyleBox[
           RotationBox["\<\"n=4\"\>",
            BoxRotation->0.],
           StripOnInput->False,
           LineOpacity->1,
           FrontFaceOpacity->1,
           BackFaceOpacity->1,
           Opacity->1,
           FontOpacity->1], 
          Offset[{21., 4.6629367034256575*^-15}, \
{7.450139658433443, 2.1068400148085122}], 
          ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}], 
       GraphicsGroupBox[{
         {GrayLevel[1], AbsoluteThickness[4], Opacity[
           NCache[
            Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], JoinForm[
          "Round"], 
          BSplineCurveBox[{
           Offset[{0, 0}, {7.145833333333333, 2.6371550689105208`}], 
            Offset[{0, 0}, {7.145833333333333, 2.6371550689105208`}], 
            Offset[{0., 0.}, {7.215833333333332, 2.6371550689105208`}], 
            Offset[{0., 0.}, {7.215833333333332, 2.6371550689105208`}], 
            Offset[{0., 0.}, {7.285833333333333, 2.6371550689105208`}], 
            Offset[{0, 0}, {7.450139658433443, 2.6048675403504675`}], 
            Offset[{5., 1.1102230246251565`*^-15}, {7.450139658433443, 
             2.6048675403504675`}], 
            Offset[{10., 2.220446049250313*^-15}, {7.450139658433443, 
             2.6048675403504675`}], 
            Offset[{10., 2.220446049250313*^-15}, {7.450139658433443, 
             2.6048675403504675`}]}]}, 
         {RGBColor[
          0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
          AbsoluteThickness[1.25], 
          BSplineCurveBox[{
           Offset[{0, 0}, {7.145833333333333, 2.6371550689105208`}], 
            Offset[{0, 0}, {7.145833333333333, 2.6371550689105208`}], 
            Offset[{0., 0.}, {7.215833333333332, 2.6371550689105208`}], 
            Offset[{0., 0.}, {7.215833333333332, 2.6371550689105208`}], 
            Offset[{0., 0.}, {7.285833333333333, 2.6371550689105208`}], 
            Offset[{0, 0}, {7.450139658433443, 2.6048675403504675`}], 
            Offset[{5., 1.1102230246251565`*^-15}, {7.450139658433443, 
             2.6048675403504675`}], 
            Offset[{10., 2.220446049250313*^-15}, {7.450139658433443, 
             2.6048675403504675`}], 
            Offset[{10., 2.220446049250313*^-15}, {7.450139658433443, 
             2.6048675403504675`}]}]}, 
         {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
           NCache[
            Rational[2, 3], 0.6666666666666666]]}], 
          PolygonBox[{
           Offset[{32., 6.500000000000007}, {7.450139658433443, 
             2.6048675403504675`}], 
            Offset[{32., -6.499999999999993}, {7.450139658433443, 
             2.6048675403504675`}], 
            Offset[{10.000000000000002`, -6.499999999999998}, {
             7.450139658433443, 2.6048675403504675`}], 
            Offset[{9.999999999999998, 6.500000000000002}, {7.450139658433443,
              2.6048675403504675`}]}]}, 
         {RGBColor[
          0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
          AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
          StyleBox[
           RotationBox["\<\"n=8\"\>",
            BoxRotation->0.],
           StripOnInput->False,
           LineOpacity->1,
           FrontFaceOpacity->1,
           BackFaceOpacity->1,
           Opacity->1,
           FontOpacity->1], 
          Offset[{21., 4.6629367034256575*^-15}, \
{7.450139658433443, 2.6048675403504675}], 
          ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}], 
       GraphicsGroupBox[{
         {GrayLevel[1], AbsoluteThickness[4], Opacity[
           NCache[
            Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], JoinForm[
          "Round"], 
          BSplineCurveBox[{
           Offset[{0, 0}, {7.145833333333333, 2.8796424304393864`}], 
            Offset[{0, 0}, {7.145833333333333, 2.8796424304393864`}], 
            Offset[{0., 0.}, {7.215833333333332, 2.8796424304393864`}], 
            Offset[{0., 0.}, {7.215833333333332, 2.8796424304393864`}], 
            Offset[{0., 0.}, {7.285833333333333, 2.8796424304393864`}], 
            Offset[{0, 0}, {7.450139658433443, 2.911936380231097}], 
            Offset[{5., 1.1102230246251565`*^-15}, {7.450139658433443, 
             2.911936380231097}], 
            Offset[{10., 2.220446049250313*^-15}, {7.450139658433443, 
             2.911936380231097}], 
            Offset[{10., 2.220446049250313*^-15}, {7.450139658433443, 
             2.911936380231097}]}]}, 
         {RGBColor[
          0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
          AbsoluteThickness[1.25], 
          BSplineCurveBox[{
           Offset[{0, 0}, {7.145833333333333, 2.8796424304393864`}], 
            Offset[{0, 0}, {7.145833333333333, 2.8796424304393864`}], 
            Offset[{0., 0.}, {7.215833333333332, 2.8796424304393864`}], 
            Offset[{0., 0.}, {7.215833333333332, 2.8796424304393864`}], 
            Offset[{0., 0.}, {7.285833333333333, 2.8796424304393864`}], 
            Offset[{0, 0}, {7.450139658433443, 2.911936380231097}], 
            Offset[{5., 1.1102230246251565`*^-15}, {7.450139658433443, 
             2.911936380231097}], 
            Offset[{10., 2.220446049250313*^-15}, {7.450139658433443, 
             2.911936380231097}], 
            Offset[{10., 2.220446049250313*^-15}, {7.450139658433443, 
             2.911936380231097}]}]}, 
         {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
           NCache[
            Rational[2, 3], 0.6666666666666666]]}], 
          PolygonBox[{
           Offset[{38., 6.500000000000009}, {7.450139658433443, 
             2.911936380231097}], 
            Offset[{38., -6.499999999999991}, {7.450139658433443, 
             2.911936380231097}], 
            Offset[{10.000000000000002`, -6.499999999999998}, {
             7.450139658433443, 2.911936380231097}], 
            Offset[{9.999999999999998, 6.500000000000002}, {7.450139658433443,
              2.911936380231097}]}]}, 
         {RGBColor[
          0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
          AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
          StyleBox[
           RotationBox["\<\"n=16\"\>",
            BoxRotation->0.],
           StripOnInput->False,
           LineOpacity->1,
           FrontFaceOpacity->1,
           BackFaceOpacity->1,
           Opacity->1,
           FontOpacity->1], 
          Offset[{24., 5.329070518200751*^-15}, \
{7.450139658433443, 2.911936380231097}], 
          ImageScaled[{Rational[1, 2], Rational[1, 2]}]]}]}}, {}}}, {{{}, {}, 
     
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxN0H0s1HEcB/DfXUkeSp4vhbqu5lxpZRaHU+HG4jwmV24eQl3XjVN5qIiz
QknM+Uk2Og/zVNaxsXFmyqLtbJdnM1ckRpZdbpxDV235fH229957/fH+53M0
JiE4johhmP/f/GtxeFN77slsBvb/ajQWwmo82mPb/s90qOm4AFw19HCTi2eB
ZSnO8VF4EXja16L8Gi4GL5197MTGJWBBnZQYjveAHRzelrWEDIJp3crEDPok
mJAj513STIMbRMHndNrmwHh6QNX0kR/gbllyLW9xGczroqoHWL/AJOFl/toj
FfhbGt6c8nUVHPhF5JFHWgc7qvgqvvcG2Mkt4l6DeAs8odRlJo9owSx+rNLv
MOH8tm+5tAT5+BDBV6QKtmHULvDwuHn/gxe7weQ3NEVrow5YS/K7Wjq1B1w6
xb45q78XjLGZNppjemA1353eGaoP7nEx/e0lMAB7c0ZDnHMNwWyrGqOxtn1g
RkHgHcbn/eCJgeyKesIBsAALk82VIicVWLL0KMZgOlchJEiReZUiA4WvCTgt
6wJneRg54N1K9CjPFPycXtIhViMXG7t9vFhkBiZ6DR7vtzUHs8iRLGETcoy/
kmriaQFWDCWxn8iRyXXrrnKuJdjzRMo8CyOBB7DZOUk+sq1dWNki5SD6R2N7
pW4rsmDCKIHNsALLQ/nKzBHkl7SOvvyYQ+DxhbsiYhwyqf50dOoN5DJKreb6
beRX1oWnXJORy43iixfykCtWjCOZEmSFREaTtiLbJOaoz7QhVy5tFll3Ir/+
Pt+r6kUWj3XZV48jz5SkrpEmkcmhjr0FU8hV8nrO/Zkd/lRcGLS0Y5/D4vT9
3LFn6tm7K5Gr32d8sFtFns10KaxQI1M8VBFmG8ixW83Up1vINZ3cVa0W+Q8B
ShZn
        "]]},
      Annotation[#, "Charting`Private`Tag$22040016#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, -0.22047859582185403`},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
     "\"\\!\\(\\*FractionBox[\\(Eff[\\*SubscriptBox[\\(T\\), \\(J\\)]]\\), \
\\(Eff[\\*SubscriptBox[\\(T\\), \\(dt\\)]]\\)]\\)\"", TraditionalForm], ""}, {
    
     FormBox[
      TagBox["\[Tau]", HoldForm], TraditionalForm], ""}},
  FrameTicks->FrontEndValueCache[{{Quiet[
       Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
      Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, {{{{0., 
        FormBox["1", TraditionalForm], {0.01, 0.}}, {0.6931471805599453, 
        FormBox["2", TraditionalForm], {0.01, 0.}}, {1.6094379124341003`, 
        FormBox["5", TraditionalForm], {0.01, 0.}}, {2.302585092994046, 
        FormBox["10", TraditionalForm], {0.01, 0.}}, {2.995732273553991, 
        FormBox["20", TraditionalForm], {0.01, 0.}}, {-0.6931471805599453, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.5108256237659907, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.35667494393873245`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.2231435513142097, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.10536051565782628`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.4054651081081644, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.0986122886681098`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.3862943611198906`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.791759469228055, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.9459101490553132`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.0794415416798357`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.1972245773362196`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.70805020110221, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       3.4011973816621555`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       3.6888794541139363`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       3.912023005428146, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.0943445622221, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.248495242049359, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.382026634673881, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.499809670330265, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.605170185988092, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}}, {{
       0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}}, {
       0.6931471805599453, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}}, {
       1.6094379124341003`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}}, {
       2.302585092994046, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}}, {
       2.995732273553991, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
        0.}}, {-0.6931471805599453, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.5108256237659907, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.35667494393873245`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.2231435513142097, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-0.10536051565782628`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       0.4054651081081644, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.0986122886681098`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.3862943611198906`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.791759469228055, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.9459101490553132`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.0794415416798357`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.1972245773362196`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.70805020110221, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       3.4011973816621555`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       3.6888794541139363`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       3.912023005428146, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.0943445622221, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.248495242049359, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.382026634673881, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.499809670330265, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.605170185988092, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}}}, {
     Automatic, Automatic}}],
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->{{All, 57.65003957657707}, {All, All}},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 7}, {-0.22047859582185403`, 2.8796424304393864`}},
  PlotRangeClipping->False,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.08090169943749476]}},
  Ticks->{Automatic, Quiet[
     Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& }]], "Output",
 CellChangeTimes->{
  3.819753516566888*^9, {3.8197535715838213`*^9, 3.819753652388695*^9}, 
   3.819753687506794*^9, {3.819779458716549*^9, 3.819779470878793*^9}, {
   3.819779743641366*^9, 3.819779745328229*^9}, 3.819779808798832*^9, 
   3.81991492362389*^9, 3.819915247030006*^9},
 CellLabel->
  "Out[3216]=",ExpressionUUID->"7a03de7a-b76e-4981-aaf5-1e0d898f6ce3"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1027, 881},
WindowMargins->{{Automatic, 155}, {Automatic, -150}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"8db1b0ef-4131-4a4c-b11f-414f0e869a80"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 343, 7, 160, "Title",ExpressionUUID->"885c3c71-893f-4d5d-b400-6f8b24c883be"],
Cell[926, 31, 488, 10, 104, "Text",ExpressionUUID->"a8e66931-c88a-4a23-9853-f8e215cec53d"],
Cell[CellGroupData[{
Cell[1439, 45, 152, 3, 67, "Section",ExpressionUUID->"175de73f-80fe-4968-8eeb-5afcd16f423a"],
Cell[1594, 50, 388, 8, 58, "Text",ExpressionUUID->"406c46df-3069-4c25-bf55-5c27251c93d0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2019, 63, 157, 3, 67, "Section",ExpressionUUID->"f83989db-7d1d-4027-91b8-da9afe36c1f5"],
Cell[2179, 68, 442, 11, 81, "Text",ExpressionUUID->"7184670b-adc1-4aab-9d33-2825c271437d"],
Cell[CellGroupData[{
Cell[2646, 83, 267, 4, 54, "Subsection",ExpressionUUID->"f8cc2528-ddce-485b-9f3f-0c0158a1b7da"],
Cell[2916, 89, 763, 19, 77, "Input",ExpressionUUID->"2698f9e4-bd13-4d1f-b794-26eb387bf95b"],
Cell[3682, 110, 631, 17, 69, "Input",ExpressionUUID->"0970d2f4-46e9-40bb-b85b-30625939676d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4350, 132, 195, 2, 54, "Subsection",ExpressionUUID->"86d1ce9a-7cb8-45bd-8eb9-455ed7abce21"],
Cell[4548, 136, 916, 24, 94, "Input",ExpressionUUID->"be8bbe52-3a74-438c-b0b0-e18a67daf062"],
Cell[5467, 162, 824, 21, 94, "Input",ExpressionUUID->"6cf563cf-c8d9-4458-8607-0da21bb570e2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6328, 188, 363, 7, 54, "Subsection",ExpressionUUID->"2b1f6991-da34-4e89-9a77-d4fa110b683c"],
Cell[6694, 197, 1090, 29, 128, "Input",ExpressionUUID->"0dd4d647-990b-4347-94fd-86790e9bc30b"],
Cell[7787, 228, 181, 3, 35, "Text",ExpressionUUID->"345a457f-6e35-485e-926e-7d064a8caea1"],
Cell[7971, 233, 1009, 25, 94, "Input",ExpressionUUID->"df1c138b-ed45-4d1a-80c4-b3ce2dad98f4"],
Cell[8983, 260, 212, 5, 35, "Text",ExpressionUUID->"508c7ea9-a0df-43a6-94db-73e90c0a3cbd"],
Cell[9198, 267, 1708, 46, 149, "Input",ExpressionUUID->"4fa95096-ac6d-4722-b7ad-64f1313aba6d"],
Cell[10909, 315, 189, 3, 35, "Text",ExpressionUUID->"6317ac86-3059-4519-9783-a5b36818cc28"],
Cell[11101, 320, 1811, 47, 166, "Input",ExpressionUUID->"111d688d-d577-4f4c-9dce-4c0ed2c87bf1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12949, 372, 302, 5, 54, "Subsection",ExpressionUUID->"6a14e38a-d5a4-4075-aaf8-87f042da81dc"],
Cell[13254, 379, 180, 3, 35, "Text",ExpressionUUID->"b13f0cfb-3bc1-47b6-a6b3-6c3f49e35618"],
Cell[13437, 384, 1883, 47, 358, "Input",ExpressionUUID->"ffe46f81-4ea0-42e4-97e7-d8cdd40a0d7f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15357, 436, 193, 3, 54, "Subsection",ExpressionUUID->"0cdff726-f6b9-4b1b-a251-5f79a5d506e0"],
Cell[15553, 441, 485, 9, 58, "Text",ExpressionUUID->"75353d7b-ff0b-41b7-921f-e61d60ec1cf0"],
Cell[16041, 452, 2188, 55, 340, "Input",ExpressionUUID->"398e166c-ddfc-49ec-843d-4d255549daf2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18266, 512, 162, 3, 54, "Subsection",ExpressionUUID->"0cfd71b0-9713-494c-a5c5-af46fba3bc4c"],
Cell[18431, 517, 2324, 61, 378, "Input",ExpressionUUID->"43f09951-a01e-4011-b18c-3a919a8cb4aa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20792, 583, 166, 3, 54, "Subsection",ExpressionUUID->"15531b68-c3f6-4be4-bf29-26423d025da0"],
Cell[20961, 588, 163, 3, 35, "Text",ExpressionUUID->"1ca29a32-9749-4cd2-b3b7-290bcf7e903b"],
Cell[21127, 593, 1569, 40, 288, "Input",ExpressionUUID->"5fbbbb6e-cd79-4b87-a19c-deeb567da4d0"],
Cell[22699, 635, 171, 3, 35, "Text",ExpressionUUID->"f1ecdfda-f532-4af0-87df-74e3cc38cad9"],
Cell[22873, 640, 2200, 57, 350, "Input",ExpressionUUID->"4ca10856-3419-43c4-ae03-c4b747b4bb1e"],
Cell[25076, 699, 204, 3, 35, "Text",ExpressionUUID->"e18d7ac2-a700-491f-8fe0-9523631bff9c"],
Cell[25283, 704, 1854, 47, 289, "Input",ExpressionUUID->"c8e3ac36-f5a8-4b05-a2df-64a20fef7058"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27174, 756, 168, 3, 54, "Subsection",ExpressionUUID->"59d36a9f-e7b0-4c10-a354-9d2bcb80d3d9"],
Cell[27345, 761, 410, 8, 35, "Text",ExpressionUUID->"74f3dc22-78ff-4627-b9e4-913ef40ac97e"],
Cell[27758, 771, 3072, 75, 503, "Input",ExpressionUUID->"1ef92d76-1dd1-4ae9-917c-61323b418172"],
Cell[30833, 848, 187, 3, 35, "Text",ExpressionUUID->"47773916-0f39-41bc-aaf8-98d5417dd701"],
Cell[31023, 853, 4211, 123, 291, "Input",ExpressionUUID->"feb4697d-f6e8-4798-9261-1acd00caa878"],
Cell[35237, 978, 252, 4, 35, "Text",ExpressionUUID->"261dd6aa-14b5-4948-bf6e-2e530b7ad9b1"],
Cell[35492, 984, 4515, 129, 312, "Input",ExpressionUUID->"180d17a5-ed88-467a-9088-fd041c7ce7d9"],
Cell[40010, 1115, 328, 7, 35, "Text",ExpressionUUID->"3e0c60b6-c45f-4cc2-8858-9570fdb85269"],
Cell[40341, 1124, 5154, 149, 354, "Input",ExpressionUUID->"5a37a768-fbd1-4338-be84-44c285f2ccea"],
Cell[45498, 1275, 357, 8, 35, "Text",ExpressionUUID->"6e99dcde-f056-4320-85b7-57b194d82a5e"],
Cell[45858, 1285, 4937, 138, 354, "Input",ExpressionUUID->"37fbd550-686a-4906-8fe7-0aecf7a2feb3"],
Cell[50798, 1425, 400, 8, 35, "Text",ExpressionUUID->"9469aa15-a6db-4bb7-a71d-df8c5e043e45"],
Cell[51201, 1435, 5398, 155, 375, "Input",ExpressionUUID->"b4b49323-5311-472b-b3c8-5d6f0de65a50"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56636, 1595, 171, 3, 54, "Subsection",ExpressionUUID->"90c8a61f-ce26-42ed-a456-12136a8c225e"],
Cell[CellGroupData[{
Cell[56832, 1602, 163, 3, 45, "Subsubsection",ExpressionUUID->"5e69a57c-01a8-4724-b018-793116a5ef67"],
Cell[56998, 1607, 1978, 51, 323, "Input",ExpressionUUID->"ce7c0c34-158a-44bf-a99e-cf01dbcbef4f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59013, 1663, 165, 3, 45, "Subsubsection",ExpressionUUID->"b3734b6c-c0c0-4c92-a94c-a274a1927463"],
Cell[59181, 1668, 2419, 57, 499, "Input",ExpressionUUID->"65b1db0a-3b86-42f9-968a-bc02566a0e10"]
}, Open  ]],
Cell[CellGroupData[{
Cell[61637, 1730, 165, 3, 45, "Subsubsection",ExpressionUUID->"1401d31e-5b59-4c81-81ef-473e89d7ece4"],
Cell[61805, 1735, 328, 5, 35, "Text",ExpressionUUID->"459550af-efba-4f35-9cc2-a29c1a5bc578"],
Cell[62136, 1742, 6243, 158, 732, "Input",ExpressionUUID->"3c7d334d-c9ea-426d-98f3-1cd119f4652e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[68416, 1905, 165, 3, 45, "Subsubsection",ExpressionUUID->"f8f3e514-951f-4589-8253-e4cbd0d40c51"],
Cell[68584, 1910, 163, 3, 35, "Text",ExpressionUUID->"71c5f2d3-a619-455f-8af0-6a27998134dc"],
Cell[68750, 1915, 2830, 75, 339, "Input",ExpressionUUID->"d962fe5b-b998-42a8-985b-e1d8771dd02b"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[71629, 1996, 162, 3, 54, "Subsection",ExpressionUUID->"158d51c0-78be-4347-93c0-928981d63344"],
Cell[71794, 2001, 166, 3, 35, "Text",ExpressionUUID->"f14ca6bb-dc12-46ed-9b2a-2e582b265b9f"],
Cell[71963, 2006, 176, 3, 35, "Text",ExpressionUUID->"c265fbe3-802a-4191-8715-31a335ae23ab"],
Cell[72142, 2011, 4311, 94, 829, "Input",ExpressionUUID->"2fac3913-c380-4f4f-8ea0-18310f0cbaaf"],
Cell[76456, 2107, 253, 6, 35, "Text",ExpressionUUID->"b56fe297-f4b9-4892-b6d3-b4a4177e9763"],
Cell[76712, 2115, 574, 15, 33, "Input",ExpressionUUID->"d230c5be-b9f6-4ef3-bbf4-c6b31462e0b0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[77323, 2135, 169, 3, 54, "Subsection",ExpressionUUID->"ce8e1988-5d6b-47ae-8146-0175b6467e31"],
Cell[77495, 2140, 166, 3, 35, "Text",ExpressionUUID->"6e7d027b-e98e-46a7-91b0-eb3dd0b6e1d8"],
Cell[77664, 2145, 3197, 71, 472, "Input",ExpressionUUID->"9b43f3e3-71b3-4858-a22f-a2f850aa5ad9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[80898, 2221, 168, 3, 54, "Subsection",ExpressionUUID->"b6860615-f382-4985-ae7e-0d21aea53c65"],
Cell[81069, 2226, 166, 3, 35, "Text",ExpressionUUID->"5e61885c-b701-4e1d-83fd-50de5e7e7551"],
Cell[81238, 2231, 2389, 58, 351, "Input",ExpressionUUID->"101dd5f2-489c-4f7d-945c-bece9e85c3b2"],
Cell[83630, 2291, 172, 3, 35, "Text",ExpressionUUID->"8756acae-f5c6-4134-81cf-d48fe48be218"],
Cell[83805, 2296, 3942, 110, 317, "Input",ExpressionUUID->"f2b5182f-5ad1-4099-a3d5-d28a23d1ed37"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[87796, 2412, 167, 3, 67, "Section",ExpressionUUID->"ac53f248-739d-4eba-9202-ee7b996ec306"],
Cell[87966, 2417, 287, 6, 35, "Text",ExpressionUUID->"52710e7a-20dd-46b7-968b-5b6777872307"],
Cell[CellGroupData[{
Cell[88278, 2427, 164, 3, 54, "Subsection",ExpressionUUID->"2acc0348-954e-4c0b-bca4-30c0841a95f0"],
Cell[CellGroupData[{
Cell[88467, 2434, 9397, 208, 598, "Input",ExpressionUUID->"719f6578-f13c-4fcc-abf4-fc81a12c6b79"],
Cell[97867, 2644, 123962, 2181, 210, "Output",ExpressionUUID->"cc41affa-370f-4651-b926-c0e9e90f738c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[221866, 4830, 7048, 177, 598, "Input",ExpressionUUID->"a81afde5-9d0f-4e4d-9997-68025359d601"],
Cell[228917, 5009, 129001, 2351, 211, "Output",ExpressionUUID->"fb373562-1b2d-4704-b8e1-0f8ec5610d24"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[357967, 7366, 158, 3, 54, "Subsection",ExpressionUUID->"0b44c793-5115-4989-807f-57605517071f"],
Cell[CellGroupData[{
Cell[358150, 7373, 5117, 135, 514, "Input",ExpressionUUID->"90bae6dc-4413-4561-9ced-dcab7620cb66"],
Cell[363270, 7510, 124857, 2253, 210, "Output",ExpressionUUID->"6521c30d-39fd-462e-bb28-1ed5bb98f5fa"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[488176, 9769, 188, 3, 54, "Subsection",ExpressionUUID->"c0a70a6f-3e06-4d98-9ae5-52a642aca76b"],
Cell[488367, 9774, 224, 5, 35, "Text",ExpressionUUID->"67d413ba-a247-435f-8385-3223fe6633bf"],
Cell[488594, 9781, 245, 6, 35, "Text",ExpressionUUID->"b619ddbb-ec96-41cd-9c53-86dfa8bcd999"],
Cell[CellGroupData[{
Cell[488864, 9791, 6428, 160, 556, "Input",ExpressionUUID->"15c9f25f-84a8-4519-814c-7d11a3558956"],
Cell[495295, 9953, 134833, 2443, 208, "Output",ExpressionUUID->"9f41137f-0aaa-4114-aaf3-1fa766a9d830"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[630177, 12402, 175, 3, 54, "Subsection",ExpressionUUID->"8dc2c423-937d-4971-9f0e-31cfde53c87f"],
Cell[CellGroupData[{
Cell[630377, 12409, 192, 3, 45, "Subsubsection",ExpressionUUID->"bfb3a0bd-b3ee-4b0b-9961-f0bf9f639cc3"],
Cell[CellGroupData[{
Cell[630594, 12416, 5098, 134, 535, "Input",ExpressionUUID->"361c3a76-3723-4506-96bf-820a8c8d8d41"],
Cell[635695, 12552, 119142, 2134, 211, "Output",ExpressionUUID->"cec93254-e7ed-43aa-9fbb-859553bce9b7"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[754910, 14694, 221, 5, 67, "Section",ExpressionUUID->"47b1afe0-afc5-4772-9d86-f5ac5b3bf9ad"],
Cell[755134, 14701, 191, 3, 35, "Text",ExpressionUUID->"94aa8856-d1e1-40b6-bd11-426fcc5a1b38"],
Cell[CellGroupData[{
Cell[755350, 14708, 571, 16, 52, "Input",ExpressionUUID->"4f9b9b40-50b8-4d84-a5fc-bf7e9da356c2"],
Cell[755924, 14726, 376, 10, 52, "Output",ExpressionUUID->"6b2d915f-e2b5-4ae7-9d12-958c70c93084"]
}, Open  ]],
Cell[756315, 14739, 169, 3, 35, "Text",ExpressionUUID->"984c916c-e64e-4ca3-a41c-1e19241f504b"],
Cell[756487, 14744, 1548, 33, 304, "Input",ExpressionUUID->"36eb9445-6cd2-40b8-9609-4116f6574264"],
Cell[CellGroupData[{
Cell[758060, 14781, 1667, 38, 181, "Input",ExpressionUUID->"e67e4fe5-adef-4279-9be6-484ea121bd65"],
Cell[759730, 14821, 16705, 290, 241, "Output",ExpressionUUID->"8ae13bb2-c178-4310-a175-aad580507ca2"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[776484, 15117, 318, 6, 67, "Section",ExpressionUUID->"faf3413d-cc7f-4d16-9086-81d461802e51"],
Cell[776805, 15125, 12773, 217, 74, "Text",ExpressionUUID->"e31147cd-6d80-443a-aee5-3f6d87dbbdb3"],
Cell[CellGroupData[{
Cell[789603, 15346, 1741, 40, 220, "Input",ExpressionUUID->"d1ae8451-c0be-41de-9a1b-9e3d30f1a422"],
Cell[791347, 15388, 11853, 207, 241, "Output",ExpressionUUID->"3cd2bde7-454a-4c89-8ffa-3727e4eb052f"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[803249, 15601, 203, 3, 67, "Section",ExpressionUUID->"f9cafc14-e540-4c6e-a77c-b3a827454312"],
Cell[803455, 15606, 342, 7, 58, "Text",ExpressionUUID->"b375b14f-9f4c-47d5-977d-b755d8686b41"],
Cell[803800, 15615, 220, 5, 35, "Text",ExpressionUUID->"30feef3a-ae3d-4532-8e6c-396f0cb920ef"],
Cell[804023, 15622, 1545, 43, 228, "Input",ExpressionUUID->"4499e83f-7894-4ec0-8d19-98d0a5695090"],
Cell[805571, 15667, 259, 6, 35, "Text",ExpressionUUID->"11c7e4c3-a8d3-4607-bdb1-3550c25fba85"],
Cell[805833, 15675, 1494, 43, 148, "Input",ExpressionUUID->"3572aed8-4a48-47bc-8c0c-a516791d271e"],
Cell[807330, 15720, 1024, 28, 54, "Text",ExpressionUUID->"8e56bcae-a956-4a65-9021-ff1943aadc52"],
Cell[808357, 15750, 415, 9, 58, "Text",ExpressionUUID->"e697a1c4-41dc-45b7-a6e4-d07723ffe200"],
Cell[CellGroupData[{
Cell[808797, 15763, 1174, 37, 95, "Input",ExpressionUUID->"9f47a73c-81cd-4f2d-b62f-e5334f4344c2"],
Cell[809974, 15802, 1374, 42, 58, "Output",ExpressionUUID->"597e721b-8054-4365-a3de-c4077a33982c"]
}, Open  ]],
Cell[811363, 15847, 187, 3, 35, "Text",ExpressionUUID->"b1331508-ca37-4592-b860-837095e716c9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[811587, 15855, 171, 3, 67, "Section",ExpressionUUID->"ae9b587d-781f-41e8-90f4-9c70cf77a9e2"],
Cell[811761, 15860, 298, 5, 35, "Text",ExpressionUUID->"1d3ccdd4-c06c-42e0-8720-6ac298476398"],
Cell[812062, 15867, 179, 3, 35, "Text",ExpressionUUID->"3cf6a867-7881-4e28-bbe3-8851f0356dea"],
Cell[CellGroupData[{
Cell[812266, 15874, 2482, 68, 112, "Input",ExpressionUUID->"61fc9065-4d95-4ded-94de-81697118ccc2"],
Cell[814751, 15944, 468, 8, 35, "Output",ExpressionUUID->"234d6ee6-14fa-4504-b8f5-3115e6c9fe52"]
}, Open  ]],
Cell[CellGroupData[{
Cell[815256, 15957, 464, 12, 54, "Subsection",ExpressionUUID->"b74c77f1-766b-422e-8ffc-6efe45d7fcd8"],
Cell[CellGroupData[{
Cell[815745, 15973, 1069, 30, 81, "Input",ExpressionUUID->"e0cdb83f-1be8-4228-a306-af120946b99e"],
Cell[816817, 16005, 539, 15, 34, "Output",ExpressionUUID->"ecd8182b-f9f6-4aa8-b343-caabd2cfcdb0"]
}, Open  ]],
Cell[817371, 16023, 642, 19, 30, "Input",ExpressionUUID->"27a476b1-7cc6-483e-b472-51d56737f7f5"],
Cell[CellGroupData[{
Cell[818038, 16046, 507, 14, 45, "Subsubsection",ExpressionUUID->"1193d636-da14-4bae-acee-79934e82b462"],
Cell[CellGroupData[{
Cell[818570, 16064, 1838, 46, 199, "Input",ExpressionUUID->"089fe7a8-5a30-4fe8-a66f-b4d8ab1d9b14"],
Cell[820411, 16112, 33485, 600, 319, 11919, 246, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"d5ece37e-9433-4d77-8347-9504cea78620"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[853957, 16719, 325, 6, 54, "Subsection",ExpressionUUID->"353c503d-c520-4476-931a-77f17b3d83d8"],
Cell[854285, 16727, 434, 8, 58, "Text",ExpressionUUID->"4b4b3ede-b690-4263-a9f8-864c5528f13d"],
Cell[854722, 16737, 396, 11, 35, "Text",ExpressionUUID->"791b3672-5d85-401a-aa41-f4a28fae6f0e"],
Cell[CellGroupData[{
Cell[855143, 16752, 2451, 66, 113, "Input",ExpressionUUID->"4a0e42d9-1d37-481a-b6d2-babac2958a99"],
Cell[857597, 16820, 2263, 66, 105, "Output",ExpressionUUID->"6eaad146-dda8-4782-a504-c2b54fbab827"]
}, Open  ]],
Cell[859875, 16889, 359, 10, 35, "Text",ExpressionUUID->"d915a68d-ba9a-4143-a208-a45cf585d4ac"],
Cell[860237, 16901, 2828, 76, 168, "Input",ExpressionUUID->"f18866d0-e09e-4e54-a92a-d1a55f2b1b0f"],
Cell[863068, 16979, 251, 4, 35, "Text",ExpressionUUID->"b8cd4337-9f7b-4473-9073-7f04468e80bf"],
Cell[863322, 16985, 569, 11, 30, "Input",ExpressionUUID->"a9a612e0-2865-457d-ad61-a5bce4c74b6c"],
Cell[863894, 16998, 223, 5, 35, "Text",ExpressionUUID->"72c29d71-3bba-4db8-a3fc-2fd9672f8f4f"],
Cell[CellGroupData[{
Cell[864142, 17007, 3053, 79, 325, "Input",ExpressionUUID->"2c80dc98-2268-41b8-97ed-6e91de3a0267"],
Cell[867198, 17088, 17910, 391, 249, "Output",ExpressionUUID->"5f6d5780-bfca-417c-bea1-5860f80f582a"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[885169, 17486, 286, 4, 67, "Section",ExpressionUUID->"98f96aab-f24a-4d2e-812a-11831d89e96d"],
Cell[885458, 17492, 1411, 36, 106, "Text",ExpressionUUID->"045b95ed-c7f2-4cc6-bcec-8f8ed96f9ab8"],
Cell[886872, 17530, 35291, 590, 104, "Input",ExpressionUUID->"988a2fdb-05a8-485d-a2ae-eb7aa753214a"],
Cell[922166, 18122, 147, 3, 35, "Text",ExpressionUUID->"edca093d-6afc-490b-b169-210425108d7b"],
Cell[922316, 18127, 41004, 684, 101, "Input",ExpressionUUID->"2065b404-73c5-41fc-9791-d0ba93167aa0"],
Cell[963323, 18813, 132514, 2178, 165, "Input",ExpressionUUID->"e7036c96-1447-471e-8ba3-653efa7924ae"],
Cell[CellGroupData[{
Cell[1095862, 20995, 189, 3, 54, "Subsection",ExpressionUUID->"7c897bc2-5bcf-44a8-8b88-4e61501e75a5"],
Cell[1096054, 21000, 151, 3, 35, "Text",ExpressionUUID->"f44ce09a-e827-4c0e-9dfb-073d39c0e21e"],
Cell[1096208, 21005, 1370, 35, 65, "Text",ExpressionUUID->"4c46bc99-4342-4d91-9ce8-9a884524d651"],
Cell[CellGroupData[{
Cell[1097603, 21044, 2495, 66, 173, "Input",ExpressionUUID->"d26a36bf-128c-4b48-8bac-fcd9a4ef64fd"],
Cell[1100101, 21112, 2887, 90, 246, "Output",ExpressionUUID->"feeb1988-d4cc-48a5-abbb-ba255ba91cf7"]
}, Open  ]],
Cell[1103003, 21205, 180, 3, 35, "Text",ExpressionUUID->"ddf6af73-9be2-4a36-8118-30b3698171ad"],
Cell[CellGroupData[{
Cell[1103208, 21212, 792, 22, 55, "Input",ExpressionUUID->"dfb42619-c71f-4390-b97a-1d21b0fd5d94"],
Cell[1104003, 21236, 1991, 62, 188, "Output",ExpressionUUID->"b00834ed-fa86-4c5b-b4fe-85d62069b7f2"]
}, Open  ]],
Cell[1106009, 21301, 173, 3, 35, "Text",ExpressionUUID->"613b0265-6b9d-4aaa-9873-2289c26abc90"],
Cell[1106185, 21306, 1004, 31, 54, "Input",ExpressionUUID->"4bc23063-a2ca-4d51-8cbf-b2840bec1b3d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1107226, 21342, 174, 3, 54, "Subsection",ExpressionUUID->"e3fb112a-5889-44e6-9ef8-e82d93a6757a"],
Cell[CellGroupData[{
Cell[1107425, 21349, 2201, 58, 247, "Input",ExpressionUUID->"e338d327-3e3b-4f22-932a-e4bc47db9506"],
Cell[1109629, 21409, 2028, 66, 188, "Output",ExpressionUUID->"ae8d7ab7-de08-4cd7-ace9-73b46c220f79"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1111694, 21480, 879, 25, 55, "Input",ExpressionUUID->"6bb61bc3-107d-46b5-897f-5cb3537d204c"],
Cell[1112576, 21507, 2122, 67, 188, "Output",ExpressionUUID->"22b2b146-508f-40e6-97f8-bacdee49a5af"]
}, Open  ]],
Cell[1114713, 21577, 652, 19, 55, "Input",ExpressionUUID->"cea09984-f253-4ce5-9f33-034b2afe6f0b"],
Cell[CellGroupData[{
Cell[1115390, 21600, 173, 3, 45, "Subsubsection",ExpressionUUID->"fd83eaa1-0a00-4ce3-aacc-c5c72b5d1bab"],
Cell[1115566, 21605, 752, 20, 73, "Input",ExpressionUUID->"aef53a7a-120c-46a6-912f-fac26a2ad48b"],
Cell[1116321, 21627, 703, 19, 73, "Input",ExpressionUUID->"0193f2e9-bdf9-4025-8d26-b50d5bd1c6f7"],
Cell[CellGroupData[{
Cell[1117049, 21650, 4889, 134, 411, "Input",ExpressionUUID->"cd3c9db6-422c-4e36-8299-74ff38067d23"],
Cell[1121941, 21786, 15269, 272, 260, "Output",ExpressionUUID->"cecbe101-762b-4da0-aa29-e67d3efaa040"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1137283, 22066, 181, 3, 67, "Section",ExpressionUUID->"8dca8c1b-eb08-4140-9d5c-31df1f86e588"],
Cell[1137467, 22071, 1077, 22, 128, "Text",ExpressionUUID->"26c70d74-8c93-4239-9da0-ba9195ee1998"],
Cell[CellGroupData[{
Cell[1138569, 22097, 219, 4, 54, "Subsection",ExpressionUUID->"42966fb6-441d-4b00-8afa-d9acc388b9a8"],
Cell[1138791, 22103, 191, 3, 35, "Text",ExpressionUUID->"f575138e-acea-4c51-bd75-07bf12a3048e"],
Cell[1138985, 22108, 500, 15, 60, "Text",ExpressionUUID->"c4353726-6536-49e0-bdde-56a2f8a64c62"],
Cell[CellGroupData[{
Cell[1139510, 22127, 182, 3, 45, "Subsubsection",ExpressionUUID->"bbd94d80-68bd-4723-846f-d17059cb630f"],
Cell[1139695, 22132, 3084, 78, 272, "Input",ExpressionUUID->"6c6054e4-b3bc-455f-8e10-f9d0f9deda3d"],
Cell[CellGroupData[{
Cell[1142804, 22214, 1382, 36, 131, "Input",ExpressionUUID->"e6ac368b-93c8-4929-a5d1-8819b03b76c1"],
Cell[1144189, 22252, 29111, 591, 236, 15318, 365, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"0b36fbf4-cda4-4963-aea2-8bb287dbd295"]
}, Open  ]],
Cell[1173315, 22846, 2977, 77, 293, "Input",ExpressionUUID->"4a56d6da-f462-4c9e-b3cb-7562885c537a"],
Cell[CellGroupData[{
Cell[1176317, 22927, 642, 19, 45, "Input",ExpressionUUID->"73c25399-5b18-490e-9a93-767347bc1f66"],
Cell[1176962, 22948, 404, 11, 50, "Output",ExpressionUUID->"8c7b5ab3-541d-4aba-9deb-01b274e262bd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1177403, 22964, 1530, 44, 146, "Input",ExpressionUUID->"7b1ab7b2-b413-4e9e-acea-f63f7a4c9840"],
Cell[1178936, 23010, 21643, 504, 233, "Output",ExpressionUUID->"36bd93f3-44bc-4971-b53d-ab60a10f6133"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1200640, 23521, 187, 3, 54, "Subsection",ExpressionUUID->"2753cc6d-4c2b-46f2-8930-6d1bbe11127b"],
Cell[1200830, 23526, 201, 3, 35, "Text",ExpressionUUID->"727a093d-9260-45ac-b7f9-6f61dfd28253"],
Cell[1201034, 23531, 229, 5, 35, "Text",ExpressionUUID->"45b875d6-cb50-44fe-9a51-fe9a7d8957d3"],
Cell[CellGroupData[{
Cell[1201288, 23540, 4237, 106, 306, "Input",ExpressionUUID->"5af02d75-973d-4dd9-b616-eae32e56b0d8"],
Cell[1205528, 23648, 5225, 161, 286, "Output",ExpressionUUID->"f002e5d8-6742-4514-8eb6-c7c7fb18a0eb"]
}, Open  ]],
Cell[1210768, 23812, 197, 3, 35, "Text",ExpressionUUID->"f134be73-936d-4911-ab5e-1cc1f9dafecc"],
Cell[1210968, 23817, 61284, 1010, 128, "Input",ExpressionUUID->"c21ab1db-197e-4e3f-83ee-31e403f5008f"],
Cell[1272255, 24829, 16694, 279, 44, "Input",ExpressionUUID->"9e2834c3-7fed-4005-b7fd-e8e22164bbd5"],
Cell[CellGroupData[{
Cell[1288974, 25112, 2490, 67, 294, "Input",ExpressionUUID->"3d99a911-6953-4774-8826-a5855a2ee86b"],
Cell[1291467, 25181, 5250, 161, 286, "Output",ExpressionUUID->"5d82db17-da67-48a8-8d7d-88499671adee"]
}, Open  ]],
Cell[1296732, 25345, 168, 3, 35, "Text",ExpressionUUID->"1a056954-2899-4787-b6f2-c3d2118d67d4"],
Cell[CellGroupData[{
Cell[1296925, 25352, 267, 6, 30, "Input",ExpressionUUID->"af0fb45c-2197-40b5-b342-3c940a9f1664"],
Cell[1297195, 25360, 755, 25, 178, "Output",ExpressionUUID->"229d2eab-90d5-42b1-9d11-de675e3b2443"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1298011, 25392, 176, 3, 67, "Section",ExpressionUUID->"ae1c5595-8de2-4222-8801-adee1e93f7f0"],
Cell[1298190, 25397, 1971, 32, 311, "Text",ExpressionUUID->"afa6f004-1abb-4d65-9661-84392502cc62"],
Cell[CellGroupData[{
Cell[1300186, 25433, 2162, 57, 194, "Input",ExpressionUUID->"e22e9242-ea7c-4655-a42d-e1457fb10c9d"],
Cell[1302351, 25492, 42770, 820, 225, "Output",ExpressionUUID->"7a03de7a-b76e-4981-aaf5-1e0d898f6ce3"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

